(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     68808,       1685]
NotebookOptionsPosition[     63728,       1558]
NotebookOutlinePosition[     64149,       1574]
CellTagsIndexPosition[     64106,       1571]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LATTICEEASY NOTEBOOK : Energy", "Title",
 CellChangeTimes->{{3.717360493614624*^9, 
  3.717360498188978*^9}},ExpressionUUID->"76acf1e0-25d0-4c77-b10b-\
916253b4a028"],

Cell["\<\
This notebook produces plots of components of energy density from the output \
of the latticeeasy program..
Note that the output files contain detailed information about kinetic and \
gradient energy of each field and each potential term. In practice, however, \
we have not usually found this detailed information necessary, so at the \
moment this notebook plots total values of kinetic, gradient, and potential \
energy density but doesn't break these down further. Since each of the \
individual components are stored in separate columns of the output file it \
would be easy to plot these separately if you wanted that information.
Note that the energy density and its components are plotted in program \
variables, meaning that to get physical energy density you would have to \
normalize them by a normalization term involving constants and possibly \
powers of the scale factor. See the LATTICEEASY documentation for the \
conversions from program energy density to physical energy density.
Last modified: 10/18/17\
\>", "Text",
 CellChangeTimes->{{3.71736049023252*^9, 3.7173605089596043`*^9}, {
  3.717362370656074*^9, 
  3.717362375391508*^9}},ExpressionUUID->"6f50b7c0-b83c-47ad-8656-\
d4059ebea7d5"],

Cell["Clear all variables to avoid naming conflicts.", "Text",
 CellChangeTimes->{{3.7173593539180403`*^9, 
  3.717359364375927*^9}},ExpressionUUID->"c4ff263a-d322-410b-9ea2-\
b4d0629eb749"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7173584246909575`*^9, 
  3.7173584246929617`*^9}},ExpressionUUID->"c1b35bbe-ecf0-44be-9af2-\
648386456f4e"],

Cell[CellGroupData[{

Cell["\<\
PARAMETERS : Set parameters for where to read data and what to plot\
\>", "Section",
 CellChangeTimes->{{3.7173605726915812`*^9, 
  3.7173605790540295`*^9}},ExpressionUUID->"1d1c634f-5e09-4e6e-8236-\
4275fa94d1f1"],

Cell["\<\
The run variables are\[IndentingNewLine]dir - The directory where the files \
are stored\[IndentingNewLine]ext - The extension of the data files\
\[IndentingNewLine]nflds - The number of fields for which data were output\
\[IndentingNewLine]numpotentialterms - The number of separate terms in the \
potential (i.e. terms calculated separately in the output)\
\>", "Text",
 CellChangeTimes->{{3.7173605902609158`*^9, 
  3.717360596713111*^9}},ExpressionUUID->"dd17f80c-5060-413b-be9e-\
2c6bdaa23a5b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "dir", "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{"ext", "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{"nflds", "=", "2"}], ";", 
  RowBox[{"numpotentialterms", "=", "2"}], ";"}]], "Input",
 CellChangeTimes->{{3.422018199800067*^9, 3.422018205128294*^9}, 
   3.423922392570293*^9, 
   3.717360619118803*^9},ExpressionUUID->"ad68b7be-65c1-4b7e-90a9-\
06ebaa2a9fb9"],

Cell["\<\
The number of potential term labels as there are potential terms. Any extras \
will be ignored.\
\>", "Text",
 CellChangeTimes->{{3.7173608262525263`*^9, 3.7173608581113853`*^9}, {
  3.71736126173812*^9, 
  3.7173612675058365`*^9}},ExpressionUUID->"16b2b9cc-9be5-4ce2-b456-\
7ec6e515602b"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"potentialtermlabel", "[", "1", "]"}], "=", 
   "\"\<(1/4)\!\(\*SuperscriptBox[\(\[Lambda]\[Phi]\), \(4\)]\)\>\""}], ";", 
  RowBox[{
   RowBox[{"potentialtermlabel", "[", "2", "]"}], "=", 
   "\"\<(1/2)\!\(\*SuperscriptBox[\(g\), \
\(2\)]\)\!\(\*SuperscriptBox[\(\[Phi]\), \
\(2\)]\)\!\(\*SuperscriptBox[\(\[Chi]\), \(2\)]\)\>\""}], ";"}]], "Input",
 CellChangeTimes->{{3.7173608606549654`*^9, 3.7173609421254454`*^9}, {
  3.717361271204042*^9, 3.7173612715891*^9}, {3.71736130678292*^9, 
  3.7173613100913057`*^9}},ExpressionUUID->"d33dbdbd-0621-4685-b4a1-\
6e3ff04b3735"]
}, Closed]],

Cell[CellGroupData[{

Cell["DATA: Read in data and make tables", "Section",
 CellChangeTimes->{
  3.7173606444042873`*^9},ExpressionUUID->"ba88b55f-3909-451e-b066-\
44d27936367a"],

Cell["\<\
The columns in the output file should be time, a kinetic energy and a \
gradient energy for each field, and one column for each potential term.
The notebook counts how many numbers it finds in the file and uses that to \
determine at how many times the data is stored.\
\>", "Text",
 CellChangeTimes->{{3.7173606822069693`*^9, 
  3.7173607052934704`*^9}},ExpressionUUID->"171b5500-ad39-409d-acf1-\
18fddd606d9e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"numcolumns", "=", 
   RowBox[{"1", "+", 
    RowBox[{"2", "*", "nflds"}], "+", "numpotentialterms"}]}], ";"}]], "Input",\
ExpressionUUID->"983f978b-09f8-4de4-bdee-8f36e128d898"],

Cell[BoxData[
 RowBox[{
  RowBox[{"intableenergy", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
     RowBox[{"dir", "<>", "\"\<energy\>\"", "<>", "ext"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"Real", ",", 
       RowBox[{"{", "numcolumns", "}"}]}], "]"}]}], "]"}]}], ";"}]], "Input",E\
xpressionUUID->"79a8cc92-166c-43f2-bd73-b6f5892a4279"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"numtimes", "=", 
  RowBox[{"Count", "[", 
   RowBox[{"intableenergy", ",", 
    RowBox[{"Table", "[", 
     RowBox[{"_Real", ",", 
      RowBox[{"{", "numcolumns", "}"}]}], "]"}]}], "]"}]}]], "Input",Expressio\
nUUID->"8fdafe35-0a64-4fcf-a7ab-cccc260e520d"],

Cell[BoxData["21"], "Output",
 CellChangeTimes->{3.4220183315682216`*^9, 3.423922403663583*^9, 
  3.424184194886989*^9, 3.7173606705214105`*^9, 3.717361372072913*^9, 
  3.7173623451063414`*^9},ExpressionUUID->"dd18be43-2db8-4589-9b19-\
30094fe08c10"]
}, Open  ]],

Cell["\<\
Make tables of total kinetic (time derivative), gradient, and potential \
energy density as functions of time.\
\>", "Text",ExpressionUUID->"ae3f02f1-f3ec-480f-9614-faada165fbdc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"kinetictable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"intableenergy", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", "column"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"column", ",", "2", ",", 
           RowBox[{"nflds", "+", "1"}]}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"gradienttable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"intableenergy", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", "column"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"column", ",", 
           RowBox[{"nflds", "+", "2"}], ",", 
           RowBox[{
            RowBox[{"2", "*", "nflds"}], "+", "1"}]}], "}"}]}], "]"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"potentialtable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"Sum", "[", 
        RowBox[{
         RowBox[{"intableenergy", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", "column"}], "]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"column", ",", 
           RowBox[{
            RowBox[{"2", "*", "nflds"}], "+", "2"}], ",", 
           RowBox[{
            RowBox[{"2", "*", "nflds"}], "+", "1", "+", 
            "numpotentialterms"}]}], "}"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",ExpressionUUID->"961162b9-04e8-477d-af02-4d5002dbee35"],

Cell["\<\
Make tables of total energy density, pressure, and their ratio (alpha).\
\>", "Text",ExpressionUUID->"5e5039b3-591c-4a2d-bd20-f198c7b02ecc"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"energytable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"kinetictable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"gradienttable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}], "+", 
        RowBox[{"potentialtable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"pressuretable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"kinetictable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}], "-", 
        RowBox[{
         RowBox[{"gradienttable", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", "2"}], "]"}], "]"}], "/", "3."}], "-", 
        RowBox[{"potentialtable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"alphatable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"intableenergy", "[", 
        RowBox[{"[", 
         RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{
        RowBox[{"pressuretable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}], "/", 
        RowBox[{"energytable", "[", 
         RowBox[{"[", 
          RowBox[{"time", ",", "2"}], "]"}], "]"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",ExpressionUUID->"216f4f0d-4028-42d3-9fee-cbd77f8a467d"],

Cell["\<\
These tables of the different potential terms aren't currently plotted.\
\>", "Text",ExpressionUUID->"793992a3-8876-4273-8c56-777848863268"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"term", "=", "1"}], ",", 
    RowBox[{"term", "<=", "numpotentialterms"}], ",", 
    RowBox[{"term", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"vtable", "[", "term", "]"}], "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"intableenergy", "[", 
           RowBox[{"[", 
            RowBox[{"time", ",", "1"}], "]"}], "]"}], ",", 
          RowBox[{"intableenergy", "[", 
           RowBox[{"[", 
            RowBox[{"time", ",", 
             RowBox[{"1", "+", 
              RowBox[{"2", "*", "nflds"}], "+", "term"}]}], "]"}], "]"}]}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"time", ",", "1", ",", "numtimes"}], "}"}]}], "]"}]}], 
     ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.717360741760309*^9, 
  3.717360747864597*^9}},ExpressionUUID->"f14af63f-a0d5-4fdd-9ade-\
519e5eb391fc"]
}, Closed]],

Cell[CellGroupData[{

Cell["PLOTS : Make plots", "Section",
 CellChangeTimes->{{3.717361907452015*^9, 3.7173619142892885`*^9}, 
   3.7173622117714005`*^9},ExpressionUUID->"12356bd5-6f16-4acd-8383-\
3e5da04fa551"],

Cell[CellGroupData[{

Cell["Energy density and components", "Subsection",
 CellChangeTimes->{{3.717362204262356*^9, 
  3.7173622071965303`*^9}},ExpressionUUID->"3d088c7d-3204-40e2-90f0-\
8a49eccc0df0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energyplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"energytable", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "1"}], "}"}]}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Total Energy Density\>\""}]}], 
   "]"}]}]], "Input",ExpressionUUID->"baed8c6f-2b64-444a-9297-fc1e9881fce9"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAACmmOu6ZF7fPxyxFp8C
ACRAPq8/59w30D+QwB9+/j80QDMJ8Egd09E/odrgRPR/PkDVb+2zU5TSP4l+
bf30X0RAVOI9ebr70j+RC87g739JQN5VBAYZJNM/mpguxOqfTkDQjJbhoefS
P7X+lgD8z1FA5O/LiRk50j/xgR3/BVBUQH31ZNPbQtI/FsPVARDQVkAFPgDz
C5DSP1JGXAAaUFlAc5hKEzPP0j+OyeL+I9BbQFrg7vcwutI/swqbAS5QXkA8
i/z/2k/SP/jGEAAcaGBAPoELDR9s0j+WCFT/IKhhQO9XLD44idI/KCmwACbo
YkAYlrE0/47SP8Zq8/8qKGRAZ5CKGNmC0j9krDb/L2hlQGr2BoCmddI/98yS
ADWoZkCsYr9hgXPSP5UO1v856GdAJXC7NYht0j+8H7dfPgBpQB5U5s5adtI/
C+qeXQ==
      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Total Energy Density\"", TraditionalForm],
  PlotRange->{{0, 200.007614}, {0, 1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.4220183955225744`*^9, 3.423922407248036*^9, 
  3.424184197433159*^9, 3.717361372574509*^9, 3.717361972490028*^9, 
  3.7173623453052607`*^9},ExpressionUUID->"28067027-cb2e-41b2-9cda-\
90af9b5d77e5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", "kinetictable", "}"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"vtable", "[", "term", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"term", ",", "1", ",", "numpotentialterms"}], "}"}]}], 
      "]"}]}], "]"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Hue", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "0.8`", ",", "0.1`"}], "}"}]}], "]"}]}], 
   ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"Join", "[", 
     RowBox[{
      RowBox[{"{", "\"\<Kinetic\>\"", "}"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"potentialtermlabel", "[", "term", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"term", ",", "1", ",", "numpotentialterms"}], "}"}]}], 
       "]"}]}], "]"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.422018353428016*^9, {3.7173609650848813`*^9, 3.717360970905702*^9}, 
   3.7173610143719354`*^9, {3.717361046683279*^9, 
   3.7173611273856063`*^9}},ExpressionUUID->"4dbbf738-ec11-4657-8781-\
5bca803321d2"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0., 1, 1]], 
        LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAACD7gNzyLzOPxyxFp8C
ACRAyMXPljDkyD+QwB9+/j80QFshTj5anNE/odrgRPR/PkBJWy10U5TSP4l+
bf30X0RATYf46Uul0j+RC87g739JQJQig4a9ms0/mpguxOqfTkB+qYf2dSay
P7X+lgD8z1FACLJZPWE8sj/xgR3/BVBUQPDMZId4EdE/FsPVARDQVkDByFZC
CpDSP1JGXAAaUFlA6pTE9Ews0T+OyeL+I9BbQOyaaA5LLrE/swqbAS5QXkCW
sBW4ZVW0P/jGEAAcaGBAQDzg9A1QzD+WCFT/IKhhQPkiTuW8GM4/KCmwACbo
YkD7eKafiZPIP8Zq8/8qKGRAlsb1EAm2xD9krDb/L2hlQNX+1mcxJcE/98yS
ADWoZkBJuRwrCFDBP5UO1v856GdAFqVjUmwawz+8H7dfPgBpQEOe0RQJP8U/
1deaMA==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0.1, 1, 1]], 
        LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQjQou2MtsFJvPxKDi8FO28pqK3jr7CQfk6/7Zmzi0
zziyszkx237hrQcuX+rtHLwK72T9O51v11mX+/dLvIvDsp7w64tnl9pP5D73
4H29p0OfR8eGl1Eb7WfN0Dvyar6fg3mWlgHnnjP2W/9NY/hzPtChT+DKfcaQ
0/YfG2X/swaEOPzwfXpXTWyyvdjhq4wCF8IcCj9Htr4RzrMLcothkAqIdChs
KChY/3amfd/JR/+UL0Q7JCUc4p3rfMZ+M9dsRr2AOIdI7r+xL48dsv9xTIBB
JiPBwXHK1z3TL7XaT+MI+a+wItGhOijhga0Bq72G5gYGtRdJDrKmsy9eXlxg
fyzr838tjRSHp3q3N7be67JPWWP2Xz8j1SF9G9ezG/yT7b+fmcRguiLNYYWp
QRqn1WT7qXzX/lu+SHfYLrnudp9whf0e+e3xdgyZDv41PCfFKizsAT3wles=

         "]]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0.2, 1, 1]], 
        LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAACbC8SqvSzGPRyxFp8C
ACRA3CQn3vL/uT2QwB9+/j80QFVKtXRyC589odrgRPR/PkDuT86cj3UkPYl+
bf30X0RAB70XKh1hpD2RC87g739JQAZcFDKN78s9mpguxOqfTkBd96eVfDTR
PbX+lgD8z1FA/xUi8FsEdT7xgR3/BVBUQL29rbcfY4k+FsPVARDQVkD19rgW
dANyPlJGXAAaUFlAknS6JdoSMD+OyeL+I9BbQIa+tNtAF3M/swqbAS5QXkCV
AbG2c6ujP/jGEAAcaGBAff0YjHSzkT+WCFT/IKhhQKoqpmWzCXE/KCmwACbo
YkD2JobkZOKaP8Zq8/8qKGRAoPV0nkaUoz9krDb/L2hlQPEWYe2cJKM/98yS
ADWoZkD0GOWZl8OaP5UO1v856GdAiMnpJaUkmD+8H7dfPgBpQIPHMz9pboY/
uhCZVw==
         "]]}}}, {}, {}, {{}, {}}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 200.007614}, {0, 1}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 200.007614}, {0, 1}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{
      "\"Kinetic\"", 
       "\"(1/4)\\!\\(\\*SuperscriptBox[\\(\[Lambda]\[Phi]\\), \\(4\\)]\\)\"", 
       "\"(1/2)\\!\\(\\*SuperscriptBox[\\(g\\), \
\\(2\\)]\\)\\!\\(\\*SuperscriptBox[\\(\[Phi]\\), \
\\(2\\)]\\)\\!\\(\\*SuperscriptBox[\\(\[Chi]\\), \\(2\\)]\\)\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0., 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0., 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.2, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.2, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0., 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0., 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0., 1, 1]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0., 1, 1], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.1, 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0.1, 1, 1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.1, 1, 1], Editable -> False, Selectable -> False]}],
                  "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.2, 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0.2, 1, 1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.2, 1, 1], Editable -> False, Selectable -> False]}],
                  "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.4220183556780596`*^9, 3.423922405303801*^9, 3.42418419636831*^9, 
   3.7173609753384557`*^9, 3.717361016581719*^9, 3.7173610883771877`*^9, {
   3.717361129710698*^9, 3.717361141308203*^9}, 3.7173613723687725`*^9, 
   3.7173619757086983`*^9, 
   3.717362345446365*^9},ExpressionUUID->"337e0d6c-82c8-478e-825b-\
18dd4dd5ebb3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"kinetictable", ",", "gradienttable", ",", "potentialtable"}], 
    "}"}], ",", 
   RowBox[{"Joined", "\[Rule]", "True"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Hue", "[", "i", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "0.8`", ",", "0.1`"}], "}"}]}], "]"}]}], 
   ",", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Kinetic\>\"", ",", "\"\<Gradient\>\"", ",", "\"\<Potential\>\""}], 
     "}"}]}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.4220183729283905`*^9, 
  3.717361393776676*^9},ExpressionUUID->"7ee1548c-6ab3-4a81-bdb0-\
be878482c39b"],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{}, {{{}, {}, {
        Hue[0.67, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0., 1, 1]], 
        LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAACD7gNzyLzOPxyxFp8C
ACRAyMXPljDkyD+QwB9+/j80QFshTj5anNE/odrgRPR/PkBJWy10U5TSP4l+
bf30X0RATYf46Uul0j+RC87g739JQJQig4a9ms0/mpguxOqfTkB+qYf2dSay
P7X+lgD8z1FACLJZPWE8sj/xgR3/BVBUQPDMZId4EdE/FsPVARDQVkDByFZC
CpDSP1JGXAAaUFlA6pTE9Ews0T+OyeL+I9BbQOyaaA5LLrE/swqbAS5QXkCW
sBW4ZVW0P/jGEAAcaGBAQDzg9A1QzD+WCFT/IKhhQPkiTuW8GM4/KCmwACbo
YkD7eKafiZPIP8Zq8/8qKGRAlsb1EAm2xD9krDb/L2hlQNX+1mcxJcE/98yS
ADWoZkBJuRwrCFDBP5UO1v856GdAFqVjUmwawz+8H7dfPgBpQEOe0RQJP8U/
1deaMA==
         "]]}, {
        Hue[0.9060679774997897, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0.1, 1, 1]], 
        LineBox[{{0., 1.2048455778*^-7}, {10.00002, 9.3917575*^-10}, {
         20.249977, 2.95560109*^-9}, {30.499821, 1.4581978*^-10}, {
         36.664673058650884`, 0.}}], 
        LineBox[{{74.58469506683788, 0.}, {81.250366, 1.7727273*^-8}, {
         91.250977, 2.798180371*^-7}, {101.251587, 1.53571291*^-6}, {
         111.252197, 0.00002733806}, {121.252808, 0.021583181}, {131.253418, 
         0.03871442}, {141.254028, 0.050295229999999996`}, {151.254639, 
         0.06765861000000001}, {161.255249, 0.07607068}, {171.255859, 
         0.09847942}, {181.25647, 0.10813218}, {191.25708, 
         0.10923611999999999`}, {200.007614, 0.11116146}}]}, {
        Hue[0.1421359549995791, 0.6, 0.6], 
        Directive[
         PointSize[0.011000000000000001`], 
         AbsoluteThickness[1.6], 
         Hue[0.2, 1, 1]], 
        LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAABfFgsAAADQPxyxFp8C
ACRA3x2t1iQurj+QwB9+/j80QBv0vLqDYWs/odrgRPR/PkAXazWy/8tvPol+
bf30X0RAj5X616ObdT+RC87g739JQKgnwLDpWrE/mpguxOqfTkAw00wwCbzM
P7X+lgD8z1FAD/D2hwJUyz/xgR3/BVBUQM8pdY8zFpM/FsPVARDQVkBX+LIs
tYaAPlJGXAAaUFlAQ2oH2fotmj+OyeL+I9BbQFYGoBRX3Mw/swqbAS5QXkC+
S6lLxrHHP/jGEAAcaGBAnseTasCcnD+WCFT/IKhhQE/rZuETNHE/KCmwACbo
YkA99OzYWQufP8Zq8/8qKGRAWcHrCuhLqj9krDb/L2hlQCRyZmCJrKw/98yS
ADWoZkBOpwqA0P6mP5UO1v856GdA9k/V3Igpnj+8H7dfPgBpQGUrfPUpMoc/
69aYsg==
         "]]}}}, {}, {}, {{}, {}}, {{}, {}}}, {
    DisplayFunction -> Identity, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, AxesOrigin -> {0, 0}, 
     PlotRange -> {{0, 200.007614}, {0, 1}}, PlotRangeClipping -> True, 
     ImagePadding -> All, DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, DisplayFunction :> 
     Identity, Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], 
     Method -> {"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& ), "CopiedValueFunction" -> ({
           (Identity[#]& )[
            Part[#, 1]], 
           (Identity[#]& )[
            Part[#, 2]]}& )}}, PlotRange -> {{0, 200.007614}, {0, 1}}, 
     PlotRangeClipping -> True, PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {0, 0}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FormBox[
     TemplateBox[{"\"Kinetic\"", "\"Gradient\"", "\"Potential\""}, 
      "PointLegend", DisplayFunction -> (FormBox[
        StyleBox[
         StyleBox[
          PaneBox[
           TagBox[
            GridBox[{{
               TagBox[
                GridBox[{{
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0., 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0., 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.1, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                   GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.2, 1, 1]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.198], 
                    AbsoluteThickness[1.6], 
                    Hue[0.2, 1, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                 GridBoxAlignment -> {
                  "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                 AutoDelete -> False, 
                 GridBoxDividers -> {
                  "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                 GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}},
                  GridBoxSpacings -> {
                  "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
             AutoDelete -> False, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
            "Grid"], Alignment -> Left, AppearanceElements -> None, 
           ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
           "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
         FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
         False], TraditionalForm]& ), 
      InterpretationFunction :> (RowBox[{"PointLegend", "[", 
         RowBox[{
           RowBox[{"{", 
             RowBox[{
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0., 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> Hue[0., 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0., 1, 1]"], 
                    Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0., 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0., 1, 1], Editable -> False, Selectable -> False]}], 
                 "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.1, 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.10000000000000002`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0.1, 1, 1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.1, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.1, 1, 1], Editable -> False, Selectable -> False]}],
                  "]"}], ",", 
               RowBox[{"Directive", "[", 
                 RowBox[{
                   RowBox[{"PointSize", "[", "0.011000000000000001`", "]"}], 
                   ",", 
                   RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                   InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    Hue[0.2, 1, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    Hue[0.20000000000000004`, 1., 0.6666666666666667], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], "Hue[0.2, 1, 1]"],
                     Appearance -> None, BaseStyle -> {}, BaselinePosition -> 
                    Baseline, DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    Hue[0.2, 1, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["HueColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    Hue[0.2, 1, 1], Editable -> False, Selectable -> False]}],
                  "]"}]}], "}"}], ",", 
           RowBox[{"{", 
             RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
           RowBox[{"LegendMarkers", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"False", ",", "Automatic"}], "}"}]}], "}"}]}], ",", 
           RowBox[{"Joined", "\[Rule]", 
             RowBox[{"{", 
               RowBox[{"True", ",", "True", ",", "True"}], "}"}]}], ",", 
           RowBox[{"LabelStyle", "\[Rule]", 
             RowBox[{"{", "}"}]}], ",", 
           RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
      Editable -> True], TraditionalForm], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.422018376272205*^9, 3.423922406401531*^9, 3.424184196953216*^9, {
   3.7173613725294304`*^9, 3.717361396483406*^9}, 3.71736197907782*^9, 
   3.7173623455164213`*^9},ExpressionUUID->"a8d5ce9c-9c07-4068-8582-\
6b2549467fa0"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation of state", "Subsection",
 CellChangeTimes->{{3.717362228587282*^9, 
  3.7173622401282516`*^9}},ExpressionUUID->"2a5caa1d-9fd6-482d-aaa6-\
e02e231f0924"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphaplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"alphatable", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Pressure/Energy density\>\""}], ",", 
    RowBox[{"GridLines", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox["1", "4"], ",", 
         FractionBox["1", "3"]}], "}"}]}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]], "Input",ExpressionUUI\
D->"e75ab5b3-eb44-4ee3-9bcc-0822f69d7875"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJwBYQGe/iFib1JlAgAAABUAAAACAAAAAAAAAAAAAADgORLkkJuUvxyxFp8C
ACRAM6sPv+cc4T+QwB9+/j80QJWeEzlgO+8/odrgRPR/PkBHp5Qk///vP4l+
bf30X0RAkf4u65rc7j+RC87g739JQARnv7wpfuE/mpguxOqfTkCohq+gfaPg
v7X+lgD8z1FAlG5jjj3637/xgR3/BVBUQLO4k7m00es/FsPVARDQVkBlUJOF
+//vP1JGXAAaUFlAvLOiSbNu6j+OyeL+I9BbQCIGyGy7UeG/swqbAS5QXkB8
tbxiqz/Zv/jGEAAcaGBAX9B0g4sM5D+WCFT/IKhhQDE3y26dqec/KCmwACbo
YkDqHiz6ILXeP8Zq8/8qKGRAp88dNt/T0j9krDb/L2hlQNICAVmrBcQ/98yS
ADWoZkDWgbV2ehvIP5UO1v856GdAo08jTEOI0j+8H7dfPgBpQGwbpKJ/F9o/
WNuiMA==
      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->NCache[{None, {
      Rational[1, 4], 
      Rational[1, 3]}}, {None, {0.25, 0.3333333333333333}}],
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Pressure/Energy density\"", TraditionalForm],
  PlotRange->{{0, 200.007614}, {-0.5412270664821259, 0.9999995912996632}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.422018402491458*^9, 3.423922407320955*^9, 
  3.42418419768093*^9, 3.7173613726205416`*^9, 3.7173619863778887`*^9, 
  3.717362345560454*^9},ExpressionUUID->"dafb82fd-9249-4af5-8f2d-\
6e75699c309b"]
}, Open  ]],

Cell["\<\
Because alpha tends to oscillate strongly it is sometimes useful to calculate \
a binned average of it over time. The parameter delta sets how many times are \
averaged in each bin.\
\>", "Text",ExpressionUUID->"d4593604-04c9-4631-80ce-08604a3c57da"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"delta", "=", "3"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"coarsealphatable", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Mean", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"alphatable", "\[LeftDoubleBracket]", 
           RowBox[{"j", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "i", ",", 
            RowBox[{"i", "+", "delta"}]}], "}"}]}], "]"}], "]"}], ",", 
       RowBox[{"Mean", "[", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"alphatable", "\[LeftDoubleBracket]", 
           RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
          RowBox[{"{", 
           RowBox[{"j", ",", "i", ",", 
            RowBox[{"i", "+", "delta"}]}], "}"}]}], "]"}], "]"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"numtimes", "-", "delta"}], ",", "delta"}], "}"}]}], "]"}]}], 
  " ", ";"}], "\[IndentingNewLine]", 
 RowBox[{"coarsealphaplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"coarsealphatable", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotLabel", "\[Rule]", "\"\<Pressure/Energy density\>\""}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "Automatic"}], "}"}], ",", "All"}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.42201842758569*^9, {3.7173620797363195`*^9, 
   3.717362082571432*^9}},ExpressionUUID->"de02e049-83dd-48e0-8251-\
008e649cd387"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], 
     LineBox[{{15.187454500000001`, 0.6226628523279434}, {45.87458625000001, 
      0.49778058185533924`}, {76.25011275, 0.21243522654875696`}, {
      106.25189225000001`, 0.22256823678551463`}, {136.25372325, 
      0.36282011771933953`}, {166.25555425, 
      0.27968711223110493`}}]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0., 0.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageMargins->0.,
  ImagePadding->All,
  ImageSize->Automatic,
  ImageSizeRaw->Automatic,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Pressure/Energy density\"", TraditionalForm],
  PlotRange->{{0, 166.25555425}, {0., 0.6226628523279434}},
  PlotRangeClipping->True,
  PlotRangePadding->{{0, 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.423922408543256*^9, 3.424184200055716*^9, 
  3.7173613727171154`*^9, 3.717362088590766*^9, 
  3.717362345598982*^9},ExpressionUUID->"04a110be-4264-4e56-bc1d-\
f252a1c5883c"]
}, Open  ]],

Cell["\<\
The following plot averages each cycle of alpha, defined as any interval from \
one maximum to another in the plot of alpha vs. time.\
\>", "Text",ExpressionUUID->"b618af9f-f9cb-40d9-a21b-a0b8baf4c2e7"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"alphacycles", "=", 
   RowBox[{"{", "}"}]}], ";", 
  RowBox[{"firsttime", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"time", "=", "2"}], ",", 
    RowBox[{"time", "<", "numtimes"}], ",", 
    RowBox[{"time", "++"}], ",", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"alphatable", "\[LeftDoubleBracket]", 
         RowBox[{"time", ",", "2"}], "\[RightDoubleBracket]"}], ">", 
        RowBox[{"alphatable", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"time", "-", "1"}], ",", "2"}], "\[RightDoubleBracket]"}]}],
        "&&", 
       RowBox[{
        RowBox[{"alphatable", "\[LeftDoubleBracket]", 
         RowBox[{"time", ",", "2"}], "\[RightDoubleBracket]"}], ">", 
        RowBox[{"alphatable", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"time", "+", "1"}], ",", "2"}], 
         "\[RightDoubleBracket]"}]}]}], ",", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"firsttime", ">", "0"}], ",", 
         RowBox[{
          RowBox[{"alphacycles", "=", 
           RowBox[{"AppendTo", "[", 
            RowBox[{"alphacycles", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                FractionBox["1", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"alphatable", "\[LeftDoubleBracket]", 
                   RowBox[{"firsttime", ",", "1"}], "\[RightDoubleBracket]"}],
                   "+", 
                  RowBox[{"alphatable", "\[LeftDoubleBracket]", 
                   RowBox[{
                    RowBox[{"time", "-", "1"}], ",", "1"}], 
                   "\[RightDoubleBracket]"}]}], ")"}]}], ",", 
               RowBox[{"Mean", "[", 
                RowBox[{"Table", "[", 
                 RowBox[{
                  RowBox[{"alphatable", "\[LeftDoubleBracket]", 
                   RowBox[{"j", ",", "2"}], "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"j", ",", "firsttime", ",", 
                    RowBox[{"time", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], 
              "}"}]}], "]"}]}], ";"}]}], "]"}], ";", 
       RowBox[{"firsttime", "=", "time"}], ";"}]}], "]"}]}], "]"}], 
  ";"}], "\n", 
 RowBox[{"alphacycleplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"alphacycles", ",", 
    RowBox[{"Joined", "\[Rule]", "True"}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"Hue", "[", "0", "]"}], "}"}]}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}]}], "Input",ExpressionUU\
ID->"f555682a-e674-409b-9f3f-87128dbd2718"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0, 1, 1], PointSize[0.012833333333333334`], AbsoluteThickness[1.6], 
     LineBox[{{55.8750935, 0.3934704556468565}, {111.25219750000001`, 
      0.30336086322269934`}}]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{55.00982625000001, 0.29885538360149144`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{55.8750935, 111.25219750000001`}, {0.30336086322269934`, 
   0.3934704556468565}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.422018871359835*^9, 3.423922409461486*^9, 
  3.424184201625105*^9, 3.7173613727716913`*^9, 3.7173621084412804`*^9, 
  3.717362345631508*^9},ExpressionUUID->"c245638b-91a7-469a-94f2-\
b021072e63a5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Energy conservation", "Subsection",
 CellChangeTimes->{{3.717362259037235*^9, 
  3.717362260926859*^9}},ExpressionUUID->"f55a8e64-67a5-4d1f-9bb3-\
1688f1e2296c"],

Cell["\<\
The conservation variable is rho/rho_initial for no expansion. It's the ratio \
of H^2 to 8 pi/3 rho for self-consistent expansion. This file won't be \
created for runs with fixed power-law expansion.
This quantity should stay close to 1 if energy is conserved\
\>", "Text",
 CellChangeTimes->{{3.717362274638024*^9, 
  3.717362282856043*^9}},ExpressionUUID->"f19855db-7a94-46d2-8fd7-\
bba52bba0797"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"conservationtable", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
     RowBox[{"dir", "<>", "\"\<conservation\>\"", "<>", "ext"}], ",", 
     RowBox[{"{", 
      RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";"}], "\n", 
 RowBox[{"conservationplot", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"conservationtable", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "Automatic"}], "}"}]}]}], "]"}]}]}], "Input",Expressio\
nUUID->"d40fc194-144c-4ed2-bced-30f7f9bd40c9"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.012833333333333334`],
      AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQjQo+2MtsFJvPxKDicKn71l8tIH/CAfm6f/YmDqnL
tvybBuQvvPXA5Uu9ncMLf+mrL4H8zrrcv1/iXRz8N119OgXIn8h97sH7ek+H
jgVZX7KA/Fkz9I68mu/noLT0pg0f8wf7rUBT/pwPdGBzi7t2hOmD/cdG2f+s
ASEOB5lmGBUA1YsdvsoocCHMgX9rrgQr4wf7ILcYBqmASAc7x6Td1UD5vpOP
/ilfiHYIYDSY5wg0bzPXbEa9gDiHcuGay18kP9j/OCbAIJOR4CCh+kL/C8cH
+2kcIf8VViQ6XF/EmhHN+8FeQ3MDg9qLJIffkTqun0Q/2B/L+vxfSyPFgfll
0mUvxQ/2KWvM/utnpDr8+W+ReEjjg/33M5MYTFekOWx4oiW2X/OD/VS+a/8t
X6Q7pMQUFobofbDfI7893o4h00H43dTK1UA+AJAolIs=
      "]]}, {}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {0, 1.011394}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.422018889313305*^9, 3.423922410042921*^9, 
  3.424184202167797*^9, 3.7173613728570166`*^9, 3.7173622859888697`*^9, 
  3.7173623456635303`*^9},ExpressionUUID->"ebfdd880-fd86-44a9-b7b3-\
90afd447eacd"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1272, 977},
WindowMargins->{{70, Automatic}, {Automatic, 6}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 172, 3, 101, "Title", "ExpressionUUID" -> \
"76acf1e0-25d0-4c77-b10b-916253b4a028"],
Cell[742, 27, 1222, 20, 144, "Text", "ExpressionUUID" -> \
"6f50b7c0-b83c-47ad-8656-d4059ebea7d5"],
Cell[1967, 49, 190, 3, 30, "Text", "ExpressionUUID" -> \
"c4ff263a-d322-410b-9ea2-b4d0629eb749"],
Cell[2160, 54, 206, 4, 30, "Input", "ExpressionUUID" -> \
"c1b35bbe-ecf0-44be-9af2-648386456f4e"],
Cell[CellGroupData[{
Cell[2391, 62, 224, 5, 70, "Section", "ExpressionUUID" -> \
"1d1c634f-5e09-4e6e-8236-4275fa94d1f1"],
Cell[2618, 69, 509, 9, 106, "Text", "ExpressionUUID" -> \
"dd17f80c-5060-413b-be9e-2c6bdaa23a5b"],
Cell[3130, 80, 474, 12, 30, "Input", "ExpressionUUID" -> \
"ad68b7be-65c1-4b7e-90a9-06ebaa2a9fb9"],
Cell[3607, 94, 299, 7, 30, "Text", "ExpressionUUID" -> \
"16b2b9cc-9be5-4ce2-b456-7ec6e515602b"],
Cell[3909, 103, 620, 13, 30, "Input", "ExpressionUUID" -> \
"d33dbdbd-0621-4685-b4a1-6e3ff04b3735"]
}, Closed]],
Cell[CellGroupData[{
Cell[4566, 121, 157, 3, 56, "Section", "ExpressionUUID" -> \
"ba88b55f-3909-451e-b066-44d27936367a"],
Cell[4726, 126, 422, 8, 49, "Text", "ExpressionUUID" -> \
"171b5500-ad39-409d-acf1-18fddd606d9e"],
Cell[5151, 136, 212, 5, 30, "Input", "ExpressionUUID" -> \
"983f978b-09f8-4de4-bdee-8f36e128d898"],
Cell[5366, 143, 354, 9, 30, "Input", "ExpressionUUID" -> \
"79a8cc92-166c-43f2-bd73-b6f5892a4279"],
Cell[CellGroupData[{
Cell[5745, 156, 281, 7, 30, "Input", "ExpressionUUID" -> \
"8fdafe35-0a64-4fcf-a7ab-cccc260e520d"],
Cell[6029, 165, 250, 4, 30, "Output", "ExpressionUUID" -> \
"dd18be43-2db8-4589-9b19-30094fe08c10"]
}, Open  ]],
Cell[6294, 172, 189, 3, 30, "Text", "ExpressionUUID" -> \
"ae3f02f1-f3ec-480f-9614-faada165fbdc"],
Cell[6486, 177, 2243, 67, 69, "Input", "ExpressionUUID" -> \
"961162b9-04e8-477d-af02-4d5002dbee35"],
Cell[8732, 246, 150, 2, 30, "Text", "ExpressionUUID" -> \
"5e5039b3-591c-4a2d-bd20-f198c7b02ecc"],
Cell[8885, 250, 2154, 64, 69, "Input", "ExpressionUUID" -> \
"216f4f0d-4028-42d3-9fee-cbd77f8a467d"],
Cell[11042, 316, 150, 2, 30, "Text", "ExpressionUUID" -> \
"793992a3-8876-4273-8c56-777848863268"],
Cell[11195, 320, 1009, 28, 69, "Input", "ExpressionUUID" -> \
"f14af63f-a0d5-4fdd-9ade-519e5eb391fc"]
}, Closed]],
Cell[CellGroupData[{
Cell[12241, 353, 190, 3, 56, "Section", "ExpressionUUID" -> \
"12356bd5-6f16-4acd-8383-3e5da04fa551"],
Cell[CellGroupData[{
Cell[12456, 360, 179, 3, 49, "Subsection", "ExpressionUUID" -> \
"3d088c7d-3204-40e2-90f0-8a49eccc0df0"],
Cell[CellGroupData[{
Cell[12660, 367, 403, 9, 30, "Input", "ExpressionUUID" -> \
"baed8c6f-2b64-444a-9297-fc1e9881fce9"],
Cell[13066, 378, 1893, 45, 267, "Output", "ExpressionUUID" -> \
"28067027-cb2e-41b2-9cda-90af9b5d77e5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14996, 428, 1332, 37, 50, "Input", "ExpressionUUID" -> \
"4dbbf738-ec11-4657-8781-5bca803321d2"],
Cell[16331, 467, 16282, 340, 254, "Output", "ExpressionUUID" -> \
"337e0d6c-82c8-478e-825b-18dd4dd5ebb3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32650, 812, 847, 24, 50, "Input", "ExpressionUUID" -> \
"7ee1548c-6ab3-4a81-bdb0-be878482c39b"],
Cell[33500, 838, 16083, 332, 254, "Output", "ExpressionUUID" -> \
"a8d5ce9c-9c07-4068-8582-6b2549467fa0"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[49632, 1176, 167, 3, 49, "Subsection", "ExpressionUUID" -> \
"2a5caa1d-9fd6-482d-aaa6-e02e231f0924"],
Cell[CellGroupData[{
Cell[49824, 1183, 569, 14, 53, "Input", "ExpressionUUID" -> \
"e75ab5b3-eb44-4ee3-9bcc-0822f69d7875"],
Cell[50396, 1199, 2050, 49, 242, "Output", "ExpressionUUID" -> \
"dafb82fd-9249-4af5-8f2d-6e75699c309b"]
}, Open  ]],
Cell[52461, 1251, 260, 4, 30, "Text", "ExpressionUUID" -> \
"d4593604-04c9-4631-80ce-08604a3c57da"],
Cell[CellGroupData[{
Cell[52746, 1259, 1721, 46, 69, "Input", "ExpressionUUID" -> \
"de02e049-83dd-48e0-8251-008e649cd387"],
Cell[54470, 1307, 1736, 44, 253, "Output", "ExpressionUUID" -> \
"04a110be-4264-4e56-bc1d-f252a1c5883c"]
}, Open  ]],
Cell[56221, 1354, 212, 3, 30, "Text", "ExpressionUUID" -> \
"b618af9f-f9cb-40d9-a21b-a0b8baf4c2e7"],
Cell[CellGroupData[{
Cell[56458, 1361, 2694, 68, 182, "Input", "ExpressionUUID" -> \
"f555682a-e674-409b-9f3f-87128dbd2718"],
Cell[59155, 1431, 1489, 38, 239, "Output", "ExpressionUUID" -> \
"c245638b-91a7-469a-94f2-b021072e63a5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60693, 1475, 167, 3, 49, "Subsection", "ExpressionUUID" -> \
"f55a8e64-67a5-4d1f-9bb3-1688f1e2296c"],
Cell[60863, 1480, 411, 8, 68, "Text", "ExpressionUUID" -> \
"f19855db-7a94-46d2-8fd7-bba52bba0797"],
Cell[CellGroupData[{
Cell[61299, 1492, 546, 14, 50, "Input", "ExpressionUUID" -> \
"d40fc194-144c-4ed2-bced-30f7f9bd40c9"],
Cell[61848, 1508, 1828, 44, 279, "Output", "ExpressionUUID" -> \
"ebfdd880-fd86-44a9-b7b3-90afd447eacd"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

