(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1206698,      20075]
NotebookOptionsPosition[   1201826,      19966]
NotebookOutlinePosition[   1202248,      19982]
CellTagsIndexPosition[   1202205,      19979]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LATTICEEASY NOTEBOOK: Two-Dimensional Histograms", "Title",
 CellChangeTimes->{
  3.717363891294754*^9},ExpressionUUID->"62449385-f0cd-4d6c-8ec6-\
c58fa3953db9"],

Cell["\<\
This notebook produces plots of 2D histograms (i.e. histograms of two fields) \
from the output of the latticeeasy program.
Last modified: 10/18/17\
\>", "Text",
 CellChangeTimes->{{3.717363884882352*^9, 3.717363893790534*^9}, {
  3.717364390580594*^9, 
  3.717364396168099*^9}},ExpressionUUID->"006007ed-dc92-44ee-ba30-\
c5f43bc9d712"],

Cell["Clear all variables to avoid naming conflicts.", "Text",
 CellChangeTimes->{{3.7173593539180403`*^9, 
  3.717359364375927*^9}},ExpressionUUID->"a5a8e0ed-82e1-44d6-9ddc-\
e0906126377c"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7173584246909575`*^9, 
  3.7173584246929617`*^9}},ExpressionUUID->"436c79f0-d136-4c02-95c8-\
b3667b2d035f"],

Cell[CellGroupData[{

Cell["\<\
PARAMETERS: Set parameters for where to read data and what to plot\
\>", "Section",
 CellChangeTimes->{
  3.7173639234280443`*^9},ExpressionUUID->"2f1ebb92-06d2-4e58-a6a3-\
7220254ecf8c"],

Cell["\<\
The number of labels should be at least as large as the number of fields. \
Additional labels will be ignored.\
\>", "Text",ExpressionUUID->"26e28150-0828-4830-a308-ac434091014e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"label", "[", "0", "]"}], "=", "\"\<\[Phi]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "1", "]"}], "=", "\"\<\[Chi]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "2", "]"}], "=", "\"\<\[Sigma]\>\""}], 
  ";"}]], "Input",ExpressionUUID->"e43a05ab-e7fc-4489-98a0-01b8baf3d21e"],

Cell["\<\
The run variables are\[IndentingNewLine]  dir - The directory where the files \
are stored\[IndentingNewLine]  ext - The extension of the data files\
\[IndentingNewLine]  nbins1 - The number of bins in the first field direction\
\[IndentingNewLine]  nbins2 - The number of bins in the second field \
direction\[IndentingNewLine]  nbins2d - Total number of bins = nbins1*nbins2\
\>", "Text",
 CellChangeTimes->{{3.7173639315288987`*^9, 
  3.7173639468443995`*^9}},ExpressionUUID->"100d05ff-2e13-4021-bb5e-\
b67a1878cc0a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "dir", "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{"ext", "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{"nbins", "=", "10"}], ";", 
  RowBox[{"nbins1", "=", "nbins"}], ";", 
  RowBox[{"nbins2", "=", "nbins"}], ";", 
  RowBox[{"nbins2d", "=", 
   RowBox[{"nbins1", "*", "nbins2"}]}], ";"}]], "Input",
 CellChangeTimes->{3.423922448965716*^9, 
  3.7173639593155756`*^9},ExpressionUUID->"6005a74d-683f-4965-a981-\
caedf9dc7422"],

Cell["\<\
List all the pairs of fields for which 2D histograms are being plotted.\
\>", "Text",ExpressionUUID->"54ad4eaf-887e-45c7-b9e9-3a4ac3e87a0f"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pair", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"pair", "++"}], ";", 
  RowBox[{
   RowBox[{"field1", "[", "pair", "]"}], "=", "0"}], ";", 
  RowBox[{
   RowBox[{"field2", "[", "pair", "]"}], "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"numpairs", "=", "pair"}], ";"}]}], "Input",ExpressionUUID->\
"3bd8e18d-589b-4aef-bab0-580c00e57261"],

Cell["\<\
Plot settings
  range1 - Default range of values to plot in first field direction
  range2 - Default range of values to plot of second field direction
  pairrange1[] and pairrange2[] set the ranges for individual pairs. By \
default these are all set to range1 and range2 but can be reset individually.
  Note that setting range[] to be the same for all times makes it much easier \
to see time evolution than it would be if each plot were done to its own \
minimum/maximum value.\
\>", "Text",
 CellChangeTimes->{{3.7173643244816656`*^9, 
  3.7173643380928893`*^9}},ExpressionUUID->"38220200-926a-40e0-b2a8-\
c4c41d2c80f2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rangelimit", "=", "1"}], ";", 
  RowBox[{"range1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "rangelimit"}], ",", "rangelimit"}], "}"}]}], ";", 
  RowBox[{"range2", "=", "range1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"pair", "=", "1"}], ",", 
    RowBox[{"pair", "\[LessEqual]", "numpairs"}], ",", 
    RowBox[{"pair", "++"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"pairrange1", "[", "pair", "]"}], "=", "range1"}], ";", 
     RowBox[{
      RowBox[{"pairrange2", "[", "pair", "]"}], "=", "range2"}], ";"}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.717364352136865*^9, 
  3.717364352198425*^9}},ExpressionUUID->"a17e3b8b-5b03-49f2-a16a-\
cd26b47f68ca"]
}, Closed]],

Cell[CellGroupData[{

Cell["DATA: Read in data and make plots", "Section",
 CellChangeTimes->{
  3.717364004809172*^9},ExpressionUUID->"f071f974-6bd3-4a2f-a4ad-\
a74d80e9b0b2"],

Cell["\<\
Read in the times at which 2D histograms were recorded and the minimum field \
value and bin spacing for each field in each pair.\
\>", "Text",ExpressionUUID->"b62b7d7f-b889-48d3-9bf2-f218168756a6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"histtimestable", "=", 
   RowBox[{"ReadList", "[", 
    RowBox[{
     RowBox[{"dir", "<>", "\"\<histogram2dtimes\>\"", "<>", "ext"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{"Real", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"4", "*", "numpairs"}], "+", "1"}], "}"}]}], "]"}]}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{"numtimes", "=", 
  RowBox[{"Count", "[", 
   RowBox[{"histtimestable", ",", 
    RowBox[{"Table", "[", 
     RowBox[{"_Real", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"4", "*", "numpairs"}], "+", "1"}], "}"}]}], "]"}]}], 
   "]"}]}]}], "Input",ExpressionUUID->"60b37f6a-8fca-4fe3-bc39-5bde5ae28531"],

Cell[BoxData["21"], "Output",
 CellChangeTimes->{3.422111056731469*^9, 3.4221120931732435`*^9, 
  3.422121411244527*^9, 3.423922454075677*^9, 3.42418423715372*^9, 
  3.7173640526777325`*^9, 
  3.717364643067752*^9},ExpressionUUID->"c5273edd-a3e4-431a-9874-\
a47323159379"]
}, Open  ]],

Cell["\<\
For each pair read in the histogram data and verify that the number of data \
points in the file is correct.\
\>", "Text",ExpressionUUID->"4b3148a4-1b09-4118-afb8-d4c0aef9dafd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"pair", "=", "1"}], ",", 
    RowBox[{"pair", "\[LessEqual]", "numpairs"}], ",", 
    RowBox[{"pair", "++"}], ",", "\n", "\t", 
    RowBox[{
     RowBox[{
      RowBox[{"intablehist2d", "[", "pair", "]"}], "=", 
      RowBox[{"ReadList", "[", 
       RowBox[{
        RowBox[{"dir", "<>", "\"\<histogram2d\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"field1", "[", "pair", "]"}], "]"}], "<>", "\"\<_\>\"", "<>", 
         RowBox[{"ToString", "[", 
          RowBox[{"field2", "[", "pair", "]"}], "]"}], "<>", "ext"}], ",", 
        "Real"}], "]"}]}], ";", "\n", "\t", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"numtimes", "*", "nbins2d"}], "\[NotEqual]", 
        RowBox[{"Count", "[", 
         RowBox[{
          RowBox[{"intablehist2d", "[", "pair", "]"}], ",", "_Real"}], 
         "]"}]}], ",", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<Mismatch in pair \>\"", ",", "pair"}], "]"}], ";", 
        RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";"}]}], "\n", "]"}], 
  ";"}]], "Input",ExpressionUUID->"8e474607-3f5e-4605-8343-6c9fdb5dc4f4"],

Cell["\<\
Create plots of histograms. The plotting parameters skip, start, and finish \
are stored here because it is often useful to change them and rerun this cell \
to generate different plots.
The run parameters are
  skip - Number of times to skip between successive plots
  start - Time of first plot
  finish - Time of last plot      \[IndentingNewLine]Setting skip=1, start=1, \
finish=numtimes will plot all slices\
\>", "Text",
 CellChangeTimes->{{3.717364061480208*^9, 3.7173640830434637`*^9}, {
  3.717364314153781*^9, 
  3.717364316352603*^9}},ExpressionUUID->"9199c38c-2d64-4aa6-aa43-\
85ff526d49e1"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"skip", "=", "1"}], ";", 
  RowBox[{"start", "=", "1"}], ";", 
  RowBox[{"finish", "=", "numtimes"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"numpairs", ">", "2"}], ",", 
    RowBox[{"plotwidth", "=", "700"}], ",", 
    RowBox[{"plotwidth", "=", 
     RowBox[{"400", "*", "numpairs"}]}]}], "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"time", "=", "start"}], ",", 
    RowBox[{"time", "\[LessEqual]", "finish"}], ",", 
    RowBox[{"time", "+=", "skip"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"startindex", "=", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"time", "-", "1"}], ")"}], "*", "nbins2d"}], "+", "1"}]}], 
     ";", "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"pair", "=", "1"}], ",", 
       RowBox[{"pair", "\[LessEqual]", "numpairs"}], ",", 
       RowBox[{"pair", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"fmin1", "=", 
         RowBox[{"histtimestable", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", 
            RowBox[{"2", "+", 
             RowBox[{"4", "*", 
              RowBox[{"(", 
               RowBox[{"pair", "-", "1"}], ")"}]}]}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"df1", "=", 
         RowBox[{"histtimestable", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", 
            RowBox[{"3", "+", 
             RowBox[{"4", "*", 
              RowBox[{"(", 
               RowBox[{"pair", "-", "1"}], ")"}]}]}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"fmin2", "=", 
         RowBox[{"histtimestable", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", 
            RowBox[{"4", "+", 
             RowBox[{"4", "*", 
              RowBox[{"(", 
               RowBox[{"pair", "-", "1"}], ")"}]}]}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"df2", "=", 
         RowBox[{"histtimestable", "[", 
          RowBox[{"[", 
           RowBox[{"time", ",", 
            RowBox[{"5", "+", 
             RowBox[{"4", "*", 
              RowBox[{"(", 
               RowBox[{"pair", "-", "1"}], ")"}]}]}]}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hist2dtable", "[", "pair", "]"}], "[", "time", "]"}], "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"fmin1", "+", 
              RowBox[{"i", "*", "df1"}]}], ",", 
             RowBox[{"fmin2", "+", 
              RowBox[{"j", "*", "df2"}]}], ",", 
             RowBox[{
              RowBox[{"intablehist2d", "[", "pair", "]"}], "[", 
              RowBox[{"[", 
               RowBox[{"startindex", "+", 
                RowBox[{"i", "*", "nbins1"}], "+", "j"}], "]"}], "]"}]}], 
            "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", 
             RowBox[{"nbins1", "-", "1"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "0", ",", 
             RowBox[{"nbins2", "-", "1"}]}], "}"}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"hist2dplot", "[", "pair", "]"}], "[", "time", "]"}], "=", 
         RowBox[{"ListPlot3D", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"hist2dtable", "[", "pair", "]"}], "[", "time", "]"}], 
             ",", "1"}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"pairrange1", "[", "pair", "]"}], ",", 
              RowBox[{"pairrange2", "[", "pair", "]"}], ",", "All"}], "}"}]}],
            ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"label", "[", 
               RowBox[{"field1", "[", "pair", "]"}], "]"}], ",", 
              RowBox[{"label", "[", 
               RowBox[{"field2", "[", "pair", "]"}], "]"}], ",", "None"}], 
             "}"}]}], ",", 
           RowBox[{"BoxRatios", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"2", ",", "2", ",", "1"}], "}"}]}], ",", " ", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", "Automatic", ",", "None"}], "}"}]}]}], 
          "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"GraphicsGrid", "[", 
         RowBox[{"{", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"hist2dplot", "[", "pair", "]"}], "[", "time", "]"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"pair", ",", "1", ",", "numpairs"}], "}"}]}], "]"}], 
          "}"}], "]"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{"\"\<2D Histograms for t=\>\"", "<>", 
          RowBox[{"ToString", "[", 
           RowBox[{"histtimestable", "[", 
            RowBox[{"[", 
             RowBox[{"time", ",", "1"}], "]"}], "]"}], "]"}]}]}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"plotwidth", ",", 
           RowBox[{"plotwidth", "/", "GoldenRatio"}]}], "}"}]}]}], "]"}], 
      "]"}], ";"}]}], "\n", "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.422111072497397*^9, 3.422111078122505*^9}, {
   3.4221119312795105`*^9, 3.422111946686056*^9}, {3.4221120260313296`*^9, 
   3.422112061688264*^9}, {3.422121376724786*^9, 3.422121403426875*^9}, {
   3.4221214433160563`*^9, 3.422121479091753*^9}, {3.717364107976986*^9, 
   3.7173642352352095`*^9}, {3.7173642960810623`*^9, 3.71736429659616*^9}, {
   3.717364422270086*^9, 3.7173644397443676`*^9}, 3.7173645069999523`*^9, {
   3.7173645431636963`*^9, 3.717364543475938*^9}, {3.717364582610608*^9, 
   3.7173646009139576`*^9}},ExpressionUUID->"3b69998c-f106-4fa2-905b-\
105d59eead72"],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1m3lcTdv7x1dCoStDSKaIUqZQx3SdneGKi1uGUOaxjtwGs0gHmZpFlA5K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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3scl+MZxt/nfiuVUi0hqaSzqNBBJR1EKjpTSEcpnU8rJE1qlLScllMH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             "]], Polygon3DBox[CompressedData["
1:eJw1mHcckNMax885rwZpqCgNlaSsUhQh6pasliRRlNxUqC4aiIy7wsWHy3VV
pCIkqyFZN1nZm2yy98iW8fv6PfeP53Oe3znnfd/znvOM33PajJ40eGJJKf01
p7SR2o0E9lfbTHinKqUthAcL9xQ+SPhetVsLXyN5VmNd1NeGPsmu0jeo/ZPG
mqrdTvhN+oV/kjQU3kTPHCh9oPqHCj8nPE94vuQF6Q9KLpZ+ieRh6Y9oXgfp
ayUvCV8n3DD5GZ6tJH2lj5dsq/e9ovGdpX8kqRXrP1j6qervK/y62s7CddS2
E16ltq3wYskrmnuf5N/SL5Xcz15ozj7Z/3+g9CVqm8X6Vml8vnCD5DWz9u01
Z8vs/dtRenP1DdHYIOHDhe9U2zre/4DGtpMcLv0s9Z+p8X6SHtL3lgyQ/qXa
PTTeXu1elfeQvfxZ0lh6az0/VPpojf+58hzmduAd0mtr/ACN7yc8SPg9td2E
a6rdSvi12I8vJHWFm2n+Ieyn+o8TbipJ0jP/JP1rtXuqq5Pa3sJ1Nb+f8NHC
xwqv57uxvs0r/98R0ndX/2jhBsL9hccKn1D5/PYVPlT4aOEmYW/HCI8R/o3v
CO+rdrDww2q3Ff5Qsonw0+yz9I8ltYU/Ft5dehO1HSsLOva4s/Rfwj7ZY/Z6
U33vIOHDhI+p/A2+1VcypPIesVe1ODfpjTR/oOYPFT5S+Hn8RPhLSQPhxhof
hK2rv49wS+FDhYcJjxJ+NeyzBj4T/tJLuLPafWP/egjvqXYz4Rrhj9ggtog/
tBf+XFJf+Fb+TfoCyVOau0h4C+lTJTcJPya5QvosyRPSv9f4Psk+i+8uV9tc
+H/sqcY/F+4uvRV2Ev/XUfh1zlTj50ecOEGyULihZID0Ceo/SfPnCY/BvyT/
Ud+vwq/F80njd4X9r5S8obHVwtskz2HuPcJtpN8neVe4RfjPJPX/Rc8/pnZ7
npVs0FidOL8unKvGvwn7wwfxxRVqWxBLOCPNXcC+Sj9NcovwG8K7YKtqfxJe
E/v7tGS98NWSE6VvGv/TJvztNOmnxnljDycLTxOerbau8HTJrRprLxkmfYb6
z9D4xdhSfH+Zxl4W7iT9N0kLjb8j3DXZ5/A9zoCzaI1dR/zqouFvJd/o+WfC
/p6VfC/cIeLJZPVP0fyP1O7G+vkv4cuz/2WKZJHmrhRuie1IfiD+RTx8RvKj
8I1hT8REYuNyyVn4muTq7P3bNc7jl2KbwDbqSc7T2LyIj5MlNxR/c0rY52Lp
T4X/PkoMEn5SeAfOXlIq2/Pm0pdLrtf4VcL1pU+UXFe8x+z16ZIlxTGIWEQ8
HFc5n+2nsZHExPB34hXxdT/hx+N7qyUfFMfnVtJfwSeELxKuGeu/WfhHcoH0
7YjLev4ytRsL/0Nyb/EaL0jeM9a+QPg4m37aS/pt6ttS+kzJPcLXhj3io/jq
khi/EZ8QvkG4EXsnebXYZrAdnukd54X/3IGPCd8s3ET6bMkjwo+Gv9wpeZP8
KtxO+jrJRpXPZFLynnJWS7Pz2wrJW8UxgdiwSvJx2MtW7DXvFL4y+6zPltzO
3Gx+8IjkU+E5MY5NXFv8zhWx3nXk2mxbwqbuEM6SPtL7q/+Iymtibf+UzC32
QWLLRcm+uTjbRrHN1cU5+bzkPWQvyWnkNuJlHen1KsdqfOb44hj6dTLHILZu
G/46UfqkyjH9q+QYSCzsJbxjNoeByxBzegWvIRaRs7EtbGxmcUzfJXLOhsgJ
I7JjBrFj4+BD26tvz8o5m9zNHpyjsRL5cWfiduWc0ChiHLni3ex8Tv7bWGP3
Z8dUYulvkq+y8zV8p63GP4n4TrxpUjnmoNN3sua3rJybyFEfqn0/mzOQB1tJ
OpHT4h28CyHndowxfKx7ds7C9+BYDSJmEbuIEcQKbHJMrPGtZJtk7fWCH5B/
B7KWyrmenP+c+t6K+Eh8qCrH7O9SxKDsmMEYc57NXnPtiIH8Cxx2j2xOCDeE
E8INhwtvLvxrNt8g3nauzBmaxvlN1/guwm0jBvyQLeRUciljcGC4MJzr57Ch
iZJ2xbZVM/gYc7pWzmnktqPU17Z47gnChyU/QwyfXDmPENvRT8q2UfpOrpx7
sKdtSnwvOx9PkH58ZS4Hp7uEXBbfI6deJvxFds4nz+wW0i6bczJGDdA4O4Zy
nuSg1rFHMwpB2raKzXbX2AH4Q/x/zfjfPzhMjBFzd83O2cRiaoT62RwI/9hB
uHk2R/k2cla9bE5HLqOPHE9uZy4cu1nY23fZ9lYnbH5aMWeHu8Mpawn/FN+q
S9yszMFqxP9OKa4humX7HNy0bbwPjvwZ61Df6OR8fnrlHPlccgwmFl+fXaNQ
mzxfzDGI1+T8Weq/TfiM5JhIbFwc8Zr8tbQ4h6HTNzd7DpyCPMezcLqTknMi
+WWq1jAlm2NeTr6WTEvmIP/NzrHkWvLRFdk5ilxFTtm/OAfdXcwjyU3of0vm
lPQtzK63iM/kfnIguZCc3qv4G3CKRfHtP+w12yaxzf6S3mEv+BYCB+8XY/h7
3cjbY0PGZMcAxuDMcGf4+VGVOTfcm3pheOWaYXh2Dch5dSr2JWwcW8cH8AU4
aqvimgZ/OFJ4K+Edi3X68BXiwVFhL8SHHsI7hT0RS+8qzkXkpD7FNVBX9e+V
XBuRD+Ci8PmelWs+aj/q3cMqv4OajjqNd1NDU0svkDxdnFNvTeZk5FpyInvP
GfQt5khwJfLrZ8UcFa4Kf/uqmAPCBeFv3xZziJuSczr5EA5xC7knmVvA+V5I
zul8Dw60Opl/v1dcE1Mbw0fWFtvP+eS+ZO6DjV8X9oTtw6+piamFHwq5PJmv
LAj/YC42uDLsDy7EnrK3cK6lyTUCXOxt5iTXKMuyBY4Cj2AMTnBu2CNcoavw
0fiT9NMq++iMiJddNDa98hhz5rAX2bZ+jmRFMR/CvuF8F2Zz+mnZNR35+pTw
t5H4k/AekmOS6/cZGrummO/hf3/P5qhw1RqSvYtr/LOza2Jq45Xhj3DIa7Lr
p7EOq+mcbP/iXbwTLgmHgktRg/WQPj/mw+m5wzkj/pcYdWWxDXaOmHdmfJ+1
suarim0EW2krGSX9a8mTyfmWWnt99KFTG2Ff3xXX3dQe1GDkc/LvE8SP7Ppt
juTR4prx+WS+BX+Cr1DjUNtsWdmmsC342sHF58tZU6+uKb7DqVm5TuJuB44D
16FmGF98J5EjX3xALlPfA8mc/smw5/eL60a4Pu/jbghOAbd4KPtf10g+KfYp
fGtryYhizrsqmZ+MlH57ds0ML/6o2EfwFf55mPSXJQvjebgwe/V4rJc9o2Zb
n5xP4EO848HkGpV3Nwh+Cl+ZEGu/O5kv8Q/sWcnmfOwld1SXhr/clH2ndGFy
DYP/wHnhvtS0a4U3Ff4smd9xFwE/pg+duyBiELEIn+hffOf2YjwPP2aNrHU+
+1vMx7jj416qUeUY9FTErwewEeGrYn+o7YlfnBFnQ+3HnQp3Kz01/mn2OzYk
8zfeDWdjL9iTehEveSfvuvf/Pp7Nl3YqzlfUVNRSjxfzBWwDG2leuW9ucjxl
LneMl0R87FfMieHD1OTrsm3vg8DYIHcosyIeDZK+BRwgmZ+cKHxH9r8vkrxY
zKHgFnAMuDV3nPPjvIcU35F9n3znA5/nTo+7M/j929nxF5vClrirhD+/nHxn
Ad8lUHBHxr3VIZKRksHZ/I67E+olYgMxgtiydfFejVP/+Mo5ldwKH7uAs87+
13fYs8o11WXJfASuMiq+wbu52yK/Dat8b8hd5w9xlpxpmyru5JLt9SX1bVac
iwdIP7Tyndvh2fUSfJCandqdO5ZLi3MmuZMa6dziGEv84o6jW/Gd4imBiacz
s2tt4iWxmDtE7hJHEGOK13pgNh9mzdyZHpHNn7hLhVPALeB/9Yv5xojK91zc
/TUtfnZ/zTm4cg1LLQv/G04sz47d7DexmXfybnIGuaNzce4Aw91eyK4tsSFs
iTsl7pZGCc8urnHejXh2bOSfqbE/vJuaidhEjHqnuMZfxl4k1/5sBndvfGNc
8Z0mtRX86l/FNQb2gA9Nj38dkn1G/PMfdwrJ+QF+i40dlM35+dHfAU/ewv4=

             "]], Polygon3DBox[CompressedData["
1:eJw1lwWUFUcQRf/M4hJcAgSCu7u76wKLLu4Oi3twd3eCJ3hwd9fgGixYcLcA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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+FXXeoyEe1YsbmlVCstZWVVI6pVBhYknboLGhVF+0FI+CqE
r6GJ0XPC8JzfP2d4T94zXTvfOesLIRxyyibjXkywbee1wK5d1mMtxkI40jVd
pWYXNB/7O2dFc1TtrFY0o0sc2Iuapmwv6Dz79pzuacN3SlrVClv2uhbZsJOa
IGv/MMsXn0zxxisJ2twzRp3orpcePhWu9Jp++0abDNi32mLQvtOh6AxtE7cf
9JFh+0k7jNhdHdUWkzzzQop3Ppjhmx7LXER34+T///8Cj3IkSA==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 575, 685, 426, 680, 585, 708, 
          442, 703, 599, 735, 458, 613, 765, 478, 762, 623, 789, 499, 785, 
          632, 813, 516, 808, 645, 843, 534, 838, 533, 554}], 
         Line3DBox[{391, 572, 675, 408, 683, 576, 691, 428, 706, 586, 714, 
          444, 600, 741, 743, 460, 614, 771, 480, 787, 624, 795, 501, 811, 
          633, 821, 518, 841, 646, 849, 536, 658, 875, 556}], 
         Line3DBox[{393, 573, 677, 412, 689, 578, 695, 431, 589, 720, 722, 
          446, 604, 749, 751, 463, 617, 777, 484, 793, 626, 801, 504, 819, 
          636, 827, 521, 649, 855, 857, 539, 661, 881, 559}], 
         Line3DBox[{396, 574, 679, 414, 580, 699, 701, 433, 593, 728, 730, 
          448, 608, 757, 759, 465, 619, 782, 486, 799, 628, 804, 506, 639, 
          832, 834, 523, 653, 862, 864, 541, 663, 886, 561}], 
         Line3DBox[{397, 398, 681, 417, 671, 583, 704, 434, 732, 597, 733, 
          449, 761, 611, 763, 468, 784, 621, 489, 807, 630, 809, 508, 837, 
          643, 839, 524, 867, 656, 868, 544, 888, 665, 563}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 436, 737, 602, 739, 
          451, 767, 615, 769, 470, 482, 791, 491, 815, 634, 817, 510, 845, 
          647, 847, 526, 871, 659, 873, 546, 557, 890, 565}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 438, 745, 606, 747, 
          454, 467, 773, 775, 474, 488, 797, 495, 823, 637, 825, 512, 851, 
          651, 853, 529, 543, 877, 879, 550, 562, 892, 568}], 
         Line3DBox[{404, 420, 697, 424, 724, 595, 726, 440, 452, 753, 755, 
          456, 472, 779, 781, 476, 493, 803, 497, 829, 641, 831, 514, 527, 
          859, 861, 531, 548, 883, 885, 552, 566, 894, 570}], 
         Line3DBox[{405, 702, 584, 425, 731, 598, 698, 441, 760, 612, 727, 
          457, 783, 622, 756, 477, 805, 631, 498, 835, 644, 806, 515, 865, 
          657, 836, 532, 887, 666, 866, 553, 895, 670, 571}], 
         Line3DBox[{555, 537, 869, 535, 519, 842, 840, 517, 502, 812, 810, 
          500, 481, 788, 786, 479, 461, 764, 459, 742, 601, 734, 443, 429, 
          707, 705, 427, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{558, 542, 874, 538, 856, 650, 848, 520, 507, 820, 818, 
          503, 487, 794, 792, 483, 466, 770, 462, 750, 605, 740, 445, 721, 
          590, 713, 430, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{560, 547, 880, 540, 863, 654, 854, 522, 833, 640, 826, 
          505, 492, 800, 798, 485, 471, 776, 464, 758, 609, 748, 447, 729, 
          594, 719, 432, 700, 581, 694, 413, 394, 678, 395}], 
         Line3DBox[{564, 667, 889, 545, 660, 872, 870, 525, 648, 846, 844, 
          509, 635, 816, 814, 490, 625, 790, 469, 616, 768, 766, 450, 603, 
          738, 736, 435, 588, 711, 709, 418, 577, 686, 399}], 
         Line3DBox[{567, 668, 891, 549, 878, 662, 876, 528, 652, 852, 850, 
          511, 638, 824, 822, 494, 627, 796, 473, 774, 618, 772, 453, 607, 
          746, 744, 437, 592, 717, 715, 421, 579, 692, 401}], 
         Line3DBox[{569, 669, 893, 551, 884, 664, 882, 530, 860, 655, 858, 
          513, 642, 830, 828, 496, 629, 802, 475, 780, 620, 778, 455, 754, 
          610, 752, 439, 596, 725, 723, 423, 582, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 702, 139, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0mnk01O/7/8nWQva9qJAlWZI15rKksoSsUZZISpQIKYWKRGUtawjRIrJk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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07910156}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=0.\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646432514443`*^9},ExpressionUUID->"442db7f9-e124-4ddb-8836-\
08fcbbd6b727"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XHlYTdsbXhmOKEpCrqF+5nkIcQxnp8zFzcwVpcwORUqEcxokNEop0UlE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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHfYV8URhe/ORQIEEWwRQXoRQUABKYL0SFG6gopUKYJ0AioiEUEFlWAL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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkckEMax2fmLaGTSpJUEgrpdCVyJFJUKlEq2Zwd60gUod21bh82a11F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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUFUcQRf/MQnAnuEOQ4BrcXXdxWdwdFvfg7u4EJ3hwd3f3YMGCuwZy
3+k6Z+/p169neuZPd1X1pmzSsWoHPxAI7ILw0D8oEBjgBQJzMfNDAcgFjRjr
jd8dZtJfBC3wBtOfDjMgKfeGo+3C2EvaV1AQ3Yzr6qMHwjz68zQ/bEYPZqwU
bQZID/3s+b+hE0ICaI7XDG8S+q3m5J5OEBPdA68e49XQ49Gh6PrwD3of1+yH
g3o+/Rj4L9Av4S3oh9+Hveg99g3q0m/CdXn1DpofZuHdgq2Mb4HVUIN+LK4r
oPeBuNAT7zZsZ3wbbIBa9JtyXS3Ga0NdmICXHS8FOrm+G/TGy4mXA3JBGry+
eA3QIehx6IboRpAanQp6ofswlgUdHf2U512l/xAewRDgL9AFmsMgOgu4djx6
AoRBUfpB4ENd+44xtWboJujGUMfeeQ9c554bsNF+2w3GrkMSW/sn+m7oPPqG
kJZ+P67rjG6j34vOCtkgKkSBmvYbx6IroIuii0A+GIpXDq8slIfieMPwcqNT
oVNCYuiFd5b2DPiMPeD9WuOVQRfGKwQ5YTBeUbyM6N/RxTQn/EB/VyCg79K0
RBdBZ+O6rJBZ+xcvPN5Dxtugf0JHgGAow3hZKA+jFDd4v6IzQGpby5J4sdGx
oB5MxPtK+wXy2zsNwCuFzo7OAbnsnY/QHoZw9vyL6Cro0rSloAQM57pqeFWh
OlTEG40XEuTeTe9YzL5fYrz/mOce/ffwQXsYPw6EMdaZ/i9oz75HK/RlvCvQ
Gq8VbUtoDpMZ62L3zEB3RXeDdkHuGl3bDqYxthw2Md9mGAfl6I/Re8JSdHu8
IrRboD96Pv5aWAfJ8JJCJ+btpLyD7m0xMFt7AvLABujJvTPxV8FqyzUDFQMw
BErrPWAAuiTtEj0fPqHP4J2Fy9CMflvLP4nQmSAzTNL6wUabY4HWEf0zbTz4
iNeR/mc4hz6vNYOm9CMz32P0E3gO7fBq4ZWzvVMbXQdead0ZPwqnoQn9E9pT
6E9wTXGtfQ9z0ZX1LDgPD2AHXh3ah/AIbsJKvFWwxnKY8t9udD3aA8x9EPbA
bs/l0AOMhSrOYQX6T1gHNek/hcPohr7bm0dsH2vPa+9nshgrhFdQcQhZLI60
vloLrUk/KEF/F2M74W9799q0JYJc/CkO8yinWWwpP36DSPqeFquae5DlMuW0
Z3CMeY7DSWhMf4r2K2xFD8Vb7Lk9fl+xAHcs9hVn6st/ZPEehHdba8E9d+Au
nIKTehffjbXQ96d/DiJaTm6L9y/9vOjP8Bra2/fT2mqND0EDvS/XHfXcHnmm
NbY4L0k7QnkeYmif4X1l/At8sL0Wxe7RfoqKjgaRLBde0HrCA7isOMSrTruV
/jaopHwBle1ZyiXJ0clUpzQPXlfLDe3RHSDM4j3E8nJE39XrhLYmWptg29cj
FdvotpYHOqA7QkoIwnus2IPPEJvxWL7LH7o+he9yTgv0FN/VPtXAvnj98Oag
80I+6G65IQ06O+SAHnhd9P7Q03P1PIlyILSxujTVd3WoCjoYqnqu5qpOJ0P3
QX+n/eG5OlmJtjJU99y5Iz1eQ3QjxYDn6lZjvBromhBq+T6f1cT+6IDyK6Sx
7/vcaoFqQkv9XuVZ+93KsRkhVDmEfgPlGd/VwSTKN/AT/Qj2jPT00ymHe67+
3oU7cM/iXeecrIoZ1Tj7jTqD1Ahyv0u/r4Ln6kcNqyVjbF20PopRnXF01tlp
eSaO6hvEtdrSCS8turXqB+S2+N3hu3OfcvBOxT1sh7/w1sNayy/bLEbL0C7j
3uXKT4phvMkw1urHaViI/kP1AqrQnw/D0SNgFJSlfxEuwCXb/9X0TOZcD2fQ
S/BCaNdCL3RxzcvYItUQ7S28btDZzk0TtPawxq6fpX2knIQeBqNhBf39jO9T
LoVpeOVp98Ik9EQYae/3Hk5YnvoAH+GdfLx38CbgzqxP4LFyiuVf5Y3XcMpq
xBt467u4Vny/srFD6Kv2O6vSXoPrejf8vZ7Ll3p+I9/lCOV65fxl9q3Wwzp9
M9/VZuVsfbdFyqOw1OZ97ru6oTP3C3hpa7QAL5h2M8/a4rmartp+zHf1q5Lv
andfdB/oAcXoH4VZqucwHSrQz8y+SsS9CSGO587eqfEio7vpe9C+gcPoQ3AE
Zti9x20d1li9Ud25BTchlc3xAjLqDAeZLMZ62btonoq0G/E2Kc4Yj0obDWJA
d9+dk3ReisfYd9URz8W5rtG1ES2fZsBLgI4P0e1enc08tA7v3yyO4ts8ndFP
tVb67bpX38FyaJjvvuVsrpsD8+xMsFJrCat8dy7SN70CV9FX4FLAnXP0XXSf
7p9q+/Qr3ELfVA0JuPPLcJ41DBb67n/AQrQjVZ9gMbotXmHFrO/Oc6M89/+e
/u87qT2m/Wj7QbE61nP/e3ZQHYNx9JfYPEPRs5XjPVcrIijPgW+/N51yDPSx
WpAT/T8e/dKl
             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 427, 680, 585, 708, 
          443, 703, 599, 735, 459, 613, 765, 479, 762, 623, 789, 500, 785, 
          632, 813, 517, 808, 645, 843, 535, 838, 534, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 429, 706, 586, 714, 
          445, 600, 741, 743, 461, 614, 771, 481, 787, 624, 795, 502, 811, 
          633, 821, 519, 841, 646, 849, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 432, 589, 720, 722, 
          447, 604, 749, 751, 464, 617, 777, 485, 793, 626, 801, 505, 819, 
          636, 827, 522, 649, 855, 857, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 434, 593, 728, 730, 
          449, 608, 757, 759, 466, 619, 782, 487, 799, 628, 804, 507, 639, 
          832, 834, 524, 653, 862, 864, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 435, 732, 597, 733, 
          450, 761, 611, 763, 469, 784, 621, 490, 807, 630, 809, 509, 837, 
          643, 839, 525, 867, 656, 868, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 437, 737, 602, 739, 
          452, 767, 615, 769, 471, 483, 791, 492, 815, 634, 817, 511, 845, 
          647, 847, 527, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 439, 745, 606, 747, 
          455, 468, 773, 775, 475, 489, 797, 496, 823, 637, 825, 513, 851, 
          651, 853, 530, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 724, 595, 726, 441, 453, 753, 755, 
          457, 473, 779, 781, 477, 494, 803, 498, 829, 641, 831, 515, 528, 
          859, 861, 532, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 425, 702, 426, 731, 598, 698, 442, 760, 612, 727, 
          458, 783, 622, 756, 478, 805, 631, 499, 835, 644, 806, 516, 865, 
          657, 836, 533, 887, 666, 866, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 869, 536, 520, 842, 840, 518, 503, 812, 810, 
          501, 482, 788, 786, 480, 462, 764, 460, 742, 601, 734, 444, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 856, 650, 848, 521, 508, 820, 818, 
          504, 488, 794, 792, 484, 467, 770, 463, 750, 605, 740, 446, 721, 
          590, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 863, 654, 854, 523, 833, 640, 826, 
          506, 493, 800, 798, 486, 472, 776, 465, 758, 609, 748, 448, 729, 
          594, 719, 433, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 526, 648, 846, 844, 
          510, 635, 816, 814, 491, 625, 790, 470, 616, 768, 766, 451, 603, 
          738, 736, 436, 588, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 529, 652, 852, 850, 
          512, 638, 824, 822, 495, 627, 796, 474, 774, 618, 772, 454, 607, 
          746, 744, 438, 592, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 531, 860, 655, 858, 
          514, 642, 830, 828, 497, 629, 802, 476, 780, 620, 778, 456, 754, 
          610, 752, 440, 596, 725, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJyse2k4VVEbtnkKGVIRMoZkigzhPIhMkSEalAqZKgkhIUkqkSaVIVNRijJU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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.06640625}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=10.\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643300482*^9},ExpressionUUID->"c152e57f-80a5-4f0e-a987-\
7ac2f1d7979f"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYTdsbx5eQbqUyZ0rCLTIccU1xdgNFptybXJnimEopzcYOijJHjhCN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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHfYV8URhe/ORQIEEWwRQXoRQUABKYL0SFG6gopUKYJ0AioiEUEFlWAL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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkckEMax2fmLaGTSpJUEgrpdCVyJFJUKlEq2Zwd60gUod21bh82a11F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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUFUcQRf/MQnAnuEOQ4BrcXXdxWdwdFvfg7u4EJ3hwd3f3YMGCuwZy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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 427, 680, 585, 708, 
          443, 703, 599, 735, 459, 613, 765, 479, 762, 623, 789, 500, 785, 
          632, 813, 517, 808, 645, 843, 535, 838, 534, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 429, 706, 586, 714, 
          445, 600, 741, 743, 461, 614, 771, 481, 787, 624, 795, 502, 811, 
          633, 821, 519, 841, 646, 849, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 432, 589, 720, 722, 
          447, 604, 749, 751, 464, 617, 777, 485, 793, 626, 801, 505, 819, 
          636, 827, 522, 649, 855, 857, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 434, 593, 728, 730, 
          449, 608, 757, 759, 466, 619, 782, 487, 799, 628, 804, 507, 639, 
          832, 834, 524, 653, 862, 864, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 435, 732, 597, 733, 
          450, 761, 611, 763, 469, 784, 621, 490, 807, 630, 809, 509, 837, 
          643, 839, 525, 867, 656, 868, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 437, 737, 602, 739, 
          452, 767, 615, 769, 471, 483, 791, 492, 815, 634, 817, 511, 845, 
          647, 847, 527, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 439, 745, 606, 747, 
          455, 468, 773, 775, 475, 489, 797, 496, 823, 637, 825, 513, 851, 
          651, 853, 530, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 724, 595, 726, 441, 453, 753, 755, 
          457, 473, 779, 781, 477, 494, 803, 498, 829, 641, 831, 515, 528, 
          859, 861, 532, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 425, 702, 426, 731, 598, 698, 442, 760, 612, 727, 
          458, 783, 622, 756, 478, 805, 631, 499, 835, 644, 806, 516, 865, 
          657, 836, 533, 887, 666, 866, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 869, 536, 520, 842, 840, 518, 503, 812, 810, 
          501, 482, 788, 786, 480, 462, 764, 460, 742, 601, 734, 444, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 856, 650, 848, 521, 508, 820, 818, 
          504, 488, 794, 792, 484, 467, 770, 463, 750, 605, 740, 446, 721, 
          590, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 863, 654, 854, 523, 833, 640, 826, 
          506, 493, 800, 798, 486, 472, 776, 465, 758, 609, 748, 448, 729, 
          594, 719, 433, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 526, 648, 846, 844, 
          510, 635, 816, 814, 491, 625, 790, 470, 616, 768, 766, 451, 603, 
          738, 736, 436, 588, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 529, 652, 852, 850, 
          512, 638, 824, 822, 495, 627, 796, 474, 774, 618, 772, 454, 607, 
          746, 744, 438, 592, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 531, 860, 655, 858, 
          514, 642, 830, 828, 497, 629, 802, 476, 780, 620, 778, 456, 754, 
          610, 752, 440, 596, 725, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJyUu3c41fEbPm6TlZWZLZTsEeE8ZiWpjEhIUimFNESDhkJSmSEZCRXKFtLL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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07763672}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=20.25\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646433560314`*^9},ExpressionUUID->"9338cd4e-1e89-4591-8c22-\
2b960729e4ba"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYTdsbx1dzmeriEhrMM2UI13D2Qdd8dSTzUFKuucJV11BHZUpXRSrd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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3kYUFMaxu/5biWNVEiTaFeihXaNpJSipI0sLYqUSiVRpLKnLJNCmhQa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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkcl1MWxu+9rwpFi6SFVlHZK1LK0oqKRKUQFaJRkewxMYYGw8c2xi5Z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             "]], Polygon3DBox[CompressedData["
1:eJwtlwO0HUkURV/3jz2xbdu28WPbyY+tiW07E9vGhBNNbE40se3M7LPqrvX2
qlOnqrurq6vurZesWafgED8QCOyD0HDaCwTSUX6B69CcxghBgcAT9FN4CW3x
BuINou98dH4oACkgOfShrR9tmdFLoBXXDKU+E2bp/nhpYYDdIw/6GiyjXzDl
dbgBOaEJXl/69ITZ1O/AbrxdsAVqUS8ILdAN6TMYFlDPxL3jo+NBDOiB1w2v
i8aA7o7uAX1trHPxckFu+If6bUhIWyjKl/AJCvKMzhAN3Z1+sSAmdLX7pkIP
o+QX6AYtYQiVf/EPog/BEWigZ/juHfQue6EO9QTc5yf6Edd8ga+wCH8i3iTo
CkWpP4AD6P323epS78K17eifBJ0FskIpvGx42SGn5gZvC/TmmtnU18I6CKZf
NagOFamPoU9iSASd8Trr26HjQVzNNV4LvCnotug26NbQEqbiVcYrhh6OroKu
Cr/Qt3jubbinuaGeDz8F/fpqDaELqB/1n5AXnYFyAG1F0FnRWSATDNK3wssJ
uSE1Xj+8BVqPsB09lGeUouwQ5MamMXaAGXhN8fJq3UEvmINXT++PnoCuj24A
DTUveOPxGqEbQ3t79/h4GbXOIDJEgprWfxw6NISCunbf39C10OXQo9G10XWg
OTTDawp1YSJtzfBqo+tAPfOmUE6GrehBvNsifVf6JaNMDiltHovavA1EF0MX
h6/o81xzAS5BU+orYRt6O0yActTHcd1YWI7uiFeE8g0cQx+HM9CE+hc4iz4H
V6AZ9R2KCeiFXL8BNkJonv0IrzVtYdBhYZuNv6T2u55l32uw9goMg9LUcwS5
99L7JdD+x/umPYeODZ/p1556HKiG7oPXSHNEvRLXlkGXhfI23xXxSqNLQQkY
gXeR8gL4tD3kHq3wsqGTah9BIq0PvBOUxyGUvc9VdBl0EcqiUNzWetkgV5ef
D4bilcYrjC4EOWwPlsSLrjUB9WES3m3Yyb13wDqoQf0MLEb/oXmFKtQfwh6L
F4/gscWDP/HqUf7F/Y7CNO1F2Ik3nLal6PD2nlfQT+Cp2mGH6rqWtsPoy3AJ
wtH/OV4b2p5ae0PKZ/Dcd3s0Hf3SQ0ZbcyWC3D7Vfs0NQ/BuwiquXQ0boSb1
e3AX7tvYFcMKcW1BzRdktn3+N+VJz+WgF/S7hY5oWnkoEjoyHMDfb7H2MG31
KY/DLHRFyq20bYP/9FyLPwGu8yCGvgfEtPjbgbYg9B2tcd0THtq8an5/2T3O
y9O8aI/YsypQfvddnFO8u2j77ZpiF/oNvFUM9Nye0ZrX2h8AJbQmffe99d1X
QnXtNfqegR++G1ML363F++gH8Nj2mNZ4SfqNREeFaFBeMQcqWJvW/S1YwzVr
Yb2tNeWwjrSHQFfP5UjFrkroylDDYmMNyxFj0dEhhmKF4qLF1hB0pyDnR7f4
q7ak6ISQANpZrppuMbMKuioEW6zthdcN3R16W3zWczUOjaeC53JUGkgN/Wgb
oP3lu3zUSuvfd2cRnUn6W/s8rVnIB/vhBu9+E7baOSIJ/YLo9wK+a74hD15a
yjSQynN5JiJEsDijeD4KHR7C+S4uKPcN8921yk390b7WlNY69X2ey//ax7Up
E9k5oxP6HeV7SKt8Q9kE8lssaYJXE10LGljcULxKrHnSegYPsmj/KGdam2LY
D3un7JZz++C11lwpf9ucTbW4mxD9zXPvo/eKptxMvSDE9NxZKjleOHQXzTE6
JcSC7wzjG3yy+LwbNqM3wQbb+7ssJpWhXME9VmqPo2doPdr8aJ72+C6PKx/s
hX0wXXEMbwSMhVXUF+KPRI+CMVCWek87t6TUHEF23z1Hz9MeW6Hchz6Hno+u
THkeLsAk/ImwHt2HtjnoI+hp6Kkw3vLlITioeGNjL095AKagJ8NoG8tV7X/l
Dbhs+fIDfER/gHfQjvpbOG059h28911c1jlP572jFn+j8m6v0K/hvV0bxWL1
Tcb6DJ7DbtjluRyu+x5Dv7T4qDPoK3itcSjO4jWm/ASfYZ3mEK8HdAm4c+ch
rj+o/WH9G/lOn0CfhFN2j8SMJQz9wupb2RrZYHNZnHIx3hLP5bdFeFV9l4OU
izahN2rN+O48oZgYR+dCdEeNV+8D8fDiQnzbs/oT89zePbGtzc7a45TXIbbd
47HnziY6o5ywb1/J9r7Gq3H7dr+7lHcUu2iLQPkWUqPbKidCLstvOrd7aB38
f1j+SIMXiXpkiArd8NJpzOg4EMW8DHjpIaPtO51zktnzumqdUH7UuvXdmWyM
5864Ousuw2uPNxw9V/ENTunb6Hvb3OrMsFnzCmd99x+rmu/+B/RH94NeUMx3
+XIOejbMtFy2BlbDWt/9b1C/S7Z/lJsuwxXfzeVcvHmwwPbTaMVGWGrjLEw5
3nP/M0OgE0xQvlJegsW++69YyHfxQPfSPafb3tL4l6CXwvKA+69YxM4Kv/vu
vK1z9/9a7dOg
             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 427, 680, 585, 708, 
          444, 703, 598, 735, 461, 611, 765, 483, 762, 619, 789, 503, 784, 
          629, 813, 519, 808, 643, 840, 535, 657, 869, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 429, 706, 586, 714, 
          446, 599, 741, 743, 463, 612, 771, 485, 787, 620, 795, 505, 811, 
          630, 819, 521, 644, 846, 848, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 432, 589, 720, 722, 
          448, 603, 749, 751, 467, 614, 777, 489, 793, 622, 799, 508, 633, 
          825, 827, 523, 648, 854, 856, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 434, 593, 728, 730, 
          450, 606, 757, 759, 469, 616, 782, 491, 624, 802, 804, 510, 637, 
          832, 834, 525, 652, 861, 863, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 435, 732, 596, 733, 
          452, 761, 609, 763, 472, 481, 785, 494, 807, 627, 809, 511, 837, 
          641, 838, 526, 866, 655, 867, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 437, 737, 601, 739, 
          454, 465, 767, 769, 474, 487, 791, 496, 815, 631, 817, 513, 842, 
          646, 844, 528, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 440, 451, 745, 747, 
          457, 471, 773, 775, 478, 493, 797, 499, 821, 635, 823, 515, 850, 
          650, 852, 531, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 438, 724, 726, 442, 455, 753, 755, 
          459, 476, 779, 781, 480, 497, 801, 501, 829, 639, 831, 517, 529, 
          858, 860, 533, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 425, 702, 426, 731, 597, 698, 443, 760, 610, 727, 
          460, 783, 618, 756, 482, 805, 628, 502, 835, 642, 806, 518, 864, 
          656, 836, 534, 887, 666, 865, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 868, 536, 847, 645, 839, 520, 506, 812, 810, 
          504, 486, 788, 786, 484, 464, 764, 462, 742, 600, 734, 445, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 855, 649, 845, 522, 826, 634, 818, 
          507, 492, 794, 792, 488, 470, 770, 466, 750, 604, 740, 447, 721, 
          590, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 862, 653, 853, 524, 833, 638, 824, 
          509, 803, 625, 798, 490, 475, 776, 468, 758, 607, 748, 449, 729, 
          594, 719, 433, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 527, 647, 843, 841, 
          512, 632, 816, 814, 495, 621, 790, 473, 768, 613, 766, 453, 602, 
          738, 736, 436, 588, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 530, 651, 851, 849, 
          514, 636, 822, 820, 498, 623, 796, 477, 774, 615, 772, 456, 746, 
          605, 744, 439, 592, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 532, 859, 654, 857, 
          516, 640, 830, 828, 500, 626, 800, 479, 780, 617, 778, 458, 754, 
          608, 752, 441, 725, 595, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 823, 294, 822, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 803, 265, 263, 799, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 801, 266, 800, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 785, 241, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 167, 724, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 725, 168, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          197, 745, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 746, 198, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 224, 767, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 768, 225, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 860, 859, 340, 334, 852, 332, 851, 
          326, 844, 324, 843, 318, 838, 308, 306, 834, 833, 300, 298, 827, 
          826, 292, 290, 819, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 264, 802, 268, 807, 270, 279, 814, 815, 285, 287, 820, 
          821, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 865, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 867, 346, 344, 863, 862, 338, 336, 856, 
          855, 330, 328, 848, 847, 322, 320, 840, 314, 352}], 
         Line3DBox[{315, 784, 275, 281, 810, 811, 283, 289, 818, 291, 825, 
          297, 824, 299, 832, 305, 837, 307, 317, 841, 842, 323, 325, 849, 
          850, 331, 333, 857, 339, 858, 341, 864, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 868, 355, 869, 350, 377}], 
         Line3DBox[{351, 808, 313, 319, 839, 321, 846, 327, 845, 329, 854, 
          335, 853, 337, 861, 343, 866, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0e3c4VuH/vxnKSkZFGWWXvbLeSGZRZnYRJSqyKomQpCISiYyEiEgUwm2U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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07397461}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=30.4998\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.71736464340007*^9},ExpressionUUID->"8f7736bc-5416-467a-b3f3-\
a1d1dd037a8f"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlcTN0fxw8SpUjxyFpZ4lGPki1hbvYllIxkbZGU0kaLtpnWKaSQvZQU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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3scl+MZxt/nfiuVUi0hqaSzqNBBJR1EKjpTSEcpnU8rJE1qlLScllMH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             "]], Polygon3DBox[CompressedData["
1:eJw1mHcckNMax885rwZpqCgNlaSsUhQh6pasliRRlNxUqC4aiIy7wsWHy3VV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             "]], Polygon3DBox[CompressedData["
1:eJw1lwWUFUcQRf/M4hJcAgSCu7u76wKLLu4Oi3twd3eCJ3hwd9fgGixYcLcA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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+FXXeoyEe1YsbmlVCstZWVVI6pVBhYknboLGhVF+0FI+CqE
r6GJ0XPC8JzfP2d4T94zXTvfOesLIRxyyibjXkywbee1wK5d1mMtxkI40jVd
pWYXNB/7O2dFc1TtrFY0o0sc2Iuapmwv6Dz79pzuacN3SlrVClv2uhbZsJOa
IGv/MMsXn0zxxisJ2twzRp3orpcePhWu9Jp++0abDNi32mLQvtOh6AxtE7cf
9JFh+0k7jNhdHdUWkzzzQop3Ppjhmx7LXER34+T///8Cj3IkSA==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 575, 685, 426, 680, 585, 708, 
          442, 703, 599, 735, 458, 613, 765, 478, 762, 623, 789, 499, 785, 
          632, 813, 516, 808, 645, 843, 534, 838, 533, 554}], 
         Line3DBox[{391, 572, 675, 408, 683, 576, 691, 428, 706, 586, 714, 
          444, 600, 741, 743, 460, 614, 771, 480, 787, 624, 795, 501, 811, 
          633, 821, 518, 841, 646, 849, 536, 658, 875, 556}], 
         Line3DBox[{393, 573, 677, 412, 689, 578, 695, 431, 589, 720, 722, 
          446, 604, 749, 751, 463, 617, 777, 484, 793, 626, 801, 504, 819, 
          636, 827, 521, 649, 855, 857, 539, 661, 881, 559}], 
         Line3DBox[{396, 574, 679, 414, 580, 699, 701, 433, 593, 728, 730, 
          448, 608, 757, 759, 465, 619, 782, 486, 799, 628, 804, 506, 639, 
          832, 834, 523, 653, 862, 864, 541, 663, 886, 561}], 
         Line3DBox[{397, 398, 681, 417, 671, 583, 704, 434, 732, 597, 733, 
          449, 761, 611, 763, 468, 784, 621, 489, 807, 630, 809, 508, 837, 
          643, 839, 524, 867, 656, 868, 544, 888, 665, 563}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 436, 737, 602, 739, 
          451, 767, 615, 769, 470, 482, 791, 491, 815, 634, 817, 510, 845, 
          647, 847, 526, 871, 659, 873, 546, 557, 890, 565}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 438, 745, 606, 747, 
          454, 467, 773, 775, 474, 488, 797, 495, 823, 637, 825, 512, 851, 
          651, 853, 529, 543, 877, 879, 550, 562, 892, 568}], 
         Line3DBox[{404, 420, 697, 424, 724, 595, 726, 440, 452, 753, 755, 
          456, 472, 779, 781, 476, 493, 803, 497, 829, 641, 831, 514, 527, 
          859, 861, 531, 548, 883, 885, 552, 566, 894, 570}], 
         Line3DBox[{405, 702, 584, 425, 731, 598, 698, 441, 760, 612, 727, 
          457, 783, 622, 756, 477, 805, 631, 498, 835, 644, 806, 515, 865, 
          657, 836, 532, 887, 666, 866, 553, 895, 670, 571}], 
         Line3DBox[{555, 537, 869, 535, 519, 842, 840, 517, 502, 812, 810, 
          500, 481, 788, 786, 479, 461, 764, 459, 742, 601, 734, 443, 429, 
          707, 705, 427, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{558, 542, 874, 538, 856, 650, 848, 520, 507, 820, 818, 
          503, 487, 794, 792, 483, 466, 770, 462, 750, 605, 740, 445, 721, 
          590, 713, 430, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{560, 547, 880, 540, 863, 654, 854, 522, 833, 640, 826, 
          505, 492, 800, 798, 485, 471, 776, 464, 758, 609, 748, 447, 729, 
          594, 719, 432, 700, 581, 694, 413, 394, 678, 395}], 
         Line3DBox[{564, 667, 889, 545, 660, 872, 870, 525, 648, 846, 844, 
          509, 635, 816, 814, 490, 625, 790, 469, 616, 768, 766, 450, 603, 
          738, 736, 435, 588, 711, 709, 418, 577, 686, 399}], 
         Line3DBox[{567, 668, 891, 549, 878, 662, 876, 528, 652, 852, 850, 
          511, 638, 824, 822, 494, 627, 796, 473, 774, 618, 772, 453, 607, 
          746, 744, 437, 592, 717, 715, 421, 579, 692, 401}], 
         Line3DBox[{569, 669, 893, 551, 884, 664, 882, 530, 860, 655, 858, 
          513, 642, 830, 828, 496, 629, 802, 475, 780, 620, 778, 455, 754, 
          610, 752, 439, 596, 725, 723, 423, 582, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 702, 139, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0u3k0VeHbPm7KVGTImGSIJMmcxLlDKFOmDE0yJSFKGYrIkAwhJSrK1CAl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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07519531}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=40.7497\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.71736464344661*^9},ExpressionUUID->"e20977bf-2407-42b4-a2c6-\
15d565931ab0"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlcTdsXwDcSGpQ5Q7cyRobwzLnnImQstzweIpkiQ4PoGeomKZJSSojS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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3kcV1Maxu95byUJJaRFKi0SLZKUpV0qQllTtGjRrqhIEoUsyZqkZJsy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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkYkFMWxu+9n0qUqLRKm5gwEykkSwlZUkQShTLJkhqUKGszY18ehjFE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             "]], Polygon3DBox[CompressedData["
1:eJwtlwV0VUcURf//AYq7FYfi7hrcHYJ7cAkECRZCoLi7O8XdtUCR4sWhuHvQ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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0L0uQ2EAx+FXfRVTRTtqbAwIbbTR1tiuGFGtMrCoxGSXlqhofVwIid4K
qdvQxOg5YXjO758zvG/OWWg0d89HQghHnFEm4cUs23ZO8+zZVT3RrVgIx1rS
Ig27oJuxv3PymqNub2hNs5rh0F7XNar2qq5wYC/rvl65Z0frWqNiF7VAyU5p
koz9wxJfDEjT550kXR6Y4ZLoW689XBVa2mbUvtFbxuw77TBu3+tEdIZ2mbR7
+kjcftJnpuwXndYOc7zyxjwffLLIN8PoP3ARfRun////F8TiJHU=
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 578, 685, 427, 680, 587, 708, 
          444, 703, 600, 735, 460, 614, 765, 481, 762, 623, 789, 502, 784, 
          632, 813, 519, 808, 645, 843, 537, 838, 536, 557}], 
         Line3DBox[{391, 575, 675, 408, 683, 579, 691, 429, 706, 588, 714, 
          446, 601, 741, 743, 462, 615, 771, 483, 787, 624, 795, 504, 811, 
          633, 821, 521, 841, 646, 849, 539, 658, 875, 559}], 
         Line3DBox[{393, 576, 677, 412, 689, 581, 695, 432, 591, 720, 722, 
          448, 605, 749, 751, 465, 618, 777, 487, 793, 626, 800, 507, 819, 
          636, 827, 524, 649, 855, 857, 542, 661, 881, 562}], 
         Line3DBox[{396, 577, 679, 414, 583, 699, 701, 434, 595, 728, 730, 
          450, 609, 757, 759, 467, 620, 782, 489, 628, 803, 804, 509, 639, 
          832, 834, 526, 653, 862, 864, 544, 663, 886, 564}], 
         Line3DBox[{397, 398, 681, 417, 671, 586, 704, 435, 732, 598, 733, 
          451, 761, 612, 763, 470, 479, 785, 492, 807, 630, 809, 511, 837, 
          643, 839, 527, 867, 656, 868, 547, 888, 665, 566}], 
         Line3DBox[{400, 410, 687, 419, 710, 589, 712, 437, 737, 603, 739, 
          453, 767, 616, 769, 472, 485, 791, 494, 815, 634, 817, 513, 845, 
          647, 847, 529, 871, 659, 873, 549, 560, 890, 568}], 
         Line3DBox[{402, 416, 693, 422, 716, 593, 718, 440, 745, 607, 747, 
          456, 469, 773, 775, 476, 491, 797, 498, 823, 637, 825, 515, 851, 
          651, 853, 532, 546, 877, 879, 553, 565, 892, 571}], 
         Line3DBox[{404, 420, 697, 424, 438, 725, 726, 442, 454, 753, 755, 
          458, 474, 779, 781, 478, 496, 802, 500, 829, 641, 831, 517, 530, 
          859, 861, 534, 551, 883, 885, 555, 569, 894, 573}], 
         Line3DBox[{405, 425, 702, 426, 731, 599, 698, 443, 760, 613, 727, 
          459, 783, 622, 756, 480, 805, 631, 501, 835, 644, 806, 518, 865, 
          657, 836, 535, 887, 666, 866, 556, 895, 670, 574}], 
         Line3DBox[{558, 540, 869, 538, 522, 842, 840, 520, 505, 812, 810, 
          503, 484, 788, 786, 482, 463, 764, 461, 742, 602, 734, 445, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{561, 545, 874, 541, 856, 650, 848, 523, 510, 820, 818, 
          506, 490, 794, 792, 486, 468, 770, 464, 750, 606, 740, 447, 721, 
          592, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{563, 550, 880, 543, 863, 654, 854, 525, 833, 640, 826, 
          508, 495, 799, 798, 488, 473, 776, 466, 758, 610, 748, 449, 729, 
          596, 719, 433, 700, 584, 694, 413, 394, 678, 395}], 
         Line3DBox[{567, 667, 889, 548, 660, 872, 870, 528, 648, 846, 844, 
          512, 635, 816, 814, 493, 625, 790, 471, 617, 768, 766, 452, 604, 
          738, 736, 436, 590, 711, 709, 418, 580, 686, 399}], 
         Line3DBox[{570, 668, 891, 552, 878, 662, 876, 531, 652, 852, 850, 
          514, 638, 824, 822, 497, 627, 796, 475, 774, 619, 772, 455, 608, 
          746, 744, 439, 594, 717, 715, 421, 582, 692, 401}], 
         Line3DBox[{572, 669, 893, 554, 884, 664, 882, 533, 860, 655, 858, 
          516, 642, 830, 828, 499, 629, 801, 477, 780, 621, 778, 457, 754, 
          611, 752, 441, 597, 724, 723, 423, 585, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 799, 263, 800, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 802, 266, 801, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 785, 241, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 167, 725, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 724, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 264, 803, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 784, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0u3c81f/7P27vvROy90hly2VkZEalIhEKZRRJqIwKWSVUCKWoJJRk97Cy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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.06323242}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=50.9995\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643492146*^9},ExpressionUUID->"6e03393c-bdcc-42a8-babf-\
f70bf51e2a78"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XHlcTdv7XkKKEFGdLsqQKTO5XcPZoVCOb4nMU8hMZKacRBpvgzE0lyGi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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3scl+MZxt/nfiuVUi0hqaSzqNBBJR1EKjpTSEcpnU8rJE1qlLScllMH
lrERazMhaz5JrBVziJm2loZFzKzFMrPv9bmeP67Pdf3u3/M+x/t+7vtpNHb6
4GlRFMWoVBQlvB6uAt8Nf58/qsKn8MdnyboxuhrckTaV4RG0eQn9GTwKNEW/
jP1M9HB0M/geMBRdD54PVwfzQBvadYFPhyuBDuiA7wfXoZ+i/TxQk99NGbch
uj/2WvCp2PqiT4Nbgu7oxnAj0E1jwTfS7jz0d+jRYBC6MzwRPge0R38A/oc+
XotHt4f+C2bzbSf4c2wHtSfgZNpciP027FvgHuF5PqlxQC30I7SbBtcA08Fd
2Mdjm8C3XdGT1QY+F0xFPwr3AjejN8PL4aqFx/g5qA9+Ab4GZ4H3wBNaq8YF
z4CGYAVYktz/evWHvhr9MHolXAfMAhvBsdpbcBM4BiwAi8AJYHH2gSXwc3zb
MHkf6sMXhO3PwiuS1/cz9CK0fGhxsh6PfijPoRp6lXypsJ4J3gctwdPad/47
W/OA5/NNA7gte3Ux3At7P/iH2Hvq/LAvR1+EHoq+Kew7XdE/Qg9BX45egR6E
vhT9LvypfBW9DHtffg9Hd0AvlI+gb8t9XoK+Bv0h7avkPofKx9Hj4MHYR8Iz
wj5SG/sd6CuwjUFP1nywv8Hvo8Ltjw/PZzC2UbS5H30teiz6j3Bz2rwKr8R+
GTwO+3DNBfvl2S6+Cvst8jP0xegD/N9WcVe4n4Pw0dh3offKh2l7nPYG/RWY
yO99sIL8+vB5tkHvwdQEvAX+A1qDf4K6/H+u1gjvUJyBneAIaAcOgzcLr/dt
MJo+fw//G35VcQ9eA9v4fpf6xH4Ourf8L/lcFO8fJse47oEv0UvDcV0FnhmO
zeOY59TwvGqirw6vsUQfglvoW/CHwvv5Dvig8F30V/APcAb4FxjEt49oz+BN
8Ilgg/aa37+B98ETtMeF47Yuv6+STzPWGPiiwud0N/ardZdgnxAe5zu4jvwB
fWrYV9VPTXhg8h04OK+xDzyMbzvCA7HPg99K3rftcP/ku07+VyP79hW074e+
Vz4DPwg3AmtAn/AdsE2+HF7Xr5LjtBL6dnhZ8p3zU/6/FD0APQK+PcfLSPpv
C5+PvQN8Z1775NLrku9fgK4lLuz3XUFP3U3w6hxTC2jzIHoM9o5wY30rf5UP
hO+ln4TvK+WCB+Bb5XNgGejNf0vhtXC38J2xDp4tHy98v0xLzi+zkvPLJHhm
6bFmKEbRTfQtejb6Vt2z2tMc4/Ln15UrwIXoTvJN0AfdA/57cnz9SfuRnEcU
ew8ohyk/0c8c+LLC8Xx6tl+P/UrdQ7pf9Vv3EHpu8rq0vhfhOeH82ZD2G+Af
Y39JfgLqoX+NbT18is5Le6S7BNwDFtGmteKTbxeiW6G7o4egH5P/h/NUbd3P
/Lc2+dsntZaca56Rb4LVipvsM/KrV+A75LOFz0D5XXPYov1Gb1bMysfBFsUZ
/Bx8svwN/Lbw/BVL6l855SnFO9wA7JZP53nuhu9SfMs/C/cvf36B9vcVzqer
tIbCa3m08B2u2BnIetfBC7VX4dz0PbVJ3sN16F3wsMjzggdk+2u6j/M98Drc
PxxDb4TndhJ6U7Jd+/O78BlpjZvhvuHz2gE/VHjctYXjS/l0dXJtoD18OO//
jehfhuNXa9quGAzn9ufD56Lc+0K4ltC6noZ7hr/dBHdX7tA+h+Nde/ZYjhHl
9g3wfcltngj7g/bs7WzXPj+enEcUCwPYwzVhP12Y79VWtNmZnB/l2y3g53Wf
aW7gknDd8WfFd77zD8JXgm3oz/Vd9pO/hONimPw4fL99hK7IWOPDfe5IPgv5
+Ht5T1SbvJ/70ZgfZX9TntqafO6V0Xcm96Oa6Ntw/bkd/Qn8SuFzfBmMzPZP
w/PXfb8n+4ZqkL3heqwienlyrlQe3J18tytvJuZ8XziOry3dp/o+oDsynHPe
hReAZrTplNuP0t0Yzvu64+flPR+HvUs4P6rGezbfLaPR7cL5SPG1P/evuPla
30XO1fB+uA34GEwK720F+n8zuYaJ0mekvH04XBsod++FVfQrHx6Cp4fz+RF4
bDhff5G1cviX+XxV5/8N3lrYT3TezemrM9wUXhWuW+rDM+AzC9fuuoeVa2qH
87jeDgewTwnXLVVz7aQ67ZjSdtU11Urnpn7oo+X74XqkVun5K+fXQO/D9i36
2NL3dgXtKfrj5LfAV8lrVB1Up3RdoZrzk+Q6X+1PKp3vhmA/IZxzlQcj3E8J
Tixd+2msenlc1UiHkusf1eQvomeF2zcq7Q/am47oxeG82qz020r79kXy+6K7
zjQ5L+it0YQ21XWPaI3w3HCN3Bz7knC+alH63HX+lfK56/2yP3mvVGedXrp+
Vk7rgz6stYLTch2oevuM0rV3T8VRck7RuEfyuBq/JW2+0bzkQ6XfVvLzs3P9
rDp9SO5f+bQituvCY7XP9cAC9PzSPqya8Zt8v+n9sRG+N5yvZ9GmgXwOe+tw
ja06pRf2m8O1xvk5p6seqx5+n6rG25P8plNcvJP8DtW4N9D+hvD8u5Suz/Wm
6JvXpbxfOVzXKV83CtcqehbekrwWvSlb5X701jyr9J2st+zj4XPR+7JffutV
wL5Uc0j24XbJ8xf3Ll2LqubZmPwG1JtxTfL79yj0StUF2KcoXkvnL+WZnWH7
ZMVQ6bhTzTM3v4lUG3TTWzXZn/Xm0d6qVppTOn+pjtgKT0y+n6dkv9X7u25+
a6v/qdlv9VY+r3Q9PELxHz4j1V2TsP8g/BbvUbo+0dsthd+/qpOvyW1Uq3Qu
XSuOpU0n+P+219ff
             "]], Polygon3DBox[CompressedData["
1:eJw1mHcckNMax885rwZpqCgNlaSsUhQh6pasliRRlNxUqC4aiIy7wsWHy3VV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             "]], Polygon3DBox[CompressedData["
1:eJw1lwWUFUcQRf/M4hJcAgSCu7u76wKLLu4Oi3twd3eCJ3hwd9fgGixYcLcA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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+FXXeoyEe1YsbmlVCstZWVVI6pVBhYknboLGhVF+0FI+CqE
r6GJ0XPC8JzfP2d4T94zXTvfOesLIRxyyibjXkywbee1wK5d1mMtxkI40jVd
pWYXNB/7O2dFc1TtrFY0o0sc2Iuapmwv6Dz79pzuacN3SlrVClv2uhbZsJOa
IGv/MMsXn0zxxisJ2twzRp3orpcePhWu9Jp++0abDNi32mLQvtOh6AxtE7cf
9JFh+0k7jNhdHdUWkzzzQop3Ppjhmx7LXER34+T///8Cj3IkSA==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 575, 685, 426, 680, 585, 708, 
          442, 703, 599, 735, 458, 613, 765, 478, 762, 623, 789, 499, 785, 
          632, 813, 516, 808, 645, 843, 534, 838, 533, 554}], 
         Line3DBox[{391, 572, 675, 408, 683, 576, 691, 428, 706, 586, 714, 
          444, 600, 741, 743, 460, 614, 771, 480, 787, 624, 795, 501, 811, 
          633, 821, 518, 841, 646, 849, 536, 658, 875, 556}], 
         Line3DBox[{393, 573, 677, 412, 689, 578, 695, 431, 589, 720, 722, 
          446, 604, 749, 751, 463, 617, 777, 484, 793, 626, 801, 504, 819, 
          636, 827, 521, 649, 855, 857, 539, 661, 881, 559}], 
         Line3DBox[{396, 574, 679, 414, 580, 699, 701, 433, 593, 728, 730, 
          448, 608, 757, 759, 465, 619, 782, 486, 799, 628, 804, 506, 639, 
          832, 834, 523, 653, 862, 864, 541, 663, 886, 561}], 
         Line3DBox[{397, 398, 681, 417, 671, 583, 704, 434, 732, 597, 733, 
          449, 761, 611, 763, 468, 784, 621, 489, 807, 630, 809, 508, 837, 
          643, 839, 524, 867, 656, 868, 544, 888, 665, 563}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 436, 737, 602, 739, 
          451, 767, 615, 769, 470, 482, 791, 491, 815, 634, 817, 510, 845, 
          647, 847, 526, 871, 659, 873, 546, 557, 890, 565}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 438, 745, 606, 747, 
          454, 467, 773, 775, 474, 488, 797, 495, 823, 637, 825, 512, 851, 
          651, 853, 529, 543, 877, 879, 550, 562, 892, 568}], 
         Line3DBox[{404, 420, 697, 424, 724, 595, 726, 440, 452, 753, 755, 
          456, 472, 779, 781, 476, 493, 803, 497, 829, 641, 831, 514, 527, 
          859, 861, 531, 548, 883, 885, 552, 566, 894, 570}], 
         Line3DBox[{405, 702, 584, 425, 731, 598, 698, 441, 760, 612, 727, 
          457, 783, 622, 756, 477, 805, 631, 498, 835, 644, 806, 515, 865, 
          657, 836, 532, 887, 666, 866, 553, 895, 670, 571}], 
         Line3DBox[{555, 537, 869, 535, 519, 842, 840, 517, 502, 812, 810, 
          500, 481, 788, 786, 479, 461, 764, 459, 742, 601, 734, 443, 429, 
          707, 705, 427, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{558, 542, 874, 538, 856, 650, 848, 520, 507, 820, 818, 
          503, 487, 794, 792, 483, 466, 770, 462, 750, 605, 740, 445, 721, 
          590, 713, 430, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{560, 547, 880, 540, 863, 654, 854, 522, 833, 640, 826, 
          505, 492, 800, 798, 485, 471, 776, 464, 758, 609, 748, 447, 729, 
          594, 719, 432, 700, 581, 694, 413, 394, 678, 395}], 
         Line3DBox[{564, 667, 889, 545, 660, 872, 870, 525, 648, 846, 844, 
          509, 635, 816, 814, 490, 625, 790, 469, 616, 768, 766, 450, 603, 
          738, 736, 435, 588, 711, 709, 418, 577, 686, 399}], 
         Line3DBox[{567, 668, 891, 549, 878, 662, 876, 528, 652, 852, 850, 
          511, 638, 824, 822, 494, 627, 796, 473, 774, 618, 772, 453, 607, 
          746, 744, 437, 592, 717, 715, 421, 579, 692, 401}], 
         Line3DBox[{569, 669, 893, 551, 884, 664, 882, 530, 860, 655, 858, 
          513, 642, 830, 828, 496, 629, 802, 475, 780, 620, 778, 455, 754, 
          610, 752, 439, 596, 725, 723, 423, 582, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 702, 139, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 767, 224, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 768, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0unc81f///29lZ1NWVkRGRma4yyhUklWSkbJKiZJVZBWpREhKysooRURG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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07299805}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=61.2494\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643535686*^9},ExpressionUUID->"7e56f6d8-c7d5-405c-b480-\
380c34ac6bb1"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxtXHlcjdv33oWE0DwoDeY5kjH3vCGEEknGe8sYcglRCpXipGiQBooy5F5j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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHv8j+UZx+9DThlJyMjh5xBCrZRRC5FQDVHGMKeIWjnkkEOY1iadrFRq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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkYkFMWxu+9X1FJaZdKC0pFkpCKqVAjRClbEYVJi4jKNEOMmTHDPGaY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             "]], Polygon3DBox[CompressedData["
1:eJxNlgPQnUcYhe/9bmzbaGzbtm3b+ZM/tm0njW2nUdvYtm07TZ8z+3amM/eZ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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vA3EAx/Fr66FIJITBorExiV6jimJibW1oi+qsJrp2aDwVUbwNknor
pN5GJXafC8Mn398Nd/e/m6vWd09jQRAc0zLieqlXJOxrvWHAvtU2g/adDum9
PjBsP2qHpP2kz4zYLzoaPYspXnljlg8+mafPN2nG3bOuoWbYtvd0n4J9rhfR
td3Ums44/Ilu6SZVe0Pz8b/vW9NVjuycHmpWl6nYGQ0pR2fQJUr2oh5ow3uK
WtYSO/aKZsnbkzpBaP+wwBc9UrzTZTr6f7QZ44zY////BUgqJLw=
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{389, 386, 672, 407, 671, 579, 685, 428, 680, 588, 706, 
          445, 702, 601, 735, 462, 614, 765, 482, 761, 624, 790, 503, 784, 
          632, 813, 521, 805, 645, 841, 540, 837, 538, 559}], 
         Line3DBox[{392, 577, 674, 410, 687, 581, 690, 431, 708, 590, 713, 
          447, 603, 740, 742, 465, 616, 770, 486, 792, 626, 795, 506, 815, 
          635, 820, 524, 843, 647, 848, 543, 658, 874, 562}], 
         Line3DBox[{394, 578, 676, 412, 683, 584, 696, 433, 594, 721, 723, 
          449, 608, 750, 752, 467, 620, 776, 488, 788, 628, 799, 508, 811, 
          639, 828, 526, 651, 856, 858, 545, 662, 880, 564}], 
         Line3DBox[{396, 406, 677, 415, 427, 693, 695, 435, 444, 718, 720, 
          451, 461, 747, 749, 469, 481, 775, 491, 807, 633, 798, 510, 520, 
          825, 827, 528, 539, 853, 855, 547, 558, 879, 567}], 
         Line3DBox[{397, 582, 678, 418, 704, 591, 700, 436, 733, 605, 729, 
          452, 763, 617, 758, 472, 786, 484, 494, 809, 636, 803, 512, 839, 
          648, 834, 529, 868, 659, 864, 550, 889, 560, 569}], 
         Line3DBox[{399, 413, 679, 420, 711, 592, 699, 438, 738, 606, 728, 
          454, 768, 618, 757, 474, 489, 781, 496, 818, 637, 802, 514, 846, 
          649, 833, 531, 872, 660, 863, 552, 565, 885, 571}], 
         Line3DBox[{402, 417, 692, 423, 715, 596, 717, 440, 744, 610, 746, 
          457, 471, 772, 774, 477, 493, 797, 499, 822, 640, 824, 516, 850, 
          653, 852, 534, 549, 876, 878, 555, 568, 892, 574}], 
         Line3DBox[{404, 421, 698, 425, 725, 598, 727, 442, 455, 754, 756, 
          459, 475, 778, 780, 479, 497, 801, 501, 830, 642, 832, 518, 532, 
          860, 862, 536, 553, 882, 884, 557, 572, 894, 576}], 
         Line3DBox[{405, 701, 587, 400, 730, 600, 731, 388, 759, 613, 760, 
          426, 782, 623, 783, 443, 804, 631, 460, 835, 644, 836, 480, 865, 
          656, 866, 502, 886, 665, 887, 519, 895, 670, 537}], 
         Line3DBox[{561, 541, 870, 542, 522, 844, 842, 523, 504, 816, 814, 
          505, 483, 793, 791, 485, 463, 766, 464, 741, 604, 736, 446, 429, 
          709, 707, 430, 408, 688, 686, 409, 387, 673, 391}], 
         Line3DBox[{563, 548, 869, 544, 857, 652, 840, 525, 511, 812, 810, 
          507, 492, 789, 787, 487, 470, 764, 466, 751, 609, 734, 448, 722, 
          595, 705, 432, 416, 684, 682, 411, 390, 675, 393}], 
         Line3DBox[{566, 666, 888, 546, 854, 657, 867, 527, 826, 646, 838, 
          509, 634, 808, 806, 490, 625, 785, 468, 748, 615, 762, 450, 719, 
          602, 732, 434, 694, 589, 703, 414, 580, 681, 395}], 
         Line3DBox[{570, 667, 890, 551, 661, 873, 871, 530, 650, 847, 845, 
          513, 638, 819, 817, 495, 627, 794, 473, 619, 769, 767, 453, 607, 
          739, 737, 437, 593, 712, 710, 419, 583, 689, 398}], 
         Line3DBox[{573, 668, 891, 554, 877, 663, 875, 533, 654, 851, 849, 
          515, 641, 823, 821, 498, 629, 796, 476, 773, 621, 771, 456, 611, 
          745, 743, 439, 597, 716, 714, 422, 585, 691, 401}], 
         Line3DBox[{575, 669, 893, 556, 883, 664, 881, 535, 861, 655, 859, 
          517, 643, 831, 829, 500, 630, 800, 478, 779, 622, 777, 458, 755, 
          612, 753, 441, 599, 726, 724, 424, 586, 697, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{112, 101, 672, 103, 673, 102, 674, 104, 675, 105, 676, 
          106, 681, 113, 677, 107, 118, 678, 108, 689, 121, 679, 109, 691, 
          124, 692, 125, 697, 130, 698, 131, 701, 136, 137}], 
         Line3DBox[{140, 671, 110, 114, 686, 687, 116, 119, 682, 683, 122, 
          126, 703, 142, 693, 128, 704, 148, 132, 710, 711, 152, 134, 714, 
          715, 156, 158, 724, 725, 164, 166, 730, 172, 174}], 
         Line3DBox[{175, 731, 173, 167, 727, 165, 726, 159, 717, 157, 716, 
          135, 699, 153, 712, 133, 700, 149, 129, 695, 694, 143, 127, 696, 
          123, 684, 120, 690, 117, 688, 115, 685, 111, 141}], 
         Line3DBox[{178, 680, 138, 144, 707, 708, 146, 150, 705, 154, 721, 
          160, 732, 180, 718, 162, 733, 186, 168, 737, 738, 190, 170, 743, 
          744, 194, 196, 753, 202, 754, 204, 759, 210, 212}], 
         Line3DBox[{213, 760, 211, 205, 756, 755, 203, 197, 746, 195, 745, 
          171, 728, 191, 739, 169, 729, 187, 163, 720, 719, 181, 161, 723, 
          722, 155, 151, 713, 147, 709, 145, 706, 139, 179}], 
         Line3DBox[{215, 702, 176, 182, 736, 184, 740, 188, 734, 192, 750, 
          198, 762, 217, 747, 200, 763, 221, 206, 767, 768, 224, 208, 771, 
          227, 772, 229, 777, 233, 778, 235, 782, 239, 241}], 
         Line3DBox[{242, 783, 240, 236, 780, 779, 234, 230, 774, 773, 228, 
          209, 757, 225, 769, 207, 758, 222, 201, 749, 748, 218, 199, 752, 
          751, 193, 189, 742, 741, 185, 183, 735, 177, 216}], 
         Line3DBox[{245, 214, 765, 219, 766, 220, 770, 223, 764, 226, 776, 
          231, 785, 246, 775, 232, 786, 251, 237, 794, 254, 781, 238, 796, 
          257, 797, 258, 800, 263, 801, 264, 804, 269, 270}], 
         Line3DBox[{273, 761, 243, 247, 791, 792, 249, 252, 787, 788, 255, 
          259, 806, 807, 275, 261, 809, 281, 265, 817, 818, 285, 267, 821, 
          822, 289, 291, 829, 830, 297, 299, 835, 305, 307}], 
         Line3DBox[{308, 836, 306, 300, 832, 298, 831, 292, 824, 290, 823, 
          268, 802, 286, 819, 266, 803, 282, 262, 798, 276, 808, 260, 799, 
          256, 789, 253, 795, 250, 793, 248, 790, 244, 274}], 
         Line3DBox[{311, 784, 271, 277, 814, 815, 279, 283, 810, 811, 287, 
          293, 838, 313, 825, 295, 839, 319, 301, 845, 846, 323, 303, 849, 
          850, 327, 329, 859, 335, 860, 337, 865, 343, 345}], 
         Line3DBox[{346, 866, 344, 338, 862, 861, 336, 330, 852, 328, 851, 
          304, 833, 324, 847, 302, 834, 320, 296, 827, 826, 314, 294, 828, 
          288, 812, 284, 820, 280, 816, 278, 813, 272, 312}], 
         Line3DBox[{348, 805, 309, 315, 842, 843, 317, 321, 840, 325, 856, 
          331, 867, 350, 853, 333, 868, 354, 339, 871, 872, 357, 341, 875, 
          360, 876, 362, 881, 366, 882, 368, 886, 372, 374}], 
         Line3DBox[{375, 887, 373, 369, 884, 883, 367, 363, 878, 877, 361, 
          342, 863, 358, 873, 340, 864, 355, 334, 855, 854, 351, 332, 858, 
          857, 326, 322, 848, 318, 844, 316, 841, 310, 349}], 
         Line3DBox[{376, 837, 347, 352, 870, 353, 874, 356, 869, 359, 880, 
          364, 888, 377, 879, 365, 889, 378, 370, 890, 379, 885, 371, 891, 
          380, 892, 381, 893, 382, 894, 383, 895, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJwsXHc819/3VzRQsspI2SPKDkmOvTIyIjNEVCQklJVRSmRk7y2izOyblZGI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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.04125977}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=71.2498\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646435782185`*^9},ExpressionUUID->"32eb7425-88ad-4f7b-a805-\
00c5b7978309"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJxtXHlYjVsX3ymVJAkVToN5CBmua25ndg2dkDHURWZXxoy344gyNClRhsqY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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJw1l3n8SFUaxs85l1CSkCLbzz4koqGG7CFM1pAsIdIoPxpLJO2LlFJNpkWk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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkYkMMWxmfmI4lU2lBpJSkpS5ZE0iKRZMuWdEuJVJaLsnUt1+O66vFY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             "]], Polygon3DBox[CompressedData["
1:eJwtlwPUXTkUhd+9r5h6akxt27Zt27Zt25x2alsztW1j2qlta769ctb6v5Wd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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0L0uQ2EAx+HTlvpKJBpNOmlsDEL6kSJtbbpWN7RUmTFp1w5UUUFdBwm3
QrgNErvnhOHJ73+Gk/ecd751UjuOBEFwwLkR1QvtEbMvtc+IfaXXjNo3GteB
3jJm3+k94/aDDpmwH3VS+8zyxDNzvPHOAl98k2HaO0XNao5Ne1t3qNpn2g6f
7a4eacrHH+qGlmnZJS1G//5vXddo2gXd17zm2AvP0gwNe0WXqdtLuqsd52xp
Q+tU7FUtULITOkPW/mGRTz5I88oLyfDewjtkilMi//f/CymSJJk=
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{389, 386, 672, 405, 681, 577, 683, 427, 701, 585, 705, 
          444, 732, 598, 734, 462, 610, 765, 482, 785, 620, 787, 503, 804, 
          629, 808, 519, 835, 643, 839, 538, 868, 537, 557}], 
         Line3DBox[{391, 576, 674, 408, 686, 579, 688, 429, 708, 588, 711, 
          447, 600, 738, 740, 465, 612, 769, 485, 790, 622, 793, 505, 813, 
          632, 816, 521, 842, 646, 845, 541, 656, 873, 560}], 
         Line3DBox[{393, 406, 675, 412, 703, 586, 690, 433, 445, 715, 717, 
          450, 463, 744, 746, 469, 483, 773, 489, 806, 630, 795, 508, 837, 
          644, 820, 525, 539, 849, 851, 545, 558, 877, 563}], 
         Line3DBox[{395, 410, 676, 415, 431, 692, 694, 435, 448, 721, 723, 
          452, 467, 750, 752, 471, 487, 775, 491, 810, 633, 797, 510, 523, 
          824, 826, 527, 543, 855, 857, 547, 561, 879, 565}], 
         Line3DBox[{396, 413, 677, 417, 710, 590, 671, 436, 737, 603, 680, 
          453, 768, 614, 700, 472, 792, 624, 493, 815, 635, 763, 511, 844, 
          648, 784, 528, 872, 658, 803, 548, 890, 666, 567}], 
         Line3DBox[{398, 416, 678, 420, 713, 591, 698, 438, 742, 604, 729, 
          455, 771, 615, 760, 475, 492, 781, 496, 818, 636, 801, 513, 847, 
          649, 832, 530, 875, 659, 865, 551, 566, 885, 570}], 
         Line3DBox[{401, 418, 679, 423, 719, 593, 697, 440, 748, 606, 728, 
          458, 473, 757, 759, 478, 494, 780, 499, 822, 638, 800, 515, 853, 
          651, 831, 533, 549, 862, 864, 554, 568, 884, 573}], 
         Line3DBox[{403, 421, 696, 425, 725, 595, 727, 442, 456, 754, 756, 
          460, 476, 777, 779, 480, 497, 799, 501, 828, 640, 830, 517, 531, 
          859, 861, 535, 552, 881, 883, 556, 571, 894, 575}], 
         Line3DBox[{404, 699, 584, 399, 730, 597, 731, 388, 761, 609, 762, 
          426, 782, 619, 783, 443, 802, 628, 461, 833, 642, 834, 481, 866, 
          654, 867, 502, 886, 663, 887, 518, 895, 670, 536}], 
         Line3DBox[{559, 542, 871, 540, 522, 843, 841, 520, 506, 814, 812, 
          504, 486, 791, 789, 484, 466, 767, 464, 739, 601, 736, 446, 430, 
          709, 707, 428, 409, 687, 685, 407, 387, 673, 390}], 
         Line3DBox[{562, 664, 888, 544, 850, 655, 869, 524, 645, 838, 836, 
          507, 631, 807, 805, 488, 621, 786, 468, 745, 611, 764, 449, 716, 
          599, 733, 432, 587, 704, 702, 411, 578, 682, 392}], 
         Line3DBox[{564, 665, 889, 546, 856, 657, 870, 526, 825, 647, 840, 
          509, 634, 811, 809, 490, 623, 788, 470, 751, 613, 766, 451, 722, 
          602, 735, 434, 693, 589, 706, 414, 580, 684, 394}], 
         Line3DBox[{569, 667, 891, 550, 660, 876, 874, 529, 650, 848, 846, 
          512, 637, 819, 817, 495, 625, 794, 474, 616, 772, 770, 454, 605, 
          743, 741, 437, 592, 714, 712, 419, 581, 689, 397}], 
         Line3DBox[{572, 668, 892, 553, 863, 661, 878, 532, 652, 854, 852, 
          514, 639, 823, 821, 498, 626, 796, 477, 758, 617, 774, 457, 607, 
          749, 747, 439, 594, 720, 718, 422, 582, 691, 400}], 
         Line3DBox[{574, 669, 893, 555, 882, 662, 880, 534, 860, 653, 858, 
          516, 641, 829, 827, 500, 627, 798, 479, 778, 618, 776, 459, 755, 
          608, 753, 441, 596, 726, 724, 424, 583, 695, 402}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{112, 101, 672, 103, 673, 102, 674, 104, 682, 115, 675, 
          105, 684, 118, 676, 106, 121, 677, 107, 689, 124, 678, 108, 691, 
          127, 679, 109, 695, 130, 696, 131, 699, 136, 137}], 
         Line3DBox[{140, 681, 110, 113, 685, 686, 116, 119, 702, 703, 144, 
          122, 706, 148, 692, 125, 710, 152, 128, 712, 713, 156, 132, 718, 
          719, 160, 134, 724, 725, 164, 166, 730, 172, 174}], 
         Line3DBox[{175, 731, 173, 167, 727, 165, 726, 135, 697, 161, 720, 
          133, 698, 157, 714, 129, 671, 153, 126, 694, 693, 149, 123, 690, 
          145, 704, 120, 688, 117, 687, 114, 683, 111, 141}], 
         Line3DBox[{178, 701, 138, 142, 707, 708, 146, 150, 733, 182, 715, 
          154, 735, 186, 721, 158, 737, 190, 162, 741, 742, 194, 168, 747, 
          748, 198, 170, 753, 202, 754, 204, 761, 210, 212}], 
         Line3DBox[{213, 762, 211, 205, 756, 755, 203, 171, 728, 199, 749, 
          169, 729, 195, 743, 163, 680, 191, 159, 723, 722, 187, 155, 717, 
          716, 183, 151, 711, 147, 709, 143, 705, 139, 179}], 
         Line3DBox[{215, 732, 176, 180, 736, 184, 738, 188, 764, 218, 744, 
          192, 766, 221, 750, 196, 768, 224, 200, 770, 771, 227, 206, 774, 
          230, 757, 208, 776, 233, 777, 235, 782, 239, 241}], 
         Line3DBox[{242, 783, 240, 236, 779, 778, 234, 209, 759, 758, 231, 
          207, 760, 228, 772, 201, 700, 225, 197, 752, 751, 222, 193, 746, 
          745, 219, 189, 740, 739, 185, 181, 734, 177, 216}], 
         Line3DBox[{245, 214, 765, 217, 767, 220, 769, 223, 786, 248, 773, 
          226, 788, 251, 775, 229, 792, 254, 232, 794, 257, 781, 237, 796, 
          260, 780, 238, 798, 263, 799, 264, 802, 269, 270}], 
         Line3DBox[{273, 785, 243, 246, 789, 790, 249, 252, 805, 806, 277, 
          255, 809, 810, 281, 258, 815, 285, 261, 817, 818, 289, 265, 821, 
          822, 293, 267, 827, 828, 297, 299, 833, 305, 307}], 
         Line3DBox[{308, 834, 306, 300, 830, 298, 829, 268, 800, 294, 823, 
          266, 801, 290, 819, 262, 763, 286, 259, 797, 282, 811, 256, 795, 
          278, 807, 253, 793, 250, 791, 247, 787, 244, 274}], 
         Line3DBox[{311, 804, 271, 275, 812, 813, 279, 283, 836, 837, 315, 
          287, 840, 319, 824, 291, 844, 323, 295, 846, 847, 327, 301, 852, 
          853, 331, 303, 858, 335, 859, 337, 866, 343, 345}], 
         Line3DBox[{346, 867, 344, 338, 861, 860, 336, 304, 831, 332, 854, 
          302, 832, 328, 848, 296, 784, 324, 292, 826, 825, 320, 288, 820, 
          316, 838, 284, 816, 280, 814, 276, 808, 272, 312}], 
         Line3DBox[{348, 835, 309, 313, 841, 842, 317, 321, 869, 351, 849, 
          325, 870, 354, 855, 329, 872, 357, 333, 874, 875, 360, 339, 878, 
          363, 862, 341, 880, 366, 881, 368, 886, 372, 374}], 
         Line3DBox[{375, 887, 373, 369, 883, 882, 367, 342, 864, 863, 364, 
          340, 865, 361, 876, 334, 803, 358, 330, 857, 856, 355, 326, 851, 
          850, 352, 322, 845, 318, 843, 314, 839, 310, 349}], 
         Line3DBox[{376, 868, 347, 350, 871, 353, 873, 356, 888, 377, 877, 
          359, 889, 378, 879, 362, 890, 379, 365, 891, 380, 885, 370, 892, 
          381, 884, 371, 893, 382, 894, 383, 895, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJxsm3c4l+/3wJVRCiUjJNnZK7LimJnJDNkUKjKSSvaWvUIZGSFR9ojcRlS2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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.04980469}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=81.2504\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.71736464362325*^9},ExpressionUUID->"13267bf3-0451-4ccc-b1e6-\
f787b6dad6dd"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XHlcTdv7XjKVqTQIoYTKHJnJCmkgSklcrsI3ZAwhFedUVMaiKEMqU+a6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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3v8UPMZx8/3OVS6TEg23fxKF6mkVMqtG1KayrqolK66qiZdSOWWWy4h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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkcUFMWx++9r1VK0qqSVArZYkiLIipSKEQhSgymsqUwyT6MMY1tmMmU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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUVTcQht+7rzgULW6Lu7u7u7ssusviFHd3d/cixd3d3Z3iLsUp0NLv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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0L0uQ2EAx+HTlpZadazGhhbVFh1qbde2qcW3MgoJbqBJpYSERELqYyXh
Vgg3QuIOPCcMT37/5Zz3vGe8fdDcjwRBsE3PiOqpnhGzz/WCAftSrxi0rzWu
N3pLwu7rHUP2vT4wbD9qUjuM8sQzY7zxzgRffFMg7pmKZjVH1W5ok7p9qEes
hO/VXU37+B2d0zxte0ano3/3y+oUW/akbmpZF9mwF3SedbukRdbC79FVPXZO
Q5e1Rc3O6yxLdjK8L0X7JzyDTz7I8MoLKU7oMsIekf///wv1+yPj
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{391, 386, 677, 414, 676, 576, 698, 435, 697, 585, 725, 
          452, 724, 598, 752, 469, 611, 782, 490, 781, 620, 803, 510, 802, 
          630, 831, 526, 830, 644, 857, 542, 658, 885, 562}], 
         Line3DBox[{393, 388, 681, 417, 679, 577, 702, 438, 700, 586, 727, 
          454, 599, 754, 756, 472, 612, 786, 493, 784, 621, 807, 513, 805, 
          631, 833, 528, 645, 859, 861, 545, 659, 886, 564}], 
         Line3DBox[{396, 572, 685, 420, 683, 578, 704, 440, 587, 729, 731, 
          456, 601, 758, 760, 475, 613, 790, 496, 788, 622, 809, 515, 632, 
          835, 837, 530, 647, 863, 865, 548, 660, 887, 566}], 
         Line3DBox[{400, 574, 687, 422, 579, 706, 708, 442, 589, 733, 735, 
          458, 603, 762, 764, 478, 614, 792, 498, 623, 811, 813, 517, 634, 
          839, 841, 532, 649, 867, 869, 551, 661, 888, 568}], 
         Line3DBox[{403, 575, 688, 394, 671, 581, 709, 423, 675, 591, 736, 
          443, 696, 605, 765, 459, 615, 793, 479, 751, 625, 814, 499, 780, 
          636, 842, 518, 801, 651, 870, 533, 829, 552, 553}], 
         Line3DBox[{407, 424, 690, 398, 711, 592, 713, 426, 738, 606, 740, 
          445, 480, 767, 769, 461, 500, 795, 482, 816, 637, 818, 502, 844, 
          652, 846, 520, 872, 662, 874, 535, 569, 890, 555}], 
         Line3DBox[{410, 427, 692, 402, 715, 594, 717, 429, 462, 742, 744, 
          447, 483, 771, 773, 464, 503, 797, 485, 820, 639, 822, 505, 848, 
          654, 850, 522, 556, 876, 878, 537, 570, 892, 558}], 
         Line3DBox[{412, 430, 694, 405, 448, 719, 721, 432, 465, 746, 748, 
          450, 486, 775, 777, 467, 506, 799, 488, 824, 641, 826, 508, 538, 
          852, 854, 524, 559, 880, 882, 540, 571, 894, 561}], 
         Line3DBox[{413, 433, 695, 408, 722, 597, 723, 389, 749, 610, 750, 
          434, 778, 619, 779, 451, 800, 629, 468, 827, 643, 828, 489, 855, 
          657, 856, 509, 883, 666, 884, 525, 895, 670, 541}], 
         Line3DBox[{554, 667, 889, 534, 663, 873, 871, 519, 653, 845, 843, 
          501, 638, 817, 815, 481, 626, 794, 460, 768, 616, 766, 444, 607, 
          739, 737, 425, 593, 712, 710, 397, 582, 689, 406}], 
         Line3DBox[{557, 668, 891, 536, 877, 664, 875, 521, 655, 849, 847, 
          504, 640, 821, 819, 484, 627, 796, 463, 772, 617, 770, 446, 743, 
          608, 741, 428, 595, 716, 714, 401, 583, 691, 409}], 
         Line3DBox[{560, 669, 893, 539, 881, 665, 879, 523, 853, 656, 851, 
          507, 642, 825, 823, 487, 628, 798, 466, 776, 618, 774, 449, 747, 
          609, 745, 431, 720, 596, 718, 404, 584, 693, 411}], 
         Line3DBox[{563, 543, 858, 544, 860, 646, 832, 527, 511, 806, 804, 
          512, 491, 785, 783, 492, 470, 753, 471, 755, 600, 726, 453, 436, 
          701, 699, 437, 415, 680, 678, 416, 573, 672, 392}], 
         Line3DBox[{565, 546, 862, 547, 864, 648, 834, 529, 836, 633, 808, 
          514, 494, 789, 787, 495, 473, 757, 474, 759, 602, 728, 455, 730, 
          588, 703, 439, 418, 684, 682, 419, 387, 673, 395}], 
         Line3DBox[{567, 549, 866, 550, 868, 650, 838, 531, 840, 635, 810, 
          516, 812, 624, 791, 497, 476, 761, 477, 763, 604, 732, 457, 734, 
          590, 705, 441, 707, 580, 686, 421, 390, 674, 399}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{108, 101, 677, 111, 672, 103, 681, 114, 673, 102, 685, 
          117, 674, 104, 687, 120, 105, 688, 121, 689, 122, 690, 123, 691, 
          124, 692, 125, 693, 126, 694, 127, 128, 695, 129}], 
         Line3DBox[{132, 676, 106, 136, 678, 679, 109, 140, 682, 683, 112, 
          144, 686, 115, 706, 148, 671, 118, 150, 710, 711, 152, 154, 714, 
          715, 156, 158, 718, 160, 719, 162, 722, 164, 166}], 
         Line3DBox[{167, 723, 165, 163, 721, 720, 161, 159, 717, 157, 716, 
          155, 713, 153, 712, 151, 709, 119, 149, 708, 707, 116, 145, 704, 
          113, 684, 141, 702, 110, 680, 137, 698, 107, 133}], 
         Line3DBox[{170, 697, 130, 174, 699, 700, 134, 178, 703, 138, 729, 
          182, 705, 142, 733, 186, 675, 146, 188, 737, 738, 190, 192, 741, 
          194, 742, 196, 745, 198, 746, 200, 749, 202, 204}], 
         Line3DBox[{205, 750, 203, 201, 748, 747, 199, 197, 744, 743, 195, 
          193, 740, 191, 739, 189, 736, 147, 187, 735, 734, 143, 183, 731, 
          730, 139, 179, 727, 135, 701, 175, 725, 131, 171}], 
         Line3DBox[{207, 724, 168, 210, 726, 172, 754, 213, 728, 176, 758, 
          216, 732, 180, 762, 219, 696, 184, 221, 766, 223, 767, 225, 770, 
          227, 771, 229, 774, 231, 775, 233, 778, 235, 237}], 
         Line3DBox[{238, 779, 236, 234, 777, 776, 232, 230, 773, 772, 228, 
          226, 769, 768, 224, 222, 765, 185, 220, 764, 763, 181, 217, 760, 
          759, 177, 214, 756, 755, 173, 211, 752, 169, 208}], 
         Line3DBox[{241, 206, 782, 244, 753, 209, 786, 247, 757, 212, 790, 
          250, 761, 215, 792, 253, 218, 793, 254, 794, 255, 795, 256, 796, 
          257, 797, 258, 798, 259, 799, 260, 800, 261, 262}], 
         Line3DBox[{265, 781, 239, 269, 783, 784, 242, 273, 787, 788, 245, 
          277, 791, 248, 811, 281, 751, 251, 283, 815, 816, 285, 287, 819, 
          820, 289, 291, 823, 824, 293, 295, 827, 297, 299}], 
         Line3DBox[{300, 828, 298, 296, 826, 294, 825, 292, 822, 290, 821, 
          288, 818, 286, 817, 284, 814, 252, 282, 813, 812, 249, 278, 809, 
          246, 789, 274, 807, 243, 785, 270, 803, 240, 266}], 
         Line3DBox[{303, 802, 263, 307, 804, 805, 267, 311, 808, 271, 835, 
          315, 810, 275, 839, 319, 780, 279, 321, 843, 844, 323, 325, 847, 
          848, 327, 329, 851, 331, 852, 333, 855, 335, 337}], 
         Line3DBox[{338, 856, 336, 334, 854, 853, 332, 330, 850, 328, 849, 
          326, 846, 324, 845, 322, 842, 280, 320, 841, 840, 276, 316, 837, 
          836, 272, 312, 833, 268, 806, 308, 831, 264, 304}], 
         Line3DBox[{340, 830, 301, 343, 832, 305, 859, 346, 834, 309, 863, 
          349, 838, 313, 867, 352, 801, 317, 354, 871, 872, 356, 358, 875, 
          360, 876, 362, 879, 364, 880, 366, 883, 368, 370}], 
         Line3DBox[{371, 884, 369, 367, 882, 881, 365, 363, 878, 877, 361, 
          359, 874, 357, 873, 355, 870, 318, 353, 869, 868, 314, 350, 865, 
          864, 310, 347, 861, 860, 306, 344, 857, 302, 341}], 
         Line3DBox[{372, 339, 885, 373, 858, 342, 886, 374, 862, 345, 887, 
          375, 866, 348, 888, 376, 829, 351, 377, 889, 378, 890, 379, 891, 
          380, 892, 381, 893, 382, 894, 383, 895, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJx0vHc4198b+E8JlUqyiuwte2Tf9iYrEdlZWVFKtqyIFjIyS7JSMhNHCKWM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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.04956055}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=91.251\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646436670704`*^9},ExpressionUUID->"20cd43eb-9e4b-4977-924d-\
360a037f9b02"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1XHlYTdsbXsYTMl/zkDEZrpDxoJW4RChjCKWklNMgQ9yuBpSpORWVTnFl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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHncj1Uaxs85D9nJlqyFMCSTtBAjW5Ze6ysUQq9RlpC9EZo0qanRQutY
Rvu0KMa0UNEwbZr0oZomDaOoRh+aGm2mbb5X1/nj/lzXc//u53nOc597O7+m
ZdNLp6UQwtgYQgE+CFYCl4Ez+KEC2IQfZsGrwZvBfwXvhs33XC+C94QncCZS
Gd2J2CyA9wj6IYRfI+3Qd0c/Cv4y6v+CFyGvwb8CtYgf4MdjUwKvB3+Ce+bB
z4F/C78cXg5shM218H7oqySvpwn69ug7gn3QHwsGvRNoltfZBvwFNsvgU/R9
+bs6Y7OD67rwoWDLvP6W8E7w6fAIbwCfhG0NZAHSS+8G14GzwWrILcideg7Y
GFwdbXs//C74XPi98CVgbeSPyBr0V4EPJPv/WvhD8L3wQ/B/wadm++uR+9Av
1l6hXxx/cnH4TTSfoOfJ98gs+D3giuh13gfvnXzv0+C5ye99ErwBGYTdGL5x
CLyhbLg+Cp6B1JVfk9e2UXue/C2Pg0v1OzJd6+O6BNuRPGcG11WRacgg9A30
Ln67Et4C7IhNbbCrfArWi97rzuB12PQBh2HTFD4BPjzv3WXwcfBb4JfAR8AH
gAOC97Uf0h8+MXrvzoIfgj8INkK2B39LLfkZ/e/yvl/McwbD70f/NjgGXSl8
FHgQOQX+DnhEsQbfB96M3XhwKPd+Bp6Kfg/YSjENlqF/Fd3PkU+Qw9F8N7gU
mwvAS7BZBS9Dfw54iuIK/aXoPwLbon8LvBDpDR8BvobsgG/B9lLkY3ilwnl0
pt6V16l8/BHdB+Dp6A+Aj4KtkDeRhfzWGl0X7t3I9cnIXuRLpAPy9+AcbKDv
x2Yq/Ft0x8FrKZ/gXwSvoR34rmIcXl/rxuYhdC2RN5Dng7/lfeT1YF8dRq7S
N2PfrXCOd0T3aa4/neCfw78KXv8RxbpqArqB2FeJzl/dfwX6xtqDvE7F7cdc
/yV47w4gO4P37jPkOuUoshYZnRwXX4L/AFsj65Hfct2fZ4zimTfCB8PHwuvD
R/F7O60RXV/lCdiG6xm6xuYicAj6M1UTkRJ4X/ksunap5qqOdQMHYd81um4o
nhQDoxU3Kb8L3STZKGfhE+FDk+N5o3ID/jT8Za1XtQb+ivID+QheEfuvc64d
VQwgt8If4fdT9f7gWFzO9XB4Cz1DNRp+GthW/oafD1ZFzpUefE7fBt8cXZcq
qgaCd3PPleB83ntbdB24I7puqE7eHV0/q8NXwnsg5wfn82r1DNXEws8ZI98m
P0c17Q/wy8EqwfVO9uPB43N9q6l6G13fjlUNVM9AzoP3is41+XARz18Jvxh9
F/D3yALVJ/TDlW/o54Ar0I+Dd8o+ma96WthXqkUz4QNVh1QDo5+5CFxY+N6F
6gHwUvACbGZGv2ss/Cx9V/J947F5AdyE/lV0fVWX4VvlS7A+siq4Pj+g3ASX
BffKp3KNvQfclXLcwmsmx61qY235Ndg/a5T7wf5ZiQxIfvZT4AbwBORG5Cbl
evA61JdvB1/SdyfXip2qm/Dd8A/B5WBT5Fnkz8GxsQ5ZgTRHtiGlyX3vXfBO
sBmyJXgeaKFvVy5rPxUnwTPDSYrt6Jh/GL4bHIm8pPqQfaX1bgMHZj88I9vo
nvksfBt8s2qPYiq5Jr2gGpz8/h3g6uA+tRW5MHm9b+Z3aW55BxyR/H3bk/0m
//0NvDe4b2pNygvl42b0/ZJz7QlwXnDM3xacg/Lt2ui+oz3dlOxP+XBL9Por
w5dH57X8sQG8Jrh/qVetj873P6HvntyH14Ln5f1an+xz+e3RbKOe/FjyfHKM
9jr3I/WWCcThrfBJ8NHw3uCw4Ov5WhvYAf1crRv9bPCOZJyHvhq8p/pNjmft
4zpwV/RebwXfjo6HF5X3yTV4D1gB6YKuBffOTp7j2hSuz5oV30ueB1RLayS/
Vzl6ReG+oFp6Grxh9IyqPqH91b7/GyzLsbo3v0t1uxJ4eq5X0wvXUuXT8+BE
5CC8cuFeqRmyKbx9rgNTC/di9ZFN4DV5/e2yDzWDTINfDY4Mrmvlo/uaZqDO
uVbMxeb25N4xp3CMqQ4cSJ5PVHdboV+SXMPOgI+F78LmO/AtsEnw9aTkvroP
nIDsh5fHviL3nR3c74cl97f94JNgG/k2eN5Qfy9XOH4Upy+Cv0T2wYvC85tm
4xPgHwb3fc3HqgnfwFPh5yvvPwCra0+Czw/jud4j+8KzUxm6yfDJ0X1H9Vf7
rnmwNfpxyTOIDifaC81Q/0ueZ/SuH3JeqzZuAB8H6yi2g/2jGef7nO+al75J
nuV01jiGZ74SXHPUI5sk94iqyTGpZ/wzeQ3yzxvRZxz58IvoOO+uNcDfi46T
o8k9V/PY12DH5Po/u3Ce6uywCkzRc45y6erkXtqr8OykWas+/KbkGaE3vAPY
Bfv24HfBM55mLO2v5pojybO3ZpWu2DfQuuF9Csf8T3ub7H/Nd58kP182g7H5
MXhO1vykezX3NkqeqXS2aphnD/XEtuCU5Lmvbs4F9e4Tcx6pVjRPPr9oznwd
PFnfF3zGmMNvx4H1CvtcMVBa2IeaFbdHn0c0a/Uo7EP11pbJ9+osUrNwPVEs
HUw+L2i2OrtwTqnPtgYXJ89f/dG3ij6rluQ6pnNh48L+l197Fs5fnT9OKtyX
NcPPKvy9mj3rFO4va+A7k8+MmoXKg5OT58oahWu+zoIPJ58FNDvVyevRnFhS
eO7Vubh24TNgBWyWRp8RdM6tkmc2+apW4XNceWxuiM7H9+GfJp8ry8Gvjz5r
y8/lwM/BnyH/Qf4a3EP35762FTyUfIbS2eqywjVZOX44+QyrM8iUwvVE59Cq
8ObR53qdzXTe0f8D1Qp/u95TvfAMrHmyXnJN07zTL9cu9YUhhc+n+r9hCdf/
B4Je2BA=
             "]], Polygon3DBox[CompressedData["
1:eJw1mHkcl1MWxu+9L6WNkha0SwtRKSGjqbRIKpVsWSpUhCgmSxoGYxo+zAxj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             "]], Polygon3DBox[CompressedData["
1:eJwtl2WYFUcQRd+bxSW4sxDc3d3d3RZ3Z/EFFrfg7u4Edwluwd0JbsHdLeem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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0L1KQmEAx+Gj9i0ERYJT0lZLhZaWKDXpam2VVlqzNVVrYN9JZvdhULdS
2G0UtPccbHj4/c/wcs555xon281IEAR1WkZUr/SamH2jtwzZd3rPsP2gI/qo
bUbtJ+0wZj9rl3H7RSfC88zQ45VZPvhknm9+SDPpTEEzukLJ3tFdKvaZnofP
9qUea9LHH+mmbtCwi1qIDv4vr+sc2jk90Kyush++S9PU7GVdomov6p5eeM+W
1rRK2V7THEV7WqfI2L8s8EWfFO+8kaAd3h1xTon83/8fGGIkjg==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 672, 405, 684, 577, 685, 428, 706, 584, 707, 
          445, 738, 597, 739, 463, 608, 768, 483, 788, 619, 789, 504, 809, 
          628, 810, 520, 843, 642, 844, 539, 873, 537, 558}], 
         Line3DBox[{390, 578, 673, 407, 681, 585, 687, 430, 701, 598, 711, 
          447, 609, 741, 743, 465, 620, 770, 485, 785, 629, 791, 506, 804, 
          643, 814, 522, 838, 654, 848, 541, 663, 875, 560}], 
         Line3DBox[{392, 408, 674, 410, 709, 586, 689, 432, 448, 713, 715, 
          450, 466, 745, 747, 468, 486, 772, 488, 812, 630, 793, 508, 846, 
          644, 818, 524, 542, 850, 852, 544, 561, 877, 563}], 
         Line3DBox[{394, 411, 675, 413, 433, 690, 692, 435, 451, 717, 719, 
          453, 469, 749, 751, 471, 489, 774, 491, 816, 632, 795, 510, 525, 
          820, 822, 527, 545, 854, 856, 547, 564, 879, 566}], 
         Line3DBox[{395, 414, 676, 415, 716, 589, 694, 436, 748, 601, 723, 
          454, 773, 613, 755, 472, 794, 623, 492, 819, 634, 797, 511, 853, 
          647, 826, 528, 878, 657, 860, 548, 891, 666, 567}], 
         Line3DBox[{397, 416, 677, 418, 721, 590, 696, 438, 753, 602, 727, 
          456, 776, 614, 759, 474, 493, 779, 495, 824, 635, 799, 513, 858, 
          648, 830, 530, 881, 658, 864, 550, 568, 884, 570}], 
         Line3DBox[{400, 419, 678, 421, 725, 592, 698, 440, 757, 604, 731, 
          458, 475, 761, 763, 477, 496, 781, 498, 828, 637, 801, 515, 862, 
          650, 834, 532, 551, 866, 868, 553, 571, 886, 573}], 
         Line3DBox[{402, 422, 679, 424, 729, 594, 683, 442, 459, 703, 705, 
          461, 478, 735, 737, 480, 499, 767, 501, 832, 639, 787, 517, 533, 
          806, 808, 535, 554, 840, 842, 556, 574, 872, 576}], 
         Line3DBox[{403, 425, 699, 398, 732, 596, 733, 387, 764, 607, 765, 
          426, 782, 618, 783, 443, 802, 627, 462, 835, 641, 836, 481, 869, 
          653, 870, 502, 887, 662, 888, 518, 895, 670, 536}], 
         Line3DBox[{559, 557, 871, 540, 538, 839, 837, 521, 519, 805, 803, 
          505, 503, 786, 784, 484, 482, 766, 464, 742, 610, 734, 446, 444, 
          702, 700, 429, 427, 682, 680, 406, 404, 671, 389}], 
         Line3DBox[{562, 664, 889, 543, 851, 655, 874, 523, 645, 847, 845, 
          507, 631, 813, 811, 487, 621, 790, 467, 746, 611, 769, 449, 714, 
          599, 740, 431, 587, 710, 708, 409, 579, 686, 391}], 
         Line3DBox[{565, 665, 890, 546, 855, 656, 876, 526, 821, 646, 849, 
          509, 633, 817, 815, 490, 622, 792, 470, 750, 612, 771, 452, 718, 
          600, 744, 434, 691, 588, 712, 412, 580, 688, 393}], 
         Line3DBox[{569, 667, 892, 549, 659, 882, 880, 529, 649, 859, 857, 
          512, 636, 825, 823, 494, 624, 796, 473, 615, 777, 775, 455, 603, 
          754, 752, 437, 591, 722, 720, 417, 581, 693, 396}], 
         Line3DBox[{572, 668, 893, 552, 867, 660, 883, 531, 651, 863, 861, 
          514, 638, 829, 827, 497, 625, 798, 476, 762, 616, 778, 457, 605, 
          758, 756, 439, 593, 726, 724, 420, 582, 695, 399}], 
         Line3DBox[{575, 669, 894, 555, 841, 661, 885, 534, 807, 652, 865, 
          516, 640, 833, 831, 500, 626, 800, 479, 736, 617, 780, 460, 704, 
          606, 760, 441, 595, 730, 728, 423, 583, 697, 401}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{112, 101, 672, 103, 671, 115, 673, 102, 686, 118, 674, 
          104, 688, 121, 675, 105, 124, 676, 106, 693, 127, 677, 107, 695, 
          130, 678, 108, 697, 133, 679, 109, 136, 699, 137}], 
         Line3DBox[{140, 684, 110, 113, 680, 681, 144, 116, 708, 709, 148, 
          119, 712, 152, 690, 122, 716, 156, 125, 720, 721, 160, 128, 724, 
          725, 164, 131, 728, 729, 168, 134, 732, 172, 174}], 
         Line3DBox[{175, 733, 173, 135, 683, 169, 730, 132, 698, 165, 726, 
          129, 696, 161, 722, 126, 694, 157, 123, 692, 691, 153, 120, 689, 
          149, 710, 117, 687, 145, 682, 114, 685, 111, 141}], 
         Line3DBox[{178, 706, 138, 142, 700, 701, 182, 146, 740, 186, 713, 
          150, 744, 190, 717, 154, 748, 194, 158, 752, 753, 198, 162, 756, 
          757, 202, 166, 760, 206, 703, 170, 764, 210, 212}], 
         Line3DBox[{213, 765, 211, 171, 705, 704, 207, 167, 731, 203, 758, 
          163, 727, 199, 754, 159, 723, 195, 155, 719, 718, 191, 151, 715, 
          714, 187, 147, 711, 183, 702, 143, 707, 139, 179}], 
         Line3DBox[{215, 738, 176, 180, 734, 218, 741, 184, 769, 221, 745, 
          188, 771, 224, 749, 192, 773, 227, 196, 775, 776, 230, 200, 778, 
          233, 761, 204, 780, 236, 735, 208, 782, 239, 241}], 
         Line3DBox[{242, 783, 240, 209, 737, 736, 237, 205, 763, 762, 234, 
          201, 759, 231, 777, 197, 755, 228, 193, 751, 750, 225, 189, 747, 
          746, 222, 185, 743, 742, 219, 181, 739, 177, 216}], 
         Line3DBox[{245, 214, 768, 217, 766, 248, 770, 220, 790, 251, 772, 
          223, 792, 254, 774, 226, 794, 257, 229, 796, 260, 779, 232, 798, 
          263, 781, 235, 800, 266, 767, 238, 802, 269, 270}], 
         Line3DBox[{273, 788, 243, 246, 784, 785, 277, 249, 811, 812, 281, 
          252, 815, 816, 285, 255, 819, 289, 258, 823, 824, 293, 261, 827, 
          828, 297, 264, 831, 832, 301, 267, 835, 305, 307}], 
         Line3DBox[{308, 836, 306, 268, 787, 302, 833, 265, 801, 298, 829, 
          262, 799, 294, 825, 259, 797, 290, 256, 795, 286, 817, 253, 793, 
          282, 813, 250, 791, 278, 786, 247, 789, 244, 274}], 
         Line3DBox[{311, 809, 271, 275, 803, 804, 315, 279, 845, 846, 319, 
          283, 849, 323, 820, 287, 853, 327, 291, 857, 858, 331, 295, 861, 
          862, 335, 299, 865, 339, 806, 303, 869, 343, 345}], 
         Line3DBox[{346, 870, 344, 304, 808, 807, 340, 300, 834, 336, 863, 
          296, 830, 332, 859, 292, 826, 328, 288, 822, 821, 324, 284, 818, 
          320, 847, 280, 814, 316, 805, 276, 810, 272, 312}], 
         Line3DBox[{348, 843, 309, 313, 837, 838, 351, 317, 874, 354, 850, 
          321, 876, 357, 854, 325, 878, 360, 329, 880, 881, 363, 333, 883, 
          366, 866, 337, 885, 369, 840, 341, 887, 372, 374}], 
         Line3DBox[{375, 888, 373, 342, 842, 841, 370, 338, 868, 867, 367, 
          334, 864, 364, 882, 330, 860, 361, 326, 856, 855, 358, 322, 852, 
          851, 355, 318, 848, 352, 839, 314, 844, 310, 349}], 
         Line3DBox[{376, 873, 347, 350, 871, 377, 875, 353, 889, 378, 877, 
          356, 890, 379, 879, 359, 891, 380, 362, 892, 381, 884, 365, 893, 
          382, 886, 368, 894, 383, 872, 371, 895, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzkvHdQlc3TNoiooARFEBUDKmACkSBZpEFQQFBBQBFRgkgUJUclSFZyEBUF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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.03979492}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=101.252\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643710101*^9},ExpressionUUID->"750243f2-945a-4a5a-8575-\
1613f0275948"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1m3dUFVfXxkdFRMCCFTEIttgVu1F0EHsFLKhJbNg7KiI2OgJW7HQuTbFF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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3v8UPMZx7/nOV0oXQiVdPkloqwLFdbIrHSRVCop3dNFJV2logumlXId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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkc0FMWxd97v6QFlVLSpiRFJQlJiUYSoUxhKqKFUFowCcmMGcvUZxjD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             "]], Polygon3DBox[CompressedData["
1:eJwtl2WYFUcQRd/MIsEJwW3R4La4u7u7Le4uizsEd3eCuwVN8ODuwTW4EyxA
zk3Xj/P17ds9PW96qqvmJQ/tVK2jHwgEfofwsIrOSlgNPegXpR3lBQIjYRG6
JV5B2nXQE12M9lfGlsIadDe8rtARimgM2qBHMD4P5sNCWABbGRvEWEnaDbAe
NkJfvOK0o5nzCyyxNQrRLoN26DG2htbahBeG1xu6228e77nnaQ8dYAL9STAR
1tpvn4ueDtNgG94QvGXo43AMgoICgXt4V9G7YRe8ZN4xvKPog3AAnuIdwWtE
exkWo6vRXoGr8Az24jWgfQ4v4Lz2Bq867QW4CK9s7Sa0r+EN7NO1sB+mMFaO
dg9MQI/XvkIZ+gdgEnoijIay9N/Z72pM+x7+gZuwDe832AC16GfjOZPwHEkh
GfTBu+u7mNgNO6Eu/XvwB3oP7LPnuQ/b0XVoH8BDuOG79XWfHTb2t+/W0poH
oCH967AVvUVxBzXon+b+6dDv4RI0035a3A1lbBbMhp0WO6Vod2ltmIEfSfNg
FKymH8yzhdO7hO+KSz0b+o6elbGItG8hEfob41/hk+KGefHwvih+9D6Y8wYS
4MWHhBDw3HrPaZ9p//DC03bGy4pOrHV1DfTCS27366p3QfsBtlvclda5o78K
zsIZ+KI9Yqw5bUiQez96T/GgJ95hPTPj02EqlPfd9VrnnMXXdvRp9Gx0Jdoz
cBa24G+GUxavVRUrMBM9C+bY/M/wl84AnIGm9I8rTuEEzMOrTHvUd9fp+skW
pxn5zXG5RxyIAT3wxtGOVb6wc1yYdrj3/1YGOkMLGKI94tqOtDOVU9DdoQik
wRuAVxRdDApBRrwMihsYyFgevGCL47zofHpX6O94uW2N/ro/ujm6BbRRLsAr
qfnovJAFBuMlgKrKL/TrK4/QL8W8/OgCUAiG47XFa4pOjM4EmSEZBEMnxjow
NgOdCBJCM5s/GR2KboxuBDVhAl5dvMro8eh66PrQECrijcNrpGugdZB7Bj1L
KExhLCJEgDq2xk/ozuhW6OSKT517xTjEhS6232nQy2ETz7tZedZySVXGq0A1
KMO80XgV0QXt2SvpPrADPYxrhsNIy00ZID30Z3wA8/OgB5ieh84PBSAnNOGa
MPxuOuv0U0MqCGN+H70T5SC4zLwrsNFy2AIYix4Hnaz29LFr5qBzQW6IAdGh
hu3jWOUq39WcRfQ3qp7AFrx+eCW0H/RXQAWuKU5bAkqpNjFWOsjFgGIhJwzF
q4lX0sZroWtDecUrXlEoDCMYy4GXHXJCCry+vquJA7jvQBhs+U31TbV4DnPW
wXqYqvesM2y/czE6PeukgwzKUZYj0qJj6/1DFO0rXkrLU120t+jU8Ai93/Ly
Y3iicw/L8JbDWqhp51x1aAPX74G9cFL7jzdfNdXygXLTNHQF7S9ztilnww7P
1QLd65BdqxxSxXdjO23/9R6OWN6q6Ls8tVDvCJZYfVXd/RN9WPXY6txtuAV3
YJfVrZY6H4p9aGbnowm6Kroa1IGJeEkhCbSxczIN3RRdD10Xatu8u7Z2PT2n
fqfnvgsO6pnguNXwvbZHqoeqkbX13PT3ea6W6pugvu/Or37XVIt1xfwlWMH4
StUxq43K6dpj7fVS+3b46rvcrBx9U/mT/if4kfViwTu8dvQ/wkX0BTgHofQ/
wAn0SThvXiR+ywP0Q3gCbfDeav/Rp+Gs1YCLrH1BeZv5d/Fa4oWz76VW6PDo
CHANvR5vHayxGFKt/Yx+xPWfVedU1/A82k6Mv6N9DynwItFGhqgWu9EUq1x7
w3M1V7U3Ot5TvGfwCtrqnOO9Qb+Gl+bFxMut/AMxrR7dpr2lnG33f+m5Oq7v
BX03RLBzEmz1/gV8hW+eyyHllRegkuXk6pYfx6BjQxxogFdd86GW5fbIeI9t
f6Ogo8IhxZBi2s6O6nnxIFfbVONCYAheCbwc6OyQzTzVwfToQb7L+8r/J+mf
8Nw71b1uKvegM9Fmhqyeq28FVMuUy20N1dAo+o2+q3PK8cOUD2gzsc5zeAH3
6P9g7/8K+gk8hetwDeLa99NjdBz0R/QHeGsx6Qe575tzjD9UXvDcN/ctvNtw
32JJ50vnTLF+Q7GqfMa8WMptFkv6XruMfwkiWoy0xvtm1+hcfIcAY9Foo/ou
nytPj/Jdfi6CHqmzA7GgrN4llLMx5ez2qree+1booJoJPa22/4wXAtmVk/H6
4c1F54V8kE75WLXGxnKge6E7K8YUjzDbYkax087ulcJ3dbwsuhxU8dw3QW+8
Xsrz0N2uVR1vi26ns+S57yfFpK7T9aU9V7tDrEb867n3rPd9Cl2ALYpOG01r
4qVhXgN0Q8jlufqWWTEEWSCh575tVUNVs1S7+gTc/7esNt5b7xqCfPf9lVp7
BWk99y2Xy+pfP+UQ5Q7fnS+ds2z2LRdm81KhU0Jyz9XL+NBctVKxD/Pp/wd7
LtLT
             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0M8vgnEAx/GnIj/abJq2Tlo3NoxCSV1zjRtKiTNOuDq0MBnz67/Ixr/C
+DfY3L2ecXjt/XkOz69vtn24cRAJgmCXjhHVrp4Tsy/0kgH7SnsM2tca1xu9
Zci+03uG7Qd9ZMR+0tHwWUzQ55lJ3nhnii++yTHmnrLmdZGqvalb1OxjPQmv
7TPd17SP39OyrtK2S7oS/fu/gi7Tspe0GT5fc+zYCzpPw57TWer2jG7rqfes
a0PrrNlFLVCxkzpO3v5hmk8+yPDKCyl64XmS4IjI//n/Aj3SJJc=
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{389, 386, 672, 408, 671, 576, 684, 429, 679, 585, 707, 
          446, 702, 598, 734, 463, 611, 764, 485, 761, 619, 789, 505, 784, 
          629, 812, 521, 807, 643, 839, 537, 657, 868, 556}], 
         Line3DBox[{392, 573, 674, 410, 682, 577, 690, 431, 705, 586, 713, 
          448, 599, 740, 742, 465, 612, 770, 487, 787, 620, 795, 507, 810, 
          630, 818, 523, 644, 845, 847, 539, 658, 874, 558}], 
         Line3DBox[{394, 574, 676, 414, 688, 579, 694, 434, 589, 719, 721, 
          450, 603, 748, 750, 469, 614, 776, 491, 793, 622, 799, 510, 633, 
          824, 826, 525, 648, 853, 855, 542, 661, 880, 561}], 
         Line3DBox[{397, 575, 678, 416, 581, 698, 700, 436, 593, 727, 729, 
          452, 606, 756, 758, 471, 616, 781, 493, 624, 803, 805, 512, 637, 
          832, 834, 527, 652, 861, 863, 544, 663, 886, 563}], 
         Line3DBox[{398, 399, 680, 419, 697, 584, 703, 437, 726, 596, 732, 
          454, 755, 609, 762, 474, 483, 785, 496, 802, 627, 808, 513, 831, 
          641, 837, 528, 860, 655, 866, 547, 885, 665, 565}], 
         Line3DBox[{401, 412, 686, 421, 709, 587, 711, 439, 736, 601, 738, 
          456, 467, 766, 768, 476, 489, 791, 498, 814, 631, 816, 515, 841, 
          646, 843, 530, 870, 659, 872, 549, 559, 890, 567}], 
         Line3DBox[{404, 418, 692, 424, 715, 591, 717, 442, 453, 744, 746, 
          459, 473, 772, 774, 480, 495, 797, 501, 820, 635, 822, 517, 849, 
          650, 851, 533, 546, 876, 878, 553, 564, 892, 570}], 
         Line3DBox[{406, 422, 696, 426, 440, 723, 725, 444, 457, 752, 754, 
          461, 478, 778, 780, 482, 499, 801, 503, 828, 639, 830, 519, 531, 
          857, 859, 535, 551, 882, 884, 555, 568, 894, 572}], 
         Line3DBox[{407, 427, 701, 402, 730, 597, 731, 388, 759, 610, 760, 
          428, 782, 618, 783, 445, 806, 628, 462, 835, 642, 836, 484, 864, 
          656, 865, 504, 887, 666, 888, 520, 895, 670, 536}], 
         Line3DBox[{557, 540, 867, 538, 846, 645, 838, 522, 508, 811, 809, 
          506, 488, 788, 786, 486, 466, 763, 464, 741, 600, 733, 447, 432, 
          706, 704, 430, 411, 683, 681, 409, 387, 673, 391}], 
         Line3DBox[{560, 545, 873, 541, 854, 649, 844, 524, 825, 634, 817, 
          509, 494, 794, 792, 490, 472, 769, 468, 749, 604, 739, 449, 720, 
          590, 712, 433, 417, 689, 687, 413, 390, 675, 393}], 
         Line3DBox[{562, 550, 879, 543, 862, 653, 852, 526, 833, 638, 823, 
          511, 804, 625, 798, 492, 477, 775, 470, 757, 607, 747, 451, 728, 
          594, 718, 435, 699, 582, 693, 415, 395, 677, 396}], 
         Line3DBox[{566, 667, 889, 548, 660, 871, 869, 529, 647, 842, 840, 
          514, 632, 815, 813, 497, 621, 790, 475, 767, 613, 765, 455, 602, 
          737, 735, 438, 588, 710, 708, 420, 578, 685, 400}], 
         Line3DBox[{569, 668, 891, 552, 877, 662, 875, 532, 651, 850, 848, 
          516, 636, 821, 819, 500, 623, 796, 479, 773, 615, 771, 458, 745, 
          605, 743, 441, 592, 716, 714, 423, 580, 691, 403}], 
         Line3DBox[{571, 669, 893, 554, 883, 664, 881, 534, 858, 654, 856, 
          518, 640, 829, 827, 502, 626, 800, 481, 779, 617, 777, 460, 753, 
          608, 751, 443, 724, 595, 722, 425, 583, 695, 405}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{112, 101, 672, 103, 673, 102, 674, 104, 675, 105, 676, 
          106, 677, 107, 678, 108, 109, 680, 113, 685, 118, 686, 119, 691, 
          124, 692, 125, 695, 130, 696, 131, 136, 701, 137}], 
         Line3DBox[{140, 671, 110, 114, 681, 682, 116, 120, 687, 688, 122, 
          126, 693, 128, 698, 132, 697, 134, 142, 708, 709, 148, 150, 714, 
          715, 156, 158, 722, 164, 723, 166, 730, 172, 174}], 
         Line3DBox[{175, 731, 173, 167, 725, 724, 165, 159, 717, 157, 716, 
          151, 711, 149, 710, 143, 703, 135, 133, 700, 699, 129, 127, 694, 
          123, 689, 121, 690, 117, 683, 115, 684, 111, 141}], 
         Line3DBox[{178, 679, 138, 144, 704, 705, 146, 152, 712, 154, 719, 
          160, 718, 162, 727, 168, 726, 170, 180, 735, 736, 186, 188, 743, 
          194, 744, 196, 751, 202, 752, 204, 759, 210, 212}], 
         Line3DBox[{213, 760, 211, 205, 754, 753, 203, 197, 746, 745, 195, 
          189, 738, 187, 737, 181, 732, 171, 169, 729, 728, 163, 161, 721, 
          720, 155, 153, 713, 147, 706, 145, 707, 139, 179}], 
         Line3DBox[{215, 702, 176, 182, 733, 184, 740, 190, 739, 192, 748, 
          198, 747, 200, 756, 206, 755, 208, 217, 765, 221, 766, 223, 771, 
          227, 772, 229, 777, 233, 778, 235, 782, 239, 241}], 
         Line3DBox[{242, 783, 240, 236, 780, 779, 234, 230, 774, 773, 228, 
          224, 768, 767, 222, 218, 762, 209, 207, 758, 757, 201, 199, 750, 
          749, 193, 191, 742, 741, 185, 183, 734, 177, 216}], 
         Line3DBox[{245, 214, 764, 219, 763, 220, 770, 225, 769, 226, 776, 
          231, 775, 232, 781, 237, 238, 785, 246, 790, 251, 791, 252, 796, 
          257, 797, 258, 800, 263, 801, 264, 806, 269, 270}], 
         Line3DBox[{273, 761, 243, 247, 786, 787, 249, 253, 792, 793, 255, 
          259, 798, 261, 803, 265, 802, 267, 275, 813, 814, 281, 283, 819, 
          820, 289, 291, 827, 828, 297, 299, 835, 305, 307}], 
         Line3DBox[{308, 836, 306, 300, 830, 298, 829, 292, 822, 290, 821, 
          284, 816, 282, 815, 276, 808, 268, 266, 805, 804, 262, 260, 799, 
          256, 794, 254, 795, 250, 788, 248, 789, 244, 274}], 
         Line3DBox[{311, 784, 271, 277, 809, 810, 279, 285, 817, 287, 824, 
          293, 823, 295, 832, 301, 831, 303, 313, 840, 841, 319, 321, 848, 
          849, 327, 329, 856, 335, 857, 337, 864, 343, 345}], 
         Line3DBox[{346, 865, 344, 338, 859, 858, 336, 330, 851, 328, 850, 
          322, 843, 320, 842, 314, 837, 304, 302, 834, 833, 296, 294, 826, 
          825, 288, 286, 818, 280, 811, 278, 812, 272, 312}], 
         Line3DBox[{348, 807, 309, 315, 838, 317, 845, 323, 844, 325, 853, 
          331, 852, 333, 861, 339, 860, 341, 350, 869, 870, 354, 356, 875, 
          360, 876, 362, 881, 366, 882, 368, 887, 372, 374}], 
         Line3DBox[{375, 888, 373, 369, 884, 883, 367, 363, 878, 877, 361, 
          357, 872, 355, 871, 351, 866, 342, 340, 863, 862, 334, 332, 855, 
          854, 326, 324, 847, 846, 318, 316, 839, 310, 349}], 
         Line3DBox[{376, 347, 868, 352, 867, 353, 874, 358, 873, 359, 880, 
          364, 879, 365, 886, 370, 885, 371, 377, 889, 378, 890, 379, 891, 
          380, 892, 381, 893, 382, 894, 383, 895, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzFu3k0leH3B4qKjJmigSIVpSJTg7STSKSUaJIpmkxJyFAyJpEUSanMY2Wm
kMc8D+c45vGMzjnOcQ6iwdS1lu79rXvX6t7VXd/v+ln+2ov3ffb77L2fvT+f
zyNr43zWjouDg8N3BQfH0u9ffibgn+1Nos4eP0jIz4IvbR+OhMYea/x67j0M
67f/OsejyYQrDK7BdqFhZODAsWu7XgIM2QpndEaz4QfW+qvD3Rr44Go66SHw
FG5yzyjpEdgo5Z7A9pUKycDh+a119Es+oGKZr6ZvCMgx4KztplgizLheef9B
ifTv6/xHu674VocylwY0f/IgyY/Yheru2+8JcRkH8wdq0RTndhQjefC+RSUL
0QIlSs0UK0BFrH7iVAQD5FUU2lNl8SCwKUKUwz0HpIv6CSYeLCCV6u0zLKhD
bzO+zaqOtoNb94PhMsVxlG2mltrt0422vNZtkjzTDOmJCl9e2raj4TxaWWgP
FaaspN4d6iNB9LrB/jzLRkT9UGonsqoBThtv/ExpYP3H/E1V3+XIONSHgmw1
7DS20lDhSpuK2CY8qK13PVVdSAHOw3bDgimjwB3koxeo0whriJZfPqqQ4e2X
/W/9JskgoHRcpSypH563/H7ax4GDEo7r56hho+hGaa9b6zsy4DlENKmibBCx
sl+982QDPN9fOyn9tArqFB762ZBG0e8Thzn23CTDHoJ0g9HxDpgaieRPtm1D
gtoSO34Sh6Fm/MgFxdmxf/YLg//F8f5IA1rTlcdRlNuFDrK7RiXuj4PBzwrn
nI0U1Ptjp9/Vz1RUru2wQrUZgZhJfN9YyDDcvtVC5CMxwGa9I1/ouq9wZxs3
3fxxPfy0en3Pid0JzwOdJy5kjEMp15fP4TvbQPWhTp0mZRAZzbivnXrMgJ15
z8J6D4yCuWt3c9EqMjLbmlNY+aUbbjx6lvSUyEKr5qvmbVMb0a9DdyIVQmvh
fHqk+avjWHSt6/gCK3YU1Nh++t8myBCM05H1kuhCP6naYxsOYkHB+0hR2Azz
r/5mnl1N0/UcQZSBiFoHt1H0ym11Sdl9PHCwCkqSqR8QeeKryIg+C2i5cSHl
lzrBStn5nVH8ILy55nBadQMVUjNX754g4//6fE3O9fDw2dJ3qL5csc6yFoVk
Xt/9fZEFX88WsSsbWsFP1kZsIIyKbIieNz0vkEGr5xttU9Q4HNQ3yRL0w4Ga
gdc1KbtWSNHUKxrFk1Fl7Bv3V2NEUDyw6pDGxWEQ+B3DlUAaQv2c59YMh9Gh
pnE4xPVML/RJ++lUGvUjdFj+xvNQKmK4mZe8PkgAwVP8we+tKcjpXcfZZ4FU
pP575VqNzK9wACyKVEyGocjzyILyCiZ8unBZXeXRZ1Bx8jmSNVcPG4Yi29tu
dUGizJf08PDxf46rn9Zi0rNlbeA6qlcQoIxH3iJZWUT/MdgyLfjFDahwZm5r
nHcTGXmZ6J43Sm6Bve47Xbf/YKIgY46f+z51I/01jNNWfG1A7J9tvPWjCDLH
w28u4Niwx4NSdM8lE6bNaj4LXWlFa+Z72iwl2WgbI3SvY/ZH8HJoMe8ppoER
JwfH16c9qH2tzNsPEXjgzPo6Ixk1BKbJLnaUdVTQExAPuufz9338V3vtvJVf
SFIT7CEGPZntbETk8x+x++JZcCLz8Pdtxb2gP+ZkFbaUx+JxNtw3k4iwBW9t
G3aYDb4/e46OxdZCt8w51UydSuieHfFqla1FsR+78xcusuFAarLbl9VfYe19
ud96cgiJBxWfPZHIRlHHM88OdxbB3tKtaxp6qYCrc1Q4wUmBrKuUVvs15ZAQ
r1WUotwAwsEbxh8ldEHDKcMThIf/vo//ak+6J/u0KKgVhs2ticXDBPSt45Jd
vi8dTAJPbtvfNg4pZqpVUVgcSngluXO/ZwN4HzAxnHfoQSVn/WZFeMbRpexj
Oy++aoJLa4Rbktyr4F1HAcNPgw2orKvqvWktHNC+dutQyCDYNaxIu8hJBd+A
HROtwoT/ul9/s3vabHz+3LQF9Arid12TbEELjdsKeq6z4Pyxd++dWQOQVZN6
b0MBEb15EbM6iUQBzxlbamtlDritalrVW8lGepePys4llwC59p7ZSkkEm6NE
Sw8lsoEVxX1/lF70f733sBh9r6vzALTGuHLK0P9e3/637ORjP0seneoA0Rju
tWBOR0K7Q1eZHSKAg4v3pxlTMhy20nd94UlDZy+oobuCpf+x9/JErbgXLVSG
rkhoXwvc1Ig65HOZlnvYkLDl/ETVQB+yxPs5TPmOoEpDQf6rH2gwFmJYvDVl
AO2GEy6MEwwkwR40lG7qgCsD71rmBDvh1X145qHMQhs2lvMH1ZfC+l+Vhjex
bNinetxxpqsIXDbNLB1LH8HxclwSDjcOH6Zf77VY0QO2cazK0D2p/zG/5M48
56l4z4bblHOBHYfeI4eF2qkQxep/fs7ehAfaHFG1qPpgilfsGRwClDjdys0C
szgrVoxuNsL+dll/6Xcp+s1O9/VEbAhMXCc56jgEFlcHzK9Z9iJnh5XWSVl0
+MjrOvaWn434uMX1Tr+rR/yuT0mfZGrgyE97ZqduCzKvP2Y6V9CHqHfGFd7d
ZsI+9L6rnKsbnXttJfWhjYz27T5xN+ojBZ4VU356b8KiqH0oV96IhaR3bx7b
gKsDTUGlqubmbvTNsGxHFGEMuW7eEtOm3A+m6Yl5o/eY6EpMqKDyplwIrs2w
fEAZhLsXBJmbXvcinWQivWSEAns2rpDu7SdB8xt0oOFeLZJcsBtKEmCjigHP
7lDjOlBLVLq4PocBYMt8WUJtB22hxANj3QOw4VbYpm0/xgBf8wmvupoAll7i
2XtwBfDxjClufwMVrl85XPa2nQz17tvrfmyugfCn98X0o6vR4+HIyqHyIcB7
7bxjSmOAVfidoXFMGRK68GFa93gpKMXwy/+OY8PVloJtZuwxIHWSizcz8ECM
jmxs4SmDW1EjX0grqPB+l9fghUESGDYe1tw3j4OvRqeTPGKW+oU325O08/JR
RWaaVN+mDnjBpcjp+Y0Oso9vntpzZgBSRC4dCorr++t7/1Nx+K/2ib4xyrej
4zAlKcXbao5BmGlShMraTsD3aSQfFCICfw9H0KFFIuq5K0c/d4UISdL1dwTe
paOfM9tD9VcVIReB2giZXjY4Exdz1CnVKFnm5faZZixKqxD+oWrKAiOxXVe/
1HQjO9wX8rNoCgpI0fG2ySfDQEhUba5yG3J9IZz6KH4AeYxsNrw4yIA0z8Vw
mw0MtLhzBET3DiKGoOPUpAAOxP3fWj9OqkQOB9c/dZKmocSjbqP6kWSwYe4R
jbZnoqygscKB3h4UxYrtY+zDwshBQ7tzBxmwh56z4vb592go7/DTyAY8yMrI
1nltHUbsh2XfF57T0O3oI2FnGgZg6Jwyq6qXhFKnz0n5HaIh9yTlCppcE1Q2
Wxrd3kuBFybrkdQJCuToK2dwiXZDy/VufQFvEip1dfj+cQ0VtV1/PL5wsAu4
FEsPG3CXootpLm7rfGiA88PKiZmQ4SePRw/spsHVzaLmOwzxcNfxe3erdT/c
klJ+ea0Lh459x14YH6LC9/zuh1eHifCQQ/33nV4i+sGuSj5wYRT6c/hOb+Tv
hw1ZNRvztMhwZVWKbM1mGjhSSsLulNdBXvQtiScv8LBjf95UrCADCjbtNfyY
UQHW7RjNmqMk6FC7k3hhNRW2Tjzs15PrBrOpkuqEG3iovszjaE0bgwe4bfMG
u+rAcQNG2BRhkWjPFgOJexgwXBCk7Xo/DiUnQmLkUkjoOE6+RySFADjXbd9s
xIgQPBCAX7G9CQ3mCBn1jraAoK6zHIc3Cwxxv7dHbG1FFpH4oj3QBzJjXD/Z
PkzAaVRY8UUTIH2rfWCjDQlcHqk0dd0kAlH85oY0lQ6gCTFuqWj2Q8b0Zodf
pQyQof3icXPCwa2I6HOD8njUf7NojdsAHU6wCPgCx1Z4oX56SM6uAg42qexR
HWEBRvzKz8rxd4g73ZfL2CkbjAN1BNqYbFhpESUoHVKLzlCyROIIXZDzjfJ2
Mfrf+6up41yCMaRyhOub0/ZIaEaJBxlc4ZxssOjQzO2sD0GnfPUepu98icwJ
z1d5L/x7XuuWib66sL8Drg994itGZITnSeAXezUKK2Ss1qxjtYNfvXW+3GY8
Ko4xCWe6L9VBeZWMKZNO5Hv4nZcSaQTtEfTfyI2lg30Ii8v0xTDiODHJ4/Sd
gmiK0s+1wwjQYBiDVw0kIXPLLSrfq6jo8BjnKu3PWKAWb9g+thOPLl1v9y7N
GEW4uCTXbREjsIUQ+ezyi3Egb5os/FGSAIb0g8VU015wrhUmNFcNwu8BrkI1
3R7Um3O68a3UGHCHVhR5arOh/FXZtvxdEejt/KuvB62aIa/Y+sz2FDrcUlpL
zCkaQeVh5/dOOXdBrP+jZI8bTGRA2CNveasFmcmcmKe29UGd0YlHxS3V6Lm7
H5Z8axwYce2iijt6QKPBdOKKewdo8K9Xov0ahyjI8Qu90ggWn3tPCcW/REnT
XWFUZxYYP47kLS3AwRb1R3TMSTISlfCF4hVEaFDcKNXxDQ9Clr91Iy2JcNGZ
Q5ySjkd2GbTv3vvJoPPW4akLaww1ANZaL2MI9mm/tItBWHBrWjgjaMRGfSoK
W97eTUSEvPcD19SaoNfW+pxm8DDkmZU8Lywcg3ATVUL9eyy4DLJaiscGAZu0
8uWLJ1TwYssU3tmKh0vYSxfY3ztA6M7j7TmEEdgR+WU+TGwMKM+v+E71D8C5
qhKK8ZNROEBPS1GaIMDl8dLX6W4jqPOQdO2gbQ88TUG86w3pILLixwsf3DgS
qZHdkhebgzopxV3D7d0Q1TG20iu3HXkQT2mQLAnAdznvie9HOsxoxj+e/o1B
EplhKtm2FDimHNxkenAULgRsDpSe+Ao2qsJrRRKalros9xp9MTZc8lJuPrki
BJwGV5uSL0dD7ZmJ8LSleDbE/XLyelgNufzcRjs/daC5JBHGwX0smP7d2nfJ
PALG8NPC8nzvkEOBpFPAHBu2iFnI3g/KQ0dP1mSUHGiAM0Xp28XN2PByV/68
t20r8rUp3kvdTwJxSfFbl/xo0KbsucHYsxB1rGUF9IbmAm4+g97azoZ1R3GB
OFMsev+D3Jp5tgV6pEZPvZ4dhxyV1REbGYMozebzSX5uKooZWjj2Gv/vc6Ki
WF2UAWcLqPeIKR09041Ol68IztgxDkfG/eWjBRpATeHhZlpZPaIGB9Kth1iQ
wvERY7iKhHY2p98zj6CixYQSz/f5nfCyiauzNWEMJdUf5L0j0Q5MTMmKo5QR
uB3unHRgngB1Gk2fnu/Do+86b8L7xshg1/5CDzvcAizgs9m9rQnZW3++FLRU
P9/efSXLOk2AV+nozdntoyj/XtfbvOfDEOVt0GU/g4HqX9omiqFU9F5lhi7y
jQR17EeJT2jN0GOFuad3lwVbNp35cfRDM2x45hS5qD8Mt3+r8NseHYO8e5fw
u/07of++ZuxG81FEiv7IvesqAUWPmjQ21A/BXr0dus0ZVXD6kvhH3+9U5H2+
I1YzhwyfOndasZLoyJuwEP8hOAEVfnMhXpEmgdVuqVibCCYkFWZcs43qBMfT
8jjJw53gt6u0I/VcFxS0JrmEVRLgOdNBwNKWBp6azBdBdz+DWbioQml3LVy0
yswatGYDBWO5t7CiFTwXY53oh6jgciks+WwBGUIFt1xsusMEMYvuPcniPSAW
dPiGp1AHLJKVT+0RG0A2hPqQ/CIKzDX2Bp/YR4LLh1avrNAgo+ia/Tu265CA
O6C9N0Vn5K/7fmTYOc6mohjM1H6fDg4tRPoOZwN8lvpq+5vCYcXHhlFUkWbi
9FJf25x4BCP1kwadUcWaLq5kNGccuCPEgwi317RYHdPFQ74s7gja148uvt/6
8LIEHvZfO+YwcpkG+0uyRA/1DKEA3xapd8M0ePu5Q4ZXYADESp+Wb00no+2T
PB8iFWko4ud9selvS31m145YN75+5IrtlmuXGkfqqH2wS6gQmvflGrQttKIh
Qt8Vr55+9F66wPeLMPOv67d6EH+0n01CxXNGamXhNLSw7dPA/TvV0Khh0FOx
sxMOCIcal3XT0Gx4fJKbJwHcXd/0P83Cw4nJ5gfcHAy4k+rLfhq6dK56Kf5Y
1cuA219bs53MquHa5rLz06uG4YFe15Z7HhUQmXTA7+TSei8Rj33KnGCC4kmX
njdv2qCRM2X39DoycsjUMLPJowL2+CTP/N1h2O7keNV2mAENSy7ucECQHtRJ
eRs9DL9bzpx8EE6HUtraIFPHHlBU/prX6tMED3u6t/zS7IFBu2vN3qLjMLBW
B9cq2gslj2l7us+RIGxEI/mw9yi4UXrY5PtU4FSrUazSrECONjINGRcoQJVx
0MIsZVfcetcNSL8RKSv9Wt/8FgPHol6mUaPr4D7OrOeM4lLeGgiMcfWMg+IQ
aJla5IFLrpMRXK+AtsoF/I60fz/HE83XZr+jl8Apc3ww1qAQKUk0HBQuYkMf
/rFTSx8TrY3EbLkXWgmluO2vso72/9f7/OCfrvy8XEy0Tagb81GmA2JGsj2f
SPbBq695w+lpjWj1m5gekhcLbKq8bopcbAXWp9ebYiso0Pv1yt0jDgS0GFo1
cMx1BPK+DQRuXl0FCo89GPvLWIjXXzRZoLQNwr+dk5nB9qGatMj0L1o09F6d
p1TBAQ8rflsOferAodrzky68FuNIrFRMy6+z/Z/Xb/n2C+8dZQaQh5+MfZls
QKKbgx1FzEegdV1YgvkLBmAevOPLnB8Aj4wz6lh3DHC9mCbxteKBJtmuPrOF
ClXMj0EaZYNAjvtqFy88CuEb7Tom+UfhzsuAnTUvW0DpdWKti1QraD7N/3Y0
cxh9ILzbPyDDAF0zjLWf8md4pbZtVNi7EVmc3X4kSYMNSedFn2ZGtcExUymM
u84Iav0pv5nRPwZGw59P14e1QPTsV5EvDzpRaClJxdF9qc8s8q7rkBqA6wHY
yTrnpbg8sWPfhD8JKq70X9FRW+oXQr3KHRcG4aoIz2VvVQbsKjuzOtc8Ecx9
lANv2OdARBODt5/OhpIHIuqaV6pg62O8KNkeAx8icWo8L1mwM0bs91vKKFjX
Q9UtfzLKZq7od2zEQtz1h36raobA0B2ai84NoP5DOI8HGBoY0c9XNJaOgvc+
tnmgGAUd1Hi371x5OzirXT9s/h0PR8UFJ8TrRpFd99x1bb+h/3p8NpF1kuY5
mEjnErfHkTd9qGAD/Y2LPRbWnnsjm8VXg6hm9wZhioZuThde6blOghs71tic
iGMi9WNWG49Z9iDbaOGk7bEYyCJ0XtsZQ4NN2TPS6WeqkZSo1/59o/99fs1e
5z2fn3M1/PxYeez8czZccCrR6HT9BCVfzzpqKtEhzTD32bAxCYb41rtUGFdA
a0OV6qPxPJAg3U4ZHGTDaoLboIbXBzi6ji9/AyMXbUvl2TzUyAajt3Er9E8U
g+o+2l5oJULvPq0y/EM60AUdK28yKuE2PVAnQb8VjI+tyerKZ0FZ14nCa2K1
sM3W8HhqaxOaPng1UOcAG3F+Kx89cTkHWjqJnPN81ej8i4CLBo/ZyOV+/MHs
gYJ/z0cOTAufFwVws2f3zuqNgo/wuXD7Uxjorw0r4HMbgRLjUecb66jQkB76
tEd5BCYe7o57O4kF5mg9WLoNQ2q2XyH5wxgcbXIiZH3vB7nFWQlvwtJ8zSUQ
nCBMAqETcf5ejbUQ8MTJ+IlMLZr7khdyU4INxwkFG7NmM+Ho1nJ/zx2ZSCLD
Tpi6lBf/+vfmohIr08YqYGpy5yCPdhsUL2gH0ltZoOjnsfl2+StgzVdfPCuT
ClcIz/HfZv69/ievLRtED7rgQkuOpRiNhPCx53YMJozCaN7Z58LHy+BpR5OU
qHITqhyOPu+7mQ0qk7t3ca/sgdv71TFJG0eRgItrE0uEDKtztv9Ys5QHJ+X3
DTQakdDHtcOy1xao//V4Xp9jbqYcxoJBBQuTcHYi4Kz3BauMdQAhAHxDUvEw
qKTnphUxgJReXVujEEuFm1GDg7WhbAjHsg73vykAe7N8C+6ZKhihzv/WGWTB
F73WM+TsBtQm4ppYtrP+v75+oTtHpl6lZMG7XPewIm82FDws4i7tqYWyi3gu
hUgWRE1Erz53rgJuYTtcTkhgIdP48tav53Gown3krcDAOARGFkneWtEIm7w5
glN5KEhaU5Q/JY+MUsIrL6jW9EKz1t7X/Lc6weOCuHf2RiZ4xzuWcTV0w6Pb
kiE5Yl/QDHZuSN+bhfRcYw2+uHRAAufwWkWHaigijg8rHmfBepefIkqGHf/s
FyPiUtP8FAZGyUL9XJxkEBJs56x58D/xgGE7zk2+aoA8Joo8c/1/D1f8m737
cMtw2eFaCEljhSh97kPWqrFoK5YJP1eKK721eA9sz/cpP+bzULvKD60oChvG
z34P1nrVCgpX5xc/XxtCd9UV8iNcGJAg6YUeFbTAVY8+SgcDg8574xIZK/5d
PyAuIfPszgQd9p5cN5Ad1YnMFb9stTg7AtOuIUn9v7rAt+m6DF9fOyJmbdqx
co4J33fOC4oEjEE1f6FDMMcAOorLOzXwrAe2GXO9inqFh5I7FVJpckT0wPPe
kQhv8j+vxzmGL7E6pgI1p3AYlq0cR6pDnM0KWX1g8lks029vN2QnSa4qs6Og
NZf4JI8JUEDw8U2Ko04beiRGWvzxlIWMpUPdCNN1sEefvDezNQi+xn7b9KmW
je5VCtL6LMrBNvx7hKVqJcgohwzud2ADXwPJhcJd+R/bX1vHPNENchWwybc7
2OY3QtkP0odH7rP/ap/oDryJXYeFIs2tXCmUbjT345GdWCITSsVyLr6Y7YHN
YeePjPZR0H51RkX1Uj3063BU1vKqBTsOsY59HCzUG+3R7umHA673OyzeyS/V
24CVLj2L4+i1zqk7iwpl/7x+40nNMLmWSqSB7xeRlugAnUc/tCQs/x5XT9ji
rapanWjulvPRyuwBFLP++IknKxn//N4nqlezJ3XrUElc16ifdB0y1cJPE1ct
nWtdfHmr3QjoCO95rfOmBBQRoODwzZ0MnW5DfI5ebbDQ/dRn4zALfZh/IUBd
KIPYGS3/OJdi9GDmoup6OgOV8/+uu1oxDGsWUwTdv46BRoCs5FNLAlJuilvx
1LIQWI6Ex2sj2KB89OCRHmYNatzQ8ihU/jWYXvB185Fggfd04cnMpC5YXOMu
//FVMvya5KO89GPDp6b6dulDdXDpXqpxZG40UAb8Xj47zkQyWo1yJR19cLhq
eqT5QhuohC3zHRNmy3zHvj98x7pJ9pCVKBsZdzw55KBSDTlCcZly3fVwp2/y
/o0NVHTNtszzzf1hSBMtPBgphAemScYP5Tf9aNtxX4vcDYOAYVqcifChgyYp
sK/qez66Lnf6eJBEIZxV3i0v0/zvde8el9zQ1oxXaDDXdZO0eCrKt5Zx5vjO
hjGD52KTQpWIT6Yj0OZJG8pZ/Fku2sAC5mpW+VvhWJR3bL1Txe1U9CrOsSlr
qU9wib87anUjBa06rWaHOdSHpqmuQZZW47D6t4PFnFQrknn58ppAFgGt1x/v
lMiig+pTF9cj9hgkh+lW+gDjSH/VbLe/VCdkuYxTTpT1gGnOUTHOTiaq6bB7
Sh5uAf7rUT3REuOwfa7e5Cp/P1RulPvxna8Yvn7Y6X7NpAe1nY1W1bUeQ6u0
NMIGipfmDdJUW2QSFWlVPQ/H1vVASvS7LcK/CbBRXYfG4mfDd+FvujZWdUB8
v/tK6r1auKXo8rhvcRwOeODTp3iaUd7x8436pVhYENETkr/ej16m8RlgMkaR
uQZn1D5TIqTMXCjf2paAKCPXtoTyL+0vd1/YrlY2zF5mSL6NHkdv+mhPbrFq
Ec7xsOv+pi6AJ67ONicJ6ArG0/NBIgHW65/SdDtPBoOTJQK/frUh9VUy2NRd
JNiV9vt1nj0N9lX6Ny5gmlC17vhohAgWqgKY0r4bWKD+J66m/sTV/j9x5dbw
SdLhBQ6xhOd2JvIQ4HzO+RNyOvS/7rv/sywXt4xMpHLba4D+8Auqj5EOFmth
gyWeoVu8B4d2x1w/Yn6RiK6KhL5UvkaDI6YrZ78caUGpsZLJnDl9qE8oZsWa
O0yY6FpjTGxsQh6z1JlnKWREezQbejaACu+9KcEv0ynQtj7k/apHBKh+31El
4DUCixurDAL1KGChE7K4ctso/Nwup6L0GwvrN4caypqQoeo31/NTayngxV2f
md7SB7+xqU+111CAHMrl46aZiCbLNqqvFKFB3NBs0o0v3aBKMfHAfKUgKydM
2cEwMrhfX3tr8AoTSmJvux/63ICYJhTnmbF+eLZumd9x6lrmd9r+8DvfqV6N
o3lMuO7r7sbD0QsJyh8lIlcvzbfHhTOMLLpQwbazmcStDDj3SeH1/tP94KYQ
4/PDmITidhjgT0uTwXLvMX+pqyNQ83VUUx6PQyEkD0/fZDzEVuENeNzpYL4G
H1zrRUQGn9/FdgiOwqleARtjrkE462famYgrRSvcw/vVyA0o/+D07s0qbOAi
OO9L6scg9daS6FjHfiR8QmBQc5QBsr2y+RY3ieinGeNK265R5Nn2rViqbQDu
KMsllW2iotf5awySsWRk4R+tajbZCgbVXCdxU53gdNRAd3LlOPCS7F+8WMCA
nkeilTTvAFi9uBo7F0kD6grPdym4YTh8y24L97ZmWBmuEWhypBcU7w4/Nccx
wVpjmUfQkFzmEcR3LPMIiZhd5vf3tILNgzxTA6NcxPNQ4CbPWjb033Ifj1LE
wtXr2cRjq4fRyfZtuVLMMeh1bimbLSOAhhNBKHgNCZlMhIiqvyaCX9wcv2Nk
DyJMdVnb2g/AF7msEPfrYxCZyJ5xiVqqfyIHdoTHUVHnnh5phewBGNS+zn1U
joa8z87fd79EQMcnh6WFsnvgoQt7C9+xcaTidiNR9ccXuNg66cEU6oPG3Mic
xwH9yGAsZy/mFhkqeWb2bawlQ1uaioPNbQbCB8yqsB8PQNf6vlBToQ6wv2XW
gj3RiTIeP39tND2IOMcO90YuzWu1dfIyab/xaHO9cI28Lgklc6Raq4uSoBxb
ynjk0YP2Cd0XDbAnA85VW1g6kwJlbptKEiLo6MQBTHXiRwLK/+S4e+WDNrgd
sYyHP9+/jIf3H1nGww0Hj2XW2uXBhgfuVa89xmES2yDyLbgXVN/nZ25d0wPh
vw0vO+6ig+z6oAY8Hx6Gbg5GnNDrhHv04olyczzMdf4wvPiMDvdJEut8g+Kh
buTeqsLMTODxWTf/ZoINLe+r/D38h0ESxMyzzzBgXH1s88qOJvhi3PgoZ8UY
es6RuZHnwiDyCXYrkFXtBUvKMr7acnAZX5X9g6+ePC6yn+9YA+Reu1X382gT
0sHbaRG/sCBMWPH2mu8tsHXLPompVwTUK2xpfrSEDrveXDLwcSkHiyv6OjlK
zdCUeC72FS8bpNpleKNXlCIdHh3xeG8qZBTbKrp6UmDE9UJo44oBiJt6ezNN
gYyEFw/LXxkkQ33E613F80y4ojF58mFGFDScTiXbig/AjuuVND0WGY57mXwo
2ESC/A9bVcjZQ2A+FYVRLB9GRyL7PMMmKcAblMmf6EuAM3/8Qv8Pv+y/cUVe
308BZml2J86ACo8vll/LOVcHe3UI0Z7nicjtyuTiVl0aCrnl4PG6Hwc6mcmj
RSqjiE9jlX/mk1GkKtnt81GhGlRP79rQ+L4WmBgNmmD0OJxP7ewcwHdB1cOZ
0F+vxyA1NTMmoqERhYQ/3aL5HA83R+TaFXfUQO/rZzYdhBGUt4VL/Lc+A0Jb
95U8rxyEaUl12z63MXAUO226kNwFH5rIUS/1sPCyb+buE90RYEolfMKFjQHn
1/rCqUfl4P3joAfSWfrO7WN121ezYe/4UHb//RBwqu7PEB6JhuNlYjFPFtgg
fjql1Ee0H14leDb4FpMB2zwe3By3dB4xZKNVuZfq59O9KUGCnyHiS0T1jlPD
fz1HLjK3KugJRkDeoR7Ltkvx6O4VyQT8LBsktpWD9fdqEFLYy7WbpwupTR1u
mm8bh1pF2p5yHgI6x/PWgCg+AqZajEOzyqMQ3XXERNCgG2x2SjgHMQnI8+Ga
E96CNCAaBfeMLM0TU7MSvHokMnJ+IRHiweqDd6sfPr6c1QUP7e5zbSAyUNzN
AoZuSTdk6ruWZHrQkazalKcgFo+aRgWTVAEHTMszpxt98WDUfN5WZZSOLOjv
pg5zdECcgoWyxcUBWO2cH5YzTEc+9tcU3Kh9oE8v+xp5lg5uM70J+pwY5H26
aNuVfgKovPkxaXSaArsP6brjnwxAZ/VA/ztfEqQ+2iLEy0EFrrydcVqRFMjc
+4SDs78Weo4dELq6lMe3ZInvMreToOl0WnFQwCjcXrMzyWVFCSg48Y8dMK6B
69L52ZqO/7m59ZGpY1dlQShYx0me/UR5jNLnb3KkLrKhNU77MKG1Ao7uiKJF
GVagy7mr5Afc2PBIcT3PqsV20G6VbvMsxyGdxSHCO4tx+Fje8flydTdEyfc2
BfiT0IS9xMfJzFE452qqrf6GAkSHAq3H7/HoooLx8Y1VeFCQlX6zuHSOtW7Q
tN+dkAb8+V9qpLqbwUBuocteGgc9ZJOYT7FjyLtPbPM5zmGY9+eLsz/Pgovh
OjqyczUo74XOfl4HLEQcxIP+4ij4501wvZ4jg/JdddqRD61A4DLcN8YxACbT
Qvu+bcKD4rPhNdObaJCr0HNh+mYVcKQEJR/zwADs+6a/KooFHXtuKHyJTISr
qY+cOl/nQPKBMLWL9P89fIBdFyqxlcUCPTUxJQtMAZAux+w6KNMOwuxF1dOD
qaB24frPgQ+l6MJovFdtPRvCkr7K7CHUQXmYrn9l3gD6dSHB5rYeEy4GJhcJ
CuOh0U5QbcOupTlJ4BvWtYACBVJ23+3OMsHi3pmAW4Y9aCRhZdlUZAe8HPp+
ueHgEFjw7hSXmacjRX/Jz7u1e+CH09GCC32dgJ9ZUer+mgEnqmiXVtX2gtt3
bEbVhX4Q4ptph8MU4PzodwE7SwKXoymBPDk1MMN/aWHbJwy8Vl4dq+P2P3Oi
mbwWd+LS+XHypb9F7vv/vo73b3Yd2Ujtzb/qIH4vxudr+wByW9eRs/Hwf1+P
ukh2rlz5jglnqSM/x606kWWBvPi1zZ1w+VkBZupmCuzjtBiaOZiCTN3rP9dP
ssGhhBqteqsWqk67iGto1qI+I9epm+vZ0FygauU03wFTiRHKVZNdKAKXqRkd
xITKrISF20/6QUl9VXnsXQKKmVYxPnSKCi6Tl92D9bPhoF5EJ7GRBgd/CXma
b/0fHMZaSmeTm04vPKj3Kb0b9z/7ohaZ9LY9sRJaIahnOPd/Ly88fZ1qdi99
h+wbZaeVl76DcUuEy631/7n1YILL1xop9IHU1Ln7Ub14FGIjLtW/mfbPzzk3
JH7H6+kX2JbPtS4lH4ssqrYd6Ihmwe7bAfxzXzHQrSf/9MpeKuq9IbTB3+7v
OBiffOhsx9I5R5aak13XSETrW58ZMPKJ0EP4diViegw0FamVScoE5N4levzE
1r/rdYvbiVdoEpUoUGE7f2psGyo7/ewyvY4F6WNnzs4bLNXv5NGCAadmtJOX
+S2zrQt2+cOVCxgs0uZuH/PmYSG6QGo5U7UJxhO8zoaWjCOH4KfnM7PrUNGd
oHtdjZ1wpjD6+71jDHhz08MkOxoPv22Pe7qk5MHmb+/msYo0UM3JxNYu9b2h
I84JvaLVoJWWkX3vTD1qXHftaEIhASqx5CgG5xjMH3lSGevABB1tYS2cDBZE
d3hOvif3/NWvFmPnNz8EulG5msY9hT4yUi6430WOp8CTwcOSpjVE9Lb1oVvl
XTJqdBsOC+gaAZm7Pi+8TzZDnfnmzWX7qeio1tHohqW+sO3zbSNkQQG+ueRq
3w8UMFa3UjpSiQOzitiPv54Q0S+9AL4qr1GkUbjixlrnftAeuKip1VwMQw2b
guWeLsUHV3CqmxEZni0w9H99YIApZt9+ubV9UD/rurlCrBNM3cu4QuZIsKdP
X/SmDwV4eJMvND/uAxEJb34ZdwL4X7oiqlVDB+PXugRsUSs06C/rCd07lvWE
qW7LesLbrg8zzph1wOsq6/PsY22ol2FPKCwchy6crH1ndSUiGVtezxLsgPwn
Ns9SrFjwJYBDBz9cinKDz1QfZTWgDfneL9z3sqF4AV+kjiWhqfTP5za1UNE3
2vuGr5swYBlqbfb4JR5tCgsPXNk/in6ImuRMbByGNTTsmqilum8pt+4xUegj
Skm+87pxLR7WX9czz67GwaPJZrG9ygNIhPDMWk2TAQF3duq3JfcCh03GuPmG
cZDak4bZLVYDb9YfvyGzoRC+YXEfJ9JYwPWk039dFBYEzZf1ZoUOy3ozw0/L
erMiQjN/3uomaOi3eZDQ2w2YXsPOD7vGAbubWG+u37PUD6056b2bBIs0Qac3
2FFQGoHQpI1MNBXq+VDidTw8TM57IhE0DPUng6gP7iIQPe9Uryfbhi7b+HaM
97Fgr3zdlp9itchX3VGnNnIAxJXGL/TYMoE3d3SgWGsIPVorphc/PYq+n9U1
LenEw9cRzWl3VTLaYpit8opGhEelZhY8YnhQGlrWKZmdXNYpsS2XdUq8h3+z
xpyGYGdvYU/MbRpYPTbblLgwCIdxJAsFkTQkVpb3TE6Dhg4fknaoHCGD72o9
jQa/EPC4Yx/3nBgNTXP2raFLfTjO+bKcJycFND6v7z1wjQgiVkU5l7RH4Cf9
x2STPAEpqlw9QFUfhuf8Dka8dqPA3TwRI2s/gobKOC5gihno3dHBk7a0Yhi8
hnUd6aOCcZiwoxuVCFuitClmdTigz1njjyY/g68zWiTZM5norJ1uoMQ0G4ZO
C/lPp7VDTYO16+4f/dDPldxXz2DAK40Zzt2pg9DDkFYp9u1FvOYPTx8Z/DuO
9Dc7DRIey7H74PBty+qbH7qR0wJl17qff7/3VxkdwLcTy0QjqQK3N+Y2wbXQ
eXbTrV6AYT+p20v+dzX9JJNW0ZFUy09/mmA/aARyrTRcR4St6xIiXAWpoJTD
gevN7wPb9MptmexqUC8dltvA0YXITU/aAzDjMGdgO/JwzzOwvWq3NZE/AfnU
mHo7L80pppnLeoMbDst6g9I/eoN+z2W9QUPgst7g9vNlvUHiytGZSLGl/n69
7EzBIhHVKrqc8n41BK8TaqKkZ7pAVV/EAeffiZ6JFH/k1f73fmO/gH3qQ68x
5PH5i6iS6xAK06UXjb/qBP7+cyfmTuSiCyW23K9l6eiQe13OfM7f+X1Bq5pj
TVFUUPBo+V52jAIWeglCi88R8J6SHtP2xMPjNVGTNtwMWHQpsHfBVwHBZ5mn
7sEv89Qiecs8NbNumacunVvmqd9zL/PUSi9jknlxFTCdmmUcbVyBHqS1RAYt
zRGNW4r5di6GgsLeR2ZDu0LRmZapR+8W//0cV8MYsuyUO0FEyU/eOY+Irhyh
5zuMU6Hrwjz55plCGDO/LitZXo0kHxfv3eX3/6NP2MM5Pl5FhEs8uTidhV60
l2kQH1M0+nddU8s+t6BROnBrM+7+MMXDiqlbJk+jOuCGzjIfSjZd5kNV0pf5
0P/zP9HzhUPcSZVwckR9cvA/2F/Jt8Xs/xSaBoHzaZbTvmVIt31X6eWavz8/
QfjxBvYXPPhES1vpGnUgw7Sfs2r5f8/rcJM1v2QWCsGdfe5jOGYM+aZFvmYf
/vv9ta8S+XmfYlLgZu2krdGNFJQ8MfYhdKm/jeCskXjnXw0TksErVss2oRWs
TKu8SRbc4QiZ38PbCBFt8lQblXEk8NzsWw7X3/uBf7XPRZNjD6/PQBN8Xzi8
7hWh2GFPjwfdbJhdEIt21+1A8gfEL4dy96K1txjOBfuYkOWz584NlUEUZfSO
hHOmIafimWojtWF4/WZXXI1fMxz6bSBTPc5CLYkivJ6TlUA873pp71KdOKSV
HN5sHYdee3kq1X3O/et6cgn79s/pscDxt+6Rmzc6YXOy1Lrpex/gIG5a8krf
KyRvd7FDH1KRfbD0jr4ZNjyeqbxrv7ESmXBEnytJaFs650dSj9T9nX/523vV
6bjBvHYWlJrxqX2qKERn+vLIRtcxsO4I6ePD/ljEKlDy6dAdRreECr+n7GHC
zRdaMhRbDDK0wamNLc37apIrUt9w0ADLcNkqZ4dFj8iXVYew40jvXG7O1ao2
6DlPNrfs7kYWm0WndpHpqPZtnvQW4hC0TVoLnDdtRRom23+YhQ6gg0evHnKb
YED1rvY44xAWekWTHJHmL0CvueQ/cz7oADEJtfp7xhR0V7yW4JExCPj1ybIm
EiSIeJQXM3iABGfMx4syUqkoureqSuQBDjri7x5fgacBnGnYok3MRUNGW9Ue
cpKhnH7sV9ajFsRJeK+ycicBviu029sJjMG7qx56Rv4IbWySMZSWbQCTkvib
ubvZsNa+WXo2lgW3tsq766U0wBAHIbxtZwsQ7lqEsb+NwRlWxeD6WTzYfX32
e5PTZwjsxljXl1GhOq3JbD0iwxbL4y4V32rhxu2gucWNVLi0K/wc/gcJqonj
WQc24P7K18xHXz3eji9F7c9OP1tgNyAvte7Qi0v9G9+HEF6rpbr8aWZfZ0lM
LfBrbq14qoOHo88FevrulyBH7uBsQmgDGilX8FLWZMPtnT12+LAudEn/YLLG
LTISmuPUPbtjFMp2+Iw0DjWhdA8v/fo7veibX7wAvoUJyfeC7P3e5CEt1L97
dUoF4hjWbn6ZvJQXGMcD9y8zQZR8h1vYDIdEap+FcPp0w141uUaTbjzK2qGR
+vIyBd2qKNfFD+Kharb1gaHZIEjm9ZndpZORdE1km2YKCZ7qM6PyNfvAW/19
yLwaAan9msPvWOpL9Cc+dds8q0cbUp8H6J4nIv+VxQdMwukgtyZb2fIJHn0q
VC32kRtFn4j3nu2SxUMi7cZC4V0m6kwbvZZ2sQYdefcg/4jrAMS+iH9RwNOB
fnwgv3yRT4F6Fna1/WcKCFjN9r+9MQaZ4lqEHYE4WHhkFIaxHwZxMFSPolWg
7Idremdix0Ai7VgvU48AQ/RZTDiOBCJ35t9uzqICkc5zKRmLgZpL/DRBHgo4
ST/wBNFREHS3EfFxx0F2VdfKg4EkZHv8451451Fk7fm4el9yD/g5zG7DeA5A
QJSua0n+GBS/nLD3kO6GQPxzvct0HMJmX9zgK0oCQY5Du5VyqJDzh4cy7V7m
odL/8FBf/8wFK//cM5L/MxekcJnbJHnikG/ZMzH3tAEoEjm63XcnAzKu3+7h
8RkCnZLvx3JiapAIZus3ZxYDBr7u9D2ziQgX5H3OdzqSoUBNfb9uNh7c5/Tv
8QWPgLVobcX7a3TovcST19rVDefzd7+3m8CBoHfzrYETQ+DgMlssmjoGW0Nw
Y9e0ytHIxg+GwYFVMG+re6LfmQ1jkpEnbLGVSLPuRbLrxg6wnhG2Xm/BguzD
nx6c58KAvlnqzUQOhLh5lY4c/8oCLzP/7m+sXuT/3MK/dwsRDXJu3cavSYX1
K58cnWnrQG+v7Lfg2TmALBU3KLOuM0D6tmtM0v1uIB/a/HnlJxKy8Wm5n/9y
FHJ/fKdUSDIhRxB7cgBfhMzEMzKfLM0vTryKsblXOmFcnOnTdmcIfaThHQSD
x0BsSGHnoDsFlD6aD3xRHUIZl2z6vhcSwUhfqNVcgIquelkeWPupHz4R5fdp
lxPg8IE4RA2joAXNwYB7jylorit0MDcSBx8it5gqfMejJC3LGCkpCjJfK/82
WYAAVXcq7WJThlCPjwHu0WEiZO2kGusXUcAkhoJuTDFg3cFAgxmlRnjQtGtT
fOAgiO5f5tH01i7zaJv/8GgJl5fnI//by/NRWNbyfMSfNH5/ypaOFqW0P3g1
dqA6hpGluhABOmvd5aNZveC5vrcce40CQ041Gao6ZDgTDb+t0nphQiJh44VH
THjJsA+z9muDXbnfas9J5MMFG0bo7bZxkHUJjJFt7gb3Yyetf5j0AI9ybuR8
LB0G7h2Y3uM7DIXhtROTt6io80HDo1eugxBmW56X/AgPr/oCoq3He1BLZ4xy
1I0h2DPE+2Osng4bdp8KvpfFRAkOupEZIZngH72OOqk5CLTfFze9XdmPrihK
cdznJcH8UKr1DeVRaPx6Y4fJXBWUJrFqS0QbkRnpcidtJRvaq5vVHJbsvVGX
pO2eYyBXzqC5KZQF8TccHwkMd0LAnsg6ZToeirCYhaNr6RBmtNVIxz8VnFWe
ntj+MQ+OZDmlHSSyAfvzWG8OfzWSsw73OSLYDbwpg/7bMsYhM95Z2TGuHQke
3+/JEzkC21UtW1fmjsF4zOWRXF4ierrruMj6QRriT2pstpvBws2gX7kbCj/D
aoFdg9XnS9DQts+Zwp/YsHhSWHCjGRXZnBoXtwsloNM+xpvq1fuhTPKh4KUd
w4jZcU7eXpGKGIfFitql8SD53v5y/CUMnOHM7tYL70FJSXpcA2+YcOPPvRi1
A8s8oNTRZR7wGHZ53iz+M2++t1qeNy3frDUfr8TAvINa2c6XBGQx0nJC+iod
ZpzdOyqsu6GYWkK2yl3KjyNaZ3WssOBB8+BateSX3AbzGhgnQ3X7EXfN7Xi4
kRBYy7jaBF2FThTdY3RkVKZyv+QBEe48chIx1KKh0z0zvquLe1Ew0YSh2YsH
r40Oe09lYCF8qC/UHkNB2syPm2mfKKCIu3payYwBNNcrXrYrnkH2osxG/3g8
yNZHi1ucrQHztYEaBj5YOMH/OvOoOQuobzZcJTztAxfRi88Ll/7/DUOZ+1g1
CXpuubZeK+9BrpaWv4A4CHuwNzY/+0mHB/x1+288aUZXeDtEKq2ooM2mfukv
I4OfyKqroQYU6M88nTtdRIT96ot0Su4QJF1rtBTWGUIrTqbP8G8ZhVf2vZdZ
JMJf525ZrtlzPkv5m2g1U/718wiEXr4c5eNPhaPpd/hX3SSih9E2uMYDFCDP
i7ydix+GAVuX+tLpIdgr7BQU+5OGDm2U1nIL7f/rPRR+jTRRylky+tmQYfx2
iIro2kp53iWNoOz08ayueh+o56VaNgky4MCXfv7ctT3QP7+yzvgtEe6/wz+n
2xDQ+VXPSJ0WJIi/iQkcCmtCaEjJSNaMhRql+V4dILfBIYnZ8hVCX+BmnyY1
bXUFum4lb9gVwwY12RptHcUaSKNM5znhhpBiiDlBYZABh8brVwelD4KppLqm
vNgYeHw0K3kd0QOeuF0pThUY+LZna9Ht8iGo8PhSYCXCABtWyJxGST+43S5s
yG+hQNFQcKy/FgleckaaeplRgbz7wuvC23gglbBreBmD4Ghzp0t+YhDm1yjE
f5kbQjZl59o+nKBB4OKWIol4BjDNFfY+Pl+LpBOoVRifYaBiRgZ8w0uhWmj7
9PDrBrBeRyws0WDDhld71iy014Lr3g/2HZs6QF1RU7ZelQW+/A/y9DjwcGWj
kli0ajU6Pr+FLmrIgKFi++cjGkv9+sod24adP8PGiQZ5rbx/1x/+q/2BQ+FE
9zYmWpna8vnFLAb2PiVkDR3rAwdRzpXoOQU+fjXeduzMKHzUzE1P3/T3ex9z
K3ONpJbyyPbhtgizix/RnmanNy9Dlr4r7dRqj3YShMz8sB7/RII7cutuRsEI
KDbz7pLaRIefF9c4Xzu0FC93G1jBMu2g8MF480bzUVDUfnInX4GEmtm0U01C
fbB6fYh7xsUIEHlj8IM3IB49zBc4WT/LhqwkWbftfDXAtdr2KodUF5rSa9jq
1fR3nKT2pRoXV2UVpIfSuoow7Yj3uYtbXBIL7nNmtNrwdEHLxCA+tgAPt7Yd
XcQo0WHI73B8xtAw2NDWx19QIMGkGj6M04MM22qee6xy6oafby33028SUARJ
helqSwPt0wX3V3xZyu9PKr2rPcno4oDAdOD9fuDzI9L89brBObFfKUm5F71r
Oscx5coA00SV0iZfPPA3pV03jiQhnZOxfp1qf8dD/obz0P7gPF1/cB6nPziP
eYBaV1ZgImhtsYhWiMgB105zAc+lv5/eleF7oxMLluLb3b8JMpGXm3TM1Lo+
yBH+XHNZawx9s92j1TI+jAz6nvEqJiz1D43iOxsupyILpUm5Di86+omlx/Cf
JgH/dxXXC3gySKxaGD7fgkNli2KCeLm/4w//KbvsB3NfD1M6mkxID/j8Ag9B
F6dYHCWd8LS2dfdNOyrkSwes/u5MAfttl4PfBVX89Tl3w5+eSV25tH7+e56C
JAqsk1Av5F7VC2JvSrZUfO0B/g4HdnUBA2SNL9g/vd8FHhPPUh8Nh8JJbs9D
ykKhqCXyXVXCIhvGP6UInequgJVnte0qTCqQmrmm0en/FxxJ/8+9Bp0/9xok
/9xrmOqTr1n1uRDKP83WddpXA+ZYXK9uABveei3jWpWDy7jW2/xlXKuydhnX
CppdxrWcVi/jWsaegqesDerhhbeaeow4DvBVmK3i8+MQUSpw6rVzM1hfGwvE
tC7NwSJE/v3fx8HRy+qjD7kTthroSAv9IKKzezMIQs+ocNbP5zgz+TPkRHbP
lJ+rRVc/CxgOXGMD9yVtY+m8FmA/lr2bxBhGA9uc1lqt/Xfd7L/aBxzm466G
UIDzVd7lbNFhFKwiQdPTJ4JbyGBd+XcWQPq8tZtzJuwYuVu+Lr4dZs2vtahp
EuGg7vc6I3w/OsDTzL37zSjUPRZIuZs6DvG/x1I8pNqR2w2ZBLLFv+v5/9Ve
PhS20tCYDBsXDzyTbqbCqoVr19NHm4BZls7u4WbC2eO9Ax/aS5D0NW/31O1/
16sEvSPauW1uBvdow3STmwTQ31937/osHb4fWsbxNP7geCa5/3cc77/l1/+X
/f+JH7qbqu5vT0kDE0FbwZb4MiQyRnfFVrNh84PrNumsOrg1U5bQ7NmPbt05
O3PuGRMOY4Pv8uNS4VtR7lrl4CL0KaivR7CXDVeCTgWlNtSCyEUzppNEM5Jv
y/q4reXf7xHcNjvBW07Ew9yJs/sDJQcQ0yd4nDuSCj428UcqzcdAUi5iLcWv
FxnNec7kon7wYpyP12nrhfQceyYjqRN5GLj+sk9kgOiGt0VXf47Ao0/p6hl4
PGqdPDjUukD55/Vce3PRlOsyBjhWfSBLnmKgyOxJorDkEHBh3/baEdrA3mRv
AE/RGLINvL7m1Ke/34/+m/1vOOffdP7K682l199ugn3Nipfuu2BQT7o3j7jG
0rkpYTIh5NoNInfVWBNHSEjvLf/R0O9L+ZUvT7HEN0OQTnjoic9MJCjGnj74
pBf+DwOwvPE=
       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.1225586}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=111.252\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646437531414`*^9},ExpressionUUID->"15fb8021-2a1a-4990-a80d-\
2906d0999a64"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyNnHlcT9n/x489e5YwDDIzCNmFGctNksa+JSQhxq5sZS+yZC1lyVq2kWXI
XsQnsmRPWUOKJBUay9c+9zef677e9zHv8+jx+HnMP/N8vB/nvt7L+dxzzn2f
ag336jOyoBDCr5AQ//4nvua2HOIde0PptSX+QtEfb5qConPCVNVNAa+5/tbf
FS9dNTXJ2v5IVfsS3/K+Vv8fB100Ce3fUOI1+nid+DnnjKmbfdFLqqoQ/819
Rrv+H6N1e+O53rY2pS632CfxuBk+07Y8XSLxJo/vb3u/cIvC+dXT1SIm+h2S
eZF5dz3cTxG3quJawHP4LfKXc/jL+X/9NTj8RXzA4W+VdzdfqeoY4vB3a+No
RyEGEIe/L71OlxbCmTj3F5z7S5z5uy8mJHlF5j3JX3DuLzj3Fxz+cs7zCw5/
nR9Ou6qqExRw+PuuyDoLIaYQh7/f42lw7i9x5q+D2/Wd0WMfSf6Cc3/Bub/g
3F9w7i84/P2u31MB5/6C/ze/C4jD3+/2AQbX/QUf/0/h2Ekf0iR/wbm/4Nxf
cO4vOPcXHP6ibsH/6+8s4vC36JwjX1S/+cTh76vAJ6WEv7/BdX+/z6NJSusb
P9Ve/OtTyV9w7i849xec+wvO/QWHv99/3xqTHvi7xi5iteq3lDj87T7wvr8Q
C4nz/BLX/cXvZ6EI+5WbZj2T/AXn/oJzf8G5v+DcX3D++wwOfwf2DTWpfmtI
J/x9snKGlfAPIg5/uV98/l73HvLh4Knnkr/g3F9w7i849xec+wvO/QWHv337
t7QW9uEKOPwt9Xn0B1X1J85/r4gzfzd0mD30ovpC8hec+wvO/QXn/oJzf8Hh
b41Ji7JVv2AFHP7GeA4pItJ2EufvI3DuL3Hm78jyGy497JAr+QvO/QXn/oJz
f8G5v+Dwt22z/htV1ysKOPz9/NmyhDiXRhz+ZpVsVE4IH+LcX+LMX88C7p2C
RycpVazGXPK/e8NUf9zrdNWvgwK+dtKxhoGjL+s6uxFHHGDvuO/IrEh34/eh
t/Y+baccm3R70a1tGcT7RJ27o6p1aZz/xs0Yv9L1QiFBn86ZHKY/u6GqDYgj
nk7xva+pft2JN3DZltvQymRqOXLAfdXPiTjivLHZvlxVcSder0y7o21bHSGe
lBnqPbvKE9JZfcDwHPP70Xn5FresN7eUoJddirzzuUb5alg5bZL9nLvKuSNe
rw44JJp4PFE/czpc36n6OdNzkd81dj27C9GVxud1hfE5h32ZLmFjvhRLkOyL
XbDtMKrSFVnPygNf1h7aRs8FR13ltPMpK0Qb0sPrGeNzDvuVfz67VnD9WVM9
rR56K7Bf9NPMnRN3nTe1flLqtqq2pudu+nY3zK3LdAXPBefzF+Mj73x8cIwP
+2pF/xhRsd8J0+qjH/JU0x9kX9TvYnGf1nGm5a07vleVXvTc6BXP0huej5Tm
BZ9HGB91xccHx/iwbzq3wCCn3P2mffVqtRXChexLHK/38HPIUdOCNpkuQrQn
PQ9LD7AJtD8u62Hzt/y2WoFhxVIU4XCmSvIv1ykvH2w9t+Steqh8S60/PXx9
opQv/vsGPZzDHnUbF9G+sfAfTPrBM653f656jFagh9ct9HAOe78tZeakHE2Q
7KdX3d7P6dwVSc+wtAl3Lg4NMZVMsP6kqkY9lE8L/L3C2J2mpub1rd8fFH9a
7yX3KCFEP7IHzzOv68R40s/rHHo4h7362S093Slesv/gkxfd3eWCpP+vNnWL
fau0Xvmkra86kh7/2eN6XZriqDSNvFFSWI8l/ZgXdtq63bAH7+hxJlH1G0f6
+XsHejiH/df9fZYlHTgp2fsmt6vukhkn6c+1ajwj6ueDkp4PbUqtPlj6T9ID
ez6PYM859PD3I/RwDvvPo172Tb8ZZWqu/f7/ocA+16NSoZhXx0xV9PcC6R+8
OmprgVhJz9cR4wpczjgqzXc+70g/4w+P7zji/ONjZfLaVraHkoz5OLTWlJG9
ktMUu+KZBYLyEiX9fN5BP+ewx7zroMcZ9uBvOo1LUR+PVKCHzzvo4Rz2eW8W
BMd4XpLssyb+MLr2ZHn+Pguwnhx3Y51p9pnaBUWcN+m503T4uqBakaZU7fdh
FNUn32/CnnPo4fMOejiHvXfPpHdx7+Il+9FX/rhqW0iev3XDpo4rHBmqbD0w
NEs1GXoiapxyHNNwisnDe4kQTaaQfsy7Oq9+y1TV6WQPftH94le15nzSz+cd
9HAO+8euyqHgkqfk+Nc90qTFann+VkpZsCMj6IBSXKMjSE/z7GZOdv23K0XM
2N6f9GPefdXi7En24MfGvC8t0uaSfj7voIdz2D+yTJkZ3vCQyVZ7Lw9QYH/N
olB93y7RpsTn5t+Nn0lPySO7ljzdeULSUzV2bkrJJUdID+nX552kX+ewx7ou
LfsvZZX/DUknn1/QyTnVlT6/Gq2LuKv6uZNf4C/mdy0s/LvSc/n8Ah/S+cv2
sHKXpfEn1U0uHdN+s+np1qL/vo/G0vhrA9o8K3l/jylN87cX5QXz5YPGfcge
/H9m7j+T9PD5Ap663dkiYts5SU+zFwHhlScvV6r13lRABM+j8Qfcib+/c+oC
06o1pS1E4izSQ/vr/Z7/qF4BZE/vL7tPX9R180kPr3/wk8L2fo9Rp+V8Be7t
P/rePmVj+bOFROJ8Gn9y2MCP0VsilDU7539VFxvzDvVczrV5CWFp2IOfTtxc
SkT6kx5ez+AxMRe2ui85rJ8jtabxbUqeHF67S4w0/q8VQg53b3iYxic9en2+
0epkrqFH50Hm9aQyhfZTLvFBswpbG/sO7Kd21Qyp17pyoqST1y34f88N7Gl8
Xp8Yn3PY36r56HHJgxcl+6sbJx33NV2Wn/vs7K17/bea/tfqcVHz+goc9fn9
3DWA9PD6xPicw77f7PqOFRzOSvbdPp6u5tfrvByfbTVG11k9T+kxsH6C6reI
9KA+6+c4tRdxhh5enxifc9jvOvi6l92fMZL9ut1VROl4k6QnrGWSRa71HqXG
34+cRJwxL1Cfky7GlhBx80gPr0+Mzznsu9yu2Dww+C/T9/14Q9qPrxl+OKHa
syOm7/vxyvTcbsOvtxn1CvuO2YpNq/+tElnyOdiGr5U22zaUz4tgf75y0aCn
14y6hX3q790P152YKOnkdQudnMMe9cz9Aodf0COdU+l6OIe949S+b7OHJEj2
bfOeX+4/4Yqkp071euXW9QkyOZrPbe4Gkp66rTb95FJmh6mTzfQD6mNjXqP+
t21yDlUXLyN7cOsaG+LVUSGkXzpP0/VwDvv4xAjXN6/PSvYnu9k1HvLPeUn/
7BXCZcb1jUr1Rqe9xdBFpCd6gnkCj1WSbmW8Vj1WkX7Ml+2Df54pIheSPfiF
mafaieBlpF8699P1cA77hYMe+r4tcFKyb7N7fujIoDhJv8fYncuDbh5U/BqN
LC4SAkhPWsbHE15jdikLNu6wFIlLjXMqfX6dqPKmmEibZ5xT6bxMUfP71Iv0
S+eTuh7OYR9Qwde+4C9Rkv3UkhGv79sfk/UfLHHO/0AsnT9TPcekV9wdcox4
qbOtIgdMzpLm3dzFAw4vOC6fZ8K++fjZ287OMvYjsLeaatGu8vlESb903qvr
5xz2/Fwa9pxDD5930MM57A8lXCp6udQlyX6345BUu2ry/C3VrPMvjlXWmM4e
3nVF9V2lQE9G4DTvm+f/NAVq3wWmUX4x754+PXhT7buO7MGDtHXOJoo/n3fQ
wznsm9WuPO7m5njJ3mbrXod2+y5I+gtmd4/x91irtAiJLyMiQ0iP9f4DVfO2
DDWFvLlbVQzdSPox7wpMuVNWJCwne/AuNV/+o4YvIP183kEP57AfXujSloPu
sZJ95LePfzq2k+fvvDPRI29Oi1KenXzzXFU9SM8voTUnvD24QykQ3OGNqs4w
3i/6vOte0SVZVX8le/DVWv3XJP183kEP57AfGus5Ks7voGTf48jySmGbjsv6
LWpsPtv3pPS+C7F8/zK7pXE+kNdtxumor9nSvAPfGvfm6NZ6NyQ9fB5BD+ew
xzxqVtrmmRo+VYE9eKK231+u4Ll8HoFbV7evuvvEJWn8ubc/mdou3mA6PcSr
rNixgcYPS+lxuvuc3abbE9r+rbqGUPwxL27axpUSq7eSPXjE16NFRZWdpIfP
C/DwGSvmRnU9J+lZ4bSxemBesGJbcZQQC0Jp/OgRP80eVHKuSU2dUFjs2056
UOc5rk3eqR6+ZA8eoX3/6kV6eJ2Dt9t39LxXzClJz+9Nw+bUabFf+r317uBU
0/fzVun3lp9r0e8z43gur1vwNiN7rZz74JBpnHL3uRo0n/zd4dHUp/DHGGn8
6FEWF20fHJbG53UFjvrZ0jdzh9r+BMUne/o+N7v/hZsuf5iwW61wmjjy6zu3
cXF7u0Ti7Z1uFqpZaLHy5NjmcsL1GnHEv0UXi7LC3pN46OPTjffM3ivx/OJz
+ZhjT6dN0cSbrLDKKXHvphKpz68W+vne0+1ldz26maxE6e+Fc6r5X2Pq84H9
IO3331U52Dih24AOyUqcvi76Uf+dgT3GsdG+O7gQj9bfR9/P+QcTxzhlRgR/
VdWBxBP09VjTpXteqKqzMvek/5ukqCQlXN8XdNHOSZzJHvw37Xy1OfH92F90
MOtU24Of0veniE/Xzr+GdbdOIm6r9ScYesL08wTYg0/Qzx84j9TPwTj/QT83
4/yVfg7MeZZ+bsz5ffa9A/1Ckez3EzyKvffBo9k6YWanrjMs+t+T7Ksk/90u
Iegm+Xvx56XNhXAw+p30PFbQ4w+OPIbbWmWYv++AI1+1NXsP4shXeS3+oxXn
f6dJwPm7NH5ZffzMIXueOqiJFM/K3uZzBhsaB3n8rJ93gSOPDSJS7IW9K3H4
lbLasobw76Uczh6+5NTERCn+FGc9vx9P1C8p/DvSONBTienh+QXPb3yeX/RH
8fyC83yB8/xaPl/UtXnKw3zt49h+BzyB7Y/Aw9k+HXw/29eDIy/NtH2oO/WD
IS+Kdj4/kTjyUkTrL5pEPJKdM4P/wM6lwRH/fvr5PzjiP17/LgPO449+LR5/
cB5PcB5/6h9jcQbncQbncQbncQZHnGvpfYzgiPPIpQ/T1JojiSPOc9unfFMV
LyWtYUrDCr73KT5ttdH7kT3in3jkc1GR50Mc8T+RVr6AGDqPOOL/qOmBgiLK
6H/D+C1rLygmrA2O+PO+OB5/cB5/cB7/mlaqr+PfTyR7nDciDpn6eTL1v7F8
gfN8gfN8gfN8FXV7cLnA7ifS+Ls7ug+KX5ZK8YzV4mn01yG/D/TzVXDk96YW
tz7E4dffvQoVFWKykhtxvLpp6BNJp88NK9H+i5GXO1p+jeci78e0PqLZxKFz
nlY/84gj7yaz/jSDY/zJ2nmd0R+IvKeYn+s9k/roeN7BeR7Bed6zn/2YPrD5
M8k+xtY7/tfEdIrPJJ+YwsLe6EvkeQHneQfn8QTneb/Z4FPzyjkZ0vgRk7tV
+rA4neLZSFtHLSA9yHsLfd0FjrwXu5Mab163g8OvO3tWxaomfyVaPyfhOhdF
24w5oqRTXr4OH1ZNWM4z4q/n/ffc7DjVdwlx6BxmeaWT+RwMHHl3CHd0E0MN
/Rh/aK/wysLe6JNE3ueWr2ch7H2on5DnHZznEZzn/eix37p4TXuerz2PPzjP
LziPGzjP7yach+QzPl9/giOPD/qY19suFAfk8SftXHSpER89LzV/2HtNHbea
OPIyYeybD2rjVcSRl+xav5URHxcSR152aPXvSRx5abGgQrqqNqV+SJ4XcB5n
cJ6Xefr+Kz97HjdwnhdwnhdwnhdwHn9wxH+ji7kv1IP8Rfxz3teqKAJDleqD
RrR5HG/EravW/+ZqxEfPy8Zv7j+IrxuIIy8XMncXF0OXE0de0vT9ODjGt9f3
4+B8ffJW3/fxvKBvMz/O4w/O89VtgM+PGz7l5GvP8wXO8wXO8wXO89V8Sx8v
14M50vgFn+3s3apHFsUzKshHVXuuor5W5Le81gfrTxz5nXFnSa7aPIQ48ruw
eT9VjY9QqmY0OltxTI6kM6v+/B3vimRJ63aKs5730gcHFxYXttL40JmqvTcX
Euf7AvD8xud5R58qzy84zxc4z+9zr+ejgu5lUxwyfml0THU9afTTsviD8/yC
87iBS/PxaPyJbsHZxj7ui7lfN46eizzW1fp7DT3IY0Lp2jv8kq8Rh/4ankc/
+VmlKEe+hJcu4ZxN8bQpZe77dSJ75GvMzNGWoucD4tAzpOz0EsL5DHHka4r2
/ppIPL/xeb7UKteDF3a+SfF/p523uChXdyxqKY4nUjyb6ee665soD2fWSaS4
RWjr+QpKQqPep+wG35HyvvZEcc+oK7el/H5zb97Puqqx/43aN95e+PdXPJ3O
WjRoc1vap19+kfNpw5JkaZ/bJGnm/p17jH36de0712jFyj323LcWd428+1Z/
q/r1VcKm7Qi3+pQk1fmTrKljp++4Q/kN1u5POSsj9L5NHrchicuDhqalSP7a
Du5k96BniuTvgakNLd9WuEP10F6Lm7uyWp1Yp+sWY7/Zzdwv7Tde+fz8W4qL
6b5Uz6mTlb//+v2hVP9zRObRCQG3jf2+9v2rrzJsWd2r50sb+9Nora9monJx
yjH/xEb3pfrf+8+HtTYxD6T50kXvo0Ndeev708Z6Hx3fz85YGtV2u80Dimdz
fX/9ZVtY5ZO5d6R4vpuUMGzZiMdSPOO/+RcreitVimdfx/QyjQ/I+yynSmOe
VA9LkfaP9bfu+TjtJ3m/Gbzk17/8O6ZKcf5t6alhuX/I+6wKev8S39ejf4mf
A7hbvenz5ZC8L66VuP7I7hryvux8dDXHcQUeUjwrmKH/LKWsbW6Z6/seS/vo
EMdbL555P6B4ntbe49OU88ULVnV7ly7F86+eqeOr7EuX4ok+FsQnRe9TCl1z
wnTbM12KT+dRPaNLLzP2X0na/miOMvPB2vKh1dIlfxv91aDkFQdj/5XY+aSq
7pqvJOt9C3z/aJNZNtby/WPyK8KvQEkRNk9ZlVIzwLtlhuTXdOuvtxu+kvdZ
tm+Cr4+0MvYjpk/mdYuj4vHHPZucnfK+qXzrCbV+vvaE/PpW8N0uVQ1UOunf
eblfn+b8PjVtwRPyq1nrTYNFWICy5fjB+6sGZZBfdvr+6HF87Yub2z4hv+ab
+y3t5yiD97bLXTg9U/Kr498/KB2bZEp+Lfy2wrZn+Qyq82m1MmLVIH/lw9n9
rWa5Guv2jy3M98W6KPX172LS+UDHsX6lLhv7pu+/w0uVVItlS1uXNdbz1SrG
3lW9QpVyc5IyToXL+4sAh7evX2RkSvXcZ4lT0qV5xj6rkrnPKniBcr7HqEfv
L2RQ3Kqfm1xOhC1TxgTecNi1KVNaD+9d3bHJ4bkZFDd8T7eZ7eay8USWFLcy
+ncWHrde1/euGdEvU9q/nA29GhG83lhvp+j7nffFKn6xqp8lxW30tRZFHbzk
dWarioFZtUplUjybNKhmKSJCld33I992722sw1csa/yjGLBJedg9r3tyurwv
6FGh3EC1jrwuDa650KlkcWN9bm1+r6m+it3Al3tjU7OkuPmMHLY+IS5T+r1N
CXEpN/FIthSfauGX/pmxNovi4za0YikRvV5ZOSK7+J8PjPXqeK/0l+q4VcqZ
e01HNBifLcVn6p4Lgz1DjfXnuU3vC4mQbf/+f5njWT9nS/665W07YN1VXn+K
+iWtkqxzyK9y+vq5Q0u/gqkF5fXnQDuLKSerG+uxA87HtqqfLin2szLOT7+d
Q3rS1rlZ+rd/oNQ9E1el5Yoceu5UfR1VutjmcW8dc6Tx0U8OPbnaPUQP6kvn
dYh7H+D8fhbeX1U0vxyN+yz/yYtxrwr11lL7/q4QR/zrdGuRoqqdiKN+2mv9
rp2JI/7B2v0pN+rLzU8//K2uraPcyF/+/gXndYV+e24Pnt9zkUd+7wn1GXuv
ekvhb9wLQHzK6d9lwPl6ku6PsO844Fw/5VGvH37viX/3wXMR/xpa3t1pfOjh
96p4/YPz/RfGya8+kV9+vwl6cL8JHPb8XhUfH+fSPF8YB3UyVrtH0Ifqiucd
nMcZ6yhuT+sr9lz4izrpUm5YAxFn1Cfq5Ps9HePeFuzrFfN4pqqjiMO+vPa7
atyH4r/z0MP10++AXiczPhUuLuJ6kx763nrLfI/JiZ4L+0Mb25USaWOJw/4X
7Z7CWNLD3wvg/HeY7mXko5/bQyfqEPeDnNn6n98besXuDYHDfrRuj+eirvi9
AP5egD33F5zbQyevW4xP59X6fgTjgO/Y3uyuanKlfm9eh1gn8zrE+Kir7/Pa
uM+Fuvr+PcK4XwP7FwnHUlUP494T37/QfQGWR/D81vP56ef29Pufz32Z/+9+
Bxz2Bc3fSVXjHgrPIzivQ7oHwfwFl9btuk7UYYT2uzeZ9KMOCweY+/aN+yaw
P2f+HmTtTxz2v2n3+Pyozx911cfHuriIMu5N8DqEPfcXnNtDJ8bHvRiMz/d9
6DvldYjxYZ+85t5nVW1P/eG8HsD5OHgu6jPsQblU1eSh8H3iI3afBXX7nN1/
AX9j/t7nP8m4R8DyC87rk947er0la98BZ9BzUW+DtTo07nHAvuKt50WE5Rzi
tN/5X41/VNd5pIfnC5zXG577n++J1gGkB/Wzxtx32svQA/sgm+tCWBgc9g7m
870s4z4LrxOMjzrBvZWk/PbR+r6P5xf1w+sBnMcf/czcHpyPT/cj9Do5stGr
kHkdC456sNx+PUv1m2r01efT387jT/32zJ763pl+qnO9Huotu39Zfb2A9KAe
2m9rXUhYLyQ9vB4c8zkHOJbPd0xwrh/PRT087bGzo7l+wFEPj8qd/0GI+dRP
zp8Le9RDmrmfIW822YMP1v+eA/Tzcwn0JfI8YhzY83sZvB7AefzRfyt9r9F5
fvWJ+llyqds51dSL9KN+Oo8Jj1WP+5O/sC98qF+wqnYjDvuDpxYeVw8sMPrG
Wf3Y5HNOsiGf76fg3F/6fdbrrb/Wr2jcX0C9TfSd4ihGLyadsJ85w3RffbqK
OOxNcTZVhPdK0i99t9L1cP14LuotbNvKfsLCqHPU27G+LyxFlnH/AvYnzc/N
W0oc9v1TKpcQ1r6kh9cn9OSnk9tDD+q2RGvzvbOp1E/O13V4Lj/3yMvv+6M+
DrdH/fP6LJXPOdLcfL4XU189ey508u/p4KjPWvp5FHTy8yhw2Ncx38esvMro
62b1SX3FTD+9F/R627370mNVWUt6UG8fzX+vpnAoPRf2Lm61K4nYjcRpvad9
dwgmPTzv4Lw+qf88H/3cHjpRn8XNz7UPIP2oz15K+1xznzB0wv6Jd7+36mNf
4rB3HvLp331fH9LP6xN6uF/g3B56ULej9b+fA3tez3gur0/Yg3cz58s0nfqu
86tb1M/6bXYvVa/Z5Bfqp9WncaVFVJhxX0C3d7D49bXqGUwc9vfCXAuIj+FG
PznLFzivN3q/6PWTLSLLi4wtpAf1k23+LnDReC7sn3ysXFj02EYc9s3M63kR
SHp4XsB5/eC5qIdR2rnWGNLDz1vwXH4+A87t8VxeDxif5x32/JwTHHl5bztq
p7rX6PNHXhzuLnzkt/AMccStY3CN8mLEDeKIm01c/RLiWRxx+MX7+fl3ZHCu
//8AootuWw==
      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3n8z1UWxj/3fGQwUtomkX1JhEKWyBIz/JQKI8mSrWQPg5K0UJEa01RS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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkYkFMWxu+9nyQtUlEhSUQhJSJEVBIqRVKyVJOEakhlzTIzJgweRmNs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             "]], Polygon3DBox[CompressedData["
1:eJwtl3WcVDcUhWfe4IXiLa6LFae4u7vLYovLAsvCogvFirs7xV2KO8WLu7dY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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 426, 680, 586, 708, 
          442, 703, 600, 735, 458, 614, 765, 479, 762, 623, 789, 500, 785, 
          632, 813, 517, 808, 645, 843, 535, 838, 534, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 428, 706, 587, 714, 
          444, 601, 741, 743, 460, 615, 771, 481, 787, 624, 795, 502, 811, 
          633, 821, 519, 841, 646, 849, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 431, 590, 720, 722, 
          446, 605, 749, 751, 464, 617, 777, 485, 793, 626, 801, 505, 819, 
          636, 827, 522, 649, 855, 857, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 433, 594, 728, 730, 
          448, 609, 757, 759, 466, 619, 782, 487, 799, 628, 804, 507, 639, 
          832, 834, 524, 653, 862, 864, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 434, 732, 598, 733, 
          449, 761, 612, 763, 469, 784, 621, 490, 807, 630, 809, 509, 837, 
          643, 839, 525, 867, 656, 868, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 588, 712, 436, 737, 603, 739, 
          451, 462, 768, 769, 471, 483, 791, 492, 815, 634, 817, 511, 845, 
          647, 847, 527, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 592, 718, 438, 745, 607, 747, 
          454, 468, 773, 775, 475, 489, 797, 496, 823, 637, 825, 513, 851, 
          651, 853, 530, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 724, 596, 726, 440, 452, 753, 755, 
          456, 473, 779, 781, 477, 494, 803, 498, 829, 641, 831, 515, 528, 
          859, 861, 532, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 702, 585, 425, 731, 599, 698, 441, 760, 613, 727, 
          457, 783, 622, 756, 478, 805, 631, 499, 835, 644, 806, 516, 865, 
          657, 836, 533, 887, 666, 866, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 869, 536, 520, 842, 840, 518, 503, 812, 810, 
          501, 482, 788, 786, 480, 461, 764, 459, 742, 602, 734, 443, 429, 
          707, 705, 427, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 856, 650, 848, 521, 508, 820, 818, 
          504, 488, 794, 792, 484, 467, 770, 463, 750, 606, 740, 445, 721, 
          591, 713, 430, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 863, 654, 854, 523, 833, 640, 826, 
          506, 493, 800, 798, 486, 472, 776, 465, 758, 610, 748, 447, 729, 
          595, 719, 432, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 526, 648, 846, 844, 
          510, 635, 816, 814, 491, 625, 790, 470, 616, 767, 766, 450, 604, 
          738, 736, 435, 589, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 529, 652, 852, 850, 
          512, 638, 824, 822, 495, 627, 796, 474, 774, 618, 772, 453, 608, 
          746, 744, 437, 593, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 531, 860, 655, 858, 
          514, 642, 830, 828, 497, 629, 802, 476, 780, 620, 778, 455, 754, 
          611, 752, 439, 597, 725, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 825, 294, 824, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 265, 800, 263, 801, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 803, 266, 802, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 241, 784, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 702, 139, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 724, 167, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 168, 725, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          745, 197, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 198, 746, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 224, 768, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 225, 767, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 861, 860, 340, 334, 853, 332, 852, 
          326, 847, 324, 846, 318, 839, 308, 306, 834, 833, 300, 298, 827, 
          292, 820, 290, 821, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 799, 264, 268, 807, 270, 279, 814, 815, 285, 287, 822, 
          823, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 866, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 868, 346, 344, 864, 863, 338, 336, 857, 
          856, 330, 328, 849, 322, 842, 320, 843, 314, 352}], 
         Line3DBox[{315, 785, 275, 281, 810, 811, 283, 289, 818, 819, 291, 
          297, 826, 299, 832, 305, 837, 307, 317, 844, 845, 323, 325, 850, 
          851, 331, 333, 858, 339, 859, 341, 865, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 869, 355, 350, 838, 377}], 
         Line3DBox[{351, 808, 313, 319, 840, 841, 321, 327, 848, 329, 855, 
          335, 854, 337, 862, 343, 867, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzVvHk4123XPkpzaUalpESiJKKEailpMCVCSMpYZM48z7PM8zzPU4YQyxgi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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.5239258}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=121.253\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643798174*^9},ExpressionUUID->"ce7dc847-15f2-434d-a001-\
f45d16c94612"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHdcz9sfx49Z9r4ZF9nzZsv+ZCV7j2t2QzIL2aPMXJI9LlJCiiTKKOOT
kUJpUjJKQoS4RmSc3/18fF7vz8/5PPLw1/PxepzzXud8z/pUy85xyOSCjDGX
Qoz9958tOnKktcnxJ/LTwelDc9JSZKb9Ax99bnCxD4F3DPx2jauXPi9LMPC1
xadm5f1z28Adk/sOLdwuysBHHbK4VOruZQNfnVF7iEXWGbl51sGHnE+UwP0+
xw1caXNInh15oTgL9ycePmBTedvvqyWxHVPvyn+2jAwkPn9uk4mRsY8N/oKL
/oKL/oKL/oKL/oKL/oLD32Df+i6cr5fA4W//L9NLsaAI4vD3ZxyOExf9fbZ8
fJ0yT9MM/oKL/oKL/oKL/oKL/oKL/oLD3590nwQOf3e08d7OXS4R/9Xfw8RF
f9N/s3fd1PiBwV9w0V9w0V9w0V9w0V9w0V9w+Ftj9tqX3MVPAoe/NeLfj2Nx
ocThb+Mm1coy74PE4e9rx0ulGLORUgNnPizjlGLwF1z0F1z0F1z0F1z0Fxz+
fiiyy5SxJWQP/M3wWFSJuR4gDn/zfNq85o5niP+aX3/i8HdTu+4fubRZSrSe
12Hz6SSDv+Civ+Civ+Dwt59V0RucN6P24S/iDA5/S+Y55HLuTFwcv+C/zle7
iMPfn37tJg5/Me/FPFq6q+zXOIO/4KK/4PAXfoH/6q9EHP6K/Nd6tiUOf+u+
6fCM8+XE4e+bdRklmasrcfh7rfr7xoy5EYe/iKfHa9MXtVbcNPgLDn/hFzj8
/Rm3ocRFf8Hh74Fm53owNor4r/46EYe/P/UOxOHvT/0g4vAXeQQX56uV1Ssf
rF3yqsFfcPgLO8HhL+oTHP6Kevj7oFxElf9+HYn/6u8g4r/+/g4lDn/FfsXf
X3D4i3xl7RkQZm1xVvB3EPFf61nnv9azRBz+bjqXvZvzMcTF+QpcnJ/Bf/09
0jn8FfsV/QUX/bW8GT9gm3eGHPqm68QVi5OpffA/hgdXXts7ycDFcT0gvKdV
1iJ9fih+48wjPmGydLPIHmf2VwLx9JHNP/A0J+pXnPfAfc7Xvb2+cryBi/M/
2dmjqUnN2FsGLsYZ/LdyZeY0nBlBPGHxuxJxW++Snc6nc99yeaX08dVXh5rb
H8vuGw7OqVDpLumDy9RfdcwtXc6+vC3aO90YN3G8gIv5RftiPNG+yKEv8G/F
hpUzEwx624ZFVh4+YcwXP/8kdOJvl+S603Mec5fBFH/UlcWxq8F8wgryV8wL
2hc59NlBJc+3t4816JM85lseXW7MY/xw/03zh5yUbUs1fMpr7id7UM+/X5tT
jpleInvEvKN9kUOftCynXvfCNwz6rS9j743bG22wZ8Ol8zvqddgqL1tYpQyz
P0f2YBy1bl68KLvgTfaIdYX2RQ79xT4Jm/v5XDHol5w91WNK++sGe8q/3vl3
5DRv6hdcnJ8zJnl3cPz0SJbHf7zfcolen+OPfpjl9vCBXGPH0zbh1ikGe8T6
hD0ih16sW+hFDnvEuoU9Ioe+VYT9Fss+iQb91q8jsq9VMtb/gGbTco+5npOT
4rtu4l5uEuy5YdpkwuNAWa7YcOEJZZ6BHnX+TNV7kB68YvFH2XzBLgn2iHUO
e0QOvV+TFOtOVeIMehO7KO8bmfEG+ztvnbBn2aIjcvXFl0qwaVfJnn0+b1t/
eHlKvrhkoikbf4rsx7hYssy0CMu4RnrwQXE2abzbZbJfHBewR+TQt6+77fOK
uBsGfe7muQH7psQY7H8S5x/3dI6T9MXTOpcnBpE9we9SGv++b7dseuj+We4Z
SvZjHM1S15kBpAefqXArP7JfHEewR+TQ1343b+KGWVcN+vRxI8x8i0Qa7Hcu
ur605c5j0jHVnnlkzzffsst3z90jDdl6tTTL8iT7xXEHvchTc2wOel1Lld+1
6NVzyGN9PI5o45l89liKPMjB0istIMVgvzjuYL/IoRfHHfQihz3iuIM9hv2X
prfffS5vRFCiQR9x229Y5hLj+K289OS+RlXC5Ndc+bddgj03GrdfeeJguOyt
cmfKL8bdgH0H8riXN+nB33Xc+Ia7+UqwRxx3sMewT9T0qT8aBY1xiTPo27ep
WvxFH+P4jW/yJnPh0aNyr09RATwnlOyxz7FMnb0qRH48sPd1PvIE2Y9x5/z7
x+t86EXSg7+t07odOxlG9ovjDvYY9rOafv/NtrfC99006Mdamrncb2Ucv865
O0xeNLKT2y03sWTtjpM9qXU/yeV/7Jf9okf2Z4XOkv0Yd+NtK5Zk7Q6THny+
8jtY9BDZL4472GPYd2t6t11V2t7scM2g71k470VmfKTB/sczvl7tONlPmqCe
J6wie+7OfZ91oNx2ybp+06os04vsx7izcFLW+Q1JD170fOMSzLW7hHVdnSL/
BM7ulWywUxxfsNNwXqHpMb6O95hdlFlNkqAHP72jlCkbtIj6FccX+O7pxSfN
/y3J0P7jqM9dj5w8Lz+t+vVfvs2b2reIfzDsjeNlOdDe7wePXEl5wXixUsZR
2mHSg/8Ye7M8e3uA7BHHC3jJhCVVljyNM84DEUubOd8/Ls/4Q+7CpgVT+807
ubjkVDsj5zim12Q+B8ke1H+MS0Ar5n6O9OApa7p+4IfPkD2o/z3qfqQm8YKz
Uz25wy3iaL9xZs0ZUwaskAe2+fKVmx2n9lnA30cLB/nILWs/ecMPnyY96vlW
hFlp9kqPD3jI8fIl2Hh/6hf13FCtq3bEsztfNC1mEiGfTRxQnLFZ1P6AxBmL
rFoflnL7DzFlUduo/fErAo6MmLBBCplWsThr7Ed61Geisr+QFpMe3DsqO5tv
8pCwn8o9kHexUIZeP9hPjUh5abbleLIhj2LdgqM+v6jz8AJqX6xPtJ/f/m66
6Yy5picTDPqbXcbG7FiaZOj3aCWr53X7XJT5cfuKzHw7xRP1OU87X0L7qM+o
bkrec7qgffCx6n6/Dunlh2GDq7JYOm+BvsvhmJV7+sYTR79LTxS5aLk2SPZZ
UPUhj9XzjvoMTMrM4RMCqH3UZ6chtzI4b07tgw+rODyR8/ak9zvqeaHO/ij5
eZgy//Qivb3ZcqcubaLlouO/vOe8G/U7o8/oncPKe8irlXkjzoc46jO6xYmC
7K0PtY/6FNsHR/vQb1ng2uCPTlfk7U7nc3nsXNIPzLS93ysxQh6txt+O+r3Y
/pFFz0I+0j8q/2/e7fvGr7KNfg5WrG+RL7zMbGlNrTVhf42PJr72i3I+Noz0
jeb1a1DHRl//QO92rNOKoAophroS6xZ2ihx61POYaf/m8mbO5Bf4pPMeX7g8
lexBPRc6ee0u5yZkP/iMIIU3IL3n/YsPGpglUv1A/61cYNvTGUnEaZyuu153
ZshZuUmn1m58099kzxw7N3efjEvy9W9jvbi0iPSo/2MV7NfyXutJD/4oyzuS
x64ie1D/fgufxnLekewBd1XtGUj6uqvH1/0zOlYeWSDqAXfpQXqnhTVfhZ6M
1+p5ENnj0bPyR55+WPZ65l+Mhe8ke3p862d3usYpOUmZNlw26HWujReLMguL
syhdD/6j8X+/4+buZI94zgl7RA59qcFdN9lNu2HQ37xYq/uyAjHEYc+Itpl5
CW2XSR2qjPjEpV1kz4hRfdLNp+/Q7HcnPcZXprJ/mavr6ZzfYnIxZrOZ7MH4
stjnWIgxa7IHPNmtanPG9Pr/VL1u3nTTq3KGes48nvTB6wsHrvW6LgfUWd+K
sdFkT52h8cEhFselher9iwPZM8bKK2rbIU9p4SAvM2blKi0P+KPO1qZRNO52
q/NhBWmB5d0NV/L088yFap00If0Ym/2buwX+Nx77tU7lvB7pQ5d7vIxdlCJ7
d1HiybvAfnHcwX6RQ49xV0WlE8lf8Koqn0H2YNxVbOFai7n2IHvA47r17Mhc
h5M+NrCMda9lifL6LqnfuTSc9BZPuVeSzR05zPeOJXMdSfEPv1Pq5st+obL9
4zLZvNlSssdz5PPKmzuHy7PV+WEu6THu7tZb8Y47LiE9eK+YoRVYuBPZg3FX
Ts3XYLIHPH2vUid9SN+j0oqvffvFybX8J7/jLt1I79N39vB7ZglywaLK/VQv
sqd2mq/0tZy/fM/ur2qs7DKyp2Tv7SatzgbLLUe0NWdWs0mPcTe8xtuKbLNu
P/hWtQ7tyR6Mu4o9SlVW7IQ94DfHTO3w32qY9LNzM/860PYmndtT/CdFVLoQ
E0Mc9sT1X9IqYkF/qfS6p7VZ2VVkz/wNU+aZxeyVu6j3LDP1fGnj7mPb3rWU
9T/04GHq/d1csgfjLmpJWAOWPoXsAe/S4lRl5j1fr7drkdFHk67Kh9Tf2Tmk
N2vh5xoxPVIOcnT/jaUvIHs2hXabGvrdX3roF/2R58whezqUWtnKs9suyUQ9
R50qpa/+nvV0i2w4Vwd3r/b2y18Vk+VLe47UZ67DyB5xHMEekUOPcZSizmMO
ZD/4CXVdN5z6xThCv+Bs5V8n7J8kygVrnjdhrn3JHrfawx0dnobJh7y7NFPG
L9pnP9Zn3y52WT5VwqKcMr9Bj3GR0ym9EfPW9eBP5ld/z11GUr8YF1+WhnxV
fo/A52UlTJp+Kk4O7X3InLHB1H7QwjbrP3ULkHeq6xB9fCXtuB8QNPC03EKN
/1DS073Pyr6FmWt/0oNnHChakrHe1C/qfLM6D/xJPNFzXev0grfkmj7tCjHz
2dR+gF2RwMcp8+Qt5s8TuDSB2reZ0K2Im9kB+eiOlDzOB5Ce7l8mXI7jLmNI
D173uTJvt6J+qZ6Dv//OzGcQvzBtutcL72tyjJrfrtR+QfOQGpeifSWxfsxT
J+33Td9MHO2gruxV2onaR/2gffB+jvsqPlt2Qf40adQ97mJNHPkVeYfy15Le
zT0h7+88vwxjHYkj/mLel5p1LjA+yE1bzzQhLt5bgS9aWy/pyt6D0udVFR5z
Xks6N6hA744PMmQ3bXxB/+nL6HGOJTLkRtrvAjje24j6+a7rR5r1ypBnausi
UZ9fO7e03yOR59dOdW09RnYWDRssr8yQbbV9gajPjx/U9hcif6btT6keNr7o
O+VShoGTX9p5Qujzn/sp8BTt/KF5Rsk7nI8iPl47B/NLL1+A2boRv6Gdm/1R
b7WJ8g4EPEA7B2544y8TFnKAeJZ2bhyinrsuIl5Wu++gvGjvhQz50riYF3Ax
L+8jHm1oZpFu0OdWqGJdJi+D/G2p+Yt2xDyCi3kEF/MFLuZrbr/Sa5Onphva
X7jHxupsGz2eeep4PET2iHmkOGh5LK++6+hDevjVSL0HcZU+my/sMGG2Hv/V
6nutHaRHfq8q+1/5MHHYs1H53QwKJ4788ryyxVmny8TRvqeidzpFHPm11O6z
8D5KzC+4mC9wMb/pdSKc0w48yFcvxhlczCO4mEdwMY/gYl7Ifi0vf6p5HEP+
Ii+f1d/xLXS/kCXcp0CPvJSqeCGZx/oSR14aKPn1Okc84P/vX8bpHO1/VM7V
jxwljrxMU86BF+6md1xiXsDFOIMb8qJxMf7gYvzBxfiDi/F/op0DIw79tXN7
6MW8kP1aXtydfu6zwJGXUcp9tNd+KXM2t5Bn6nFLqp1hzpb6kx556X80qhzb
eZw47Pl0NLI7m3GGOPLy96Nq3VlcCHG0/1vY9nrM+whx5KXWsQHlmcNOem8m
5gVczAu4mJfEoUkW6U3vGPQPtfNJxOGDdv6MdsQ8got5BBfzCC7mMcG2VZ3m
h+4Y2n/47ciunI73KZ7HS9fvzdxPkz3Ib5q6L5hOHPmdpezfTVcQh1+1q/lW
Yw67paSZW81cq90lO7to54qPipm4S8H3KS8blHaifKkd5L3ZY/vizEfnsLPC
jF0feKFg4sh7+wlXPvA5Okf7NrtOFWZ1A6Q72vkb/HqIc2ZNj3rYlhlUiBX3
ofd4Yj2Ai/kFF+shJvv+Bts58Qb9XbdBzLx4MsWt8M1iVVmK/j4Q+Sqq7nfK
EEc9NFfPRRsRR5y/RZp/Uc6vwFEPL9T1eS8p+nMH16AX8dQ+9lPJ2098cFyR
THGe7vj4NT92ktpB3L6q7U8hjnpoIyU/52UWEIdfpZPvH+exq6WUA6VfyJ+T
KS+flN+1wn6kR94tW47Yy5M9iMMeB/Uccgdx5P3mzaKFWZYeN7Q/XdXr7yqR
33IbG73lCzbS+0Mxv+DIV12rn+c24MhvQ+2cx8MkMv6y4y3Si+8tEecGWT/3
I+DIY5ejf9zmvBNx5FF8h4k8ipzm4SglL0OJIy/B4yK/8TQ74shLnHoOP584
4n9X5S7EEf8F6n2c/p4T8Z91ttdvbN1K4oh/gxItGrDma4kj/s6qfgW9h0T8
G63+ue8ARzybqefGlsQR/w4P5kVz3p844txMO3cFR5w7aee04IjzNbOxtRnr
Rxxx9olQ9ngjiSPO6eo+3V63U4vzd3Vf7EgccY5Uz2GmS7fiqx8MX6XHp4jy
e2S7mvSI/1nlnI1NJo74P1Dt1N+pIv6V1PMx3U60X1/dv9sRR/ytJiv7yhH0
bhPx39pmYH/G+hJH/APLfu/EXHU94n+luH1r5jpQenH75oa1JUJJz2POFmBs
IOmRl9PZR5syNoA48tJ0Rc32LHw4ceSl3diYhsxqGnHkZd6BjlVY3ALpecFe
465nhVH7D7T3qOtC3c0yDkZR3Eqr74r1d63I4yv1HexM3V8tjyvV809djzxW
V+M8RHrV9qpF0esXyM6CC5RzmOnS+sQ+bOXWGxT/w+PHZSj3PmgH+W1gMuGp
0g447Cyrjl89/sjvt1dzijFXK+Jo/+f9aWXiyG8rdb9fjd6p/jq/6e9pkS+T
SZu/KeMIHPk1r1/1Nec9pCWxD7O6WYUL+zgb0iP+A1qnnOW8N3HkNyfumD+X
RhFH3CYN3SYr57rgyK9NqPKOt5q09MXe+AyLyxSfF+rvdTfSi+tP8kvLo8hh
P/jyQqPDVla/QvHcp/3OQo98VVPnHzPisMdCm5fAkS8r9XehDXG07y20L+bL
Mrl59ydmxnOPc+NsO28YajzfaJe5ybLVJuN5RcjvaxZ8/ZFu+F1rczBk9sEO
xv376bbdbfe+1ve5Ydp5xelGmdP7zjfux9tenDO6e6MMis/i5YGx3Gu71Cao
gv37k8b9+PuEzq4uh9MN69Uz3X2GZU/KoLilzncuzxIuSs5/zlzc4HG6Ib94
n4m4tdX2uRPjy/Vb0P2RwV+7R05WkWGPDP5+SNvnHPu7vn9vrO3fgwtGeowp
m05xqKjt9ydmx7Y2a2ncz6Y3rzu1WZWHhnX1PPvoWQtG6fv698o6p+5lqdXf
n9YV6pdOcXup8EPHpEmfLRpN8Tfufx93XjXOZfNDQ9zwLg5xK6q9A8zokzE4
1uSRIW6tdw5fNvRqumEfOm5qFf/cdamGuI2bv9CzF7tviFvq+ej4Cc+N+6An
I7ta13R5ZNh3T/DcsdjSXt8PDtH26eNWJW/ZteC+IZ73oppcPzH+niGettq7
I8Tts/ZObPzmtmufv7lviNv9O+vD+J17hrjZnh06MXnYQ4rbhxo9u7F6p6UH
GS8CB/ZPNcTN7tqpkQ2iH1Lc9myuUZ5V3CmNKFCr6MLbdw1xG1HaNS+yZ7Ih
bn9q708Qh7fa+6KR1dLemF1MNsRhdLdvt0zq3NPHV8vA1uzZEWlUwy5PprTW
93eVu/58vzF64JjwkXvukV+xNf75yJedksaODQs5Ui6V7P+4uEdJ1s9TGvxP
w4mfKyQa7B/k6zbSZkOiwf4hMYdat3unr/ODlPcSTkulQcHP+u4uqO9HsO4d
llqo0TqHO2T/k9ebLvJbe6XB2j0s7H+tva+4rd3DIl+ltfcVw57bVU9Ju0N+
PcwoYcLaeku3y39xGJSSoOdL1dtLwz9cLtdw5F3yd4tyryFvl7bb2bq+O3Xb
4O+2pTWmbjkQS/7C/riao8Z5D0z8dX6YsFLqNzlgy7m28fr5hv+NNC5Plvpo
91mIQ2dtnemu3Wehnlto69K4pmcHv72eSPPDHGVdHb5N6j+nxFrTwHiK20rl
3sRljdR3VH9PB9m4/t/UsfvBAv1jDPuF+Pa/WVt10fdBJsr6R9opDXCZtnhU
vQSK55zL9Qoy1/XSluEF3A90vE3xjFHXmWOlge43ZvntS6B4DlLXY8ulv7c6
dvi3cyTFs6m2bnfT7k0QzzXaPfIq7d4E80aIdo+83VF27to4luKcqO47Fknu
eVMezv6sr6sfBk78wXOcpL+vZ5doWe0GxbmG1OUVd+kqrRi83dnuxTV93tDe
D9y8dinQqaS+fxmS+LIaC18ieVSsf73c81sU59EbXbqydEdpfbr/h/hi+vof
962rpw8ZVzAlguIMvskiM/DknWiK54Z/k6sq91lr15S19rl+neL5r3ov7Cxt
sfHZNfhaDMVT/S7Da6aUq92/IJ63tPvExQ86Pdx6NpzimauuA/tI67xuW3Q7
HUlxC1f3F3aSa+MFu+as0texWeq5zRBp6ae8iJa+lyluJ951bcPYf3np0ca1
/Jxr+r1D00qZXBoqLS8bGpiw/QrF4R/t3nbV+PcOp2wjyN+Nz6UcLg+T3k6T
mPXBS+TvU3Wel6Q1C08OHjLwuuHeITOk5MFnv58T1hsVpJdZ65zr54WSPanq
eq+2lP17EWv75POG9dXbQSvMfEMuGtZROO8V53NwcR7AuiI/Lv7egYvzJLj4
+wUuzvPg4u8UuPi7hne5+dmZn7+i/eCi/VhXiHrwfOMjrBvBUZ8ep4Zt5nwG
5UWMD7gYH/Qr6sHziz/q52nUmUc8bQvZg3lg/7fTRZlpCNmT3/oqv3yhDnN7
RJRhBcOofcy3P7Y5lGAPjtD3DuK6C/2K+aXvy/KxR9SL62F8x0Tvw4V8oR2x
TlBXYt7BxTjjHbioBxf7pToU1tXg4j0a1aGgB4e+inJfk/M3vVcX6wT2iPaj
X9TJZq/s9/yIL9mDOulqU6YYexlO/UJfW43zUf17KE3fctvUe/zwBbJHzCO4
WFewMz/7RT3sRB3+4XK8AJsVnu89l7hfKKLtF8Chf6vcWzXQv2tAXS0u1aE8
67GT/BLrEHrRX3BRDzvRvoM6LvTvDsT6RDsiR52LdYj33mIdUp1rdTVa24+A
o66+aPsXqnNh/wIO/Xfl7xic2EPjznCPo3GxDmFnfvaLethJ65agcQnc0Z/s
Rx32Fb6vgf5f7Jvw3ZCmj/puUoP1P0v2G+6VNC7WIewU/QUX9bATdfhsffOX
vIX+vQzqsE/OxlqsnT/ZCX2zInu7sUKniUNvZ7KtLivqR+/86Zy5Q/HCzOMA
+SXWIfSiv+D5/f6i/Z7K92sOu6h9sT7x7tSwT9Tah95Wfdcxhd6Hi/UAbriX
RP1r9bkvdcln5Tw/VbhnzBG+c4E+VduHgkP/p3I+b/MP2SPmF9xwPqD1i3pz
uvOkFvt0lOxBvT2zKd2RmZ/Wv+PQ9Nm+yyuz0keIQ/9uwMGvvH0w2YN8id+z
oN7Gae910S/qp93GpMrMPZg46ueA+j2RXj/Qjx7y+gPvqn+PA/165fvQK8eo
X9SJeZKyXm1L7aNOJqb3Ks3YXnr3KOYxQbiXTNTuJVE/Yj2Ai/HHe2ZRD55f
v6iHxyNaFWdlXcgv1INPnGdJ1nAH2YN6GKPFGRzxH629N0O/pBc47HfS2kG/
qId1bzxyeFf9uyrUQyNfl2fc7Bj1i3oor57zd6L2YU/P5UtTOG9L7SC/Tfv/
+MEn+xJHfsPU+0T9e5CD+XxvYit8bwIOvfgdCurhgfoeXn/PD34hekQj9nY5
9Yt6CFXGddoU/R2psO9GO9BPqlnzE5cn6t+JaPWwXoszOOJvr+UF72+hdxI4
+vUQ8o76WX3CNotL84mjftpsMg/kU1aTndCf6zk9lafNJA79NPXveCwnO1E/
/sJ3CrB/jLof7En90vsBrx0+vKb+nRfqJ9N861eeuJ36hX6ic9wTfsSNOPRu
yvca6RvIHvG8xTqf8581+Zz/gIv3krAT9elW/koh9nYncdRno1PHc7ml/j0F
9CfVczl34tD37GNahoVvIjtRn83U+6buZA/8shA49CnqOcNQsofqVv17IxtI
T/OeUg/yZOoX9VlYfYc/kvTgX9R7VTuqc9Rh5S/eVZmrDb3vRR2+U9/PW+t1
rtVVtHrfrfeLunqgnC+lLdDrXNPfVvWziEM/Wr3vnkP2II/mZ8akcd6POOpw
ifDdBOw/op13gUM/em+JSix8ENlJ817JJl957BLiqEPv8IaV2Vv9Owvov6jv
mfXvxaB33V62BnOdRnYiv/e0PIKjDhs/v8+Ya0+yE/6aCt8vQD/8eJwFCx9K
dqIORyjfC3i7EEcdBivnilb6dwfQx42JacjCZxKHvo369wr0+KMO89Tzsclk
D717ETj0yUrcnOaRPajPPso98qClpAfHPIl+6b7Y0roEe+tEenD1+yPmRO+r
kfdbS17VUOKcLpzvid8poA7vKO8HmANx1KGXki9X/f0/9P7q+Z5eb/SuQ/hO
AXm8/FkZR32Iow4/qu8WelO/qKsiIf/VlbctcdTVutd3c7k8iPqlfbH5qkzO
hxCHvrD6u9yP+qV5Rn3/P5046uqtuv7Rv4tBnbi3DHjFJZ2jTgpZe8ZzPpb6
hd4jvcdn7qLXLfQW6vv29tQv6mSr9h4A7aMeLqnnWt1Jj7x/cFPOdXW/kJc4
9R1+N+LIi/ieH3HL9LmdxV309hG3lyHbCir3/uDwq+yH+Df/b794fw0unov+
D28VLn4=
      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3n8SFUaxu95r5ApUUoy6IdBC0ooSrJFkbGVFkuUCCEpJqG9SI1WGVFp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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkcl1MWxu+9b4sUaZES2hQiKbKk0kJCUZFIQlliKJKyxMQYDDN8JGOQ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             "]], Polygon3DBox[CompressedData["
1:eJwtlwO0HkcYhv/dmzS2bdvOjc0b28aNjUaNbaex0dho3Nhs1NhWm/R5z3zn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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+FXXeoyEe1YsbmlVCstZWVVI6pVBhYknboLGhVF+0FI+CqE
r6GJ0XPC8JzfP2d4T94zXTvfOesLIRxyyibjXkywbee1wK5d1mMtxkI40jVd
pWYXNB/7O2dFc1TtrFY0o0sc2Iuapmwv6Dz79pzuacN3SlrVClv2uhbZsJOa
IGv/MMsXn0zxxisJ2twzRp3orpcePhWu9Jp++0abDNi32mLQvtOh6AxtE7cf
9JFh+0k7jNhdHdUWkzzzQop3Ppjhmx7LXER34+T///8Cj3IkSA==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 575, 685, 426, 680, 585, 708, 
          443, 703, 598, 735, 460, 611, 765, 482, 762, 619, 789, 502, 784, 
          629, 813, 518, 808, 643, 840, 534, 657, 869, 554}], 
         Line3DBox[{391, 572, 675, 408, 683, 576, 691, 428, 706, 586, 714, 
          445, 599, 741, 743, 462, 612, 771, 484, 787, 620, 795, 504, 811, 
          630, 819, 520, 644, 846, 848, 536, 658, 875, 556}], 
         Line3DBox[{393, 573, 677, 412, 689, 578, 695, 431, 589, 720, 722, 
          447, 603, 749, 751, 466, 614, 777, 488, 793, 622, 799, 507, 633, 
          825, 827, 522, 648, 854, 856, 539, 661, 881, 559}], 
         Line3DBox[{396, 574, 679, 414, 580, 699, 701, 433, 593, 728, 730, 
          449, 606, 757, 759, 468, 616, 782, 490, 624, 802, 804, 509, 637, 
          832, 834, 524, 652, 861, 863, 541, 663, 886, 561}], 
         Line3DBox[{397, 398, 681, 417, 671, 583, 704, 434, 732, 596, 733, 
          451, 761, 609, 763, 471, 480, 785, 493, 807, 627, 809, 510, 837, 
          641, 838, 525, 866, 655, 867, 544, 888, 665, 563}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 436, 737, 601, 739, 
          453, 464, 767, 769, 473, 486, 791, 495, 815, 631, 817, 512, 842, 
          646, 844, 527, 871, 659, 873, 546, 557, 890, 565}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 439, 450, 745, 747, 
          456, 470, 773, 775, 477, 492, 797, 498, 821, 635, 823, 514, 850, 
          650, 852, 530, 543, 877, 879, 550, 562, 892, 568}], 
         Line3DBox[{404, 420, 697, 424, 437, 724, 726, 441, 454, 753, 755, 
          458, 475, 779, 781, 479, 496, 801, 500, 829, 639, 831, 516, 528, 
          858, 860, 532, 548, 883, 885, 552, 566, 894, 570}], 
         Line3DBox[{405, 702, 584, 425, 731, 597, 698, 442, 760, 610, 727, 
          459, 783, 618, 756, 481, 805, 628, 501, 835, 642, 806, 517, 864, 
          656, 836, 533, 887, 666, 865, 553, 895, 670, 571}], 
         Line3DBox[{555, 537, 868, 535, 847, 645, 839, 519, 505, 812, 810, 
          503, 485, 788, 786, 483, 463, 764, 461, 742, 600, 734, 444, 429, 
          707, 705, 427, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{558, 542, 874, 538, 855, 649, 845, 521, 826, 634, 818, 
          506, 491, 794, 792, 487, 469, 770, 465, 750, 604, 740, 446, 721, 
          590, 713, 430, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{560, 547, 880, 540, 862, 653, 853, 523, 833, 638, 824, 
          508, 803, 625, 798, 489, 474, 776, 467, 758, 607, 748, 448, 729, 
          594, 719, 432, 700, 581, 694, 413, 394, 678, 395}], 
         Line3DBox[{564, 667, 889, 545, 660, 872, 870, 526, 647, 843, 841, 
          511, 632, 816, 814, 494, 621, 790, 472, 768, 613, 766, 452, 602, 
          738, 736, 435, 588, 711, 709, 418, 577, 686, 399}], 
         Line3DBox[{567, 668, 891, 549, 878, 662, 876, 529, 651, 851, 849, 
          513, 636, 822, 820, 497, 623, 796, 476, 774, 615, 772, 455, 746, 
          605, 744, 438, 592, 717, 715, 421, 579, 692, 401}], 
         Line3DBox[{569, 669, 893, 551, 884, 664, 882, 531, 859, 654, 857, 
          515, 640, 830, 828, 499, 626, 800, 478, 780, 617, 778, 457, 754, 
          608, 752, 440, 725, 595, 723, 423, 582, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 823, 294, 822, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 803, 265, 263, 799, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 801, 266, 800, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 785, 241, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 702, 139, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 167, 724, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 725, 168, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          197, 745, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 746, 198, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 224, 767, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 768, 225, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 860, 859, 340, 334, 852, 332, 851, 
          326, 844, 324, 843, 318, 838, 308, 306, 834, 833, 300, 298, 827, 
          826, 292, 290, 819, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 264, 802, 268, 807, 270, 279, 814, 815, 285, 287, 820, 
          821, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 865, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 867, 346, 344, 863, 862, 338, 336, 856, 
          855, 330, 328, 848, 847, 322, 320, 840, 314, 352}], 
         Line3DBox[{315, 784, 275, 281, 810, 811, 283, 289, 818, 291, 825, 
          297, 824, 299, 832, 305, 837, 307, 317, 841, 842, 323, 325, 849, 
          850, 331, 333, 857, 339, 858, 341, 864, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 868, 355, 869, 350, 377}], 
         Line3DBox[{351, 808, 313, 319, 839, 321, 846, 327, 845, 329, 854, 
          335, 853, 337, 861, 343, 866, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzdfHk01t3XN5U0IJSUioomKmQIyaZIkwxJGRpkKEmUOXMyhMzzPIeQWUm2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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.1694336}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=131.253\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646438412075`*^9},ExpressionUUID->"fa8cb0c6-136e-42ac-a16e-\
6f0c00259ec3"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYTdsbx5eIJFfmEIkQujLkyrgyXZndTBnLPCvVJWOHSqk00qSZkiGF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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3f4l1UZxs8AZEpiyJJtbBFBUzKWBckQEBmy8YeEhPCTKaIpaChiOIgQ
FTfhSBzhxHBAhjguJFPRkEi9lBA3puLqc1/3+eO+7vt9vud73nOe84zztqyo
HDYzhRAmxRAyvBzUB5XgFnAk+BNYDRqAFWAVOAysBBP48zb4E3gQuAH9AjwE
NEE/yry3wa3AHeCfoBn4BziTMa/Anydr2T6Dr4GPAMvAQJ7/CG+GLwG9mO8X
LPSvwfNvBKOxPwHvgieBl9EfwSPBY+h/w3fDrcGfwVCeb9ca4PmgEXO2Z851
2A4Ha8FE7C/A++GO/H4Suj18Ac9t4Z8xvhd6Hvb74JPBhej7NXe0fgC9Cszl
uZLxi+Ex2BfBpyTv7w74xuh57kR3BWeg22rfYCK6G9yZMQPRXaLnnAefy5z9
0JdhfxhurXWhW8rn0ef1ALyA33qjv0X/Er1Y5wKfD1phOzbbvgj7g3AfcAH6
L3BfUA99N+Pmg6HB++kB+qNr8PvvwAB0LfgRuIXeC3Yw5ifw3+HZcG0wE/SW
3zUnvI7fLkE/hK4Ar6G/1J6wT1MMJp/F8+h9igHsU9Br0Jeif42+CT0dfI0+
lL1MRR+NflWxUvb1CHwx3DB4/zovxfCdjFkTvZ57sC2BG4HLwWSdPbxd70G/
i1aSXKT3gIXgLOxvwV8VX2kvG5Ltu9EHy5qVY0ui1yw/XA//BuPn6APwTsWX
/A9+xfNS+HG4h/aGvh3+QrEQ7KPfJsfjT1nPQzw31vq1H9AUrAdXgR8Fx8c5
oC6YEZwjO+Av4D3wMcF7ez9avwnvAm2Vy/DPk8/iVuUWz8dpPPw6eAf9A/ar
o+dei94ANwdXBvtNY74vZ10DvQrumVxj7oJbgMHKPfg65TD6uJIXqgPr4T46
y+D8v5zfTkXXUwwothXX+GEBPBb7WI0t8ak4HZac09vhq1RrsFUw/lzFbHA8
DUiuZ8+ohoHJ6CPg7ow9WT6CB4Hh6MHwWdFrqFCul5rQlTkbl/nHok9SnjPm
+OjaqNh7ED0ger9D4Wv0Lnhidh711bzZMXkIY66NXo9qxnnZflMO3QhfDy5S
7cj220L0LPSHcBfG7IaPLvbZ2GfBo4Nrx/lgJHpOOcc26G0lXxQnt5Zzr4Je
pvqX3B+WRtcl/W9GqYFzsa+DrwVTsZ+dPV65eXOpJ8qVe0te11HOKnbL+ucz
frX8hv0E+CgwA/tU7NOj62Glaon2rrzJHjNB9VAs/6JHROeOavgK9NXFt5MY
3xw9Hnvn5HhQT3sZ/kN510zGnKqYw/4ifFpyj3g+eR6d8wTGrExey/TsOdQf
H1dNAqPQ06Lj+WzFSHYfvAn7c6W2X4h9LvbBxb4tuR4qT9dG+1AxdmRyDVcd
Xo++ObgOrwFXgJrBNWJ1mXMOc45Irrsb4U7Y+qK7RsdJBbo73F97Rj8L3x9d
qzdFx+04dMfkPcrP07LzuppqSXQvVp15ODpf1Je3wFdG18NblGtgCPoMeKny
FB6RPUZ17DbtTzb0SK0Nbhns9y3R/nws+ix0l/gbPCb5/vB09Dkqxs7M7qGq
MU/BK4rPJ2fvS3t8Mrk/qpY/UcbofKZk3w303icVX8n3iH+pJ4Ah2E5jzKPY
Ouh8VXOxvQ1/mxy3yqP28HnJ9UEFvr/qkOp3qVGnyE/Mc1nRA9FXFJ8Myq5N
PRWz6LmKAdVc9LKyhqHoJdqD6kWxq2YMkz+T/TdGdQxdFd0o++5RnTWsVH5i
Dzrb7PUfz+Ne+PfYR2nfZR7lzXD08uTaOS57jM5wdPYdqTG6Y3Ze6B73Ctys
1NgW8IfKXfCR/KjchvdF96+q6OXo/fCx4BPwn+ixtbN7zX/RVbN77i70d/CJ
8k2wX+apfqqeMebL4B6k3rkw+Q7TJXsdzUEn9OnJ/XBH8n8bqH5g/xRbO/Bx
cG1UzraGpySfb2bMwVK3qyfvZa+OF/t7wXV1X/DdSfesY7BPS95TTfRobP2C
/btYsQL3yb6fHFRPya5jypH6yXda9a++pW5H0FDvUmww5qvoHqf6Vld5mTym
QXbtUh41S44jxVPvco7DsDdI7i+q863gi5Pvj70Yc478Kz9E30MOyM/Z/fF0
dCN4f3T81M/WvXj8Rn0hen69c1FyjenJmG76TWccnUeqP1WTY7sutlolF5Qf
/bPXo77aXffP6Pcq1hXz6oP9smuI7r11kv2sc6uR/W6toWFy/22nHpUdV52x
71QfSo6rKrqzJedmlWTf6izqZq9f6+1RclO9fWS5Q+rcq2ff+fugv4+OMcV8
zeQ7WAeeT8x+l+KiWokfxWqb7LjqpHyJztNqilHs49Cbsb8Nj1e9CY6Vw6PP
pRa8Kfj+vAXMSf4GeTG6Tuq/72CrEn2317z6FnsO/V7yN47usRuwfxec+7of
t4m+q7crdU/fTW/BTcv5Kk/G8vw0enfynfAb9R7WPCq5Fu4pfUTfgpvgp4Lv
yc+UfNQ9LSX7XP45IXtO/b4X3hp9R90Y7Qft793k77ij1JuwPxt8J9E32Kc8
H6LewDw1o8+idqlvP6B/XHqf7s5vwAuC7xi6l2wN9r++UbV+fQ/uTK4P+hZ8
PbkXq69uhYcn351fg2clv7dJtv/roFuic6lverfysTv8GbbKUoebZX/LqHe8
FL1+1b098H1aL7g3+F3iV5P/q/r5gfKt5L5yRt9uqmndSs7qLA5DvxR8P9f3
cz3Fb3AOjy8x8HHpTarbHbK/xfSd8nXZl74TD0T3Vp31+/ChPHcN3qdql+6t
rbLv/KrJ/ytnp2+xD9BvBueavnO2B39z7Shr0Lf2Zsa+EXym+iafnXxurZmz
SbTf9O0tu+K9Kfb/A6521c8=
             "]], Polygon3DBox[CompressedData["
1:eJwtmHcc0NMaxs85v6Q0tJNSolJkFLpIRiENoyGUmVFIqbhGH9x7s+7lmtet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             "]], Polygon3DBox[CompressedData["
1:eJxNlnW4F0UUhn+7l6t05xWkS7iApHR3dyNcOu+lU5TubpDuTkkp6RCR7u5O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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+HTqlslkgpGYnMLrVaKsLKWDa1LmcvUdu3QuESFuH0LEr4K
0a+hSXfPG4Ynv/8ZznsuU+WznUosiqJjmkZcL/SSHvtKr0nYN9qi177VPr3T
e/rtB31kwH7SZwbtF02GsxjllTcm+OSLaX7osMSwe9Y1qzk27V3do2BXtRau
7Yae6riXP9E1XaVsr2g+/vd9y5rjKJyrh5rRNAf2oi5Qsud1jqI9q/ta95xt
LWmRrXC+5tmwRzRF1u4yQ5tvJvngnTFa4X8yxDmx////CywCJHk=
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{389, 386, 668, 408, 667, 574, 680, 428, 675, 584, 703, 
          444, 698, 597, 729, 461, 610, 759, 483, 756, 618, 784, 503, 779, 
          628, 807, 519, 802, 641, 833, 535, 653, 860, 554}], 
         Line3DBox[{392, 571, 670, 410, 678, 575, 686, 430, 701, 585, 709, 
          446, 598, 735, 737, 463, 611, 765, 485, 782, 619, 790, 505, 805, 
          629, 813, 521, 317, 839, 537, 654, 866, 556}], 
         Line3DBox[{394, 572, 672, 414, 684, 577, 690, 433, 588, 715, 717, 
          448, 602, 743, 745, 467, 613, 771, 489, 788, 621, 794, 508, 632, 
          819, 820, 523, 644, 845, 847, 540, 657, 872, 559}], 
         Line3DBox[{397, 573, 674, 416, 579, 694, 696, 435, 592, 722, 724, 
          450, 605, 751, 753, 469, 615, 776, 491, 623, 798, 800, 510, 635, 
          826, 828, 525, 648, 853, 855, 542, 659, 878, 561}], 
         Line3DBox[{398, 399, 676, 419, 693, 582, 699, 436, 721, 595, 727, 
          452, 750, 608, 757, 472, 481, 780, 494, 797, 626, 803, 511, 825, 
          639, 831, 526, 852, 651, 858, 545, 877, 661, 563}], 
         Line3DBox[{401, 412, 682, 421, 705, 586, 707, 438, 731, 600, 733, 
          454, 465, 761, 763, 474, 487, 786, 496, 809, 630, 811, 513, 835, 
          642, 837, 528, 862, 655, 864, 547, 557, 882, 565}], 
         Line3DBox[{404, 418, 688, 424, 711, 590, 713, 440, 451, 739, 741, 
          457, 471, 767, 769, 478, 493, 792, 499, 815, 633, 817, 515, 841, 
          646, 843, 531, 544, 868, 870, 551, 562, 884, 568}], 
         Line3DBox[{406, 422, 692, 426, 719, 594, 720, 442, 455, 747, 749, 
          459, 476, 773, 775, 480, 497, 796, 501, 822, 637, 824, 517, 529, 
          849, 851, 533, 549, 874, 876, 553, 566, 886, 570}], 
         Line3DBox[{407, 697, 583, 402, 725, 596, 726, 388, 754, 609, 755, 
          427, 777, 617, 778, 443, 801, 627, 460, 829, 640, 830, 482, 856, 
          652, 857, 502, 879, 662, 880, 518, 887, 666, 534}], 
         Line3DBox[{555, 538, 859, 536, 318, 832, 520, 506, 806, 804, 504, 
          486, 783, 781, 484, 464, 758, 462, 736, 599, 728, 445, 431, 702, 
          700, 429, 411, 679, 677, 409, 387, 669, 391}], 
         Line3DBox[{558, 543, 865, 539, 846, 645, 838, 522, 288, 812, 507, 
          492, 789, 787, 488, 470, 764, 466, 744, 603, 734, 447, 716, 589, 
          708, 432, 417, 685, 683, 413, 390, 671, 393}], 
         Line3DBox[{560, 548, 871, 541, 854, 649, 844, 524, 827, 636, 818, 
          509, 799, 624, 793, 490, 475, 770, 468, 752, 606, 742, 449, 723, 
          593, 714, 434, 695, 580, 689, 415, 395, 673, 396}], 
         Line3DBox[{564, 663, 881, 546, 656, 863, 861, 527, 643, 836, 834, 
          512, 631, 810, 808, 495, 620, 785, 473, 762, 612, 760, 453, 601, 
          732, 730, 437, 587, 706, 704, 420, 576, 681, 400}], 
         Line3DBox[{567, 664, 883, 550, 869, 658, 867, 530, 647, 842, 840, 
          514, 634, 816, 814, 498, 622, 791, 477, 768, 614, 766, 456, 740, 
          604, 738, 439, 591, 712, 710, 423, 578, 687, 403}], 
         Line3DBox[{569, 665, 885, 552, 875, 660, 873, 532, 850, 650, 848, 
          516, 638, 823, 821, 500, 625, 795, 479, 774, 616, 772, 458, 748, 
          607, 746, 441, 165, 718, 425, 581, 691, 405}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{112, 101, 668, 103, 669, 102, 670, 104, 671, 105, 672, 
          106, 673, 107, 674, 108, 109, 676, 113, 681, 118, 682, 119, 687, 
          124, 688, 125, 691, 130, 692, 131, 697, 136, 137}], 
         Line3DBox[{140, 667, 110, 114, 677, 678, 116, 120, 683, 684, 122, 
          126, 689, 128, 694, 132, 693, 134, 142, 704, 705, 148, 150, 710, 
          711, 156, 158, 718, 719, 164, 166, 725, 172, 174}], 
         Line3DBox[{175, 726, 173, 167, 720, 165, 159, 713, 157, 712, 151, 
          707, 149, 706, 143, 699, 135, 133, 696, 695, 129, 127, 690, 123, 
          685, 121, 686, 117, 679, 115, 680, 111, 141}], 
         Line3DBox[{178, 675, 138, 144, 700, 701, 146, 152, 708, 154, 715, 
          160, 714, 162, 722, 168, 721, 170, 180, 730, 731, 186, 188, 738, 
          194, 739, 196, 746, 202, 747, 204, 754, 210, 212}], 
         Line3DBox[{213, 755, 211, 205, 749, 748, 203, 197, 741, 740, 195, 
          189, 733, 187, 732, 181, 727, 171, 169, 724, 723, 163, 161, 717, 
          716, 155, 153, 709, 147, 702, 145, 703, 139, 179}], 
         Line3DBox[{215, 698, 176, 182, 728, 184, 735, 190, 734, 192, 743, 
          198, 742, 200, 751, 206, 750, 208, 217, 760, 221, 761, 223, 766, 
          227, 767, 229, 772, 233, 773, 235, 777, 239, 241}], 
         Line3DBox[{242, 778, 240, 236, 775, 774, 234, 230, 769, 768, 228, 
          224, 763, 762, 222, 218, 757, 209, 207, 753, 752, 201, 199, 745, 
          744, 193, 191, 737, 736, 185, 183, 729, 177, 216}], 
         Line3DBox[{245, 214, 759, 219, 758, 220, 765, 225, 764, 226, 771, 
          231, 770, 232, 776, 237, 238, 780, 246, 785, 251, 786, 252, 791, 
          257, 792, 258, 795, 263, 796, 264, 801, 269, 270}], 
         Line3DBox[{273, 756, 243, 247, 781, 782, 249, 253, 787, 788, 255, 
          259, 793, 261, 798, 265, 797, 267, 275, 808, 809, 281, 283, 814, 
          815, 289, 291, 821, 822, 297, 299, 829, 305, 307}], 
         Line3DBox[{308, 830, 306, 300, 824, 298, 823, 292, 817, 290, 816, 
          284, 811, 282, 810, 276, 803, 268, 266, 800, 799, 262, 260, 794, 
          256, 789, 254, 790, 250, 783, 248, 784, 244, 274}], 
         Line3DBox[{311, 779, 271, 277, 804, 805, 279, 285, 812, 287, 819, 
          293, 818, 295, 826, 301, 825, 303, 313, 834, 835, 319, 321, 840, 
          841, 327, 329, 848, 335, 849, 337, 856, 343, 345}], 
         Line3DBox[{346, 857, 344, 338, 851, 850, 336, 330, 843, 328, 842, 
          322, 837, 320, 836, 314, 831, 304, 302, 828, 827, 296, 294, 820, 
          288, 286, 813, 280, 806, 278, 807, 272, 312}], 
         Line3DBox[{348, 802, 309, 315, 832, 317, 323, 838, 325, 845, 331, 
          844, 333, 853, 339, 852, 341, 350, 861, 862, 354, 356, 867, 360, 
          868, 362, 873, 366, 874, 368, 879, 372, 374}], 
         Line3DBox[{375, 880, 373, 369, 876, 875, 367, 363, 870, 869, 361, 
          357, 864, 355, 863, 351, 858, 342, 340, 855, 854, 334, 332, 847, 
          846, 326, 324, 839, 318, 316, 833, 310, 349}], 
         Line3DBox[{376, 347, 860, 352, 859, 353, 866, 358, 865, 359, 872, 
          364, 871, 365, 878, 370, 877, 371, 377, 881, 378, 882, 379, 883, 
          380, 884, 381, 885, 382, 886, 383, 887, 384, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzEu2dQVsG2LYqIICiiBMWEgAEFFZUkEqaiggpIFEFJAkoSEBBBokqSnHPO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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.1015625}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=141.254\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643885147*^9},ExpressionUUID->"de9ca484-81c7-44e9-9d63-\
c6cffd82119f"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHVUVVkbxreJhRiMMiYiKnbHqOPGdkwGCxMM1BEVUGyFS5ighIioKJgI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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3kYUFMaxu/5biWNVEiTaFeihXaNpJSipI0sLYqUSiVRpLKnLJNCmhQa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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkcl1MWxu+9rwpFi6SFVlHZK1LK0oqKRKUQFaJRkewxMYYGw8c2xi5Z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             "]], Polygon3DBox[CompressedData["
1:eJwtlwO0HUkURV/3jz2xbdu28WPbyY+tiW07E9vGhBNNbE40se3M7LPqrvX2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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 427, 680, 585, 708, 
          444, 703, 598, 735, 461, 611, 765, 483, 762, 619, 789, 503, 784, 
          629, 813, 519, 808, 643, 840, 535, 657, 869, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 429, 706, 586, 714, 
          446, 599, 741, 743, 463, 612, 771, 485, 787, 620, 795, 505, 811, 
          630, 819, 521, 644, 846, 848, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 432, 589, 720, 722, 
          448, 603, 749, 751, 467, 614, 777, 489, 793, 622, 799, 508, 633, 
          825, 827, 523, 648, 854, 856, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 434, 593, 728, 730, 
          450, 606, 757, 759, 469, 616, 782, 491, 624, 802, 804, 510, 637, 
          832, 834, 525, 652, 861, 863, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 435, 732, 596, 733, 
          452, 761, 609, 763, 472, 481, 785, 494, 807, 627, 809, 511, 837, 
          641, 838, 526, 866, 655, 867, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 437, 737, 601, 739, 
          454, 465, 767, 769, 474, 487, 791, 496, 815, 631, 817, 513, 842, 
          646, 844, 528, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 440, 451, 745, 747, 
          457, 471, 773, 775, 478, 493, 797, 499, 821, 635, 823, 515, 850, 
          650, 852, 531, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 438, 724, 726, 442, 455, 753, 755, 
          459, 476, 779, 781, 480, 497, 801, 501, 829, 639, 831, 517, 529, 
          858, 860, 533, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 425, 702, 426, 731, 597, 698, 443, 760, 610, 727, 
          460, 783, 618, 756, 482, 805, 628, 502, 835, 642, 806, 518, 864, 
          656, 836, 534, 887, 666, 865, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 868, 536, 847, 645, 839, 520, 506, 812, 810, 
          504, 486, 788, 786, 484, 464, 764, 462, 742, 600, 734, 445, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 855, 649, 845, 522, 826, 634, 818, 
          507, 492, 794, 792, 488, 470, 770, 466, 750, 604, 740, 447, 721, 
          590, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 862, 653, 853, 524, 833, 638, 824, 
          509, 803, 625, 798, 490, 475, 776, 468, 758, 607, 748, 449, 729, 
          594, 719, 433, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 527, 647, 843, 841, 
          512, 632, 816, 814, 495, 621, 790, 473, 768, 613, 766, 453, 602, 
          738, 736, 436, 588, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 530, 651, 851, 849, 
          514, 636, 822, 820, 498, 623, 796, 477, 774, 615, 772, 456, 746, 
          605, 744, 439, 592, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 532, 859, 654, 857, 
          516, 640, 830, 828, 500, 626, 800, 479, 780, 617, 778, 458, 754, 
          608, 752, 441, 725, 595, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 823, 294, 822, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 803, 265, 263, 799, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 801, 266, 800, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 785, 241, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 167, 724, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 725, 168, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          197, 745, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 746, 198, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 224, 767, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 768, 225, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 860, 859, 340, 334, 852, 332, 851, 
          326, 844, 324, 843, 318, 838, 308, 306, 834, 833, 300, 298, 827, 
          826, 292, 290, 819, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 264, 802, 268, 807, 270, 279, 814, 815, 285, 287, 820, 
          821, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 865, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 867, 346, 344, 863, 862, 338, 336, 856, 
          855, 330, 328, 848, 847, 322, 320, 840, 314, 352}], 
         Line3DBox[{315, 784, 275, 281, 810, 811, 283, 289, 818, 291, 825, 
          297, 824, 299, 832, 305, 837, 307, 317, 841, 842, 323, 325, 849, 
          850, 331, 333, 857, 339, 858, 341, 864, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 868, 355, 869, 350, 377}], 
         Line3DBox[{351, 808, 313, 319, 839, 321, 846, 327, 845, 329, 854, 
          335, 853, 337, 861, 343, 866, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJy8u3VUll+3NoqUASotYiCCqGCLIopOQUJARQUsQFIUBASkuxvpEAHp7u5J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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.1391602}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=151.255\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364643928178*^9},ExpressionUUID->"bb75300e-20c1-444b-b7a4-\
33e55f024688"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlcTdsXwLehZCzJK1NleMZkJsTOlDKGkOdRSCiUMle6DSQaJSJUoiKR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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3kYUFMaxu/5biWNVEiTaFeihXaNpJSipI0sLYqUSiVRpLKnLJNCmhQa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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkcl1MWxu+9rwpFi6SFVlHZK1LK0oqKRKUQFaJRkewxMYYGw8c2xi5Z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             "]], Polygon3DBox[CompressedData["
1:eJwtlwO0HUkURV/3jz2xbdu28WPbyY+tiW07E9vGhBNNbE40se3M7LPqrvX2
qlOnqrurq6vurZesWafgED8QCOyD0HDaCwTSUX6B69CcxghBgcAT9FN4CW3x
BuINou98dH4oACkgOfShrR9tmdFLoBXXDKU+E2bp/nhpYYDdIw/6GiyjXzDl
dbgBOaEJXl/69ITZ1O/AbrxdsAVqUS8ILdAN6TMYFlDPxL3jo+NBDOiB1w2v
i8aA7o7uAX1trHPxckFu+If6bUhIWyjKl/AJCvKMzhAN3Z1+sSAmdLX7pkIP
o+QX6AYtYQiVf/EPog/BEWigZ/juHfQue6EO9QTc5yf6Edd8ga+wCH8i3iTo
CkWpP4AD6P323epS78K17eifBJ0FskIpvGx42SGn5gZvC/TmmtnU18I6CKZf
NagOFamPoU9iSASd8Trr26HjQVzNNV4LvCnotug26NbQEqbiVcYrhh6OroKu
Cr/Qt3jubbinuaGeDz8F/fpqDaELqB/1n5AXnYFyAG1F0FnRWSATDNK3wssJ
uSE1Xj+8BVqPsB09lGeUouwQ5MamMXaAGXhN8fJq3UEvmINXT++PnoCuj24A
DTUveOPxGqEbQ3t79/h4GbXOIDJEgprWfxw6NISCunbf39C10OXQo9G10XWg
OTTDawp1YSJtzfBqo+tAPfOmUE6GrehBvNsifVf6JaNMDiltHovavA1EF0MX
h6/o81xzAS5BU+orYRt6O0yActTHcd1YWI7uiFeE8g0cQx+HM9CE+hc4iz4H
V6AZ9R2KCeiFXL8BNkJonv0IrzVtYdBhYZuNv6T2u55l32uw9goMg9LUcwS5
99L7JdD+x/umPYeODZ/p1556HKiG7oPXSHNEvRLXlkGXhfI23xXxSqNLQQkY
gXeR8gL4tD3kHq3wsqGTah9BIq0PvBOUxyGUvc9VdBl0EcqiUNzWetkgV5ef
D4bilcYrjC4EOWwPlsSLrjUB9WES3m3Yyb13wDqoQf0MLEb/oXmFKtQfwh6L
F4/gscWDP/HqUf7F/Y7CNO1F2Ik3nLal6PD2nlfQT+Cp2mGH6rqWtsPoy3AJ
wtH/OV4b2p5ae0PKZ/Dcd3s0Hf3SQ0ZbcyWC3D7Vfs0NQ/BuwiquXQ0boSb1
e3AX7tvYFcMKcW1BzRdktn3+N+VJz+WgF/S7hY5oWnkoEjoyHMDfb7H2MG31
KY/DLHRFyq20bYP/9FyLPwGu8yCGvgfEtPjbgbYg9B2tcd0THtq8an5/2T3O
y9O8aI/YsypQfvddnFO8u2j77ZpiF/oNvFUM9Nye0ZrX2h8AJbQmffe99d1X
QnXtNfqegR++G1ML363F++gH8Nj2mNZ4SfqNREeFaFBeMQcqWJvW/S1YwzVr
Yb2tNeWwjrSHQFfP5UjFrkroylDDYmMNyxFj0dEhhmKF4qLF1hB0pyDnR7f4
q7ak6ISQANpZrppuMbMKuioEW6zthdcN3R16W3zWczUOjaeC53JUGkgN/Wgb
oP3lu3zUSuvfd2cRnUn6W/s8rVnIB/vhBu9+E7baOSIJ/YLo9wK+a74hD15a
yjSQynN5JiJEsDijeD4KHR7C+S4uKPcN8921yk390b7WlNY69X2ey//ax7Up
E9k5oxP6HeV7SKt8Q9kE8lssaYJXE10LGljcULxKrHnSegYPsmj/KGdam2LY
D3un7JZz++C11lwpf9ucTbW4mxD9zXPvo/eKptxMvSDE9NxZKjleOHQXzTE6
JcSC7wzjG3yy+LwbNqM3wQbb+7ssJpWhXME9VmqPo2doPdr8aJ72+C6PKx/s
hX0wXXEMbwSMhVXUF+KPRI+CMVCWek87t6TUHEF23z1Hz9MeW6Hchz6Hno+u
THkeLsAk/ImwHt2HtjnoI+hp6Kkw3vLlITioeGNjL095AKagJ8NoG8tV7X/l
Dbhs+fIDfER/gHfQjvpbOG059h28911c1jlP572jFn+j8m6v0K/hvV0bxWL1
Tcb6DJ7DbtjluRyu+x5Dv7T4qDPoK3itcSjO4jWm/ASfYZ3mEK8HdAm4c+ch
rj+o/WH9G/lOn0CfhFN2j8SMJQz9wupb2RrZYHNZnHIx3hLP5bdFeFV9l4OU
izahN2rN+O48oZgYR+dCdEeNV+8D8fDiQnzbs/oT89zePbGtzc7a45TXIbbd
47HnziY6o5ywb1/J9r7Gq3H7dr+7lHcUu2iLQPkWUqPbKidCLstvOrd7aB38
f1j+SIMXiXpkiArd8NJpzOg4EMW8DHjpIaPtO51zktnzumqdUH7UuvXdmWyM
5864Ousuw2uPNxw9V/ENTunb6Hvb3OrMsFnzCmd99x+rmu/+B/RH94NeUMx3
+XIOejbMtFy2BlbDWt/9b1C/S7Z/lJsuwxXfzeVcvHmwwPbTaMVGWGrjLEw5
3nP/M0OgE0xQvlJegsW++69YyHfxQPfSPafb3tL4l6CXwvKA+69YxM4Kv/vu
vK1z9/9a7dOg
             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 673, 406, 672, 576, 685, 427, 680, 585, 708, 
          444, 703, 598, 735, 461, 611, 765, 483, 762, 619, 789, 503, 784, 
          629, 813, 519, 808, 643, 840, 535, 657, 869, 555}], 
         Line3DBox[{391, 573, 675, 408, 683, 577, 691, 429, 706, 586, 714, 
          446, 599, 741, 743, 463, 612, 771, 485, 787, 620, 795, 505, 811, 
          630, 819, 521, 644, 846, 848, 537, 658, 875, 557}], 
         Line3DBox[{393, 574, 677, 412, 689, 579, 695, 432, 589, 720, 722, 
          448, 603, 749, 751, 467, 614, 777, 489, 793, 622, 799, 508, 633, 
          825, 827, 523, 648, 854, 856, 540, 661, 881, 560}], 
         Line3DBox[{396, 575, 679, 414, 581, 699, 701, 434, 593, 728, 730, 
          450, 606, 757, 759, 469, 616, 782, 491, 624, 802, 804, 510, 637, 
          832, 834, 525, 652, 861, 863, 542, 663, 886, 562}], 
         Line3DBox[{397, 398, 681, 417, 671, 584, 704, 435, 732, 596, 733, 
          452, 761, 609, 763, 472, 481, 785, 494, 807, 627, 809, 511, 837, 
          641, 838, 526, 866, 655, 867, 545, 888, 665, 564}], 
         Line3DBox[{400, 410, 687, 419, 710, 587, 712, 437, 737, 601, 739, 
          454, 465, 767, 769, 474, 487, 791, 496, 815, 631, 817, 513, 842, 
          646, 844, 528, 871, 659, 873, 547, 558, 890, 566}], 
         Line3DBox[{402, 416, 693, 422, 716, 591, 718, 440, 451, 745, 747, 
          457, 471, 773, 775, 478, 493, 797, 499, 821, 635, 823, 515, 850, 
          650, 852, 531, 544, 877, 879, 551, 563, 892, 569}], 
         Line3DBox[{404, 420, 697, 424, 438, 724, 726, 442, 455, 753, 755, 
          459, 476, 779, 781, 480, 497, 801, 501, 829, 639, 831, 517, 529, 
          858, 860, 533, 549, 883, 885, 553, 567, 894, 571}], 
         Line3DBox[{405, 425, 702, 426, 731, 597, 698, 443, 760, 610, 727, 
          460, 783, 618, 756, 482, 805, 628, 502, 835, 642, 806, 518, 864, 
          656, 836, 534, 887, 666, 865, 554, 895, 670, 572}], 
         Line3DBox[{556, 538, 868, 536, 847, 645, 839, 520, 506, 812, 810, 
          504, 486, 788, 786, 484, 464, 764, 462, 742, 600, 734, 445, 430, 
          707, 705, 428, 409, 684, 682, 407, 387, 674, 390}], 
         Line3DBox[{559, 543, 874, 539, 855, 649, 845, 522, 826, 634, 818, 
          507, 492, 794, 792, 488, 470, 770, 466, 750, 604, 740, 447, 721, 
          590, 713, 431, 415, 690, 688, 411, 389, 676, 392}], 
         Line3DBox[{561, 548, 880, 541, 862, 653, 853, 524, 833, 638, 824, 
          509, 803, 625, 798, 490, 475, 776, 468, 758, 607, 748, 449, 729, 
          594, 719, 433, 700, 582, 694, 413, 394, 678, 395}], 
         Line3DBox[{565, 667, 889, 546, 660, 872, 870, 527, 647, 843, 841, 
          512, 632, 816, 814, 495, 621, 790, 473, 768, 613, 766, 453, 602, 
          738, 736, 436, 588, 711, 709, 418, 578, 686, 399}], 
         Line3DBox[{568, 668, 891, 550, 878, 662, 876, 530, 651, 851, 849, 
          514, 636, 822, 820, 498, 623, 796, 477, 774, 615, 772, 456, 746, 
          605, 744, 439, 592, 717, 715, 421, 580, 692, 401}], 
         Line3DBox[{570, 669, 893, 552, 884, 664, 882, 532, 859, 654, 857, 
          516, 640, 830, 828, 500, 626, 800, 479, 780, 617, 778, 458, 754, 
          608, 752, 441, 725, 595, 723, 423, 583, 696, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 806, 310, 304, 831, 302, 830, 296, 823, 294, 822, 
          288, 817, 286, 816, 280, 809, 271, 269, 804, 803, 265, 263, 799, 
          259, 794, 257, 795, 253, 788, 251, 789, 247, 278}], 
         Line3DBox[{112, 272, 805, 267, 801, 266, 800, 261, 797, 260, 796, 
          255, 791, 254, 790, 249, 785, 241, 240, 782, 235, 776, 234, 777, 
          229, 770, 228, 771, 223, 764, 222, 765, 217, 248}], 
         Line3DBox[{115, 101, 673, 103, 674, 102, 675, 106, 676, 107, 677, 
          108, 678, 109, 679, 110, 111, 681, 116, 686, 121, 687, 122, 692, 
          127, 693, 128, 696, 133, 697, 134, 139, 702, 140}], 
         Line3DBox[{143, 672, 113, 117, 682, 683, 119, 123, 688, 689, 125, 
          129, 694, 131, 699, 135, 671, 137, 145, 709, 710, 151, 153, 715, 
          716, 159, 161, 723, 167, 724, 169, 731, 175, 177}], 
         Line3DBox[{178, 698, 176, 170, 726, 725, 168, 162, 718, 160, 717, 
          154, 712, 152, 711, 146, 704, 138, 136, 701, 700, 132, 130, 695, 
          126, 690, 124, 691, 120, 684, 118, 685, 114, 144}], 
         Line3DBox[{181, 680, 141, 147, 705, 706, 149, 155, 713, 157, 720, 
          163, 719, 165, 728, 171, 732, 173, 183, 736, 737, 189, 191, 744, 
          197, 745, 199, 752, 205, 753, 207, 760, 213, 215}], 
         Line3DBox[{216, 727, 214, 208, 755, 754, 206, 200, 747, 746, 198, 
          192, 739, 190, 738, 184, 733, 174, 172, 730, 729, 166, 164, 722, 
          721, 158, 156, 714, 150, 707, 148, 708, 142, 182}], 
         Line3DBox[{218, 703, 179, 185, 734, 187, 741, 193, 740, 195, 749, 
          201, 748, 203, 757, 209, 761, 211, 220, 766, 224, 767, 226, 772, 
          230, 773, 232, 778, 236, 779, 238, 783, 242, 244}], 
         Line3DBox[{245, 756, 243, 239, 781, 780, 237, 233, 775, 774, 231, 
          227, 769, 768, 225, 221, 763, 212, 210, 759, 758, 204, 202, 751, 
          750, 196, 194, 743, 742, 188, 186, 735, 180, 219}], 
         Line3DBox[{274, 836, 348, 342, 860, 859, 340, 334, 852, 332, 851, 
          326, 844, 324, 843, 318, 838, 308, 306, 834, 833, 300, 298, 827, 
          826, 292, 290, 819, 284, 812, 282, 813, 276, 316}], 
         Line3DBox[{277, 762, 246, 250, 786, 787, 252, 256, 792, 793, 258, 
          262, 798, 264, 802, 268, 807, 270, 279, 814, 815, 285, 287, 820, 
          821, 293, 295, 828, 829, 301, 303, 835, 309, 104}], 
         Line3DBox[{312, 865, 376, 372, 885, 884, 370, 366, 879, 878, 364, 
          360, 873, 358, 872, 354, 867, 346, 344, 863, 862, 338, 336, 856, 
          855, 330, 328, 848, 847, 322, 320, 840, 314, 352}], 
         Line3DBox[{315, 784, 275, 281, 810, 811, 283, 289, 818, 291, 825, 
          297, 824, 299, 832, 305, 837, 307, 317, 841, 842, 323, 325, 849, 
          850, 331, 333, 857, 339, 858, 341, 864, 347, 273}], 
         Line3DBox[{349, 385, 895, 384, 894, 383, 893, 382, 892, 381, 891, 
          380, 890, 379, 889, 378, 374, 888, 373, 886, 368, 880, 367, 881, 
          362, 874, 361, 875, 356, 868, 355, 869, 350, 377}], 
         Line3DBox[{351, 808, 313, 319, 839, 321, 846, 327, 845, 329, 854, 
          335, 853, 337, 861, 343, 866, 345, 353, 870, 871, 357, 359, 876, 
          363, 877, 365, 882, 369, 883, 371, 887, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJycu2dQVV2zLYwIgohiFhARA0EUAQWVII2AkoOIgglBUEBEyUHJOeeM5Jxz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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.09570312}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=161.255\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646439712143`*^9},ExpressionUUID->"7ca85ba7-3eaf-4e1a-a243-\
9869fc5fb621"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYT9kbwE+RpCgV0aDIztjGNrYTYxearGMrW9MQIkSWSqmUVlIqtFiy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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtmHcYV1Mcxs85N0qErDSUtoqKppSUShqaEiXtspKWklCEzMwkKomMKKuI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             "]], Polygon3DBox[CompressedData["
1:eJwtmHn8kFMWxu+9bwulTYvKUr9UxGQpWYqylFApiZSIIstQlsruE2NiNMPY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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUFUcQRf/MAsEhuAd3t+DuzuLuDsviiwd3dyc4BHdIcIJDcAkQgrs7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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 671, 406, 670, 576, 683, 427, 678, 585, 706, 
          444, 701, 598, 733, 461, 611, 763, 483, 760, 619, 787, 503, 782, 
          629, 811, 519, 806, 643, 838, 535, 350, 555}], 
         Line3DBox[{391, 573, 673, 408, 681, 577, 689, 429, 704, 586, 712, 
          446, 599, 739, 741, 463, 612, 769, 485, 785, 620, 793, 505, 809, 
          630, 817, 521, 644, 844, 845, 537, 656, 871, 557}], 
         Line3DBox[{393, 574, 675, 412, 687, 579, 693, 432, 589, 718, 720, 
          448, 603, 747, 749, 467, 614, 775, 489, 791, 622, 797, 508, 633, 
          823, 825, 523, 647, 851, 853, 540, 659, 877, 560}], 
         Line3DBox[{396, 575, 677, 414, 581, 697, 699, 434, 593, 726, 728, 
          450, 606, 755, 757, 469, 616, 780, 491, 624, 800, 802, 510, 637, 
          830, 832, 525, 651, 858, 860, 542, 661, 882, 562}], 
         Line3DBox[{397, 398, 679, 417, 669, 584, 702, 435, 730, 596, 731, 
          452, 759, 609, 761, 472, 481, 783, 494, 805, 627, 807, 511, 835, 
          641, 836, 526, 863, 654, 864, 545, 884, 663, 564}], 
         Line3DBox[{400, 410, 685, 419, 708, 587, 710, 437, 735, 601, 737, 
          454, 465, 765, 767, 474, 487, 789, 496, 813, 631, 815, 513, 840, 
          645, 842, 528, 867, 657, 869, 547, 558, 886, 566}], 
         Line3DBox[{402, 416, 691, 422, 714, 591, 716, 440, 451, 743, 745, 
          457, 471, 771, 773, 478, 493, 795, 499, 819, 635, 821, 515, 847, 
          649, 849, 531, 544, 873, 875, 551, 563, 888, 569}], 
         Line3DBox[{404, 420, 695, 424, 438, 722, 724, 442, 455, 751, 753, 
          459, 476, 777, 779, 480, 497, 799, 501, 827, 639, 829, 517, 529, 
          855, 857, 533, 549, 879, 881, 553, 567, 890, 571}], 
         Line3DBox[{405, 425, 700, 426, 729, 597, 696, 443, 758, 610, 725, 
          460, 781, 618, 754, 482, 803, 628, 502, 833, 642, 804, 518, 861, 
          655, 834, 534, 883, 664, 862, 554, 891, 668, 572}], 
         Line3DBox[{556, 538, 865, 536, 322, 837, 520, 506, 810, 808, 504, 
          486, 786, 784, 484, 464, 762, 462, 740, 600, 732, 445, 430, 705, 
          703, 428, 409, 682, 680, 407, 387, 672, 390}], 
         Line3DBox[{559, 543, 870, 539, 852, 648, 843, 522, 824, 634, 816, 
          507, 492, 792, 790, 488, 470, 768, 466, 748, 604, 738, 447, 719, 
          590, 711, 431, 415, 688, 686, 411, 389, 674, 392}], 
         Line3DBox[{561, 548, 876, 541, 859, 652, 850, 524, 831, 638, 822, 
          509, 801, 625, 796, 490, 475, 774, 468, 756, 607, 746, 449, 727, 
          594, 717, 433, 698, 582, 692, 413, 394, 676, 395}], 
         Line3DBox[{565, 665, 885, 546, 658, 868, 866, 527, 646, 841, 839, 
          512, 632, 814, 812, 495, 621, 788, 473, 766, 613, 764, 453, 602, 
          736, 734, 436, 588, 709, 707, 418, 578, 684, 399}], 
         Line3DBox[{568, 666, 887, 550, 874, 660, 872, 530, 650, 848, 846, 
          514, 636, 820, 818, 498, 623, 794, 477, 772, 615, 770, 456, 744, 
          605, 742, 439, 592, 715, 713, 421, 580, 690, 401}], 
         Line3DBox[{570, 667, 889, 552, 880, 662, 878, 532, 856, 653, 854, 
          516, 640, 828, 826, 500, 626, 798, 479, 778, 617, 776, 458, 752, 
          608, 750, 441, 723, 595, 721, 423, 583, 694, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 804, 310, 304, 829, 302, 828, 296, 821, 294, 820, 
          288, 815, 286, 814, 280, 807, 271, 269, 802, 801, 265, 263, 797, 
          259, 792, 257, 793, 253, 786, 251, 787, 247, 278}], 
         Line3DBox[{112, 272, 803, 267, 799, 266, 798, 261, 795, 260, 794, 
          255, 789, 254, 788, 249, 783, 241, 240, 780, 235, 774, 234, 775, 
          229, 768, 228, 769, 223, 762, 222, 763, 217, 248}], 
         Line3DBox[{115, 101, 671, 103, 672, 102, 673, 106, 674, 107, 675, 
          108, 676, 109, 677, 110, 111, 679, 116, 684, 121, 685, 122, 690, 
          127, 691, 128, 694, 133, 695, 134, 139, 700, 140}], 
         Line3DBox[{143, 670, 113, 117, 680, 681, 119, 123, 686, 687, 125, 
          129, 692, 131, 697, 135, 669, 137, 145, 707, 708, 151, 153, 713, 
          714, 159, 161, 721, 167, 722, 169, 729, 175, 177}], 
         Line3DBox[{178, 696, 176, 170, 724, 723, 168, 162, 716, 160, 715, 
          154, 710, 152, 709, 146, 702, 138, 136, 699, 698, 132, 130, 693, 
          126, 688, 124, 689, 120, 682, 118, 683, 114, 144}], 
         Line3DBox[{181, 678, 141, 147, 703, 704, 149, 155, 711, 157, 718, 
          163, 717, 165, 726, 171, 730, 173, 183, 734, 735, 189, 191, 742, 
          197, 743, 199, 750, 205, 751, 207, 758, 213, 215}], 
         Line3DBox[{216, 725, 214, 208, 753, 752, 206, 200, 745, 744, 198, 
          192, 737, 190, 736, 184, 731, 174, 172, 728, 727, 166, 164, 720, 
          719, 158, 156, 712, 150, 705, 148, 706, 142, 182}], 
         Line3DBox[{218, 701, 179, 185, 732, 187, 739, 193, 738, 195, 747, 
          201, 746, 203, 755, 209, 759, 211, 220, 764, 224, 765, 226, 770, 
          230, 771, 232, 776, 236, 777, 238, 781, 242, 244}], 
         Line3DBox[{245, 754, 243, 239, 779, 778, 237, 233, 773, 772, 231, 
          227, 767, 766, 225, 221, 761, 212, 210, 757, 756, 204, 202, 749, 
          748, 196, 194, 741, 740, 188, 186, 733, 180, 219}], 
         Line3DBox[{274, 834, 348, 342, 857, 856, 340, 334, 849, 332, 848, 
          326, 842, 324, 841, 318, 836, 308, 306, 832, 831, 300, 298, 825, 
          824, 292, 290, 817, 284, 810, 282, 811, 276, 316}], 
         Line3DBox[{277, 760, 246, 250, 784, 785, 252, 256, 790, 791, 258, 
          262, 796, 264, 800, 268, 805, 270, 279, 812, 813, 285, 287, 818, 
          819, 293, 295, 826, 827, 301, 303, 833, 309, 104}], 
         Line3DBox[{312, 862, 376, 372, 881, 880, 370, 366, 875, 874, 364, 
          360, 869, 358, 868, 354, 864, 346, 344, 860, 859, 338, 336, 853, 
          852, 330, 328, 845, 322, 320, 838, 314, 352}], 
         Line3DBox[{315, 782, 275, 281, 808, 809, 283, 289, 816, 291, 823, 
          297, 822, 299, 830, 305, 835, 307, 317, 839, 840, 323, 325, 846, 
          847, 331, 333, 854, 339, 855, 341, 861, 347, 273}], 
         Line3DBox[{349, 385, 891, 384, 890, 383, 889, 382, 888, 381, 887, 
          380, 886, 379, 885, 378, 374, 884, 373, 882, 368, 876, 367, 877, 
          362, 870, 361, 871, 356, 865, 355, 350, 377}], 
         Line3DBox[{351, 806, 313, 319, 837, 321, 844, 327, 843, 329, 851, 
          335, 850, 337, 858, 343, 863, 345, 353, 866, 867, 357, 359, 872, 
          363, 873, 365, 878, 369, 879, 371, 883, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzMu3VQl1G3NgyKHagIIgoCKqIIIqAoxgKRUJESBFFRQlpQQklJCSnp7u7u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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.09960938}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=171.256\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364644018247*^9},ExpressionUUID->"01b3144f-e2df-4f14-aa60-\
48102941265d"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHVUVtnXx4+F2NgoOmJ3F45xULELsR0VRlDMETDABHUUFUEaRpRQsAPs
vqjYAYqFBVgwimCLed7fvTzffd85z9LlX5+11767zn3u2Wcfak+cZTepMGPM
vQhj//vPnh0PPua04Y1i3s/VZndUqsIM/8DLZTrPve2SYsTLvjsx8Nvyy0b8
e+0dewY0SDLidza3qG0VcNyITyle4XLCzt1Kq+zNj4QYxsG9alj0uZbqpXwo
FmbK2ELilvP/bnClexwfaG1ySYiWxA88dE62GXeYy/pnnDpf7GapM8STTu1x
eTj7tZG/4LK/4LK/4LK/4PC3wE7OweHv6s4vRjC2kjj83b39UrpQwonDX1m/
7C+47G9isXYz8vb8a+QvuOwvuOwvuOwvOPxdd+RVuBB/cHD463rhREmWGEQc
/j7xm1+ZecURh78F9TCbuOwvuOzvyYFHnQu/fG7kL7jsL7jsLzj8Rb2Bw9/S
X6d8FmIOcfg7qUyj5yJqC3H4e9RxQjGWsZ04/DX/cCNXiKXEZX/BZX+PBnVz
rFz/iZG/4LK/4LK/4PD39axTZRjry8Hh76AxaV6M+RKHv3duPcsT9rHE4W+X
J6VvC7GLOPx1T6q2Q4gA4vBXfq7s77SD3idtEx8a+Qsu+wsu+wsOf1G34PA3
qeb7JoytIw5/C7REE/9vPUcRh79bd82wZl6BxOHvkbpr2jI2kbjsr1PPwAPz
Otw28hdc9hcc/vZ9OPeqEDM5OPz9umxAUea1lDj8/c115UvhGUwc/ka8u1ud
OcQRh78F77FI4vC3IO+6HvhbUOeuxP/rry0/sqnTqE5jrhj5Cy77Cw5/U6qO
q8PYDNLz3/dVMHH42/753vYscT1x+Is8gsPfgnrQOfwt0BNIHP4+LH+uGmOu
xOFvwfvNkdsu3rimpM8R8jem5REbxqYQh78FeuYTh79XqtteFjyAOPztsyHm
q6i1ifh/8xtLHP4WvJfiiMPfAv0bicv+gsPferm/vxBiCXH4W5D3qdy6aabT
PNdQLvsLDn8L9MwjDn8L3huricPfltl2ocxrLXH4W5BHb+Lwt4J7zffCczlx
+DtmWJAiPHX98vsZ/L/1PJ84/C3wazQ/NCu2TtHqeUpw00dpLTrfpLoFr+q9
tfIe8+tGXK7zgRPya+zv81BxOh6aULPnXqWK87afok8UbzQ4171RyXvKee/o
aR8uH1IOmQS/E8nh9Fz5vQducjjY/eexC0Zc/n0H//Biadrg8aeNOOLc+O+K
mUK0pueeb/54XjdxUOnefP5N4dmfxzrXSun2LUc5fNj3qs3MeOVHHd9+LH45
D7Rfv3j+w5fKpcyJE3aEHlY+Tcmvy/zdSN6sbL9Z8Xf0OEA+ZPSp1BIxxvGU
3xvgyPv4Nxnj2JsFpF+OM/TLnOQHelonDLliJG+eObWE0zPjPPaxcJ17ynuT
cnlNmzas7zKKD+qtqlo/6f5kj5wv6Jc55H8snLGp0LskI/ni5UdNP7DyopE9
n4KmlGInfHjy9okPRLm1ZA/qvLfH82QhLMgeuR6gX+aQTxu13zS20Umlj6an
M+X3k7XNtaKNzyhdtPdeXXpu9L7Arult4rlsp/z9A/2oN+sdza8LYUP6wZ/5
3DkglBGkP8nuyPxuuSdIj9eoyk0PnMxWjk2vcCC+6D7Fqv7fxZmlP/9riP+9
3MgXyvWQrF5VWhxVzmdUKMQyPEmP/LsMPeU7N5nq0+UGxQF6QldEXXtmkmoU
H7k+qX4kDnnU7bu4e4NYq1XkL/i0M9cqsaIBHPbIdQt7ZE72b+neztniqpF8
9c7NflSLTzayJ/SE9fJm63yVyer3ba1wsmfg8gU2oYfilPrXbX+IISFUP6jz
Fvda/CuKR5A8+MlKx0uwLZvIfrnOYY/MIS9utwg9fPKckXzJ6dXsp9ldMrLf
ovzCUe8rbOJXtN+FuWTPxawVkd0LLeGz6nnXZP4byX6sCwutbnuSPHhn+9Mp
wnM62Y910VbbL5SjugL/vdKIVCEak/zDUlZvyiWeUty+58cLMYLk89ebnD72
4YwyQKtza7InodHTrHtJB43s6fLDYteLDrvJHsjL6wjyMoc9WEcdtO83J7IH
PHlUqw/C3o2P61NqZWOvZ4pSKyyixob9SuKUQd/Eg2jen69s6/TnE+VGvxnN
l507pvg9LdmJzdDfb9OdilaoYX3ayJ4zkW0Db448brTe5XUHeZnDngpTSjlO
3qSvR9gTts/rgjIj1ah+5HUHf2UOeay7Htr31XqKD3hQ1zavROdYio+87mCP
zCFfkRVtVDPrqpG8X3/3/Kyuxut3bIv96b3qhyjLW0wqwS7GkT2jXy2v+Nfz
bcquER1zxdQtVG/0u5PkVp6FbyF58JSFjqas7HayX153sEfmkC/c6u3qmavP
K+0M73nIlz73wM7yt8tKvLYu8rrBniZ2T806XtzIx73u+l3s1d/DGRtfhpdu
YsfnrPIrwpbEkf1Yd801/e4kD679nnp6kf1YdyYXLb+ov0ewBzwnxqQ0Y31I
/q3941cnmyYqFSr6fhKeM0j+64eLB1wSzyqmy9V9ky3Zs2fOBDaz+QFeUvsO
/JPsaR1S4VFZ0x18c7PKzwRfTPLyuoO8zGEP1l3kkE3NmctSsgd8RSlvD3bP
h1t1LJQZ2SNDOZNqsXxV24PKYK0+N9Bzp5bs8dvkOYlGzz3xcs+OycpRo/eA
vL4gL3M8t2JIzrjupjeN6kFeR7Bf5pCnfqD6e3EhjvwFtzftlCeWx5K/8joC
rzT2vEXqvmtG+l1+nlv8cVlEwe9U8lbSP2GY75NelXYp52Z2eSsO6+sX66JJ
Kn8vSu0kefBhX8vfE9d2kT3yugAvsmb/4rojLihftf6GFemvsizFzXtaGM/t
Nf2+sI8g/UfCzew658xRnv3hfle47yR51PkL7TtnFcmDXz+cu0fMCiB7UOfd
tO+xYcTfHY1On/05Uekw5VsnZq2vl22JaeaFQvfxHVsaeAqxgPQ3aV6ibMe0
LbxZI4+96vcq5FG3OamDSzLWhuTBX656Upp59abnom5XaX0DP+KXdy2Y+eHo
Sb5H64fYkf6rDmK4w1DFSP/RDk3Ofm14hPRDXq5PyMsc+6l17qPfndms1w/2
U5XOXBtZ46+bRnmU6xYc9Tlj2rvPouUmDv1yfUL/r/Z3ZWpF9r7z72Uj+aoH
VpVbveS60XO7Ouf42r2JVupo+/otFE/U532tL7eF7EF9JjxQ+0LNaf8IvkXr
P08k+W+DfbY1WJukrND6Y+NJ3uTZXNc0y4uKjdZfctbrf9/JW3dLB/Dthj42
OOpznVXPj4IHkn7UZyvtu+VP0k/7i8UHvglPD5K/9eNNpdxxJ5QasasasUZ+
JP+homNq47OnlRLjL1dg/ivpuVtKj2gd8jOe/xZ935pZLyeO+tytfOmg7tOh
H/Vpeiy4PoteR/rBe6vv1ahA0vOrupoZ8LzU57jT/OR79XehNelJyv+4YlWd
E7yKlq/JvGi3Zzc3Xk1VjpS3TfxqlaBsUPtsGZt54h8H/mjwW7JyuXN9O4eJ
R5ROWr8lkuT9YzvlbCyhf+dAvnLeHtvPqTeN6kquW9gjc8ijnht57i7ERkaT
/eDRn8+bsXGbyR6jcwSDPTKHvNl8h9/XHvzfPvpsrTvCfgr5a152QBHeP1mZ
otXVIMqLW07z54taeyt1Fpwqxarr9vRN/jiuSa3Ygn2QzWaSp/OUMV7V2BS9
T0J9rQUnuzJ/PZ6of7fiAQ9F1EyyBzxPe8/MIPmf2wZteDjqnFJlVNuSzMyT
5E27WU1al3NRcelvWo5ZzyZ76p0T3ex3bOaBvZK6M6sgsufT2REzbSes4Nr+
Lv4fkqdzn/hDndi2QJIHr6f+fpULJnuwXpzHLi7Cjqwge8DHuaxmrFUAyd9P
mPt9zIeTSnZn31zhHEzyn2bWv5Dud8bQPwwmew4ti3vg53+Iz9D6wNPJnu4J
0UF21/dwi7L1k0WeD8ljfX1VmrZglo4kD+7Z7f4PwWeSPVhfmR0i88XOELIH
vMWq53VYKz0+WHf2Qv1XjvSDf9F4T9I/rWNd8+73E/kf14ZVZIljSH+ijWtk
DZ9j/Mz6rQ2Y13Tu0Tm6fPnN55Vj525tnZyyT5l3dSdjXWK4fQfzdZ+HnFCu
5W3vdPXLUSVLjVvWZpIPuFH9hcesG8o07XdtMMlXqeHf/2anVCW2ce0ujE0i
e4zO41D/Eoc81t3f929WZXaxZD9418CzZVmjGLIH667NyA6WzNqe7AEPn7W2
CsuYS/LlU+u06LH0qnK666OKzMWV5MscWLnwa8kUpXrrfeYs2p3sH3p+u9lf
nwKUxg9u9GN9I8ke246iaeHBW5VS6vvTMork6TxX62Po8uDtDe832IN1F3Fp
/0XR0pPsAQ8rV2uzKLeO5FkRM//AuucVB/X7sG4QyZcM/zq615FLyuyqJjdE
mF7/1cZ/muW9MJo7qX2M9FCy50gfh4lPernyDK0/sIHkse6uuDXNEkH6eqHz
LLVvYBtE9mDdbS0U911U/IfsAT+u7pct9Hw9nPT16TkfRemW51ubHdlI8vkX
so6FjD2rmKn9Xu8Ysif+uuWHOl8O8FbLBldn8YvInk79wpIWRO3kA6pMHMwc
/Eiefu9Wp38Sya4kDz5de1+5kj1Ydz0+LKrK2kWRPeADYvzfiAj9/Y91V0br
qw8n/eC1tX6+A+mf8sihnk/ZRN7+TJ0csc6F9J/0zzkU//4Iv399UJawX8Q3
vEr/+M/+Lcqp+WPW3XQ+oCzRzpE3Eg/8+S192O0byiIt/rNJP9aRvB7BsR7J
HsM66t23XAm2Q1/v4C1alTRhNeLouVhHXTZZFWGWHsQrNH9eO3/gNaVX4c8n
xaxVpH9c6Ik9NYeHK47lXc3YEl3/yCjTb2mLdig1Lv1ZnFWKI3msi7vNEkuz
OZEkD950odMd4a7HAeuihlOxSHHBj3ih8TeX9807r6SqdVtxPelv9DKtu/0/
6/mbj7UrMdNQ0p/95nbTI386KJUqnbgr8iJIXj73gbzM8VzU+Wb19yJ6PfE3
a5Xn4QGJSpWJR03ZwI2kf3f1DaUP/7mf/7F7ahPmv5T0t8n0/bjJZRs3L3+x
JXvjT/Ko2z0vtpdgDnNJHjy0za4cdd+N56Ju/e6szhFtN5Ae1OeLAYWfivRJ
pAf8H03PVNJzzaTrnztWnOIzsra8F3vdiMvnWeCon/5qnWRsID59cvLAawmR
SoOl3x6Lw8HEkd/h/Q6miuKhxGtUv7B5b+dg3qyphZnarwZH/PecyGzH8tcS
3z65av0BlxN4krqfDfMijvicZj/+Fcn6+oK/p7RzQEd+53zbszGBeUqQYX3h
9+h55W7lF+S8VsoafhfAMW8jy5vMvJZQdVIufRfJ8r/SU8HweyTzX+nB9xh4
g6Rxdgcf5dK+QJb/Fcf+QuaJhr6KtaHv2sci553dyDziA7X99QCaRxpj6CcM
np6XKTzHEHcy9B/+Pl2/MEt0Ix4dWdDvatFtmwmznEfcytAfuxwxqwhjE4j3
NPR76w9sd1+I+sQPGvrDGVzts4lu4BelcxDMC8n5onknKS/gcl4yx50t7dvw
pZH8FLeFQW+u55G/zdXvt3gvmmuS8wgu5xEc+eoXn3RHiIakB/my0/YLXXnh
A3a7m0S/NNbvVKz6hbp6PMV1z8fCcz7pQR43zmwxnDF34shj+TJLB7Ij3sTh
V+f2X76JsCA+wmzQy8oOevxl+5HfW2mpz4VFMOmBPV7aftmDHzacN/0qX8i7
zH/1XFkP5qbkvNPcl5RHcDnvjzb3NY2e+OKX8nL8weX8giO/8y/H71PP9cCR
37I/xkUJPpY48lVC68euII58Zai/m+1CiCNfhyfMKsfqxfA4w/kC4vZvVsG6
hjzytSwi1oy9iSGOfKVoc4m+xJGXFobzF3Doz5H0y3nBfJecF5pPk+IMLucF
HPGfZjiHAkf8exvOocAR/yraPJsDccQ/8PWdz0KZzZca+sOIwxBD3x7yyMth
re/9D3Hk5ar6HZKqz8UhL38U6f9FbN3GY/bEXhnaQY/bI61/MpTkkRcX9Vzg
cRxx2GOn2RNEHHnx3+uQra4vcOh/aNDfydDPgf12hv455OV8YT5NzhfN10n5
ApfztdNxy0+fhEdG8uMN/UzEp4GhXw09yG9RF7Wf3Ig48vvpWJNSzKsnceT3
/NODf6r7OHDkt/WyNA/W14fnlj/HL2x6TPoLG/QviVzf4EL+M4qzv5bfENKD
uLVTv0+iI4gj7/HqOdS/+nwg/Or0qGa6OLudt0x86lU4OJ3sfHzX25ZZLuCR
HxtfcHLV82Wlzf/8SXpQD+3V80q+nTjsdNLkdXtQDz0aNFojOq4mDv1HZljs
FtyZOPL+oOu8cox1pjk9Oe80ZyjlEVzOe9zb+I8JDe8YyY/x81/a5XgGxWea
ds6+jZ6LvGzX+rG6Pcj7txV8l1BGEkc8O2p5WUgceZ94dm5D1teXZ0Uld3ht
fpf0F/R1p/IFz2vVud82k+JZ+vDbJGEfQnqQdw9tXxZGHHnPDR9ViOXr85Dw
a9CX6WVYfBRf32XvGfddmRT/7OF/9WSJziSP/Lqp+zuzjcRhTytt36Hbg/xa
Wm0Yx+6tIQ79986d6cAsXYkjv3W1c5DhNJco55fmKg356mv43gBHfudp/UMn
/ruYl7a38zWS7ynJI841tXPD2cSRx2Xq96G1J3Hk8Yg63zVkDXHksdFkliPO
BhFHXtpqeY8ijrwMiEuzYF9jiSMvQa+z6zGnGOKI/wW1X2q7gTji76P188OI
I/4NVvQ4I/auI474hzdY8kDwBcQR/0B1n6U405ykHH+a8zTEs2DOswvJI/6O
tlFVmbUjH4l+kUG+pqF/BXnE/4fW111CHPEPanSdsWx/4oj/J3W/vCqUOOL/
7MXwNmy4PkeK+JfR+mAbiSP+KQ1vVGEe+hwp4t9S63NG8QYhs2d37nWL4ma+
LbkUs5xP8shL/eWfmrEDG4gjL8P2s7YsJYQ48vJc7b+5rCUO/XUmOrVm1h7E
kZdtUz+WYRnT+SrDPhF58TD0WzDnCT5P4oi/iXaOo8+FIl9xee2OiSgffrFG
2oAS7os55JM2RlwXyiKSR76stbmUEOLIl+eN9Z/EqGjiyJf5jLAPoshm4sjX
jbqrXokxsfzZ7Jvfzt9dQvpvu1d/JJID+fF/T9kNDL5A8QzR+t76c5HfgvM+
fW4W+R36c2wRNkPnyO8ZdT8+KoabLU1PibsUSnbOOPn4N9Y3nHfp/f3WmXmX
jPICPcj7cTO3x6JPBHHYGSrZibwPN7vSi0X7EYf+Odp7Zhlx5H14ReW1qOVO
c63Ir712juCmz+Ua8rW40NdUEbWAOPLbP+dlonBfwSNjx35d6bGD4lAtrPhD
kRdC8oi/NlcWtYY48ru4tek0ZqrP9yJuCZMLTWbRujzyO1etwxRvPrLUtqWt
CiVQfEZq/fAAkkce85cV7CPAkcc09fw0XZ8Thv2nLbNuCu7NxybVWVnz/AGK
p9ZPjvIkeeRrQflZF0XVVcRhz3Ot76TrR77e1V/6VszyIg79YVo/aiFx5GuR
dp7iyr/7ZSZEFTPun0z7Xvqo47d7VLfB2nt7PV/7e+Nlud2N+yc1XrjYdV1i
3A+xmeiaOyngFenZua9IP+Y1n6eWOXrqwLVXRu/t90597e165xjZM3LaJ+um
8fr++se6q7bMYwXX2o6ncozsmXd6RebFRrlU/826KM9Fw2DevqJztG9H4z5A
3VJPBl00f0Xra4ihbxBmXnnZ5Jhco3209fZP/3pczSK/hLa/W82Th3c7dsE0
28ivNzuvjZ20NNvIL6ejbF2RkjlU5/e0+gnldgkLu3R7pe9Pw0LKmDKzYG5W
ZPy3wl+zjfwVX+9u6/rghdE+eoWZf8uYZTlUz8e0c4oV3M201KMHji8pPmbq
fJdHDG89Nici2k3fR/uVyIsUnmN5LTvnfg+GZVF8lmvfyf14kGG+DvFpZdjP
dnmz8LlP8WcUn7Nan3Aj33+o8W9VR7wy2h9diTh78H7PZ0ZxU7tmHieeGcXt
/strRfZvNN43ObCVa6r0yqZ4DlPfqzlxfEg+sxra4AXFc1H95tnCdwsv0//J
p8rt9X1uL8M+91v38bG2VZ7q57OGffEsw1wT4vaXYd6sRYxr2P7d+v53aFaZ
fJE+m9f4J8cm1+8pxa2C9rvmyP231Jq/tmqW0X4z/seeak38s4zic/FJ34TX
SzKM4pPd6d5Qn88ZRvEZYJhjgb/nDXNKJQKc3zVyySR/Pxr2fdNDK98qdF/f
H3UaMvChcN7Gm2R/CjyfnUl+tYn44c6m+PC1r2PnRNk9Jfsr/PV0tTpftM3n
qJmtSQbZX8/wnbzLpl3lrleeGu2PVg3bMKbQnDQjvy4XOr6+y6T7Rn75la46
IdfqEfnVWNvnRvOS8WkP3Ec+IL8K9iMO/Pqx9lGNmzwmv/7V9hcbuNnU4RlO
Fulk/8r690ez7NW8X9xi8/PL7pGdftr704k7rqkav9r1BtVzpPa7GcO9MrfY
Nnx5w8j+s+vOBUx8cNPoO3/njqZfI3PSqD6j1LmIhzF81fraIyrt1b+3X/A7
1ZhJHM8Z3b/z/Uf3af2OVX+X//d7fbGvdeiQ6Dv677tL+lB2L4L3zilcKe3k
LcpX6ZKPXwn3YF77Yf5fg71SqA6na98hwbxZ8amLKic/oN+jaHWO3cGNl/w8
4e6agLsUn8tL8y+KPn68R9tV5XLyUyg+ZQ/8qMGiJ/NDrWwG2yefpfj0Ntwn
evd44rr1iUkUnx3aOdoIPs9wnoL4nDWcI8dadXibNPEmxeeSYe5C2I4On9P/
KsVnl2FO40vYoyDvFRcp78WL5X0UC4N4gvulfm4lE2n9VtN+KAL4C+27O5Xi
WV2bqwnjXrtDqr9qdp3iGa7m93/f4Ys+VK/y0/kyxXNK9e2t2egI3uaWydXs
nNMUz7jvB03Y6GheeMXU6/HFUyhufHudPix8LZ+7rH6Zeo/PUNwOaecpc3l4
m0lvd+VuorgVnFdG8MDxt3/O7rqH4lNubMN9YogP7+i7NOV2wjmKT7zan3wW
w9PT7pdeOvMYxWdqFQcTtiCOpzg/L7L16T6Kj6N63v00imcEjij/V5tTRt+H
9ywdTIO3HSJ/E9Q+zPbN/EP97DW7vyUa7QvqvL+V5jkskvzao+035/DSbncP
WyX70ndRyc3tX4u8FdxraYi4X6oBPTdB62P78IG/3VoX5ulH+ov5Nn4jOi6l
OXDY072t2QPh2Z3m2BH/odp3fivikJ+U0ue4OscIPfI6xX2NX3H59wVcfi+B
y7+/4PLvNd2Tks6VwGH/eMM9YszZ/spO1E94RKnKLHGUfj9Ish9ctp/uDUny
4L96LvJb/8b78cx2Ed1/QX32E4WrMBdvskeOD7gcHzxXlgf/VfxRV/3/3vVQ
DFlH9mC92/MS6aLlfLIH8e9v+N6D/l/lC/V5y3BeBi6fpyBfyMvfNq4mzFqP
A3jmKcehap/h0C/OcTCnKscfdkLPV4+Z5szUS78XI+URXI4b3ZeR5MHl58J+
5H2B+2wb9XcTHHmfpf6+7A2meEK+hdpfygggDvk66jxDsD5/Lucd9sj247nI
+wj1/eYYSvYg74mt9xZmb7zouZBPUc99hkcTh/xKrY+xmuxBnSxq0X2vEL2J
o076GO4pwE7YHyBxyLc13HeAnagr3NOJ/cV5U+AvvrfB5fMj1A/qpFCV0j/E
YT3OeM/0uJR9W3hOpPsI8NdKO48eRRzyIwZEfhC1XMlOuW7pnpTEoQf2VFDf
8//7PqH7I1IdYh5brkPYj7pKUOemgiLIL9SVpVpXw2PJfsj3f9M2R3zUOeTd
LIZ8F7e3kj3I43TD9z/dG5LqkO65/MJ+WR52og4Pp2wszUw3k/2oQ1vpngvk
Zxn2HeCQH6rK5wWSnchjxb3fv6j5BUcdmk/48l4IfU4e/hazSjdhrB5x2i/k
uJVgXj3ITtRhsLZ/cSUun8fBTnm/Ay6fr8FO1FvRtzYDmIsn2UP12bf8UGY7
lzjkp7bzdmGWa8ieX9WhzDEvKtcb9KNue6nzk9kR+hy7lHdwWQ/8on29ev/r
Wxz5izpsKN03gfwFwz4OHPK2H+s8EQHbyR75PA5crkM8F3WV+XnWW1FCr3/U
VYZ23ySUnkvy6n2Tz9uIQ/6Edq9Ejw/ydW/252Esej5x1JWdj9t54TmInos6
CVX7vbWWE0ed/L7z4w51H43nQv6mc/U1otZq4pDPd3u2S6RPpuci782r5rdl
iXbEUT8NMqfYsb5r6bmQl++VyPtZzDfKebeSzouHGs6L6Z6FVD/gcr7o/oUk
D/6r56J+er+y+SSObiJ/UT9m2j5Rv/eB+umu/X2DXsSRL5fu1+PUvhCeC/nj
Wp9zMnHYv1P7ztfjjPpJVftdUbo9qB9zbV8WQs9F/ezKsa7AHBaTftjjq/Yn
lTmkB/Uwp+xCS3ZkNXHUw80+HiOY9QzSg7zbBlh8F08D6Ll0rhHdrSXzGkkc
eVyv9eXCaT4Q8cccKfRDvos2/xOh3yMw5LGfoQ8Jjri5G/oGdL9AOh8El/MO
O5H3qAFjCjO7aLIfeU9W72+20O9HQF677zl6M3HIt/O9Zc526XPFyPs+bU54
NtkD+7VzyURHei7yrs0t5+v1j7x/26veXwih50L+D7XvYbmBOORna+dHoWQP
6qTB43Nvhbcf2YM6eaR+B7ZaS8+l90a3VkNYI/0+AuqkS+pLC5boSs+FfDV1
nvazL3HInxr6zyuRPo846meddl7pRHai3vy1vrp+fwH2F5yD63PjkH+0ek0t
lhROeqD/xPgL34W9M3HU20KPauXY5Gia25TP4+heg0E+Tr03+iZKn6s31FvF
PZMrqfcyPKS+jSLN/0O+iuH8FBzPbavOn7dyITtRb1pd5ejz4ai3Rbef1lbv
E8FOyL+2OVeOndE55KM1+/V7AajP0XXbPRF3vcke2L9Fuy+wip6Lemujzgn8
v3l+1NunTe1fi1lh9FzIzzHMG4D/9xwwlOxBfjeqfb8N+rw06rOqev64PITs
hP1NtHrT7ylA/oV6r2Srfi8J9WmzxfOFuKvP86M+P6QtKcvM5pOdkG/eY0Ff
5r+WOOTjtXsuHsRRbwX3QaaQ/ajP7WpfLlufP4e/6AeCQ/7nsMC3Yq5+Lwb6
t6jvkyFuxFGffs/ii7DL0aSH9tHqPaDpsfp8u6EOC/6u2mLSg/op+DsS+n0K
1E+OWlfL9Hl7yGv9PfM44pB/t7H3ZzE7hp6LfC2br6SJuvqcNuotV72Hy9fQ
c1E/Vtp9HH3OXD5HxnPlfh24fJ6L5yL+2vfqFH2eHPXTP2xfUeakz/nL/T1w
1IPrwmMNWcYCei7k16rneom+xCG/Sz33cdDn85HfIO19OI/sQT2MVu+J/KHb
Cfk36vlm3hziyHtTrW+g32ugvsTd1kJ8jiCOfJm2sn8ksvS8IJ42/G6Wej8O
HPFcWKlCY3ZPvx8Bf8MLDyrHzFcSh7/Wmp4l/P8AIp07tA==
      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3n8kEMex5+Z6b4kbVI6dUhItR3a8uvQpYMSSndtdNEhLYu1kiUSEuXo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             "]], Polygon3DBox[CompressedData["
1:eJw1mHkYkFMWxu+9X0mKVltpn6RNlqKQJk2LbEWJSimThAqVjMFjeSxTMxgx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             "]], Polygon3DBox[CompressedData["
1:eJwtl2WYVTcURd+7A8XdBpfiFHd398EdhsGZwQbX4u5uxYu7uxSH4u7F3SnF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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vA3EAx/FrKS2JSY2kGwONXoPo1ciKrfXQB2YWqRgl0moQ9fRGKuGl
VOptkBh9LgyffH83/HN3/1zzdPckEQRBgysjqW3tMGJfa5dR+0ZvSdl3Oqb3
2mPcftBH0vaTPpOxX3QiPsM0fV6ZZcAH83zxTYEpZyINtcimXdEq23ZLz+Nn
+1KPdcPHH2lZI5p2SdeTf/+3pqvU7RWtaVFDDuP36jIHdl6X2LcXdU8vvGdH
61pjy460RNme0Syh/cMCnwyZ4503svFd0WOSMxL/9/8LbTIlAg==
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 671, 406, 670, 580, 683, 427, 678, 589, 704, 
          444, 699, 602, 731, 462, 614, 760, 483, 757, 623, 786, 503, 781, 
          631, 807, 519, 802, 643, 835, 537, 830, 536, 557}], 
         Line3DBox[{391, 575, 673, 408, 681, 581, 689, 429, 702, 590, 710, 
          446, 603, 737, 739, 464, 615, 766, 485, 784, 624, 792, 505, 805, 
          632, 813, 521, 833, 644, 841, 539, 656, 867, 559}], 
         Line3DBox[{393, 577, 675, 412, 687, 583, 693, 432, 593, 716, 718, 
          448, 607, 745, 747, 468, 617, 772, 489, 790, 626, 796, 508, 291, 
          819, 524, 647, 847, 849, 542, 659, 873, 562}], 
         Line3DBox[{396, 578, 677, 414, 585, 667, 669, 434, 597, 724, 726, 
          450, 610, 752, 754, 470, 619, 778, 491, 264, 799, 510, 637, 825, 
          827, 526, 651, 855, 857, 544, 661, 879, 564}], 
         Line3DBox[{397, 398, 679, 417, 697, 579, 700, 435, 696, 588, 729, 
          452, 723, 600, 758, 473, 460, 782, 494, 801, 576, 803, 511, 829, 
          630, 831, 527, 859, 642, 860, 547, 881, 655, 566}], 
         Line3DBox[{400, 410, 685, 419, 706, 591, 708, 437, 733, 605, 735, 
          454, 466, 762, 764, 475, 487, 788, 496, 809, 633, 811, 513, 837, 
          645, 839, 529, 863, 657, 865, 549, 560, 883, 568}], 
         Line3DBox[{402, 416, 691, 422, 712, 595, 714, 440, 451, 741, 743, 
          457, 472, 768, 770, 479, 493, 794, 499, 815, 635, 817, 515, 843, 
          649, 845, 532, 546, 869, 871, 553, 565, 885, 571}], 
         Line3DBox[{404, 420, 695, 425, 438, 720, 722, 442, 455, 749, 751, 
          459, 477, 774, 776, 481, 497, 798, 501, 821, 639, 823, 517, 530, 
          851, 853, 534, 551, 875, 877, 555, 569, 887, 573}], 
         Line3DBox[{405, 423, 698, 426, 727, 601, 728, 443, 755, 613, 756, 
          461, 779, 622, 780, 482, 777, 621, 502, 800, 629, 824, 518, 828, 
          641, 854, 535, 858, 654, 878, 556, 880, 663, 574}], 
         Line3DBox[{558, 540, 861, 538, 522, 834, 832, 520, 506, 806, 804, 
          504, 486, 785, 783, 484, 465, 759, 463, 738, 604, 730, 445, 430, 
          703, 701, 428, 409, 682, 680, 407, 387, 672, 390}], 
         Line3DBox[{561, 545, 866, 541, 848, 648, 840, 523, 292, 812, 507, 
          492, 791, 789, 488, 471, 765, 467, 746, 608, 736, 447, 717, 594, 
          709, 431, 415, 688, 686, 411, 389, 674, 392}], 
         Line3DBox[{563, 550, 872, 543, 856, 652, 846, 525, 826, 638, 818, 
          509, 265, 795, 490, 476, 771, 469, 753, 611, 744, 449, 725, 598, 
          715, 433, 668, 586, 692, 413, 394, 676, 395}], 
         Line3DBox[{567, 664, 882, 548, 658, 864, 862, 528, 646, 838, 836, 
          512, 634, 810, 808, 495, 625, 787, 474, 763, 616, 761, 453, 606, 
          734, 732, 436, 592, 707, 705, 418, 582, 684, 399}], 
         Line3DBox[{570, 665, 884, 552, 870, 660, 868, 531, 650, 844, 842, 
          514, 636, 816, 814, 498, 627, 793, 478, 769, 618, 767, 456, 742, 
          609, 740, 439, 596, 713, 711, 421, 584, 690, 401}], 
         Line3DBox[{572, 666, 886, 554, 876, 662, 874, 533, 852, 653, 850, 
          516, 640, 822, 820, 500, 628, 797, 480, 775, 620, 773, 458, 750, 
          612, 748, 441, 721, 599, 719, 424, 587, 694, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{116, 101, 671, 103, 672, 102, 673, 106, 674, 107, 675, 
          108, 676, 109, 677, 110, 111, 679, 117, 684, 122, 685, 123, 690, 
          128, 691, 129, 694, 134, 695, 135, 138, 698, 141}], 
         Line3DBox[{144, 670, 114, 118, 680, 681, 120, 124, 686, 687, 126, 
          130, 692, 132, 667, 136, 697, 112, 146, 705, 706, 152, 154, 711, 
          712, 160, 162, 719, 168, 720, 170, 727, 176, 178}], 
         Line3DBox[{179, 728, 177, 171, 722, 721, 169, 163, 714, 161, 713, 
          155, 708, 153, 707, 147, 700, 113, 137, 669, 668, 133, 131, 693, 
          127, 688, 125, 689, 121, 682, 119, 683, 115, 145}], 
         Line3DBox[{182, 678, 142, 148, 701, 702, 150, 156, 709, 158, 716, 
          164, 715, 166, 724, 172, 696, 139, 184, 732, 733, 190, 192, 740, 
          198, 741, 200, 748, 206, 749, 208, 755, 213, 215}], 
         Line3DBox[{216, 756, 214, 209, 751, 750, 207, 201, 743, 742, 199, 
          193, 735, 191, 734, 185, 729, 140, 173, 726, 725, 167, 165, 718, 
          717, 159, 157, 710, 151, 703, 149, 704, 143, 183}], 
         Line3DBox[{218, 699, 180, 186, 730, 188, 737, 194, 736, 196, 745, 
          202, 744, 204, 752, 210, 723, 174, 220, 761, 224, 762, 226, 767, 
          230, 768, 232, 773, 236, 774, 238, 779, 242, 244}], 
         Line3DBox[{245, 780, 243, 239, 776, 775, 237, 233, 770, 769, 231, 
          227, 764, 763, 225, 221, 758, 175, 211, 754, 753, 205, 203, 747, 
          746, 197, 195, 739, 738, 189, 187, 731, 181, 219}], 
         Line3DBox[{248, 217, 760, 222, 759, 223, 766, 228, 765, 229, 772, 
          234, 771, 235, 778, 240, 212, 782, 249, 787, 254, 788, 255, 793, 
          260, 794, 261, 797, 266, 798, 267, 777, 241, 270}], 
         Line3DBox[{277, 757, 246, 250, 783, 784, 252, 256, 789, 790, 258, 
          262, 795, 264, 268, 801, 104, 279, 808, 809, 285, 287, 814, 815, 
          293, 295, 820, 821, 301, 303, 800, 271, 307}], 
         Line3DBox[{308, 824, 272, 304, 823, 302, 822, 296, 817, 294, 816, 
          288, 811, 286, 810, 280, 803, 105, 269, 799, 265, 263, 796, 259, 
          791, 257, 792, 253, 785, 251, 786, 247, 278}], 
         Line3DBox[{315, 781, 275, 281, 804, 805, 283, 289, 812, 291, 297, 
          818, 299, 825, 305, 829, 273, 317, 836, 837, 323, 325, 842, 843, 
          331, 333, 850, 339, 851, 341, 828, 309, 345}], 
         Line3DBox[{346, 854, 310, 342, 853, 852, 340, 334, 845, 332, 844, 
          326, 839, 324, 838, 318, 831, 274, 306, 827, 826, 300, 298, 819, 
          292, 290, 813, 284, 806, 282, 807, 276, 316}], 
         Line3DBox[{351, 802, 313, 319, 832, 833, 321, 327, 840, 329, 847, 
          335, 846, 337, 855, 343, 859, 311, 353, 862, 863, 357, 359, 868, 
          363, 869, 365, 874, 369, 875, 371, 858, 347, 374}], 
         Line3DBox[{375, 878, 348, 372, 877, 876, 370, 366, 871, 870, 364, 
          360, 865, 358, 864, 354, 860, 312, 344, 857, 856, 338, 336, 849, 
          848, 330, 328, 841, 322, 834, 320, 835, 314, 352}], 
         Line3DBox[{377, 830, 350, 355, 861, 356, 867, 361, 866, 362, 873, 
          367, 872, 368, 879, 373, 881, 349, 378, 882, 379, 883, 380, 884, 
          381, 885, 382, 886, 383, 887, 384, 880, 376, 385}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzMvGdQVtuyNioYwAwoBgQEETAACoIoCg2ogAEEREkGxIAEAQWJkpMIkrOC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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.05664062}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=181.256\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646440602865`*^9},ExpressionUUID->"b6054680-a9bd-43b9-8ebf-\
483b77958973"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYTtvbx5cxQ+aSIYTMM8l0WJmSOfN4FAqHUMYQJWWWlLk0q5CKOuZj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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3scj+UZxt/nfgk1SYUcIufCkBxiQkKkk0NSKIccQkiIZEa1SmVqnWTp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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkUkNMWxe+9n1SK0qQBTdJgiogMDUgelaJExgrFU5Eyxsrw8PBY0eNR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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUFjcUhf+ZhRYoFHd3KW7F3d3dHRZ3WKS4uzsUWdzd3Yq7Fnd3p/3u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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0D0vQ1EAx+Gj3nUiaiS2CqJKKWVlxYhqlYGlJCa7FFFRygephK9C9GtU
YvScMDz3988d7sm5k5WznWpXCOGQUzYY9mKELXtZ8+zaRT3WtUQIR1rQVSr2
iuYTf99Z0hxle1FLmtV5DuyMzlG0Z3WGfXta9/TSOdta1hKb8UwtsG6PaYoF
+4cp2nwxwTtvpGjwQJIL4l2vPBwVanpNt32jt/TYd1qn177XvvgNbdBvP+oT
A3ZTnxm0X3RI64zS4pVxPvgkTYfv+E84j3fj5P///wKhQiRX
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 672, 406, 671, 576, 684, 427, 679, 585, 707, 
          444, 702, 598, 734, 461, 611, 764, 483, 761, 619, 788, 503, 783, 
          629, 812, 519, 807, 643, 839, 535, 350, 555}], 
         Line3DBox[{391, 573, 674, 408, 682, 577, 690, 429, 705, 586, 713, 
          446, 599, 740, 742, 463, 612, 770, 485, 786, 620, 794, 505, 810, 
          630, 818, 521, 644, 845, 847, 537, 657, 873, 557}], 
         Line3DBox[{393, 574, 676, 412, 688, 579, 694, 432, 589, 719, 721, 
          448, 603, 748, 750, 467, 614, 776, 489, 792, 622, 798, 508, 633, 
          824, 826, 523, 648, 853, 855, 540, 660, 879, 560}], 
         Line3DBox[{396, 575, 678, 414, 581, 698, 700, 434, 593, 727, 729, 
          450, 606, 756, 758, 469, 616, 781, 491, 624, 801, 803, 510, 637, 
          831, 833, 525, 652, 860, 862, 542, 662, 884, 562}], 
         Line3DBox[{397, 398, 680, 417, 670, 584, 703, 435, 731, 596, 732, 
          452, 760, 609, 762, 472, 481, 784, 494, 806, 627, 808, 511, 836, 
          641, 837, 526, 865, 655, 866, 545, 886, 664, 564}], 
         Line3DBox[{400, 410, 686, 419, 709, 587, 711, 437, 736, 601, 738, 
          454, 465, 766, 768, 474, 487, 790, 496, 814, 631, 816, 513, 841, 
          646, 843, 528, 869, 658, 871, 547, 558, 888, 566}], 
         Line3DBox[{402, 416, 692, 422, 715, 591, 717, 440, 451, 744, 746, 
          457, 471, 772, 774, 478, 493, 796, 499, 820, 635, 822, 515, 849, 
          650, 851, 531, 544, 875, 877, 551, 563, 890, 569}], 
         Line3DBox[{404, 420, 696, 424, 438, 723, 725, 442, 455, 752, 754, 
          459, 476, 778, 780, 480, 497, 800, 501, 828, 639, 830, 517, 529, 
          857, 859, 533, 549, 881, 883, 553, 567, 892, 571}], 
         Line3DBox[{405, 425, 701, 426, 730, 597, 697, 443, 759, 610, 726, 
          460, 782, 618, 755, 482, 804, 628, 502, 834, 642, 805, 518, 863, 
          656, 835, 534, 885, 665, 864, 554, 893, 669, 572}], 
         Line3DBox[{556, 538, 867, 536, 846, 645, 838, 520, 506, 811, 809, 
          504, 486, 787, 785, 484, 464, 763, 462, 741, 600, 733, 445, 430, 
          706, 704, 428, 409, 683, 681, 407, 387, 673, 390}], 
         Line3DBox[{559, 543, 872, 539, 854, 649, 844, 522, 825, 634, 817, 
          507, 492, 793, 791, 488, 470, 769, 466, 749, 604, 739, 447, 720, 
          590, 712, 431, 415, 689, 687, 411, 389, 675, 392}], 
         Line3DBox[{561, 548, 878, 541, 861, 653, 852, 524, 832, 638, 823, 
          509, 802, 625, 797, 490, 475, 775, 468, 757, 607, 747, 449, 728, 
          594, 718, 433, 699, 582, 693, 413, 394, 677, 395}], 
         Line3DBox[{565, 666, 887, 546, 659, 870, 868, 527, 647, 842, 840, 
          512, 632, 815, 813, 495, 621, 789, 473, 767, 613, 765, 453, 602, 
          737, 735, 436, 588, 710, 708, 418, 578, 685, 399}], 
         Line3DBox[{568, 667, 889, 550, 876, 661, 874, 530, 651, 850, 848, 
          514, 636, 821, 819, 498, 623, 795, 477, 773, 615, 771, 456, 745, 
          605, 743, 439, 592, 716, 714, 421, 580, 691, 401}], 
         Line3DBox[{570, 668, 891, 552, 882, 663, 880, 532, 858, 654, 856, 
          516, 640, 829, 827, 500, 626, 799, 479, 779, 617, 777, 458, 753, 
          608, 751, 441, 724, 595, 722, 423, 583, 695, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 805, 310, 304, 830, 302, 829, 296, 822, 294, 821, 
          288, 816, 286, 815, 280, 808, 271, 269, 803, 802, 265, 263, 798, 
          259, 793, 257, 794, 253, 787, 251, 788, 247, 278}], 
         Line3DBox[{112, 272, 804, 267, 800, 266, 799, 261, 796, 260, 795, 
          255, 790, 254, 789, 249, 784, 241, 240, 781, 235, 775, 234, 776, 
          229, 769, 228, 770, 223, 763, 222, 764, 217, 248}], 
         Line3DBox[{115, 101, 672, 103, 673, 102, 674, 106, 675, 107, 676, 
          108, 677, 109, 678, 110, 111, 680, 116, 685, 121, 686, 122, 691, 
          127, 692, 128, 695, 133, 696, 134, 139, 701, 140}], 
         Line3DBox[{143, 671, 113, 117, 681, 682, 119, 123, 687, 688, 125, 
          129, 693, 131, 698, 135, 670, 137, 145, 708, 709, 151, 153, 714, 
          715, 159, 161, 722, 167, 723, 169, 730, 175, 177}], 
         Line3DBox[{178, 697, 176, 170, 725, 724, 168, 162, 717, 160, 716, 
          154, 711, 152, 710, 146, 703, 138, 136, 700, 699, 132, 130, 694, 
          126, 689, 124, 690, 120, 683, 118, 684, 114, 144}], 
         Line3DBox[{181, 679, 141, 147, 704, 705, 149, 155, 712, 157, 719, 
          163, 718, 165, 727, 171, 731, 173, 183, 735, 736, 189, 191, 743, 
          197, 744, 199, 751, 205, 752, 207, 759, 213, 215}], 
         Line3DBox[{216, 726, 214, 208, 754, 753, 206, 200, 746, 745, 198, 
          192, 738, 190, 737, 184, 732, 174, 172, 729, 728, 166, 164, 721, 
          720, 158, 156, 713, 150, 706, 148, 707, 142, 182}], 
         Line3DBox[{218, 702, 179, 185, 733, 187, 740, 193, 739, 195, 748, 
          201, 747, 203, 756, 209, 760, 211, 220, 765, 224, 766, 226, 771, 
          230, 772, 232, 777, 236, 778, 238, 782, 242, 244}], 
         Line3DBox[{245, 755, 243, 239, 780, 779, 237, 233, 774, 773, 231, 
          227, 768, 767, 225, 221, 762, 212, 210, 758, 757, 204, 202, 750, 
          749, 196, 194, 742, 741, 188, 186, 734, 180, 219}], 
         Line3DBox[{274, 835, 348, 342, 859, 858, 340, 334, 851, 332, 850, 
          326, 843, 324, 842, 318, 837, 308, 306, 833, 832, 300, 298, 826, 
          825, 292, 290, 818, 284, 811, 282, 812, 276, 316}], 
         Line3DBox[{277, 761, 246, 250, 785, 786, 252, 256, 791, 792, 258, 
          262, 797, 264, 801, 268, 806, 270, 279, 813, 814, 285, 287, 819, 
          820, 293, 295, 827, 828, 301, 303, 834, 309, 104}], 
         Line3DBox[{312, 864, 376, 372, 883, 882, 370, 366, 877, 876, 364, 
          360, 871, 358, 870, 354, 866, 346, 344, 862, 861, 338, 336, 855, 
          854, 330, 328, 847, 846, 322, 320, 839, 314, 352}], 
         Line3DBox[{315, 783, 275, 281, 809, 810, 283, 289, 817, 291, 824, 
          297, 823, 299, 831, 305, 836, 307, 317, 840, 841, 323, 325, 848, 
          849, 331, 333, 856, 339, 857, 341, 863, 347, 273}], 
         Line3DBox[{349, 385, 893, 384, 892, 383, 891, 382, 890, 381, 889, 
          380, 888, 379, 887, 378, 374, 886, 373, 884, 368, 878, 367, 879, 
          362, 872, 361, 873, 356, 867, 355, 350, 377}], 
         Line3DBox[{351, 807, 313, 319, 838, 321, 845, 327, 844, 329, 853, 
          335, 852, 337, 860, 343, 865, 345, 353, 868, 869, 357, 359, 874, 
          363, 875, 365, 880, 369, 881, 371, 885, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJzEu3k019/7LkzSPEhSaECKEpkyFTelKCFDMifKUESIJqXMZJ7neZ6nzLZ5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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.06762695}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=191.257\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.717364644103319*^9},ExpressionUUID->"2d9e8113-661e-4641-b6db-\
92effaf1cc35"],

Cell[BoxData[
 GraphicsBox[{{}, InsetBox[
    Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJx1nHlYTlsXwHeGzEq44iLzTGauaZcxY1FIhpKpSKVBhtQrESolTVQaJKFI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      "], {{
        {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
          GrayLevel[1], 3], 
         StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJwtl3n8z1UWxu+9n4gsI20oy8+WZBtbIaFkJ1uphOySkIokSlTDRKJNIpmU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             "]], Polygon3DBox[CompressedData["
1:eJwtmHkcUFMWx++9T5JU0mrXQotGUraKNiVLlmxRitIkQ5G2McZnNBjLTH2K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             "]], Polygon3DBox[CompressedData["
1:eJwtlwWUFUcQRf+fj0uwxXUTPLgTPLjD4u66LOziTnB3dw3uDsEhWHANHtyd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             "]]}],
          Lighting->{{"Ambient", 
             RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
            "Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{0, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 2, 2}]}, {"Directional", 
             RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
             ImageScaled[{2, 0, 2}]}}]}, {}, {}, {}, {}}, {
        {GrayLevel[0], Line3DBox[CompressedData["
1:eJwt0DsvQ2EAx+FX3ZmIdqzYNKGhDYdeVlaMtFqtgQWJqbu4REWpfhASvgrh
a5AY+5wwPOf3zxnOm/fMNU53TgZCCAccs8GUF9Ns2ZGusWtX9VDLiRCaWtIi
Dbug64m/70S6St1e0ZrmNce+vaxLVO2sLlKxF3RPW87Z1rrW2IzP0iJlO6VJ
8vYvGb74ZJY3XknS4Z5JzonveuHhqHCpVwza13rDkH2rbYbtOx2Jv6EdRu0H
fWTM7uoT43ZPJ7TNDM+8kOadD+b55occZ/HdOPr//32zEiRm
          "]]}, 
        {GrayLevel[0.2], 
         Line3DBox[{388, 386, 670, 406, 669, 577, 682, 427, 677, 586, 705, 
          444, 700, 599, 732, 461, 612, 762, 483, 759, 620, 786, 504, 781, 
          629, 810, 520, 805, 641, 836, 536, 654, 863, 556}], 
         Line3DBox[{391, 574, 672, 408, 680, 578, 688, 429, 703, 587, 711, 
          446, 600, 738, 740, 463, 613, 768, 485, 784, 621, 792, 506, 808, 
          630, 816, 522, 835, 642, 842, 538, 655, 869, 558}], 
         Line3DBox[{393, 575, 674, 412, 686, 580, 692, 432, 590, 717, 719, 
          448, 604, 746, 748, 467, 615, 774, 489, 790, 623, 798, 509, 291, 
          822, 524, 645, 848, 850, 541, 658, 875, 561}], 
         Line3DBox[{396, 576, 676, 414, 582, 696, 698, 434, 594, 725, 727, 
          450, 607, 754, 756, 469, 617, 779, 491, 796, 625, 801, 511, 635, 
          827, 829, 526, 649, 855, 857, 543, 660, 880, 563}], 
         Line3DBox[{397, 398, 678, 417, 668, 585, 701, 435, 729, 597, 730, 
          452, 758, 610, 760, 472, 481, 782, 494, 804, 627, 806, 512, 832, 
          639, 833, 527, 860, 652, 861, 546, 882, 662, 565}], 
         Line3DBox[{400, 410, 684, 419, 707, 588, 709, 437, 734, 602, 736, 
          454, 465, 764, 766, 474, 487, 788, 496, 812, 631, 814, 514, 838, 
          643, 840, 529, 865, 656, 867, 548, 559, 884, 567}], 
         Line3DBox[{402, 416, 690, 422, 713, 592, 715, 440, 451, 742, 744, 
          457, 471, 770, 772, 478, 493, 794, 500, 818, 633, 820, 516, 844, 
          647, 846, 532, 545, 871, 873, 552, 564, 886, 570}], 
         Line3DBox[{404, 420, 694, 424, 438, 721, 723, 442, 455, 750, 752, 
          459, 476, 776, 778, 480, 498, 800, 502, 824, 637, 826, 518, 530, 
          852, 854, 534, 550, 877, 879, 554, 568, 888, 572}], 
         Line3DBox[{405, 425, 699, 426, 728, 598, 695, 443, 757, 611, 724, 
          460, 780, 619, 753, 482, 802, 628, 503, 830, 640, 803, 519, 858, 
          653, 831, 535, 881, 663, 859, 555, 889, 667, 573}], 
         Line3DBox[{557, 539, 862, 537, 322, 834, 521, 507, 809, 807, 505, 
          486, 785, 783, 484, 464, 761, 462, 739, 601, 731, 445, 430, 704, 
          702, 428, 409, 681, 679, 407, 387, 671, 390}], 
         Line3DBox[{560, 544, 868, 540, 849, 646, 841, 523, 292, 815, 508, 
          492, 791, 789, 488, 470, 767, 466, 747, 605, 737, 447, 718, 591, 
          710, 431, 415, 687, 685, 411, 389, 673, 392}], 
         Line3DBox[{562, 549, 874, 542, 856, 650, 847, 525, 828, 636, 821, 
          510, 497, 797, 795, 490, 475, 773, 468, 755, 608, 745, 449, 726, 
          595, 716, 433, 697, 583, 691, 413, 394, 675, 395}], 
         Line3DBox[{566, 664, 883, 547, 657, 866, 864, 528, 644, 839, 837, 
          513, 632, 813, 811, 495, 622, 787, 473, 765, 614, 763, 453, 603, 
          735, 733, 436, 589, 708, 706, 418, 579, 683, 399}], 
         Line3DBox[{569, 665, 885, 551, 872, 659, 870, 531, 648, 845, 843, 
          515, 634, 819, 817, 499, 624, 793, 477, 771, 616, 769, 456, 743, 
          606, 741, 439, 593, 714, 712, 421, 581, 689, 401}], 
         Line3DBox[{571, 666, 887, 553, 878, 661, 876, 533, 853, 651, 851, 
          517, 638, 825, 823, 501, 626, 799, 479, 777, 618, 775, 458, 751, 
          609, 749, 441, 722, 596, 720, 423, 584, 693, 403}]}, 
        {GrayLevel[0.2], 
         Line3DBox[{105, 803, 310, 304, 826, 302, 825, 296, 820, 294, 819, 
          288, 814, 286, 813, 280, 806, 271, 269, 801, 265, 797, 263, 798, 
          259, 791, 257, 792, 253, 785, 251, 786, 247, 278}], 
         Line3DBox[{112, 272, 802, 267, 800, 266, 799, 261, 794, 260, 793, 
          255, 788, 254, 787, 249, 782, 241, 240, 779, 235, 773, 234, 774, 
          229, 767, 228, 768, 223, 761, 222, 762, 217, 248}], 
         Line3DBox[{115, 101, 670, 103, 671, 102, 672, 106, 673, 107, 674, 
          108, 675, 109, 676, 110, 111, 678, 116, 683, 121, 684, 122, 689, 
          127, 690, 128, 693, 133, 694, 134, 139, 699, 140}], 
         Line3DBox[{143, 669, 113, 117, 679, 680, 119, 123, 685, 686, 125, 
          129, 691, 131, 696, 135, 668, 137, 145, 706, 707, 151, 153, 712, 
          713, 159, 161, 720, 167, 721, 169, 728, 175, 177}], 
         Line3DBox[{178, 695, 176, 170, 723, 722, 168, 162, 715, 160, 714, 
          154, 709, 152, 708, 146, 701, 138, 136, 698, 697, 132, 130, 692, 
          126, 687, 124, 688, 120, 681, 118, 682, 114, 144}], 
         Line3DBox[{181, 677, 141, 147, 702, 703, 149, 155, 710, 157, 717, 
          163, 716, 165, 725, 171, 729, 173, 183, 733, 734, 189, 191, 741, 
          197, 742, 199, 749, 205, 750, 207, 757, 213, 215}], 
         Line3DBox[{216, 724, 214, 208, 752, 751, 206, 200, 744, 743, 198, 
          192, 736, 190, 735, 184, 730, 174, 172, 727, 726, 166, 164, 719, 
          718, 158, 156, 711, 150, 704, 148, 705, 142, 182}], 
         Line3DBox[{218, 700, 179, 185, 731, 187, 738, 193, 737, 195, 746, 
          201, 745, 203, 754, 209, 758, 211, 220, 763, 224, 764, 226, 769, 
          230, 770, 232, 775, 236, 776, 238, 780, 242, 244}], 
         Line3DBox[{245, 753, 243, 239, 778, 777, 237, 233, 772, 771, 231, 
          227, 766, 765, 225, 221, 760, 212, 210, 756, 755, 204, 202, 748, 
          747, 196, 194, 740, 739, 188, 186, 732, 180, 219}], 
         Line3DBox[{274, 831, 348, 342, 854, 853, 340, 334, 846, 332, 845, 
          326, 840, 324, 839, 318, 833, 308, 306, 829, 828, 300, 298, 822, 
          292, 290, 816, 284, 809, 282, 810, 276, 316}], 
         Line3DBox[{277, 759, 246, 250, 783, 784, 252, 256, 789, 790, 258, 
          262, 795, 796, 264, 268, 804, 270, 279, 811, 812, 285, 287, 817, 
          818, 293, 295, 823, 824, 301, 303, 830, 309, 104}], 
         Line3DBox[{312, 859, 376, 372, 879, 878, 370, 366, 873, 872, 364, 
          360, 867, 358, 866, 354, 861, 346, 344, 857, 856, 338, 336, 850, 
          849, 330, 328, 842, 322, 320, 836, 314, 352}], 
         Line3DBox[{315, 781, 275, 281, 807, 808, 283, 289, 815, 291, 297, 
          821, 299, 827, 305, 832, 307, 317, 837, 838, 323, 325, 843, 844, 
          331, 333, 851, 339, 852, 341, 858, 347, 273}], 
         Line3DBox[{349, 385, 889, 384, 888, 383, 887, 382, 886, 381, 885, 
          380, 884, 379, 883, 378, 374, 882, 373, 880, 368, 874, 367, 875, 
          362, 868, 361, 869, 356, 862, 355, 863, 350, 377}], 
         Line3DBox[{351, 805, 313, 319, 834, 835, 321, 327, 841, 329, 848, 
          335, 847, 337, 855, 343, 860, 345, 353, 864, 865, 357, 359, 870, 
          363, 871, 365, 876, 369, 877, 371, 881, 375, 311}]}, {}, {}}},
      VertexNormals->CompressedData["
1:eJysu3dUz+8bP56kQRllJJWRskpUhHApDZKWQiippKRdCiERTe2pvYf2nld7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       "]],
     Axes->True,
     AxesLabel->{
       FormBox["\"\[Phi]\"", TraditionalForm], 
       FormBox["\"\[Chi]\"", TraditionalForm], None},
     BoxRatios->{2, 2, 1},
     DisplayFunction->Identity,
     FaceGridsStyle->Automatic,
     Method->{"DefaultBoundaryStyle" -> Directive[
         GrayLevel[0.3]], "RotationControl" -> "Globe"},
     PlotRange->{{-1, 1}, {-1, 1}, {0., 0.07470703}},
     PlotRangePadding->{{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.02], 
        Scaled[0.02]}},
     Ticks->{Automatic, Automatic, {}}], {189., -189.}, 
    ImageScaled[{0.5, 0.5}], {360., 360.},
    ContentSelectable->True], {}},
  ContentSelectable->True,
  ImageSize->NCache[{400, 400/GoldenRatio}, {400, 247.2135954999579}],
  PlotLabel->FormBox["\"2D Histograms for t=200.008\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{
  3.422111079747536*^9, 3.42211116587419*^9, {3.4221113685655813`*^9, 
   3.422111377456377*^9}, {3.4221119352795873`*^9, 3.4221119485767174`*^9}, 
   3.4221120375784264`*^9, 3.4221120937826304`*^9, 3.4221214125417676`*^9, 
   3.423922456032356*^9, 3.424184240056937*^9, 3.7173642409519978`*^9, 
   3.717364355578748*^9, {3.717364443647849*^9, 3.7173644640105715`*^9}, 
   3.7173645102774324`*^9, 3.717364544144866*^9, 
   3.7173646441473546`*^9},ExpressionUUID->"5d1c51f2-1eca-448c-a7dd-\
4a36618b8d9a"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1272, 685},
WindowMargins->{{38, Automatic}, {39, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 167, 3, 101, "Title", "ExpressionUUID" -> \
"62449385-f0cd-4d6c-8ec6-c58fa3953db9"],
Cell[737, 27, 346, 8, 49, "Text", "ExpressionUUID" -> \
"006007ed-dc92-44ee-ba30-c5f43bc9d712"],
Cell[1086, 37, 190, 3, 30, "Text", "ExpressionUUID" -> \
"a5a8e0ed-82e1-44d6-9ddc-e0906126377c"],
Cell[1279, 42, 206, 4, 30, "Input", "ExpressionUUID" -> \
"436c79f0-d136-4c02-95c8-b3667b2d035f"],
Cell[CellGroupData[{
Cell[1510, 50, 197, 5, 70, "Section", "ExpressionUUID" -> \
"2f1ebb92-06d2-4e58-a6a3-7220254ecf8c"],
Cell[1710, 57, 189, 3, 30, "Text", "ExpressionUUID" -> \
"26e28150-0828-4830-a308-ac434091014e"],
Cell[1902, 62, 331, 8, 30, "Input", "ExpressionUUID" -> \
"e43a05ab-e7fc-4489-98a0-01b8baf3d21e"],
Cell[2236, 72, 530, 9, 125, "Text", "ExpressionUUID" -> \
"100d05ff-2e13-4021-bb5e-b67a1878cc0a"],
Cell[2769, 83, 534, 14, 126, "Input", "ExpressionUUID" -> \
"6005a74d-683f-4965-a981-caedf9dc7422"],
Cell[3306, 99, 150, 2, 30, "Text", "ExpressionUUID" -> \
"54ad4eaf-887e-45c7-b9e9-3a4ac3e87a0f"],
Cell[3459, 103, 380, 11, 69, "Input", "ExpressionUUID" -> \
"3bd8e18d-589b-4aef-bab0-580c00e57261"],
Cell[3842, 116, 634, 12, 106, "Text", "ExpressionUUID" -> \
"38220200-926a-40e0-b2a8-c4c41d2c80f2"],
Cell[4479, 130, 757, 22, 69, "Input", "ExpressionUUID" -> \
"a17e3b8b-5b03-49f2-a16a-cd26b47f68ca"]
}, Closed]],
Cell[CellGroupData[{
Cell[5273, 157, 154, 3, 56, "Section", "ExpressionUUID" -> \
"f071f974-6bd3-4a2f-a4ad-a74d80e9b0b2"],
Cell[5430, 162, 208, 3, 30, "Text", "ExpressionUUID" -> \
"b62b7d7f-b889-48d3-9bf2-f218168756a6"],
Cell[CellGroupData[{
Cell[5663, 169, 695, 20, 50, "Input", "ExpressionUUID" -> \
"60b37f6a-8fca-4fe3-bc39-5bde5ae28531"],
Cell[6361, 191, 272, 5, 30, "Output", "ExpressionUUID" -> \
"c5273edd-a3e4-431a-9874-a47323159379"]
}, Open  ]],
Cell[6648, 199, 187, 3, 30, "Text", "ExpressionUUID" -> \
"4b3148a4-1b09-4118-afb8-d4c0aef9dafd"],
Cell[6838, 204, 1190, 30, 88, "Input", "ExpressionUUID" -> \
"8e474607-3f5e-4605-8343-6c9fdb5dc4f4"],
Cell[8031, 236, 614, 13, 125, "Text", "ExpressionUUID" -> \
"9199c38c-2d64-4aa6-aa43-85ff526d49e1"],
Cell[CellGroupData[{
Cell[8670, 253, 6175, 156, 316, "Input", "ExpressionUUID" -> \
"3b69998c-f106-4fa2-905b-105d59eead72"],
Cell[CellGroupData[{
Cell[14870, 413, 59331, 975, 255, "Print", "ExpressionUUID" -> \
"442db7f9-e124-4ddb-8836-08fcbbd6b727"],
Cell[74204, 1390, 58732, 965, 255, "Print", "ExpressionUUID" -> \
"c152e57f-80a5-4f0e-a987-7ac2f1d7979f"],
Cell[132939, 2357, 58996, 969, 255, "Print", "ExpressionUUID" -> \
"9338cd4e-1e89-4591-8c22-2b960729e4ba"],
Cell[191938, 3328, 59252, 974, 255, "Print", "ExpressionUUID" -> \
"8f7736bc-5416-467a-b3f3-a1d1dd037a8f"],
Cell[251193, 4304, 59463, 977, 255, "Print", "ExpressionUUID" -> \
"e20977bf-2407-42b4-a2c6-15d565931ab0"],
Cell[310659, 5283, 59622, 979, 255, "Print", "ExpressionUUID" -> \
"6e03393c-bdcc-42a8-babf-f70bf51e2a78"],
Cell[370284, 6264, 59505, 978, 255, "Print", "ExpressionUUID" -> \
"7e56f6d8-c7d5-405c-b480-380c34ac6bb1"],
Cell[429792, 7244, 59669, 980, 255, "Print", "ExpressionUUID" -> \
"32eb7425-88ad-4f7b-a805-00c5b7978309"],
Cell[489464, 8226, 59332, 974, 255, "Print", "ExpressionUUID" -> \
"13267bf3-0451-4ccc-b1e6-f787b6dad6dd"],
Cell[548799, 9202, 58103, 955, 255, "Print", "ExpressionUUID" -> \
"20cd43eb-9e4b-4977-924d-360a037f9b02"],
Cell[606905, 10159, 53836, 885, 255, "Print", "ExpressionUUID" -> \
"750243f2-945a-4a5a-8575-1613f0275948"],
Cell[660744, 11046, 50120, 824, 255, "Print", "ExpressionUUID" -> \
"15fb8021-2a1a-4990-a80d-2906d0999a64"],
Cell[710867, 11872, 47954, 788, 255, "Print", "ExpressionUUID" -> \
"ce7dc847-15f2-434d-a001-f45d16c94612"],
Cell[758824, 12662, 50682, 834, 255, "Print", "ExpressionUUID" -> \
"fa8cb0c6-136e-42ac-a16e-6f0c00259ec3"],
Cell[809509, 13498, 55251, 909, 255, "Print", "ExpressionUUID" -> \
"de9ca484-81c7-44e9-9d63-c6cffd82119f"],
Cell[864763, 14409, 56332, 926, 255, "Print", "ExpressionUUID" -> \
"bb75300e-20c1-444b-b7a4-33e55f024688"],
Cell[921098, 15337, 57365, 944, 255, "Print", "ExpressionUUID" -> \
"7ca85ba7-3eaf-4e1a-a243-9869fc5fb621"],
Cell[978466, 16283, 55784, 917, 255, "Print", "ExpressionUUID" -> \
"01b3144f-e2df-4f14-aa60-48102941265d"],
Cell[1034253, 17202, 54290, 893, 255, "Print", "ExpressionUUID" -> \
"b6054680-a9bd-43b9-8ebf-483b77958973"],
Cell[1088546, 18097, 55932, 919, 255, "Print", "ExpressionUUID" -> \
"2d9e8113-661e-4641-b6db-92effaf1cc35"],
Cell[1144481, 19018, 57293, 942, 255, "Print", "ExpressionUUID" -> \
"5d1c51f2-1eca-448c-a7dd-4a36618b8d9a"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

