(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   1194967,      22390]
NotebookOptionsPosition[   1188512,      22245]
NotebookOutlinePosition[   1188934,      22261]
CellTagsIndexPosition[   1188891,      22258]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["LATTICEEASY NOTEBOOK : Means and Variances", "Title",
 CellChangeTimes->{{3.717360247182777*^9, 
  3.7173602528019695`*^9}},ExpressionUUID->"d3458181-ffde-4bca-9afc-\
bcb1fca4a8cd"],

Cell["\<\
This notebook produces plots of means and variances for one or more runs of \
the latticeeasy program. If the number of runs is set to more than one then \
plots are generated separately for each run and then combined plots are \
generated showing the data for different runs together.
Note that the means are plotted as square means. This allows them to be put \
on log plots, and also facilitates comparison with the variances.
Note also that it is common for errors to appear in plotting variances \
because very small variances may accidentally have been computed as negative. \
These errors should just be ignored; the plots are still produced accurately.
Last modified: 10/18/17\
\>", "Text",
 CellChangeTimes->{{3.717360243163983*^9, 3.7173602444043365`*^9}, {
  3.7173603872256927`*^9, 
  3.71736039018029*^9}},ExpressionUUID->"0a993e0d-4bab-4e22-bbaa-\
a9d5ee83aa04"],

Cell["Clear all variables to avoid naming conflicts.", "Text",
 CellChangeTimes->{{3.7173593539180403`*^9, 
  3.717359364375927*^9}},ExpressionUUID->"8b341ede-c8e3-4a5a-8142-\
dd655f018ad4"],

Cell[BoxData[
 RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.7173584246909575`*^9, 
  3.7173584246929617`*^9}},ExpressionUUID->"cc4a1111-769e-4973-9c10-\
1e5887346c35"],

Cell[CellGroupData[{

Cell["\<\
PARAMETERS: Set parameters for where to read data and what to plot\
\>", "Section",
 CellChangeTimes->{{3.7173602770168056`*^9, 
  3.717360284306837*^9}},ExpressionUUID->"b65873f5-afb3-47e6-bb19-\
9587c07fcbcf"],

Cell["\<\
The number of labels should be at least as large as the number of fields. \
Additional labels will be ignored.\
\>", "Text",ExpressionUUID->"93d5b6a3-57f2-4d80-ad57-a835ba8230b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"label", "[", "0", "]"}], "=", "\"\<\[Phi]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "1", "]"}], "=", "\"\<\[Chi]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "2", "]"}], "=", "\"\<\[Sigma]\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "3", "]"}], "=", 
   "\"\<\!\(\*SubscriptBox[\(E\), \(1\)]\)\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "4", "]"}], "=", 
   "\"\<\!\(\*SubscriptBox[\(E\), \(2\)]\)\>\""}], ";", 
  RowBox[{
   RowBox[{"label", "[", "5", "]"}], "=", "\"\<B\>\""}], ";"}]], "Input",Expre\
ssionUUID->"d0eac3ce-ae82-43df-9880-f3dd55fa6dbf"],

Cell["\<\
Whether to plot means and/or variances. 0=Don't plot, 1=Plot.\
\>", "Text",ExpressionUUID->"6c8cad30-12a1-451e-b8f8-6ee97df66600"],

Cell[BoxData[
 RowBox[{
  RowBox[{"domeans", "=", "1"}], ";", 
  RowBox[{"dovars", "=", "1"}], ";"}]], "Input",ExpressionUUID->"52f9b709-\
07e1-4688-af97-ad69f82e5a49"],

Cell["\<\
The run variables are
  \[IndentingNewLine]dir - The directory where the files are stored\
\[IndentingNewLine]
  ext - The extension of the data files
  nflds - The number of fields in the simulations
  skip - Number of points to skip between each plotted point. Used for making \
plots of large datasets\
\>", "Text",ExpressionUUID->"d7d7b5f0-54aa-46eb-a7f5-82f8138379b4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"run", "=", "0"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"dir", "[", "run", "]"}], "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{
   RowBox[{"ext", "[", "run", "]"}], "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{
   RowBox[{"nflds", "[", "run", "]"}], "=", "2"}], ";", 
  RowBox[{
   RowBox[{"skip", "[", "run", "]"}], "=", "1"}], ";", 
  RowBox[{"run", "++"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dir", "[", "run", "]"}], "=", 
   "\"\<c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\>\""}], ";", 
  RowBox[{
   RowBox[{"ext", "[", "run", "]"}], "=", "\"\<_0.dat\>\""}], ";", 
  RowBox[{
   RowBox[{"nflds", "[", "run", "]"}], "=", "2"}], ";", 
  RowBox[{
   RowBox[{"skip", "[", "run", "]"}], "=", "1"}], ";", 
  RowBox[{"run", "++"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"numruns", "=", "run"}], ";"}]}], "Input",
 CellChangeTimes->{
  3.4220308537617683`*^9, {3.423922174777664*^9, 3.423922190663041*^9}, {
   3.427464111368901*^9, 3.427464161004499*^9}, {3.427464401964473*^9, 
   3.42746440746406*^9}, {3.440254692980281*^9, 3.440254719221435*^9}, {
   3.440257488174799*^9, 3.440257490112465*^9}, {3.44050215908922*^9, 
   3.440502168283051*^9}, {3.445191076955816*^9, 3.445191089945115*^9}, {
   3.71735850525534*^9, 3.7173585298463306`*^9}, {3.717359388407908*^9, 
   3.7173593892141457`*^9}},ExpressionUUID->"40608368-8548-4d1b-b9d8-\
69ed1384b765"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["RUN DATA: Read in data and make plots for each run", \
"Section"]], "Section",
 CellChangeTimes->{{3.7173602905927143`*^9, 
  3.7173603163469152`*^9}},ExpressionUUID->"fce04f5f-a9be-4d64-949c-\
c0057b17c525"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"For", "[", 
   RowBox[{
    RowBox[{"run", "=", "0"}], ",", 
    RowBox[{"run", "<", "numruns"}], ",", 
    RowBox[{"run", "++"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{
       "\"\<Starting run \>\"", ",", "run", ",", 
        "\"\<. Reading data from \>\"", ",", "dir"}], "]"}], 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"domeans", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "Print", "[", "\"\<Preparing to read means input table\>\"", "]"}], 
         ";", 
         RowBox[{
          RowBox[{"intablemeans", "[", "run", "]"}], "=", 
          RowBox[{"ReadList", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"dir", "[", "run", "]"}], "<>", "\"\<means\>\"", "<>", 
             RowBox[{"ext", "[", "run", "]"}]}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"Real", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "+", "1"}], "}"}]}], 
             "]"}]}], "]"}]}], ";", 
         RowBox[{
          RowBox[{"numtimesmeans", "[", "run", "]"}], "=", 
          RowBox[{"Count", "[", 
           RowBox[{
            RowBox[{"intablemeans", "[", "run", "]"}], ",", 
            RowBox[{"Table", "[", 
             RowBox[{"_Real", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "+", "1"}], "}"}]}], 
             "]"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dovars", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
        "Print", "[", "\"\<Preparing to read variance input table\>\"", "]"}],
         ";", 
        RowBox[{
         RowBox[{"intablevars", "[", "run", "]"}], "=", 
         RowBox[{"ReadList", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"dir", "[", "run", "]"}], "<>", "\"\<variance\>\"", "<>", 
            RowBox[{"ext", "[", "run", "]"}]}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"Real", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"nflds", "[", "run", "]"}], "+", "1"}], "}"}]}], 
            "]"}]}], "]"}]}], ";", 
        RowBox[{
         RowBox[{"numtimesvars", "[", "run", "]"}], "=", 
         RowBox[{"Count", "[", 
          RowBox[{
           RowBox[{"intablevars", "[", "run", "]"}], ",", 
           RowBox[{"Table", "[", 
            RowBox[{"_Real", ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"nflds", "[", "run", "]"}], "+", "1"}], "}"}]}], 
            "]"}]}], "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
     "Print", "[", "\"\<Preparing to create field data tables.\>\"", "]"}], 
     ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"fld", "=", "0"}], ",", 
       RowBox[{"fld", "<", 
        RowBox[{"nflds", "[", "run", "]"}]}], ",", 
       RowBox[{"fld", "++"}], ",", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"domeans", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"meanstable", "[", "run", "]"}], "[", "fld", "]"}], "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"intablemeans", "[", "run", "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               SuperscriptBox[
                RowBox[{
                 RowBox[{"intablemeans", "[", "run", "]"}], 
                 "\[LeftDoubleBracket]", 
                 RowBox[{"i", ",", 
                  RowBox[{"fld", "+", "2"}]}], "\[RightDoubleBracket]"}], 
                "2"]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"numtimesmeans", "[", "run", "]"}], ",", 
               RowBox[{"skip", "[", "run", "]"}]}], "}"}]}], "]"}]}]}], "]"}],
         ";", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"dovars", "\[Equal]", "1"}], ",", 
          RowBox[{
           RowBox[{
            RowBox[{"varstable", "[", "run", "]"}], "[", "fld", "]"}], "=", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{
                RowBox[{"intablevars", "[", "run", "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", "1"}], "\[RightDoubleBracket]"}], ",", 
               RowBox[{
                RowBox[{"intablevars", "[", "run", "]"}], 
                "\[LeftDoubleBracket]", 
                RowBox[{"i", ",", 
                 RowBox[{"fld", "+", "2"}]}], "\[RightDoubleBracket]"}]}], 
              "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", "1", ",", 
               RowBox[{"numtimesvars", "[", "run", "]"}], ",", 
               RowBox[{"skip", "[", "run", "]"}]}], "}"}]}], "]"}]}]}], "]"}],
         ";"}]}], "]"}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"domeans", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], "=", 
            RowBox[{"ListLogPlot", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"meanstable", "[", "run", "]"}], "[", "fld", "]"}], 
              ",", 
              RowBox[{"Joined", "\[Rule]", "True"}], ",", 
              RowBox[{"AxesLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"\"\<t\>\"", ",", 
                 RowBox[{"\"\<Square Mean: \>\"", "<>", 
                  RowBox[{"label", "[", "fld", "]"}]}]}], "}"}]}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"Hue", "[", 
                 RowBox[{
                  FractionBox["fld", 
                   RowBox[{"nflds", "[", "run", "]"}]], "+", 
                  RowBox[{"0.2`", " ", "run"}]}], "]"}], "}"}]}]}], "]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{
             RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], 
            "]"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"combinedmeansplot", "[", "run", "]"}], "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"fld", ",", "0", ",", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<t\>\"", ",", "None"}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", "\"\<Square Means\>\""}]}], 
          "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"combinedmeansplot", "[", "run", "]"}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dovars", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"For", "[", 
         RowBox[{
          RowBox[{"fld", "=", "0"}], ",", 
          RowBox[{"fld", "<", 
           RowBox[{"nflds", "[", "run", "]"}]}], ",", 
          RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], "=", 
            RowBox[{"ListLogPlot", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"varstable", "[", "run", "]"}], "[", "fld", "]"}], ",", 
              RowBox[{"Joined", "\[Rule]", "True"}], ",", 
              RowBox[{"AxesLabel", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"\"\<t\>\"", ",", 
                 RowBox[{"\"\<Variance: \>\"", "<>", 
                  RowBox[{"label", "[", "fld", "]"}]}]}], "}"}]}], ",", 
              RowBox[{"PlotStyle", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"Hue", "[", 
                 RowBox[{
                  FractionBox["fld", 
                   RowBox[{"nflds", "[", "run", "]"}]], "+", 
                  RowBox[{"0.2`", " ", "run"}]}], "]"}], "}"}]}]}], "]"}]}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{
             RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], 
            "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"combinedvarsplot", "[", "run", "]"}], "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"fld", ",", "0", ",", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<t\>\"", ",", "None"}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", "\"\<Variances\>\""}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"fld", ",", "0", ",", 
               RowBox[{
                RowBox[{"nflds", "[", "run", "]"}], "-", "1"}]}], "}"}]}], 
            "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           RowBox[{"AxesLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"\"\<t\>\"", ",", "None"}], "}"}]}], ",", 
           RowBox[{"PlotLabel", "\[Rule]", "\"\<Variances\>\""}]}], "]"}], 
         "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"domeans", "\[Equal]", "1"}], "&&", 
        RowBox[{"dovars", "\[Equal]", "1"}]}], ",", "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
         RowBox[{"meansvarsplot", "[", "run", "]"}], "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"combinedmeansplot", "[", "run", "]"}], ",", 
           RowBox[{"combinedvarsplot", "[", "run", "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
           RowBox[{
           "PlotLabel", "\[Rule]", "\"\<Square Means and Variances\>\""}]}], 
          "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], ";"}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.4220311427985673`*^9, 3.422031147970542*^9}, {
   3.422105681815773*^9, 3.422105720582142*^9}, 3.422105880069579*^9, {
   3.4221062636238184`*^9, 3.4221062913743515`*^9}, {3.422106422548745*^9, 
   3.422106440892847*^9}, {3.4221065168630557`*^9, 3.422106533222745*^9}, {
   3.7173586507962766`*^9, 3.717358682620566*^9}, 3.717359058868931*^9, {
   3.717359093665506*^9, 3.7173591304323645`*^9}, {3.7173591728253255`*^9, 
   3.717359198008314*^9}, {3.7173598722209854`*^9, 
   3.7173598773875833`*^9}},ExpressionUUID->"cb2c6eeb-804f-4352-a4d3-\
f0a59dc5790e"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Starting run \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\". Reading data from \"\>", "\[InvisibleSpace]", 
   "dir"}],
  SequenceForm["Starting run ", 0, ". Reading data from ", $CellContext`dir],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.71735996767922*^9},ExpressionUUID->"de782feb-c803-42ee-8c32-\
4fca7bde16b1"],

Cell[BoxData["\<\"Preparing to read means input table\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599676802216`*^9},ExpressionUUID->"bf706d1d-3f36-4584-b30b-\
f18dd5868041"],

Cell[BoxData["\<\"Preparing to read variance input table\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599676856427`*^9},ExpressionUUID->"4e606527-b7f2-4136-a6c2-\
4d9624be2d8a"],

Cell[BoxData["\<\"Preparing to create field data tables.\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599676876445`*^9},ExpressionUUID->"6dcb8a3d-d725-4006-8c37-\
4aca03b7eb66"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
      LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-15.98223042610117, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968269144*^9},ExpressionUUID->"856555c1-688d-487b-b16b-\
3679324aa431"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -76.14742169746623},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-75.04615102694436, -6.767369454589756}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-73.68272297580947, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-71.38013788281542, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599683552094`*^9},ExpressionUUID->"21112e9a-25b7-4c68-a255-\
442b070ff0bd"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY
sFc4B7GAooIVESWgIF16h3y84M+PP1zrmjMzZ+bsPeteM1GPXusfx0cQhDqZ
IP73////q6Eb99ycmk8uQXOaS1eZp0/VFqv5p9voJ26piMdYNf/TvfSvdda2
94/2/tODdKKGxa8YOvFPj9J1c0yjS0wF8dDunIFp3gS9+FF9+e1O2X+aRz+t
u3R/lro0Hl9YuZXHI0FEcbFjeQj/P02GyWb5l78Nx9DceAGQZbz84GrU808L
gcKunkJVDe4/LQJvenRcbV68/qfFQO/XEtfqzkvob2XI6mmeBJwWy2MO7I38
p+dB+n8FyYIC99Hc+SjA/K5YebP/A9qu/vspjycFpulyAotX/f53PTIwGuiq
tU+3H+38qexKELJQ1BK6afjWFBIstd1DEHKg9rpycK2bMN53NqCKIORBfODU
dL7TfCy2ba04iVCA+5Fr0mWlKPhQyAEfEqEISR6+o6O3+bCUbeFREjEf5rm3
LTfUHkHH5So+kwglUDP6rryU2YkUBn8q8hHKEJHWUHU/tgGd+TAezkeogFza
vdMjvS+Qyi35fD5CFbqcVRvebDz7T6tBFc2noXRvBso/bNHMR1DhMc7arTr5
FM2djwYv4WcQSekL8texvkti08Cof0W6wYvWf+dXh6Wnxc6e/DKAPvP7jZDY
6lBgv4+RqUbgufloQPv2uMFVV0VxyK/kBXxsDWCZHmxqKFTHc/PThNLSUz/a
68Xx9/Ks7XxsTaiVm6fobk3Cc/PTgkvk99WlMIQiORcxH1sLFod/sHpR1vZv
vtrQGdSgF1dZh5oyMJnM1oZzqHr31dxypLHGW5tM6MAQhxm39WU2io1ocCez
dYBUFMqMMzqCLnmtSiQTupB2pvnS7o3PUKvD6D4yWxeEr9o/k93xDekZ7ikm
E3rw/IRKYLF7O1qpJPuWzNaDPe2HGt0KhlCxSEEPmdAHc+GpRtdMEu4aNaXw
s/XhvlEq9dc2iTlNGIDoMVy1apCKjdtKzfnZBlCqEnPoj4YoXvt1aQA/YQgD
t0/6/rnFQyUvv23kZxvCMvPCvxZpA6j/XsJJfsIIaEUydfGLWpHlpaEH/Gwj
KC5niLxd/RltOr7zGz9hDGpB5zKXbXmC7u+UmuBnG0PYIQcH5wOpaGR9vooA
YQJGU2oqI3vzkH20sbMAe0avzJWNa32Jtvk9YQgQpnC0OLRez+gHegqLMwXY
prCuzGz8eW/n3P0mzKDYKYmVnj2CZtcHzOB61PPI/wTJ/9bTDBKTrqc/3EDB
mycVhPmwGXxhr9Rv1FDEA6qTz0mEOTRZNO9KqhHCKXRuJgnMIRrrV9WZT6Ee
5nNnEtsc/guQvohr+1DSjisTBDYHmRKNqiX9v1DbfwcfEoQFdP1UCEMBH+b6
BywgwuRy+8Dtu3P9xbaAjA35uiSbgLn+wxYgFGE+P6O+8F9/WkAg8d1vxac3
c/1Lt4SLf+oZvw9ykeKKDR48liUIyRf1fnnRg05sD+bnIUuY3PR64vXZMSSd
71A+zbOEhT4DE6X3+HEOpmZM061AbzRERLdAGks0kx2mWVbAqV8WZL9QFu8n
t41MISt4Rtl3+UmVAL6icuzFFM8KaG7N9zOax5G285YdU3RrUAnmE1Rc2IsK
GOH0KZY15GWv2vejoglRM+mTk8gaqhU8tU/0v0PnCjQfTfKsQXn/6RH/V9fR
4yfv9kzSbWALJ7M9tlMW2f647TrJsgEl6+W1PKNb6N70SWIS2cDbVxflb+XX
IAtaWukEzwaORb4VXXO5Gd10YWyboNtC9l2/8xG/e9HbMFHPCZYtFF4LDTtU
O4GWpPfwTyBbOMa01XfLFcSvzn8oH+fZgsZR7Q2pF+WwG7qfMU63g7sENXX3
FSlczj3jMM6yA2p1WNP3KTKm87FGx5AddNzpPvZf6ShaoWzwcoxnB5S3vy7l
H+9G9Y6SO8fo9hD56RG5YF0jCo7sp4+x7MH7t9LDhCdV6BPry+QosofctYWH
5KQvIr8Ljx+N8uzBWCl4Q8eCeLT2cdzeUfoC8KTXWB+LeoC6vi92G2UtgMGb
tWKhxz+ilVPGpFG0AO5/XXO2/tdv1KomXTbCWwAxY5u2r83oR7EwvG2E7gB1
zRcP2lhNo6aoetsRlgOcZftb1D0RxrxtuwVGkANUZSaeR7uVcPq5lc+GeQ5Q
8+nJx6G4eXisdBlrmO4IPxk5wB/Fhzc3mjsOsxzBL7lkh3/ZMBog5MeGkCMw
ZS2ELtZ2ICml8pdDPEeIqRJbrc35jg45XNo5RHcC2fiEiW/ECyQWsQ+GWE5w
4BZ6FncgF+3LWD01iJzAObds4Y0TO5Agx+/xIM8J5Jh17KQDZUjr0eTeQboz
dG1OPDdc+QVdqOe6DbKcwZF89t5R9z9IbabdBpEz7N0Q2W1uOYjOql4tG+A5
Q3jx11avOAIr0rPTBuh0SNeJ4LKtxPAJ5jq7ARYdog8t2G13Rgvf2aoiOIDo
cG6kr3YExPH6/Yd+9/PosFPoa/fdDgLPrhcVYLVPkuE+7iCSWxurNkYHMByM
zj1l1za3fgwAkb/NI3ul6lCM+LVfoyyAAwJZX+WeYaSuqvZsNB/gWepN1R97
9yGucQ5nFAE03T570jP/GMp3nimgRoAG3mj4f4EVKMJnY8QoD0DyC83imHM9
UmHOPKGpLvA0Ir5saU07Ku56ojFKdwEvqeggTYHhufVnuEDp/lGBx+9IWE+S
0zjCcoE3FvdfRahL4tl6yHcB7qJTuaO5qviS6a5zI2hm//C6Lzc5ItjqaejO
kUYXuOG0W9JOn4cGqt9EjfBcYCL4+wOy+gC69cMJRqgLYZ0iqcTjVQtK6bmp
NkJfCP+5Pb4R+fwTMuGpTw0zFsL+B7UviKlHqPTAyK9h1kIQoLS/7LTegGbr
KX/hjD8UWGxp5qAF179zhtFCON96tVqp6RWara/GhbCTX5CTNvwDPXyHIoZ5
C+Fr1U2K9M4uNFtvVFewYbswlo6MIIFkIc1huivsXif7VHoFGT9P30oaZrgC
5RSjJPQ7Be/I7mwcYrmCqH/psW0GCtglL6JsKN8VWosap/IZQph34/25IeQK
fFrOAzV3Jufqs9EV9BS4mjLb+9AyL4XoIZ4rVHf463PTfs3VK9UNnp5tddz3
oBa9Xj2hNkR3A4qL/Cgj6c5c/TLcwIv5sXCItAh5HG78Pshyg7bIAQ/+n1fR
F+V7zwbz3WBLqWxjXVs1OmGke2EQuYGdUsGk9hgXBTidZg02ukF0hW7Fiqi/
SNpbLHKQ5wbaC/yUIiXGUU3kdsdB6iJYSlmd3CYrgBmd/pqD9EVAd185L8ZQ
Bs/WP2MR/Hwc9/DBJRn8Q9yWO8BaBA1nTC57xAvg2X7IXwR5jzf53F89jsJM
lM8PoEWwY0H+Kt7vv6j9ce/OgcZFMF4kPdywvAkVvomOHuAtgu833YRcP71F
8Q2fYIDqDqYvWQdjzhcjrW536gDdHfzIt+4TLVbo19TDqX6GOzBTxjLCo26j
AknDhn6WO5CVX+7ttqlFZmeJiv58d0hepG9PKP1Cf4vXX+hH7uCrrdBDse1D
N57+ZvU3usO3d2sZ3UsnUfLboMh+njsYt5yPOU0WwoY/Kx37qR7Q2KltcXSt
PH68Kk+zn+4Bdc81yYtspHBqGoWvn+EBBgleJ0cukrHtwR3cPpYHxGb93Tfl
O4qGzg2W9eV7QPWIeFLLdBe6ez3+fB/ygLzCj9pjF36iDWV1aX2NHhBT+Eis
934l4lt6I7qP5wE5v3kGbssKEA6nufRRPUHkgHoznb0GsZKPUvvonnDvQ8eW
k5UPkdN2/ulehidIt/Rff2L3CU1mb27oZXnC3ZIt1nyMFnRAyauiN98T6nZb
sFK/9KPFhmUXepEnyI/lb7v6cBoJO5qxexs9oehrwdpvNiL4lVdBZC/PE3Yr
yateElfBuyNknXqpi4G5pEBM7LYklu1o1+ylL4bXijK77lL48McZnOxlLIap
mr7zbSHD6IjYO+5f1mJYr2cxXOnWgXxVAP3NXww0lwdP1v+sR5LGt8//RYvh
liuvSVT+OXrrpJX+t3ExXBtq3PH9zQm04vVY9F/eYjjY2CfVu2APUvqe5PKX
ugS2jqU1nJPG6FvnD+pf+hKwP/20tWTbV5Q76TPdw1gCnUUXt1ys+oOCJJ41
9LCWwHDX+THRI4Oo5fSpip78JaDdUEKKuk7gi0UzAImWwPsdoUVpz8Vw9JM0
dk/jEkiWfyRl72mC1au7I3t4S6Bw/2LrvGtiuLGB4dRDXTpDQIeCd10gcF53
rXIPfSm0+j6a4mQOIuNthXw9jKXgnbqhT+3uH9S1f35TN2spPL9he3NrxFdU
dPYA6s5fChT3n73HmxBaeW3qfDdaCk9fnrn+7txupFu6Nr27cSk4TIeG9zmc
RPcXL4rp5i2FnBrRy8KOz9GmsAcu3VQv4P9bqNcyVY8sk/Rp3XQvOENxW1kc
3oH6085OdzG8INC7J5G5chiVHJT40cXygqGFXjn3Vfkwff6viq58L8iLr2r4
/U4ST+sHFnQhL7i4ZVAv7ZUyLl3wit3V6AUl9qt/sTVEcNpSe0YXzwvqt3qZ
cwum0YIVxU5d1GXwyzbvCLmyH40mq6p00ZdB82n1hKolLWjvWD9fF2MZ/Jk3
GXlH9RNyF41r6mQtgyN2u85A9kPEr/wVdeYvg52Hto3oUVajCsPFeZ1oGez6
drPh/YkCtMPxSXpn4zKg8goFaU2ViFKVE9PJWwZXxoTCblf8RO+/8S3spHoD
g+7w2E6hGx3q2EjrpHvDieqbsheiR5HXROt0B8MbcIY9K+wOGYuJh/7oYHnD
Ds0Pb1ieUvhMrsnzjnxvcDMHvmkveRxylVPQgbyB39v1cmOfIFZ4LJ3Z0egN
vVa2X9/ZTqLPr3cxOngz4xVrq9L1+9Dx78NOHVQfWHbHjk9Q6BcK6EpU6aD7
gDfvLllSrRY1pzqTOxg+sGFRUlCQyW3E2VfS1M7ygfGedod1xeaIcUYDt+f7
wKiA96UDw8VItfh4XjvygYmY809L+N6hhieC29sbfSDRuZ1oiW+a0zwfeD90
fsmP6b9onWM+aWieL9R+cbpYxB7/5we+cJh66XT4ZgF8efsG1pCpLxA6oT+2
lsnM+Q3dF/o/1dQEysrM+ZOPL0gNDtvbCAjgyPMxMMzwBQcVr9y742Nz/rfW
F9p0tr774vEXHf9pWzbM8oVF4i7BUX+4SL40gDRy2BeUhFon459Uz/lxvi/c
G2lPeZR1FXlN67JGbvqCzPuhZXtPeMzxH/IFOfWQrcs5d+b44L0vLMsulP5T
U4v41RRhtNEXsKlhKu3wrzn++OsLh74UHv2yvw/NVF/pKM8XznFLA9wqJ9FT
J2HS2Dw/2HNWXPvLOqF/POQHQ92qA2J+CrgvoyFjzNQPnhQdUqC8puAZeikf
o/tBz2/ZdbxlZDwvo5kY9/EDo/ETj7paRlBRXjV9nOEHgu8vvpdP6kKzfL3W
D0LjSs4Ef/6BZvmb5Qc1W3Xvizx8haLLnhITh/0gI9dKNjqPgyZ/XqZP5M/s
/yO0bYH0RnSKl5MxcdMPHppQOScXPEZKP6+VTyA/qO9L+TXa+GkuH7z3g8hn
6m2131uQz/8CR6MfHFjGc7ppOoA66EkZk3/94L7iQ5F4Og+tVttbPsnzA83d
Dd+u3xPBQvR1xNQ8f+CnbDc36lXFs/mF6g8DV70n7glIYif2oowpU3940OBx
ZLKchHFkVPkU3R96VkoF9w8OoTDWUmLaxx/y3tNzPj1qR0P51vRphj/URQsP
d1Dr0Wy+WusP5/Kd6ujmFXP5i+UP6RruT1Y6HkPXkTbBO+wPGoF+VnthP/Lk
zqPz8v2Bfr+Ds78Fo5m7u5130x9Cp56fyDatQ3GNcuU85A+mbHHX/d5tc/mw
xh8OfB83suud4WNahzPB9YeDau9za4YJrMYT2EH0+oP42cCzT0LF8UNqLyaI
ABCccDU52q+JA6CeR1ACgHqm3X2rqhieza+0ALitKf/xdigxl2/NAgB12m7R
0hpEYszXmAQBEFGmVlBq/gddZt/lkXwDoLP2kbfV9S8ILuQ58zED4JrhtTZx
7zJUwXqcyZcSAEa2U1JaRjv+ve8IAKU9Nhur5U6jMXyIx5cTAJF3qgb5DF6g
Y00zDc8JgPsZ+tLy5d+RPD6eSS4JAOlnDHWX9g50i5uByTOzprRHWlq8H0ZL
SSt55JoA+NSAToav4cOt6gHO/NwA8DeNPai3ax5eSazN5O8NgI0K/XdXeilh
fvVQzE8sh2dmtkd0rwjjPBdXHj9lOZR6jmA16vTc+wTachjLXdN+NaV/7v2B
2XJYV8m/zrL2NwqKssQCsByULW1DWtM/or5MVZ6A73IQeRhSJmDzAB0sEHIW
ZC6HFN+cdouGeDQvUzNTMGU5fChQltmcdhFdvSCBBdnLwfMB72BIdxVyezYy
LZizHAKTXmpyTzaiVxyZhUKc5TA/+tCSgze60Uy1sYVKlsO2St1ayZpRNNn0
Bwnh5bD62dSPCnF+fIrvw7RQzXIQp3AFuU+ksFJTt4swdzk8TtTMV9oth++S
6tjCvctB5lfAmPVeQeyj8QwJE4Fw87uXeGPZBOpYeG1amBIIzqNVqdl1vShZ
vdJFhBYIf6ye9n051YyEFt5mi5gFAuONbKb0kRpUEH0OiUAgnOfbV2Svews5
7twzLeIbCC3orGFXtidCUQUuosxAGOD//ENq+w0UtuMgWzQlEH47vJ46bPMe
DRVsRqLsQFiWKv39en0TOlzBnBbNCYQblQGP5Px6kXRBuosYZ2b/ba3yS0fG
0fVn8WyxkkBQvNtU/KpeAHv88kViOBAK188/bBMhi//3ukKsJhAaKQ7aJw5K
47jmIBdxbiCMmgbWORTyY4LswhbvDQTDYz/5zLLH0BlNQyROBIFUbrG+2IMe
ZO0mNy1OCYLI5vvb87K46KGGuYsELQjmfdQXI1rfIH9XZbaEWRCUh46u/Hb6
CuqOEUASEARvpVViI5SSUdauv1MSvkFw7FjkG8qGe0gsRsxFkhkEmQvKTxlm
f0Az6YMlmRIEXx1fa2TL/EZwsbFMkh0EPkaNgSta+lDFjgnSvJwgCJ3elRu4
dApF/NcC8zhBIKzonfrhtxAerXjPmlcSBLW3D9vu9lHEx34/KpuHg6CRNNaY
EUPB8hWfSZSaIPC+9FLaYJIPl/xCQOEGwRqzu+Mn942gpfxFLEpvEAzv9k2u
nuxErVrHyyhEMKzBiW/zYn+gRHIJSYoSDCoXTiRQsl8hstYZkKIFw/WDx23+
21uA8tx2saTMgsFyQIN9Tf8AsotbUyYFwTC/9vfCjg2l6InrfpK078zxZOk7
s/9+RkGxG0GaGQxpvw2O0ve0or5dkSzplGDoovXqyp8bQAcueZZJs4OhTvo5
reQrD0nuiiXJ5ASDnpl+npKzKL560RtkOMFgLRWpN2VHw64v7FgyJcGw1ORT
bW2MBP7ZojHjwsHwZc+RvqM7SThq5nElWxMMO5rd1ym9GkKTv/VAlhsMv2MH
rVml7eikgAxLtndGH8jyVymrR+Y6U6WyRAhI1G+zSkh+ge7yzyfJUUJgcpvG
io0fLyFvbTLI0UIg7E/afEWvS6h9UXeGnFkI2K1RMNQUfIGStUSeyUEIxH5W
u6GXUI+EFg0Q8r4hcLZkePmR9HZ0Ie4HXZ4ZAvO0WIWFJ4eQ455XGfIpIdD/
TcZTN4qEUeyvcnl2CDyd/B7lJi2BQ3e/JRRyQuDuml0fBkAdD156QFfghIBZ
Ete3+LooPvzyQoZCSQhc/+hcHpdAYOlLpeUKOAS0Xx3KfMIdRNdeFBKKNSFA
7m8nNE+3I4/WI3RFbgh4ejLtVOf/QM2C6RmKvSHQ9bwog/n4HYptOVWuSIRC
esRgHavsGfqfPcynhILtPfPcsyMv0BmdZPp8Wij0nDhWEWn/CVl5BGXMNwuF
o/Zk6uLrzeiB9vry+RAKu5MWvl1Y/Bf5u68glHxDoaBivW+FxxjqjnenKzFD
Z/LrkGHOHzLeu9csQyklFPZpZuNCfSksGu9VrsQOhcTcZmthSQV8aY8NoZwT
Chr+Baz9t4UwvZBGV+aEQlbM1rCPQ1Oo/pVohnJJKGjl/i2PcBxAEZd1ypVx
KIgfiuc4/fyDRl9SCJWaUPDsmy/nTm5AR/+MO6twQ6Hjk8MJz6AaJPdSfodK
byj0lugm3d5YiUpaiXIVIgwCx/2WXfF5j5YIdfJUKGFQs9dZP55Tj1p0Pzur
0sJA9PN/6xorWlGi4MwT3iwMflxKmy+V1I/Iut+xKoTBs8cVZ3dcmkTnPV7w
VH3DYLNdlmFNgiC2S7zprMac0dYBpofpsviJ+5tMtZSZ872fajRcKYMDE+5h
NXYY6PC3iVT+EcC9e/N5ajlh8C5h0FZfbhIduLLPmcoJgzCDo0+7JPuR5N5L
mdSSMIipfTfqEN6KrhQexlQcBi6Rk7WEQz1yrdzKo9aEwak7vVJZM9fzsy3G
mcYNA+4hLCRoUYWYr1iZtN6Z8X6oYNdQDZr4sxLTiHBQrvtT0189Y5rCy3k0
SjjUuGwScndvQ2b6zs7qtHAQ2/D8em/8ALojFJapbhYO4T9rNVeITiNvPTes
DuFwwW3DlqqTQrjd04Sn7hsORNv2zKu+8njnSkVnDWY4sE5VvPzUIIUFPa0y
NVJmtlvdfXjuNT++kKiGNdjhIG1C1Hd+HUcO+4R5GjnhsH1JMPdzQB/6crXf
SZMTDi++x37g5reg0CzJTM2ScPhesS6keOAbGrwyijRxOBw6LLcsK6AGHapq
ntasCQfO5mt5L1WqkdSVaRctbjgE931/zFL4iK5VtrG1esPhP3rzNZ3Djcij
/QPSIlYAeV3K9ApeO2oSKZ3WoqyAJceTXI/O5M3YtjoXbdoKsNn1Koqxi4d4
whVsbbMV8HFP1qXMz8L4tP4MscEK+G3yX5hIkSK2WnJqWtt3Bch7vVv1o5WC
H+jdcdFhroAti8Oe8hvxY//F59k6KStgVGLKuu/gOOpauRfpsFdAtrJZ8q19
fWjv/nXTOjkrYI2wuI78h1YkujLbRZezAt5n56VcvvgDXdy3ha1bsgImfvtS
8ww+I3pRFNLFK4B6wUuw6utHVP966bRuzQrQjU3yOV7yDUVcTXDR466AsOoU
cGT+QiNVfmy93hWgytRS6/zVjY52OCA9IgJae1LvruMMI2MxnWk9SgQILu8q
38JHwjfbXVz0aREQ9XJfrcpZUbxE1IitbxYBG5yXDylvU8EtBvJIH2bGD99Q
EtOm4P/hr75vBCRQP+7b95uM+QxUXAyYETPr3/yw6uY4Or9EkG2QEgGnbLpH
pCX6kV1Sb5kBOwLaI35V92xqQ48Xi/MZ5kQAN7N/9b5xLgpcNQyGnAiw81Tr
KI6oR737uSzDkgg4c3dLy9K339D+4tdlhjgCGMcO165U5iKJ/a0ko5oIyJD8
2Wv5Z6Y/imrAiBsBWoLjJKsZnnF985hl1BsB6hu3RNz8Mop+dF4sMyIiYXuB
UbntDC/+D2eNKZEgMxwTKjYojic6isCYFglhm40anklr4RNiJ1jGZpFwcOeE
5561ktjMiFVmDJFwZs8rU9YOMr4jepZk4hsJnuvMPXUEJ5C34W4wYUbCmNby
DieNAdS2dC3LJCUSLpMiiYiGTrQzObTMhB0JaelfHwjHtyDBpZtIpjkz42OH
X3w/0Iw4SQww5cxo6scXB+b/Qg4HF7NMSyKB3iMHcvJ/0JdrlmWmOBKi40LY
Ard6UOgBH5JZTSQc3edzPsltCA0U24MZNxIcJhwK72lMo0PVmiyz3khQbExJ
fDchgPW7JcrMCAZszedoCzVJ4eI3+iRzCgPktq3/Iqw5H7t3yYA5jQHPz11v
v3lDFDeJT2eYmzHgbqTLvkdefDjtfx/8gAEmTb1+4VXjaFqMn2Thy4B+U8kk
Pf9BdNqoh27BZIC7gql1ZGQvslpWl2GRwoAkbHE071UXum84WG7BZkCCeFuk
xbYu5Of1k7DMYUDz4O1jpvl/UVdyJd2Sw4DNb0skntsMoD3ZtzMsSxigqHb9
lPutUSSS/K7cEjPgRUKNYuZGAl88+JCwqmGAWLDxoHG1IKZfL6BbcRngd2HH
3asmUvjb24MZVr0MmEKFepFeGtgk6BNTiWDCp02f/yTOo+C0+MVsJWEmlFCK
3JqkBHHV5rJ8JQoTtvCu7OcuIbD8XkukpMiEst3REZsHRlHw5nKuEo0JLWVR
m7OIQTTrX3pMGFa45l6j1of6TxZTlc2Y8EWb/h9JrBfN+pkdE+qnQWr5lV6U
efIGUxmYIH+emicvP4DeXdZkK3sy4YIHX9Pp3SNI5UFuvrIvEzZMmtFPxk+j
la8kkHIIE24M+h+oTePHRffPcpWZTNhmkkU7nSCBZ/0vkQkmoabFgYNKeNHX
3VSVFCbY31hEUtWTwbN+mMoETbljf9tahPGnL1lMFTYTdu6cN13hzofV/0yx
VLKY0NO3+vIRy0m05n8fWHOY8MRz38LlV4fn/DKXCcSnO6/7LQfQ1PAmrgqH
CTVr74yPn+mb888rTDh3NdlX+3MfylVgUlVLmJB8TF/ctmYAfRPsAdWHTEgN
f+cTemkE6SrEMFUxE1aBQrJX4RTaqFvHUq1kQsHltJgzi8i43HZZvmoNE07e
++htZy+KZ/22jgmOk1teCFjKYl9bX64qlwkLFSt49hJKeNZ/25ggDKvThl9L
4M7gBVS1XiYULjltJ7hQABt5VILaKBNWjq9RcLYh8NZgJ6YaEQVl2hoDH9+P
oVcJt1lqwlGwrTRj24ndQ0g2VTdfjRIFpQ2aL13VB9CsXytGgQLnCHltZj/6
b4sBV40WBatb3nLMtg+gWf/WiwJh49KdL9WGkVOuLJVqFgXZfNUXrt0ZR6y9
BUC1i4K3AWSJwq8Erj41c4MgCo5Vb3S2oAhipSsHWVTPKNi6w+K3/AdJnPCQ
lE/1jYKnQh2SHT7KeNbvQ6JgukHvPyFRWTz8gJ9LZUYBft7xS2alKJ71/8Qo
yLBPqjlbRMa7Hgip01Ki4H3szf36X6bRh1fpQEud0bsmLRc5jyFqXR+Dxp7Z
PyThnfvLIZTcFs+iZUXBi5U1TDuLQXTj6yCHljMznws3/g4sGpzjhdwo+Lv+
8gfvviHkOfqzkcaZOZ6Ios1jxtgcP1yJggklycTRb9Po60gTTb0kCnbU7XXz
3UXG2sLBoP4wChpYT998qRHB6xWrGeo4ClRPhemol0hjpOfCUq+MAhN3KSvz
vZqYpPieo14TBWvOZxu9/U8Kz/JGXRSka5jtTrEWwWftHjWqc6Pgjc7gVY1s
8hx/tM1sT3NvunyThwzsntI0emfm35mTnPt9HG3xNAeN0SioXtb8ZEP7CHoR
cpmhQURD6D7+Eo/Tw0h6pTJLQzgaPMrtOq/UD6OAkKscDUo0FNsduFVcPopm
eUUxGqg/1ivLJE+intRjjRq0aBh/tOMnoUrCs/yiFw0JvcH8i7YI4O2pJ2ma
ZtHQ/anI24whjl9niYGmXTTwOXRpXZCQw4qn2QxNiAaJqcQDwakqOO7qUIam
ZzQcPvrTtzmNgi/n7uRo+kbDY/V1SttNhPEs74REg93lgqAFYmTs8mh1oyYz
GlxpadqrVvHQ/35eoJUYDct2HL9M15xANQ9TaFop0bDqvcYa0p1RpFrVQtdK
jYb4XcZryH0jaNW3MIYWOxqWeuAvHg2jc3yUFQ08qdZNCmsn0FhdBEcrJxoE
P0pr3SITeJaXcqPh9I0Vo+PHyfj4mEejFicaGFPlAUZTwvhz22dC+0o05EUF
L3ijJoU1x5bQtEuiYZPM4ajXxWo4RQTTtR9Gw7oLB9eVfpPFpfOtGdo4GhLf
jyrt/yOOZ/mqMhrUrh+K2xEuiL3m23G0a6LhTfPzGrYR3xxv1UXDeoWEVbYf
ptEfe41GbW40nPT8ZXUmZgLp6ZcQOm3R8NqZP/3MzTG0yV6bptMbDXWPT+89
mj+GKhafoeuMRgO/+zOFHwYTiBI2j6FDxAC7luOlx5pGs3wmHAOuI6WERxsJ
54dKc3QoMfDsR8xGqxk+n+U1xRiwqWo9Vmggjhdsm/ypQ4uB0ddWrnc6ZXDa
yv2Ert7M8S7Gsb5v1sD/a0ddsxhIX91laGMijeX3b6Tr2sVAw9eDsu0Jojh4
K1+ULsQA9160ofgLfjzLd54xIDd8YGOWJgn3n+7K1/WNgcuPikfrD07N8V5I
DNTvkDP88WwcsU//5eoyYyBGa2+W5ZUx9O5qLKGXGANS+bxNdqrjSPnxN6pe
SgzsXI4uYJ1JlPjam66XGgPtTzlNXB4PFT1qYOqxY2D30f42nWk+PMuHWTFg
oVKkoX5YCC+qf5mvlxMDFfuM9zAE5uFZXsyNgUb6uxWtFxTwx29VXD1ODAx6
nPNX95+P1TucCf0rMVA0lij+m0LBa8bvUPVLYuCcZb74iI8wfiKqT9d/GAML
afQ9rmfIeGrsPlMfx8CujCNjEnuJOb6sjIEpZRC8oDCFTildyNeviYGr5acG
KtvG0Sxv1sUAn/qRjafWjSMdpYtcfW4MhOx8UkO6MYE2GMwnDNpioMzMQ9D8
7jQqX3CIatAbA+SJWPUN70lYcimZbjAaA3FZNtrPDwpg3wVHmAZELKSTe5RP
+IvhWT4VjoWN5xcv3/NWGneEpeUbUGLhSEdmaDJDCxstESk3UIwF3i9f4YYJ
Gbw1LINrQIuFT5dWlQZ+E8cvVw3wDPRiQXp7yRo8IYhl0xKphmaxkDU/aSLF
k4xnedYuFu6UX74v/Y7ABduSmIYQC5d2ce49SZue41vPWLB7WFHN6plETmcD
8w19Y6Elb4FSTtMkytj/CxuGxMLqj/durg6YRtVnQriGzFhg1cj7uzwl8Pzi
tzzDxFjodF93fOEyMo5/spBqlBILZ8JKtcYchPAsD6fOzC/scUj/Ngk89HgR
04gdC5H2N8813ZHFs3ycFQvc4oY/x96r45zvpvlGObHQJLIy9+QZaVz7uhQb
5caCzqtzK0syxTD1uwXXiBMLxgt7942SBXFyZyHP6EoshDJtQhS38OFHEypU
45JY2LxnZS1Jk5jj6Yex8OhCeaf6sSnkOUFlGuNYOBi0wdn1/CSa5evKWEhe
/bTST3cK/VIWzTeuiYX4zz6FSZY8pCWWi43rYoFtkCYssZWE1ylLcI25seBw
YM3lnAR+jAx38IzbYsHlRAu1uFsYizuOqJn0xsLLuhCjS44UPMvjo7GwcmtE
8INniviswzjDhIgDLK6Vxa81H8/yuXAcdJ68qfMmmoINHKY4JpQ4WJadn/bF
QARvWboemyjGgcPOX6pb8/jx8/A/jSa0OLjjUNIhxSFh6eQVPBO9OGCEkw/z
beChgPAOmqlZHJzMNky4ypya43m7ONhYXE3b1jrjH2mfGKYQBweS159dwpua
43vPOAhI9TlsG0jg9LSvHFPfOGg63GjvcpoPvz7ghU1D4iDyqlVSEZ8gVjhX
3mjKjIMovv66Zn0xHHvNhmeaGAffUlnPDkxI4ctnn9PMUuLgeUP8vAM/VPFs
HkiNg5RcW7riXXns8vQGw4wdB3et7zWLF8/Ds/kgKw7u+9x4tr5aGL9/cotj
lhMH1LymYo2N/Fi1Wgeb5cbB1L6QlhvHSXhVw9lGM04cfHo1Sik6xkMPuig8
sytxcM3wne6hu1No7HsezbwkDtYzXym/9p1Cs3niYRwQ3GMi5tum0bHJLIY5
joOcs9zDBpeJuXxROXN/w9Ivjo3xYY3JAxzzmpnrvWxRv2e3IF4rTsLmdXGw
taZWfWBSDJeqbG4058aB/Qey5KoKaTybP9rioFby0uhfeXXspbKVZtEbB4fe
FXyR3CmHZ/PIaBwkJGZ3adVJ4lbHGIYFEQ/7XxSZiOQJYz2jPraFcDzcf1tO
VnnDjzc5xnMsKPHwmQ+JNQTz4Wde35GFYjzsG9US+F1LYEqEb6MFLR4iJtO5
QYoEns0vevEwz3DCaL0xgfNWBNAszeKhqcHUNVyFhGfzjF08LMjzlnfv4cP2
250YljCz/VYKnqgQwNuS37AtPePBUeU1o4QiiivTgWPpGw/pKSlq/akULJd9
D1mGxANniVJne4wCjj5v0GjJjAdEaO6x3qE2l38S4+FI9pKoiUfSuO+cMc0q
JR5erbrVeuSD+FweSo0H4/dau2o+CuGDpQoMK3Y8tGf9jth9gB+/vXaJbZUV
D9k96/piGXxYuVSJY5UTD1E+fJvLKCSc+PYwssqNh7iLVvdE9xP43g/+RitO
PBz+YGsDLwg8Un2UsL4SDw3rnjZXzDxv3X4I0axL4mGX+MMtcrfJ+Eh3Ot36
YTwI6jdHjx8UxB8bRKOscTwMFq51KW0QxbRuFtu6Mh5MNLskin5Q8OqpwXzr
mnh4Wxd7XKFBAT+RWIWs6+LhAfdRRukvVTw5OcK15sbDcVZ3/sFsabxEYjVh
0xYP3G0XX9asF8enVJupNr3xMPmJnbrOSwj/Ng6m24zGQ32CXNLAIBnrqLYw
bYgEELhgv6ulioQ3GIexbYQTIPa6hETTzPVhp/f5NpQEUJt8IsRHJbCktxuy
UUwA2ZKgDWrbCOzj9IFrQ0sAvet+caanSfjcMg/CVi8B3CVWinTO8GhHxFOq
rVkCXMsK9ZTJFsS2a8zptnYJIOee9VxbSQxvjUBMW5jRkda5xYul8MvVVmxb
zwRoPTsVLJQyH8tkXM239U2AtLTy9FPiyjjqkBqyDUmA1PKYkXmVUrhg+zWu
LTMBVgt8U40/LYb/ZqsTdokJsOdvwpaECkHslHeSapeSAKq/an+X5JLx/hti
dLvUBKBce509epCE35w/zbRjJ8CfO5Uin0Jn/OOGJNsuKwFG1O5YjL/kofiy
nfl2OQlQevz9cjVLAt95N1pml5sAC/rqXX8uJOGh0j1cO04CmPtJOu0yIeOF
7yZ4dlcSYLl1vGSUuSA+/DOFal+SALcN87aYPBHFtW+nwf7hzHiz2P50USms
9nMD0x4nQJLNpU3JHxRxck8by74yAR6vEnA5/FsZP5qOyLevSYBt4aSGSHFp
PN7die3rEqBF5Mbdkj4x7DnN5NpzE8Bj4L7DlIwQPiH5hWfflgDeUWHIuImM
m9WWUhf0JsBZD1Vy4jsS1pL8BgtGE0Bms8DgsXMEXqfmzVxAJILgpo6sUR0C
l5lUsBYIJ8InKQ//+jgCi9Pt8hdQEuH4i4jL8qtIeJnJS7xAMRF0t/UErPYn
4zPODtwFtERoOVygbOYiiNu8S3gL9BLBurDZevy6KJ6hW6qDWSLIpG4eeDVM
wVu874CDXSJ83bHw45uXivh5pB7TARJB6liGd8ceZSy19jzLwTMRzFtsdmc3
SmEGSzrfwTcR+rYYFRm8FcOcNRzsEJII0qnE1Vx5IdydIcd1YCYCm+xoHCnO
jx0O7+c5JCZCk9uh1xs0+HDWTBx1TEmEzKIetVF5Eq46lA2OqYnwfQNV995H
Aivk8zEd2YlQ7vM1ttufhGNvbmE5ZiXCoY7khywOH76UJ3DBMScRYno9jwp/
4McDN7Zhx9xE2Hi/MGa1tTAG9LfRkTNz/L3kN/I7JHD2+1ie45VEWLRGCs93
lcHvy/ppTiUz17tER+NxFRWrvE8Ap4eJsFkuj5uQpYBX/e8HPzgR0l+rSOu1
UPCDv34sp8pEeG5knH/ZQQzPxEuOU00itLVdb5O2FsLuf5djp7pEiBwJLPM/
w4+P8aoanbiJUPTcoDKcTMb/+1zu1JYIxUe+aYk6zPgHr5rm3JsIIkkRX7u0
+PDaeQvBeTQRkh0rB3Nr+PBT6gOGM7EStB5vsjRbyI//D0yRBcM=
       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599684282665`*^9},ExpressionUUID->"1c2484eb-f811-4542-8f89-\
6c11b49997d2"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[1.6],
      LineBox[{{0.5, -20.58731462444898}, {0.75, -18.879687777989233`}, {
      1., -22.708201886132294`}, {1.25, -27.50184105161661}}], 
     LineBox[{{4.249998, -23.11696430864725}, {
      4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
     LineBox[{{6.750008, -23.038818749837983`}, {
      7.000009, -20.322035683613738`}}], 
     LineBox[{{7.750011, -20.716014193782303`}, {
      8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
     LineBox[{{11.250025, -19.142376381324734`}, {
      11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
      12.000028, -22.492142720939622`}}], 
     LineBox[{{12.50003, -24.045787259895636`}, {
      12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
     LineBox[{{13.750034, -21.052099541576304`}, {
      14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
      14.500037, -21.409428863587927`}}], 
     LineBox[{{15.500041, -21.61333098548902}, {
      15.750042, -22.10549208407436}}], 
     LineBox[{{17.250023, -22.856107311471863`}, {
      17.500019, -22.566864012429928`}}], 
     LineBox[{{18.000011, -21.834193448858855`}, {
      18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
      18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
     LineBox[{{19.499989, -22.216470803381476`}, {
      19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
     LineBox[{{20.499973, -28.088099516986762`}, {
      20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
      21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
      21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
     LineBox[{{22.999935, -19.74888960999384}, {
      23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
     LineBox[{{28.749847, -22.783129874707647`}, {
      28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
     LineBox[{{30.999813, -24.728294878757325`}, {
      31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
     LineBox[{{32.249794, -20.837058021652666`}, {
      32.49979, -21.361849645654928`}}], 
     LineBox[{{32.999783, -20.84333950660284}, {
      33.249779, -18.469001093501973`}}], 
     LineBox[{{34.999752, -25.06864583779922}, {
      35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
      35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
     LineBox[{{38.499699, -24.377795653123645`}, {
      38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
     LineBox[{{39.74968, -22.650120892941615`}, {
      39.999676, -22.80728905851026}}], 
     LineBox[{{43.749619, -22.041875381710568`}, {
      43.999615, -22.423199188672683`}}], 
     LineBox[{{47.499561, -21.287037875136214`}, {
      47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
     LineBox[{{49.999523, -27.91448197690941}, {
      50.249519, -27.305559271827388`}}], 
     LineBox[{{51.999493, -20.885769001862567`}, {
      52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
     LineBox[{{52.999477, -22.174453342075132`}, {
      53.249474, -24.83933405846568}}], 
     LineBox[{{54.249458, -23.722525323809897`}, {
      54.499454, -23.580299515887834`}}], 
     LineBox[{{56.499424, -21.766646750655234`}, {
      56.74942, -23.57640470224996}}], 
     LineBox[{{58.249397, -23.599923997532017`}, {
      58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
     LineBox[{{59.249382, -17.837453345617426`}, {
      59.499378, -21.77661789863478}}], 
     LineBox[{{59.999371, -21.620808909572247`}, {
      60.249367, -21.022793121071274`}}], 
     LineBox[{{61.749344, -23.521435622331904`}, {
      61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
      62.499332, -19.42225543656815}}], 
     LineBox[{{63.499317, -20.822384760816565`}, {
      63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
     LineBox[{{64.499344, -25.343231741743004`}, {
      64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
      65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
     LineBox[{{68.249573, -26.50222788848888}, {
      68.499588, -26.988563201691523`}}], 
     LineBox[{{70.749725, -20.1140901131646}, {
      70.999741, -20.81539559964317}}], 
     LineBox[{{72.249817, -27.41004150424379}, {
      72.499832, -25.260157006181224`}}], 
     LineBox[{{72.999863, -23.234537488989123`}, {
      73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
      73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
     LineBox[{{75.25, -25.575903773461626`}, {
      75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
      76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
      76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
      77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
      77.500137, -21.438588076795124`}}], 
     LineBox[{{78.000168, -22.06377454291717}, {
      78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-30.753802173434874`, -2.5595472252881692`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968535023*^9},ExpressionUUID->"74eab9f2-9919-4d1e-bb01-\
00fe3f5fb897"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -30.303766533418063`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-29.898127463585265`, -4.74850513395212}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968581061*^9},ExpressionUUID->"89174521-26c5-4af6-a225-\
d3e46bc8a3ef"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[{{0.5, -20.58731462444898}, {
       0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
       1.25, -27.50184105161661}}], 
      LineBox[{{4.249998, -23.11696430864725}, {
       4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
      LineBox[{{6.750008, -23.038818749837983`}, {
       7.000009, -20.322035683613738`}}], 
      LineBox[{{7.750011, -20.716014193782303`}, {
       8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
      LineBox[{{11.250025, -19.142376381324734`}, {
       11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
       12.000028, -22.492142720939622`}}], 
      LineBox[{{12.50003, -24.045787259895636`}, {
       12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
      LineBox[{{13.750034, -21.052099541576304`}, {
       14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
       14.500037, -21.409428863587927`}}], 
      LineBox[{{15.500041, -21.61333098548902}, {
       15.750042, -22.10549208407436}}], 
      LineBox[{{17.250023, -22.856107311471863`}, {
       17.500019, -22.566864012429928`}}], 
      LineBox[{{18.000011, -21.834193448858855`}, {
       18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
       18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
      LineBox[{{19.499989, -22.216470803381476`}, {
       19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
      LineBox[{{20.499973, -28.088099516986762`}, {
       20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
       21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
       21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
      LineBox[{{22.999935, -19.74888960999384}, {
       23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
      LineBox[{{28.749847, -22.783129874707647`}, {
       28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
      LineBox[{{30.999813, -24.728294878757325`}, {
       31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
      LineBox[{{32.249794, -20.837058021652666`}, {
       32.49979, -21.361849645654928`}}], 
      LineBox[{{32.999783, -20.84333950660284}, {
       33.249779, -18.469001093501973`}}], 
      LineBox[{{34.999752, -25.06864583779922}, {
       35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
       35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
      LineBox[{{38.499699, -24.377795653123645`}, {
       38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
      LineBox[{{39.74968, -22.650120892941615`}, {
       39.999676, -22.80728905851026}}], 
      LineBox[{{43.749619, -22.041875381710568`}, {
       43.999615, -22.423199188672683`}}], 
      LineBox[{{47.499561, -21.287037875136214`}, {
       47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
      LineBox[{{49.999523, -27.91448197690941}, {
       50.249519, -27.305559271827388`}}], 
      LineBox[{{51.999493, -20.885769001862567`}, {
       52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
      LineBox[{{52.999477, -22.174453342075132`}, {
       53.249474, -24.83933405846568}}], 
      LineBox[{{54.249458, -23.722525323809897`}, {
       54.499454, -23.580299515887834`}}], 
      LineBox[{{56.499424, -21.766646750655234`}, {
       56.74942, -23.57640470224996}}], 
      LineBox[{{58.249397, -23.599923997532017`}, {
       58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
      LineBox[{{59.249382, -17.837453345617426`}, {
       59.499378, -21.77661789863478}}], 
      LineBox[{{59.999371, -21.620808909572247`}, {
       60.249367, -21.022793121071274`}}], 
      LineBox[{{61.749344, -23.521435622331904`}, {
       61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
       62.499332, -19.42225543656815}}], 
      LineBox[{{63.499317, -20.822384760816565`}, {
       63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
      LineBox[{{64.499344, -25.343231741743004`}, {
       64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
       65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
      LineBox[{{68.249573, -26.50222788848888}, {
       68.499588, -26.988563201691523`}}], 
      LineBox[{{70.749725, -20.1140901131646}, {
       70.999741, -20.81539559964317}}], 
      LineBox[{{72.249817, -27.41004150424379}, {
       72.499832, -25.260157006181224`}}], 
      LineBox[{{72.999863, -23.234537488989123`}, {
       73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
       73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
      LineBox[{{75.25, -25.575903773461626`}, {
       75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
       76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
       76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
       77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
       77.500137, -21.438588076795124`}}], 
      LineBox[{{78.000168, -22.06377454291717}, {
       78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968621477*^9},ExpressionUUID->"e799a63c-8357-4501-94b5-\
8ecad57c5708"],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY
sFc4B7GAooIVESWgIF16h3y84M+PP1zrmjMzZ+bsPeteM1GPXusfx0cQhDqZ
IP73////q6Eb99ycmk8uQXOaS1eZp0/VFqv5p9voJ26piMdYNf/TvfSvdda2
94/2/tODdKKGxa8YOvFPj9J1c0yjS0wF8dDunIFp3gS9+FF9+e1O2X+aRz+t
u3R/lro0Hl9YuZXHI0FEcbFjeQj/P02GyWb5l78Nx9DceAGQZbz84GrU808L
gcKunkJVDe4/LQJvenRcbV68/qfFQO/XEtfqzkvob2XI6mmeBJwWy2MO7I38
p+dB+n8FyYIC99Hc+SjA/K5YebP/A9qu/vspjycFpulyAotX/f53PTIwGuiq
tU+3H+38qexKELJQ1BK6afjWFBIstd1DEHKg9rpycK2bMN53NqCKIORBfODU
dL7TfCy2ba04iVCA+5Fr0mWlKPhQyAEfEqEISR6+o6O3+bCUbeFREjEf5rm3
LTfUHkHH5So+kwglUDP6rryU2YkUBn8q8hHKEJHWUHU/tgGd+TAezkeogFza
vdMjvS+Qyi35fD5CFbqcVRvebDz7T6tBFc2noXRvBso/bNHMR1DhMc7arTr5
FM2djwYv4WcQSekL8texvkti08Cof0W6wYvWf+dXh6Wnxc6e/DKAPvP7jZDY
6lBgv4+RqUbgufloQPv2uMFVV0VxyK/kBXxsDWCZHmxqKFTHc/PThNLSUz/a
68Xx9/Ks7XxsTaiVm6fobk3Cc/PTgkvk99WlMIQiORcxH1sLFod/sHpR1vZv
vtrQGdSgF1dZh5oyMJnM1oZzqHr31dxypLHGW5tM6MAQhxm39WU2io1ocCez
dYBUFMqMMzqCLnmtSiQTupB2pvnS7o3PUKvD6D4yWxeEr9o/k93xDekZ7ikm
E3rw/IRKYLF7O1qpJPuWzNaDPe2HGt0KhlCxSEEPmdAHc+GpRtdMEu4aNaXw
s/XhvlEq9dc2iTlNGIDoMVy1apCKjdtKzfnZBlCqEnPoj4YoXvt1aQA/YQgD
t0/6/rnFQyUvv23kZxvCMvPCvxZpA6j/XsJJfsIIaEUydfGLWpHlpaEH/Gwj
KC5niLxd/RltOr7zGz9hDGpB5zKXbXmC7u+UmuBnG0PYIQcH5wOpaGR9vooA
YQJGU2oqI3vzkH20sbMAe0avzJWNa32Jtvk9YQgQpnC0OLRez+gHegqLMwXY
prCuzGz8eW/n3P0mzKDYKYmVnj2CZtcHzOB61PPI/wTJ/9bTDBKTrqc/3EDB
mycVhPmwGXxhr9Rv1FDEA6qTz0mEOTRZNO9KqhHCKXRuJgnMIRrrV9WZT6Ee
5nNnEtsc/guQvohr+1DSjisTBDYHmRKNqiX9v1DbfwcfEoQFdP1UCEMBH+b6
BywgwuRy+8Dtu3P9xbaAjA35uiSbgLn+wxYgFGE+P6O+8F9/WkAg8d1vxac3
c/1Lt4SLf+oZvw9ykeKKDR48liUIyRf1fnnRg05sD+bnIUuY3PR64vXZMSSd
71A+zbOEhT4DE6X3+HEOpmZM061AbzRERLdAGks0kx2mWVbAqV8WZL9QFu8n
t41MISt4Rtl3+UmVAL6icuzFFM8KaG7N9zOax5G285YdU3RrUAnmE1Rc2IsK
GOH0KZY15GWv2vejoglRM+mTk8gaqhU8tU/0v0PnCjQfTfKsQXn/6RH/V9fR
4yfv9kzSbWALJ7M9tlMW2f647TrJsgEl6+W1PKNb6N70SWIS2cDbVxflb+XX
IAtaWukEzwaORb4VXXO5Gd10YWyboNtC9l2/8xG/e9HbMFHPCZYtFF4LDTtU
O4GWpPfwTyBbOMa01XfLFcSvzn8oH+fZgsZR7Q2pF+WwG7qfMU63g7sENXX3
FSlczj3jMM6yA2p1WNP3KTKm87FGx5AddNzpPvZf6ShaoWzwcoxnB5S3vy7l
H+9G9Y6SO8fo9hD56RG5YF0jCo7sp4+x7MH7t9LDhCdV6BPry+QosofctYWH
5KQvIr8Ljx+N8uzBWCl4Q8eCeLT2cdzeUfoC8KTXWB+LeoC6vi92G2UtgMGb
tWKhxz+ilVPGpFG0AO5/XXO2/tdv1KomXTbCWwAxY5u2r83oR7EwvG2E7gB1
zRcP2lhNo6aoetsRlgOcZftb1D0RxrxtuwVGkANUZSaeR7uVcPq5lc+GeQ5Q
8+nJx6G4eXisdBlrmO4IPxk5wB/Fhzc3mjsOsxzBL7lkh3/ZMBog5MeGkCMw
ZS2ELtZ2ICml8pdDPEeIqRJbrc35jg45XNo5RHcC2fiEiW/ECyQWsQ+GWE5w
4BZ6FncgF+3LWD01iJzAObds4Y0TO5Agx+/xIM8J5Jh17KQDZUjr0eTeQboz
dG1OPDdc+QVdqOe6DbKcwZF89t5R9z9IbabdBpEz7N0Q2W1uOYjOql4tG+A5
Q3jx11avOAIr0rPTBuh0SNeJ4LKtxPAJ5jq7ARYdog8t2G13Rgvf2aoiOIDo
cG6kr3YExPH6/Yd+9/PosFPoa/fdDgLPrhcVYLVPkuE+7iCSWxurNkYHMByM
zj1l1za3fgwAkb/NI3ul6lCM+LVfoyyAAwJZX+WeYaSuqvZsNB/gWepN1R97
9yGucQ5nFAE03T570jP/GMp3nimgRoAG3mj4f4EVKMJnY8QoD0DyC83imHM9
UmHOPKGpLvA0Ir5saU07Ku56ojFKdwEvqeggTYHhufVnuEDp/lGBx+9IWE+S
0zjCcoE3FvdfRahL4tl6yHcB7qJTuaO5qviS6a5zI2hm//C6Lzc5ItjqaejO
kUYXuOG0W9JOn4cGqt9EjfBcYCL4+wOy+gC69cMJRqgLYZ0iqcTjVQtK6bmp
NkJfCP+5Pb4R+fwTMuGpTw0zFsL+B7UviKlHqPTAyK9h1kIQoLS/7LTegGbr
KX/hjD8UWGxp5qAF179zhtFCON96tVqp6RWara/GhbCTX5CTNvwDPXyHIoZ5
C+Fr1U2K9M4uNFtvVFewYbswlo6MIIFkIc1huivsXif7VHoFGT9P30oaZrgC
5RSjJPQ7Be/I7mwcYrmCqH/psW0GCtglL6JsKN8VWosap/IZQph34/25IeQK
fFrOAzV3Jufqs9EV9BS4mjLb+9AyL4XoIZ4rVHf463PTfs3VK9UNnp5tddz3
oBa9Xj2hNkR3A4qL/Cgj6c5c/TLcwIv5sXCItAh5HG78Pshyg7bIAQ/+n1fR
F+V7zwbz3WBLqWxjXVs1OmGke2EQuYGdUsGk9hgXBTidZg02ukF0hW7Fiqi/
SNpbLHKQ5wbaC/yUIiXGUU3kdsdB6iJYSlmd3CYrgBmd/pqD9EVAd185L8ZQ
Bs/WP2MR/Hwc9/DBJRn8Q9yWO8BaBA1nTC57xAvg2X7IXwR5jzf53F89jsJM
lM8PoEWwY0H+Kt7vv6j9ce/OgcZFMF4kPdywvAkVvomOHuAtgu833YRcP71F
8Q2fYIDqDqYvWQdjzhcjrW536gDdHfzIt+4TLVbo19TDqX6GOzBTxjLCo26j
AknDhn6WO5CVX+7ttqlFZmeJiv58d0hepG9PKP1Cf4vXX+hH7uCrrdBDse1D
N57+ZvU3usO3d2sZ3UsnUfLboMh+njsYt5yPOU0WwoY/Kx37qR7Q2KltcXSt
PH68Kk+zn+4Bdc81yYtspHBqGoWvn+EBBgleJ0cukrHtwR3cPpYHxGb93Tfl
O4qGzg2W9eV7QPWIeFLLdBe6ez3+fB/ygLzCj9pjF36iDWV1aX2NHhBT+Eis
934l4lt6I7qP5wE5v3kGbssKEA6nufRRPUHkgHoznb0GsZKPUvvonnDvQ8eW
k5UPkdN2/ulehidIt/Rff2L3CU1mb27oZXnC3ZIt1nyMFnRAyauiN98T6nZb
sFK/9KPFhmUXepEnyI/lb7v6cBoJO5qxexs9oehrwdpvNiL4lVdBZC/PE3Yr
yateElfBuyNknXqpi4G5pEBM7LYklu1o1+ylL4bXijK77lL48McZnOxlLIap
mr7zbSHD6IjYO+5f1mJYr2cxXOnWgXxVAP3NXww0lwdP1v+sR5LGt8//RYvh
liuvSVT+OXrrpJX+t3ExXBtq3PH9zQm04vVY9F/eYjjY2CfVu2APUvqe5PKX
ugS2jqU1nJPG6FvnD+pf+hKwP/20tWTbV5Q76TPdw1gCnUUXt1ys+oOCJJ41
9LCWwHDX+THRI4Oo5fSpip78JaDdUEKKuk7gi0UzAImWwPsdoUVpz8Vw9JM0
dk/jEkiWfyRl72mC1au7I3t4S6Bw/2LrvGtiuLGB4dRDXTpDQIeCd10gcF53
rXIPfSm0+j6a4mQOIuNthXw9jKXgnbqhT+3uH9S1f35TN2spPL9he3NrxFdU
dPYA6s5fChT3n73HmxBaeW3qfDdaCk9fnrn+7txupFu6Nr27cSk4TIeG9zmc
RPcXL4rp5i2FnBrRy8KOz9GmsAcu3VQv4P9bqNcyVY8sk/Rp3XQvOENxW1kc
3oH6085OdzG8INC7J5G5chiVHJT40cXygqGFXjn3Vfkwff6viq58L8iLr2r4
/U4ST+sHFnQhL7i4ZVAv7ZUyLl3wit3V6AUl9qt/sTVEcNpSe0YXzwvqt3qZ
cwum0YIVxU5d1GXwyzbvCLmyH40mq6p00ZdB82n1hKolLWjvWD9fF2MZ/Jk3
GXlH9RNyF41r6mQtgyN2u85A9kPEr/wVdeYvg52Hto3oUVajCsPFeZ1oGez6
drPh/YkCtMPxSXpn4zKg8goFaU2ViFKVE9PJWwZXxoTCblf8RO+/8S3spHoD
g+7w2E6hGx3q2EjrpHvDieqbsheiR5HXROt0B8MbcIY9K+wOGYuJh/7oYHnD
Ds0Pb1ieUvhMrsnzjnxvcDMHvmkveRxylVPQgbyB39v1cmOfIFZ4LJ3Z0egN
vVa2X9/ZTqLPr3cxOngz4xVrq9L1+9Dx78NOHVQfWHbHjk9Q6BcK6EpU6aD7
gDfvLllSrRY1pzqTOxg+sGFRUlCQyW3E2VfS1M7ygfGedod1xeaIcUYDt+f7
wKiA96UDw8VItfh4XjvygYmY809L+N6hhieC29sbfSDRuZ1oiW+a0zwfeD90
fsmP6b9onWM+aWieL9R+cbpYxB7/5we+cJh66XT4ZgF8efsG1pCpLxA6oT+2
lsnM+Q3dF/o/1dQEysrM+ZOPL0gNDtvbCAjgyPMxMMzwBQcVr9y742Nz/rfW
F9p0tr774vEXHf9pWzbM8oVF4i7BUX+4SL40gDRy2BeUhFon459Uz/lxvi/c
G2lPeZR1FXlN67JGbvqCzPuhZXtPeMzxH/IFOfWQrcs5d+b44L0vLMsulP5T
U4v41RRhtNEXsKlhKu3wrzn++OsLh74UHv2yvw/NVF/pKM8XznFLA9wqJ9FT
J2HS2Dw/2HNWXPvLOqF/POQHQ92qA2J+CrgvoyFjzNQPnhQdUqC8puAZeikf
o/tBz2/ZdbxlZDwvo5kY9/EDo/ETj7paRlBRXjV9nOEHgu8vvpdP6kKzfL3W
D0LjSs4Ef/6BZvmb5Qc1W3Xvizx8haLLnhITh/0gI9dKNjqPgyZ/XqZP5M/s
/yO0bYH0RnSKl5MxcdMPHppQOScXPEZKP6+VTyA/qO9L+TXa+GkuH7z3g8hn
6m2131uQz/8CR6MfHFjGc7ppOoA66EkZk3/94L7iQ5F4Og+tVttbPsnzA83d
Dd+u3xPBQvR1xNQ8f+CnbDc36lXFs/mF6g8DV70n7glIYif2oowpU3940OBx
ZLKchHFkVPkU3R96VkoF9w8OoTDWUmLaxx/y3tNzPj1qR0P51vRphj/URQsP
d1Dr0Wy+WusP5/Kd6ujmFXP5i+UP6RruT1Y6HkPXkTbBO+wPGoF+VnthP/Lk
zqPz8v2Bfr+Ds78Fo5m7u5130x9Cp56fyDatQ3GNcuU85A+mbHHX/d5tc/mw
xh8OfB83suud4WNahzPB9YeDau9za4YJrMYT2EH0+oP42cCzT0LF8UNqLyaI
ABCccDU52q+JA6CeR1ACgHqm3X2rqhieza+0ALitKf/xdigxl2/NAgB12m7R
0hpEYszXmAQBEFGmVlBq/gddZt/lkXwDoLP2kbfV9S8ILuQ58zED4JrhtTZx
7zJUwXqcyZcSAEa2U1JaRjv+ve8IAKU9Nhur5U6jMXyIx5cTAJF3qgb5DF6g
Y00zDc8JgPsZ+tLy5d+RPD6eSS4JAOlnDHWX9g50i5uByTOzprRHWlq8H0ZL
SSt55JoA+NSAToav4cOt6gHO/NwA8DeNPai3ax5eSazN5O8NgI0K/XdXeilh
fvVQzE8sh2dmtkd0rwjjPBdXHj9lOZR6jmA16vTc+wTachjLXdN+NaV/7v2B
2XJYV8m/zrL2NwqKssQCsByULW1DWtM/or5MVZ6A73IQeRhSJmDzAB0sEHIW
ZC6HFN+cdouGeDQvUzNTMGU5fChQltmcdhFdvSCBBdnLwfMB72BIdxVyezYy
LZizHAKTXmpyTzaiVxyZhUKc5TA/+tCSgze60Uy1sYVKlsO2St1ayZpRNNn0
Bwnh5bD62dSPCnF+fIrvw7RQzXIQp3AFuU+ksFJTt4swdzk8TtTMV9oth++S
6tjCvctB5lfAmPVeQeyj8QwJE4Fw87uXeGPZBOpYeG1amBIIzqNVqdl1vShZ
vdJFhBYIf6ye9n051YyEFt5mi5gFAuONbKb0kRpUEH0OiUAgnOfbV2Svews5
7twzLeIbCC3orGFXtidCUQUuosxAGOD//ENq+w0UtuMgWzQlEH47vJ46bPMe
DRVsRqLsQFiWKv39en0TOlzBnBbNCYQblQGP5Px6kXRBuosYZ2b/ba3yS0fG
0fVn8WyxkkBQvNtU/KpeAHv88kViOBAK188/bBMhi//3ukKsJhAaKQ7aJw5K
47jmIBdxbiCMmgbWORTyY4LswhbvDQTDYz/5zLLH0BlNQyROBIFUbrG+2IMe
ZO0mNy1OCYLI5vvb87K46KGGuYsELQjmfdQXI1rfIH9XZbaEWRCUh46u/Hb6
CuqOEUASEARvpVViI5SSUdauv1MSvkFw7FjkG8qGe0gsRsxFkhkEmQvKTxlm
f0Az6YMlmRIEXx1fa2TL/EZwsbFMkh0EPkaNgSta+lDFjgnSvJwgCJ3elRu4
dApF/NcC8zhBIKzonfrhtxAerXjPmlcSBLW3D9vu9lHEx34/KpuHg6CRNNaY
EUPB8hWfSZSaIPC+9FLaYJIPl/xCQOEGwRqzu+Mn942gpfxFLEpvEAzv9k2u
nuxErVrHyyhEMKzBiW/zYn+gRHIJSYoSDCoXTiRQsl8hstYZkKIFw/WDx23+
21uA8tx2saTMgsFyQIN9Tf8AsotbUyYFwTC/9vfCjg2l6InrfpK078zxZOk7
s/9+RkGxG0GaGQxpvw2O0ve0or5dkSzplGDoovXqyp8bQAcueZZJs4OhTvo5
reQrD0nuiiXJ5ASDnpl+npKzKL560RtkOMFgLRWpN2VHw64v7FgyJcGw1ORT
bW2MBP7ZojHjwsHwZc+RvqM7SThq5nElWxMMO5rd1ym9GkKTv/VAlhsMv2MH
rVml7eikgAxLtndGH8jyVymrR+Y6U6WyRAhI1G+zSkh+ge7yzyfJUUJgcpvG
io0fLyFvbTLI0UIg7E/afEWvS6h9UXeGnFkI2K1RMNQUfIGStUSeyUEIxH5W
u6GXUI+EFg0Q8r4hcLZkePmR9HZ0Ie4HXZ4ZAvO0WIWFJ4eQ455XGfIpIdD/
TcZTN4qEUeyvcnl2CDyd/B7lJi2BQ3e/JRRyQuDuml0fBkAdD156QFfghIBZ
Ete3+LooPvzyQoZCSQhc/+hcHpdAYOlLpeUKOAS0Xx3KfMIdRNdeFBKKNSFA
7m8nNE+3I4/WI3RFbgh4ejLtVOf/QM2C6RmKvSHQ9bwog/n4HYptOVWuSIRC
esRgHavsGfqfPcynhILtPfPcsyMv0BmdZPp8Wij0nDhWEWn/CVl5BGXMNwuF
o/Zk6uLrzeiB9vry+RAKu5MWvl1Y/Bf5u68glHxDoaBivW+FxxjqjnenKzFD
Z/LrkGHOHzLeu9csQyklFPZpZuNCfSksGu9VrsQOhcTcZmthSQV8aY8NoZwT
Chr+Baz9t4UwvZBGV+aEQlbM1rCPQ1Oo/pVohnJJKGjl/i2PcBxAEZd1ypVx
KIgfiuc4/fyDRl9SCJWaUPDsmy/nTm5AR/+MO6twQ6Hjk8MJz6AaJPdSfodK
byj0lugm3d5YiUpaiXIVIgwCx/2WXfF5j5YIdfJUKGFQs9dZP55Tj1p0Pzur
0sJA9PN/6xorWlGi4MwT3iwMflxKmy+V1I/Iut+xKoTBs8cVZ3dcmkTnPV7w
VH3DYLNdlmFNgiC2S7zprMac0dYBpofpsviJ+5tMtZSZ872fajRcKYMDE+5h
NXYY6PC3iVT+EcC9e/N5ajlh8C5h0FZfbhIduLLPmcoJgzCDo0+7JPuR5N5L
mdSSMIipfTfqEN6KrhQexlQcBi6Rk7WEQz1yrdzKo9aEwak7vVJZM9fzsy3G
mcYNA+4hLCRoUYWYr1iZtN6Z8X6oYNdQDZr4sxLTiHBQrvtT0189Y5rCy3k0
SjjUuGwScndvQ2b6zs7qtHAQ2/D8em/8ALojFJapbhYO4T9rNVeITiNvPTes
DuFwwW3DlqqTQrjd04Sn7hsORNv2zKu+8njnSkVnDWY4sE5VvPzUIIUFPa0y
NVJmtlvdfXjuNT++kKiGNdjhIG1C1Hd+HUcO+4R5GjnhsH1JMPdzQB/6crXf
SZMTDi++x37g5reg0CzJTM2ScPhesS6keOAbGrwyijRxOBw6LLcsK6AGHapq
ntasCQfO5mt5L1WqkdSVaRctbjgE931/zFL4iK5VtrG1esPhP3rzNZ3Djcij
/QPSIlYAeV3K9ApeO2oSKZ3WoqyAJceTXI/O5M3YtjoXbdoKsNn1Koqxi4d4
whVsbbMV8HFP1qXMz8L4tP4MscEK+G3yX5hIkSK2WnJqWtt3Bch7vVv1o5WC
H+jdcdFhroAti8Oe8hvxY//F59k6KStgVGLKuu/gOOpauRfpsFdAtrJZ8q19
fWjv/nXTOjkrYI2wuI78h1YkujLbRZezAt5n56VcvvgDXdy3ha1bsgImfvtS
8ww+I3pRFNLFK4B6wUuw6utHVP966bRuzQrQjU3yOV7yDUVcTXDR466AsOoU
cGT+QiNVfmy93hWgytRS6/zVjY52OCA9IgJae1LvruMMI2MxnWk9SgQILu8q
38JHwjfbXVz0aREQ9XJfrcpZUbxE1IitbxYBG5yXDylvU8EtBvJIH2bGD99Q
EtOm4P/hr75vBCRQP+7b95uM+QxUXAyYETPr3/yw6uY4Or9EkG2QEgGnbLpH
pCX6kV1Sb5kBOwLaI35V92xqQ48Xi/MZ5kQAN7N/9b5xLgpcNQyGnAiw81Tr
KI6oR737uSzDkgg4c3dLy9K339D+4tdlhjgCGMcO165U5iKJ/a0ko5oIyJD8
2Wv5Z6Y/imrAiBsBWoLjJKsZnnF985hl1BsB6hu3RNz8Mop+dF4sMyIiYXuB
UbntDC/+D2eNKZEgMxwTKjYojic6isCYFglhm40anklr4RNiJ1jGZpFwcOeE
5561ktjMiFVmDJFwZs8rU9YOMr4jepZk4hsJnuvMPXUEJ5C34W4wYUbCmNby
DieNAdS2dC3LJCUSLpMiiYiGTrQzObTMhB0JaelfHwjHtyDBpZtIpjkz42OH
X3w/0Iw4SQww5cxo6scXB+b/Qg4HF7NMSyKB3iMHcvJ/0JdrlmWmOBKi40LY
Ard6UOgBH5JZTSQc3edzPsltCA0U24MZNxIcJhwK72lMo0PVmiyz3khQbExJ
fDchgPW7JcrMCAZszedoCzVJ4eI3+iRzCgPktq3/Iqw5H7t3yYA5jQHPz11v
v3lDFDeJT2eYmzHgbqTLvkdefDjtfx/8gAEmTb1+4VXjaFqMn2Thy4B+U8kk
Pf9BdNqoh27BZIC7gql1ZGQvslpWl2GRwoAkbHE071UXum84WG7BZkCCeFuk
xbYu5Of1k7DMYUDz4O1jpvl/UVdyJd2Sw4DNb0skntsMoD3ZtzMsSxigqHb9
lPutUSSS/K7cEjPgRUKNYuZGAl88+JCwqmGAWLDxoHG1IKZfL6BbcRngd2HH
3asmUvjb24MZVr0MmEKFepFeGtgk6BNTiWDCp02f/yTOo+C0+MVsJWEmlFCK
3JqkBHHV5rJ8JQoTtvCu7OcuIbD8XkukpMiEst3REZsHRlHw5nKuEo0JLWVR
m7OIQTTrX3pMGFa45l6j1of6TxZTlc2Y8EWb/h9JrBfN+pkdE+qnQWr5lV6U
efIGUxmYIH+emicvP4DeXdZkK3sy4YIHX9Pp3SNI5UFuvrIvEzZMmtFPxk+j
la8kkHIIE24M+h+oTePHRffPcpWZTNhmkkU7nSCBZ/0vkQkmoabFgYNKeNHX
3VSVFCbY31hEUtWTwbN+mMoETbljf9tahPGnL1lMFTYTdu6cN13hzofV/0yx
VLKY0NO3+vIRy0m05n8fWHOY8MRz38LlV4fn/DKXCcSnO6/7LQfQ1PAmrgqH
CTVr74yPn+mb888rTDh3NdlX+3MfylVgUlVLmJB8TF/ctmYAfRPsAdWHTEgN
f+cTemkE6SrEMFUxE1aBQrJX4RTaqFvHUq1kQsHltJgzi8i43HZZvmoNE07e
++htZy+KZ/22jgmOk1teCFjKYl9bX64qlwkLFSt49hJKeNZ/25ggDKvThl9L
4M7gBVS1XiYULjltJ7hQABt5VILaKBNWjq9RcLYh8NZgJ6YaEQVl2hoDH9+P
oVcJt1lqwlGwrTRj24ndQ0g2VTdfjRIFpQ2aL13VB9CsXytGgQLnCHltZj/6
b4sBV40WBatb3nLMtg+gWf/WiwJh49KdL9WGkVOuLJVqFgXZfNUXrt0ZR6y9
BUC1i4K3AWSJwq8Erj41c4MgCo5Vb3S2oAhipSsHWVTPKNi6w+K3/AdJnPCQ
lE/1jYKnQh2SHT7KeNbvQ6JgukHvPyFRWTz8gJ9LZUYBft7xS2alKJ71/8Qo
yLBPqjlbRMa7Hgip01Ki4H3szf36X6bRh1fpQEud0bsmLRc5jyFqXR+Dxp7Z
PyThnfvLIZTcFs+iZUXBi5U1TDuLQXTj6yCHljMznws3/g4sGpzjhdwo+Lv+
8gfvviHkOfqzkcaZOZ6Ios1jxtgcP1yJggklycTRb9Po60gTTb0kCnbU7XXz
3UXG2sLBoP4wChpYT998qRHB6xWrGeo4ClRPhemol0hjpOfCUq+MAhN3KSvz
vZqYpPieo14TBWvOZxu9/U8Kz/JGXRSka5jtTrEWwWftHjWqc6Pgjc7gVY1s
8hx/tM1sT3NvunyThwzsntI0emfm35mTnPt9HG3xNAeN0SioXtb8ZEP7CHoR
cpmhQURD6D7+Eo/Tw0h6pTJLQzgaPMrtOq/UD6OAkKscDUo0FNsduFVcPopm
eUUxGqg/1ivLJE+intRjjRq0aBh/tOMnoUrCs/yiFw0JvcH8i7YI4O2pJ2ma
ZtHQ/anI24whjl9niYGmXTTwOXRpXZCQw4qn2QxNiAaJqcQDwakqOO7qUIam
ZzQcPvrTtzmNgi/n7uRo+kbDY/V1SttNhPEs74REg93lgqAFYmTs8mh1oyYz
GlxpadqrVvHQ/35eoJUYDct2HL9M15xANQ9TaFop0bDqvcYa0p1RpFrVQtdK
jYb4XcZryH0jaNW3MIYWOxqWeuAvHg2jc3yUFQ08qdZNCmsn0FhdBEcrJxoE
P0pr3SITeJaXcqPh9I0Vo+PHyfj4mEejFicaGFPlAUZTwvhz22dC+0o05EUF
L3ijJoU1x5bQtEuiYZPM4ajXxWo4RQTTtR9Gw7oLB9eVfpPFpfOtGdo4GhLf
jyrt/yOOZ/mqMhrUrh+K2xEuiL3m23G0a6LhTfPzGrYR3xxv1UXDeoWEVbYf
ptEfe41GbW40nPT8ZXUmZgLp6ZcQOm3R8NqZP/3MzTG0yV6bptMbDXWPT+89
mj+GKhafoeuMRgO/+zOFHwYTiBI2j6FDxAC7luOlx5pGs3wmHAOuI6WERxsJ
54dKc3QoMfDsR8xGqxk+n+U1xRiwqWo9Vmggjhdsm/ypQ4uB0ddWrnc6ZXDa
yv2Ert7M8S7Gsb5v1sD/a0ddsxhIX91laGMijeX3b6Tr2sVAw9eDsu0Jojh4
K1+ULsQA9160ofgLfjzLd54xIDd8YGOWJgn3n+7K1/WNgcuPikfrD07N8V5I
DNTvkDP88WwcsU//5eoyYyBGa2+W5ZUx9O5qLKGXGANS+bxNdqrjSPnxN6pe
SgzsXI4uYJ1JlPjam66XGgPtTzlNXB4PFT1qYOqxY2D30f42nWk+PMuHWTFg
oVKkoX5YCC+qf5mvlxMDFfuM9zAE5uFZXsyNgUb6uxWtFxTwx29VXD1ODAx6
nPNX95+P1TucCf0rMVA0lij+m0LBa8bvUPVLYuCcZb74iI8wfiKqT9d/GAML
afQ9rmfIeGrsPlMfx8CujCNjEnuJOb6sjIEpZRC8oDCFTildyNeviYGr5acG
KtvG0Sxv1sUAn/qRjafWjSMdpYtcfW4MhOx8UkO6MYE2GMwnDNpioMzMQ9D8
7jQqX3CIatAbA+SJWPUN70lYcimZbjAaA3FZNtrPDwpg3wVHmAZELKSTe5RP
+IvhWT4VjoWN5xcv3/NWGneEpeUbUGLhSEdmaDJDCxstESk3UIwF3i9f4YYJ
Gbw1LINrQIuFT5dWlQZ+E8cvVw3wDPRiQXp7yRo8IYhl0xKphmaxkDU/aSLF
k4xnedYuFu6UX74v/Y7ABduSmIYQC5d2ce49SZue41vPWLB7WFHN6plETmcD
8w19Y6Elb4FSTtMkytj/CxuGxMLqj/durg6YRtVnQriGzFhg1cj7uzwl8Pzi
tzzDxFjodF93fOEyMo5/spBqlBILZ8JKtcYchPAsD6fOzC/scUj/Ngk89HgR
04gdC5H2N8813ZHFs3ycFQvc4oY/x96r45zvpvlGObHQJLIy9+QZaVz7uhQb
5caCzqtzK0syxTD1uwXXiBMLxgt7942SBXFyZyHP6EoshDJtQhS38OFHEypU
45JY2LxnZS1Jk5jj6Yex8OhCeaf6sSnkOUFlGuNYOBi0wdn1/CSa5evKWEhe
/bTST3cK/VIWzTeuiYX4zz6FSZY8pCWWi43rYoFtkCYssZWE1ylLcI25seBw
YM3lnAR+jAx38IzbYsHlRAu1uFsYizuOqJn0xsLLuhCjS44UPMvjo7GwcmtE
8INniviswzjDhIgDLK6Vxa81H8/yuXAcdJ68qfMmmoINHKY4JpQ4WJadn/bF
QARvWboemyjGgcPOX6pb8/jx8/A/jSa0OLjjUNIhxSFh6eQVPBO9OGCEkw/z
beChgPAOmqlZHJzMNky4ypya43m7ONhYXE3b1jrjH2mfGKYQBweS159dwpua
43vPOAhI9TlsG0jg9LSvHFPfOGg63GjvcpoPvz7ghU1D4iDyqlVSEZ8gVjhX
3mjKjIMovv66Zn0xHHvNhmeaGAffUlnPDkxI4ctnn9PMUuLgeUP8vAM/VPFs
HkiNg5RcW7riXXns8vQGw4wdB3et7zWLF8/Ds/kgKw7u+9x4tr5aGL9/cotj
lhMH1LymYo2N/Fi1Wgeb5cbB1L6QlhvHSXhVw9lGM04cfHo1Sik6xkMPuig8
sytxcM3wne6hu1No7HsezbwkDtYzXym/9p1Cs3niYRwQ3GMi5tum0bHJLIY5
joOcs9zDBpeJuXxROXN/w9Ivjo3xYY3JAxzzmpnrvWxRv2e3IF4rTsLmdXGw
taZWfWBSDJeqbG4058aB/Qey5KoKaTybP9rioFby0uhfeXXspbKVZtEbB4fe
FXyR3CmHZ/PIaBwkJGZ3adVJ4lbHGIYFEQ/7XxSZiOQJYz2jPraFcDzcf1tO
VnnDjzc5xnMsKPHwmQ+JNQTz4Wde35GFYjzsG9US+F1LYEqEb6MFLR4iJtO5
QYoEns0vevEwz3DCaL0xgfNWBNAszeKhqcHUNVyFhGfzjF08LMjzlnfv4cP2
250YljCz/VYKnqgQwNuS37AtPePBUeU1o4QiiivTgWPpGw/pKSlq/akULJd9
D1mGxANniVJne4wCjj5v0GjJjAdEaO6x3qE2l38S4+FI9pKoiUfSuO+cMc0q
JR5erbrVeuSD+FweSo0H4/dau2o+CuGDpQoMK3Y8tGf9jth9gB+/vXaJbZUV
D9k96/piGXxYuVSJY5UTD1E+fJvLKCSc+PYwssqNh7iLVvdE9xP43g/+RitO
PBz+YGsDLwg8Un2UsL4SDw3rnjZXzDxv3X4I0axL4mGX+MMtcrfJ+Eh3Ot36
YTwI6jdHjx8UxB8bRKOscTwMFq51KW0QxbRuFtu6Mh5MNLskin5Q8OqpwXzr
mnh4Wxd7XKFBAT+RWIWs6+LhAfdRRukvVTw5OcK15sbDcVZ3/sFsabxEYjVh
0xYP3G0XX9asF8enVJupNr3xMPmJnbrOSwj/Ng6m24zGQ32CXNLAIBnrqLYw
bYgEELhgv6ulioQ3GIexbYQTIPa6hETTzPVhp/f5NpQEUJt8IsRHJbCktxuy
UUwA2ZKgDWrbCOzj9IFrQ0sAvet+caanSfjcMg/CVi8B3CVWinTO8GhHxFOq
rVkCXMsK9ZTJFsS2a8zptnYJIOee9VxbSQxvjUBMW5jRkda5xYul8MvVVmxb
zwRoPTsVLJQyH8tkXM239U2AtLTy9FPiyjjqkBqyDUmA1PKYkXmVUrhg+zWu
LTMBVgt8U40/LYb/ZqsTdokJsOdvwpaECkHslHeSapeSAKq/an+X5JLx/hti
dLvUBKBce509epCE35w/zbRjJ8CfO5Uin0Jn/OOGJNsuKwFG1O5YjL/kofiy
nfl2OQlQevz9cjVLAt95N1pml5sAC/rqXX8uJOGh0j1cO04CmPtJOu0yIeOF
7yZ4dlcSYLl1vGSUuSA+/DOFal+SALcN87aYPBHFtW+nwf7hzHiz2P50USms
9nMD0x4nQJLNpU3JHxRxck8by74yAR6vEnA5/FsZP5qOyLevSYBt4aSGSHFp
PN7die3rEqBF5Mbdkj4x7DnN5NpzE8Bj4L7DlIwQPiH5hWfflgDeUWHIuImM
m9WWUhf0JsBZD1Vy4jsS1pL8BgtGE0Bms8DgsXMEXqfmzVxAJILgpo6sUR0C
l5lUsBYIJ8InKQ//+jgCi9Pt8hdQEuH4i4jL8qtIeJnJS7xAMRF0t/UErPYn
4zPODtwFtERoOVygbOYiiNu8S3gL9BLBurDZevy6KJ6hW6qDWSLIpG4eeDVM
wVu874CDXSJ83bHw45uXivh5pB7TARJB6liGd8ceZSy19jzLwTMRzFtsdmc3
SmEGSzrfwTcR+rYYFRm8FcOcNRzsEJII0qnE1Vx5IdydIcd1YCYCm+xoHCnO
jx0O7+c5JCZCk9uh1xs0+HDWTBx1TEmEzKIetVF5Eq46lA2OqYnwfQNV995H
Aivk8zEd2YlQ7vM1ttufhGNvbmE5ZiXCoY7khywOH76UJ3DBMScRYno9jwp/
4McDN7Zhx9xE2Hi/MGa1tTAG9LfRkTNz/L3kN/I7JHD2+1ie45VEWLRGCs93
lcHvy/ppTiUz17tER+NxFRWrvE8Ap4eJsFkuj5uQpYBX/e8HPzgR0l+rSOu1
UPCDv34sp8pEeG5knH/ZQQzPxEuOU00itLVdb5O2FsLuf5djp7pEiBwJLPM/
w4+P8aoanbiJUPTcoDKcTMb/+1zu1JYIxUe+aYk6zPgHr5rm3JsIIkkRX7u0
+PDaeQvBeTQRkh0rB3Nr+PBT6gOGM7EStB5vsjRbyI//D0yRBcM=
        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
      {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[{{0.5, -20.58731462444898}, {
        0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
        1.25, -27.50184105161661}}], 
       LineBox[{{4.249998, -23.11696430864725}, {
        4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
       LineBox[{{6.750008, -23.038818749837983`}, {
        7.000009, -20.322035683613738`}}], 
       LineBox[{{7.750011, -20.716014193782303`}, {
        8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
       LineBox[{{11.250025, -19.142376381324734`}, {
        11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
        12.000028, -22.492142720939622`}}], 
       LineBox[{{12.50003, -24.045787259895636`}, {
        12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
       LineBox[{{13.750034, -21.052099541576304`}, {
        14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
        14.500037, -21.409428863587927`}}], 
       LineBox[{{15.500041, -21.61333098548902}, {
        15.750042, -22.10549208407436}}], 
       LineBox[{{17.250023, -22.856107311471863`}, {
        17.500019, -22.566864012429928`}}], 
       LineBox[{{18.000011, -21.834193448858855`}, {
        18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
        18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
       LineBox[{{19.499989, -22.216470803381476`}, {
        19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
       LineBox[{{20.499973, -28.088099516986762`}, {
        20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
        21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
        21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
       LineBox[{{22.999935, -19.74888960999384}, {
        23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}],
        LineBox[{{28.749847, -22.783129874707647`}, {
        28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
       LineBox[{{30.999813, -24.728294878757325`}, {
        31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
       LineBox[{{32.249794, -20.837058021652666`}, {
        32.49979, -21.361849645654928`}}], 
       LineBox[{{32.999783, -20.84333950660284}, {
        33.249779, -18.469001093501973`}}], 
       LineBox[{{34.999752, -25.06864583779922}, {
        35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
        35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}],
        LineBox[{{38.499699, -24.377795653123645`}, {
        38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
       LineBox[{{39.74968, -22.650120892941615`}, {
        39.999676, -22.80728905851026}}], 
       LineBox[{{43.749619, -22.041875381710568`}, {
        43.999615, -22.423199188672683`}}], 
       LineBox[{{47.499561, -21.287037875136214`}, {
        47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
       LineBox[{{49.999523, -27.91448197690941}, {
        50.249519, -27.305559271827388`}}], 
       LineBox[{{51.999493, -20.885769001862567`}, {
        52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}],
        LineBox[{{52.999477, -22.174453342075132`}, {
        53.249474, -24.83933405846568}}], 
       LineBox[{{54.249458, -23.722525323809897`}, {
        54.499454, -23.580299515887834`}}], 
       LineBox[{{56.499424, -21.766646750655234`}, {
        56.74942, -23.57640470224996}}], 
       LineBox[{{58.249397, -23.599923997532017`}, {
        58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
       LineBox[{{59.249382, -17.837453345617426`}, {
        59.499378, -21.77661789863478}}], 
       LineBox[{{59.999371, -21.620808909572247`}, {
        60.249367, -21.022793121071274`}}], 
       LineBox[{{61.749344, -23.521435622331904`}, {
        61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
        62.499332, -19.42225543656815}}], 
       LineBox[{{63.499317, -20.822384760816565`}, {
        63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
       LineBox[{{64.499344, -25.343231741743004`}, {
        64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
        65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
       LineBox[{{68.249573, -26.50222788848888}, {
        68.499588, -26.988563201691523`}}], 
       LineBox[{{70.749725, -20.1140901131646}, {
        70.999741, -20.81539559964317}}], 
       LineBox[{{72.249817, -27.41004150424379}, {
        72.499832, -25.260157006181224`}}], 
       LineBox[{{72.999863, -23.234537488989123`}, {
        73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
        73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
       LineBox[{{75.25, -25.575903773461626`}, {
        75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
        76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
        76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
        77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
        77.500137, -21.438588076795124`}}], 
       LineBox[{{78.000168, -22.06377454291717}, {
        78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs
YIGKij4GWMwmJCQEJPa7n+8ef/zD67wG933tOudzfd6fezNKnT89Q5ZEIhnJ
kUj//v77s+Ogfc/gJjZKqwbOWUWTir7/r8Uc/qGHrcfm/q1bOEcUOuPu8P7W
3Zw8peNnSvz/1n0cZ3/r+rvmf+tBTuAC8at3WmzsX1/YOyYZ5hz4VhSpo/S3
lnBs775RXqjAxj+T65ZLJDLwLm92diT1by0HYatDYJz5379XgBtzz3EzQ//W
4yBKlh/anPG3Hg9mk1S9y5b+rZWhqks9PH0dG7vqYueOSVTgwo19206t/1ur
wX1+ZZKC4O/91EElsSe1fzkbVxt9vS2RTIK7c+pNxZF/348mrI1q7T7uxca1
H/WmkEhk2Lm8tY5vx0bFKvcNJBIFUs5nCHpU2bipKPIhiUSF+pZBx8cjLFRe
MX+iDEkLanbpsQvk2bgtdnOYDEkb9gpLho112DjJ/cROGZIO1F7Y0zWPwcbd
lLuvZEi64Dra3tQxjY1afR+1ZUl6sOj5xqeHE9l48MWfBFmSPliqW5y7m8dG
/QvUElmSATgeXaz0ff3f2hCm2FacHdvKxpLtTp9lSTRYvs1q+enVf+9HB/1v
q+75LmDjdHPXyzJCOoRV/7FOjfp7fyMwPn3xWLsjG1/JRwzICI3g5poPDz5Z
/V2PMUTqTny5VYONsV/meMoKjcGX9KL/tfzf9ZlA7bd/kj8S/X1Xk79aVmgC
J5kJa95T/67PFGyW3/lzn7h+cmk5ygpN4ShrU0NmyN/1moHl41kTm9LZ+CkX
5eSEZnAwqb4wmFi/8bxQMzmSOdCPNETVbmBjetL7qXJCc7ihqCivvouNx0Jm
8eVIFvBTIip/uYKN31mDm+SEFtB+bDEvJIuNljYbTsuRLMGqyfqiPtHfmbrk
J3JCSzjhfm3PE3s2nh5f1ilHsgKxi3Bytx4bfw46qMsLrYAjbxW5Sua/mmQN
g1c9AsyHWWjXUuUoL7SG4ri9d7OJev6b4Eh5kg241F/5skibjZUPmhbLC20g
Z0tzRpIDG3uuZO2VJ9kCuXt68nqin87H+q/JC23hTsLUwWmE3pbsXtskT7KD
31OF7b+Jeb66dtKwvNAObgV/aWMR+hxYWKKvQLKHVQfWh6gWsNEj1c5bQWgP
zedPz3FaxcYVEbe4CiQH8ExXsXmUzMbbEJinIHQAYfGN4DG///abxIDPtvSp
4Yz/+gMMyNTdMLmW8refDPgekPZGMMTCpSNaSrLIgPn2D7u+fmJhr8HIPRmS
I0S2NBf2dLIwmyPOkwFHCA9dH7mL0Gsn7563jNARNFnfLALd2Th7TcUwCR1h
bhGHaRXLxpajW66TSE5wLrdcdXTuf/oBJ3hdA39mrf1PX0InCMpYGfx2xX/6
QyeYHJBXKV75V59OcOjlo87O+f/pl+MMBw/IHrSNY6N24iJ/icAZ5kZHxha4
sXHP6hh5icgZbi7ZcW438X41Slg1YxJnYO2hLQwi5rUQabljHBcYONMz4xrx
flQ+y7HGBC4QY8a3HHrFwgK5loFRkQtUvnv948UPFlbo77o/KnGBKys/q7kT
ejDzXrZmlOMK59d3T7IwYmMZN4EzKnCFHS+LL1EC2EjL44yMiFxB3bPO4cMs
Nh4qM7kxInGFg3VyBpU5bLx56+mGEY4bTGOT/xER++H+4eKUEYEbqEs8qhcS
/b8ytpc0InKDYd1oNdN4NjrRV1YNS9xgsRIlJC6Qjed9uCuGOe5w6atP11dL
Nj6JnxAwLHAHvSeneM+JOmhVp/ywyB22D7/JOtTCwtrDL2r+SNxB06XhrXsV
C31FV3P/cJhQvy3sxNJ9LKwRH2T9ETBhqvnzw5TrLOTICgaHRExIktnwtILY
v0Q96wdDEiZwyD6b/yHm+y1bde0QxwPsB1l3Con+xyT3cIYEHrCXNy+SSpxf
LwWvRwZFHjD09t6fjnA2Rhy5eWNQ4gG1RfMPXk5h4/ybGRsHOZ6wNvz8nfFz
CH29C/QdFHjCHoHgqjrx+sxRO5lBkSd0GJdP5jEJPRtqVA9IPGGK05nY8j8s
TIffKwY4LBhp629pNSDOi5S37gMCFsyco7NW6yQLJSvWKwyIWFDuiBaZXBau
OjTzzm8JC+7sfNb21JqFQ1XTBL85bGi8Om34+Rxi3psd2b8FbMi39SzgE++n
l0Qd6hexIU77egwS59kk3ZoH/RI23ItdljGtl4XbWMfW9nO8wObQ+LR5amxU
TtoE/QIv+N25b8pOF8IPcueO9om84IYsN8mO6L9iacTNPokXrLBz3WkiZKPp
jZGNfRxvINUFC78Rfnbkrdi3T+AN4VeoLRqubDQk5NYn8oayFRkPzp1lYZHB
yepeiTdEZazyuj+BmHfO1pW9HA7o3k1Ur6GxcA9vAbNXwAED895Ot0ueeGm5
vmKviAPJG5oyFy31xIUF2772SDiwxtSN+/qPp7RfNIC4kXcznp1hIWV+uuEQ
B0DgMHV0u9p//eMCwK3tg+IGFqZNPPNlUACg2h9huLWfhUYGhncGSwC2a4zt
fTSDjWK7wtJBEcBawf7Wwo3Eee5NDFAzgFOygbEaoceksMVJgxIAvyDycRJx
vurziBOa5gPXTp8aWUP4++mft4wHOT5wJoy/ZyubJe0/1wemZMpW1O5moaVq
afOAwAdWmkpoKr6e0nko8YGOkVmjenUeeMxh3aEBkQ+Ya3QKtmzxQJfbcWsH
mn2AYvLc5/1mT+ytf5wyIPGBaMvaUI8yT7zwwQsGaJNBfapD7rxgNmZ3njcc
4EyGKzuUq2xobLSXGI3+5k6G39fhQRDRv6rNA19+CyZD07fmhUmT2dJ5KpkM
HLnxtwrnstDz7LvS36LJYCm6tj1zzFM6X82TIepyQppMmydefypK+i2ZDMkP
1ySrnv9v3mhT4OWI4quk+56oMGecyW/OFFBaaq/YkueJ91Ytl/nNnQKvx/P9
4xw9cM3W9uZ+wRSoWbVF0eMqE32Kk6r7S6bAJ4lpYsgWJkrOPTvUL5oCUS/8
Ds/z8ZTOZ/MUeObe1SbM8sBpIVqp/ZIpUPz5Znlxo6d0Xmm+0Ow9q/zQfRY+
mjts2M/xhSfXPKcs9WFJ55frC4qqfrmrEj3Rf3vzuz6BLyw28lvm1OqBr/Wu
3Okr8YXP94dONtV44B5biyN9Il9IWbVMy/iwB0Z6HRD0NfvCnBe8iqVynqgR
qpzcJ/EFs4jFFmZbPLEheTW7j+YHrx9cvbLL1AO57dNN+jh+8GtsTkDBBKZ0
/rl+4H5hl7z6bnf8MNFd3Cvwg6UDqXlpBe5SPZT4wYAXo0JnrSfG2+sd7hX5
QW5Y3z8VoUxsvdm9trfZDwwTGvekdjDxxOPU1F6JH8wfDTpoFeWBme9fQi9t
KhxMydvfR/ZA046ptF7OVDgZ6yfY/ZqJX0avj/Zwp4LZxYQDXj+ZWKZq875H
MBWsVu3UWkfyQEYR6W5PyVSYsGd2w+9iJnadXnikRzQVAvKcK/dlM/Hc7a+C
nuap0DZNvjqizxPnPIlO7pFMBX7uCasvNe5o87GO3UPzh3057qaG793w5qxi
kx6OP1zdWTH3wlw3zFmpLtvD9Yc1UVee++90Q/cta8S/BP6QrvrgshOhz/5D
fdW/SvzhSanfRrll7nj5bObhXyJ/6M45/ipK6I6LqhtX/mr2h4dUtxk7zrmj
bPC51F8Sf3DeoWehf9sdMYHu84sWAAVOO+PG1JgomLOT9osTANabBh7m1THR
a7X8WDc3AHrVTsylanvgyNal77sFAaDRfVqoocHEzbohd7tLAuB2tYb1I7o7
BtpUH+kWBUDJ2psvrWaxUInNEHY3B0B0dc/RnbPcsDakLLlbEgD0Xeafe0+7
4vokslc3LRBmDH37LRvgiuS2VpNuTiA0uIFF8hlX/IfAyW5uIJzjPO4us2Xi
DuWn4i5BIPCKhq2p49wxXB9EXSWBYIpnS5y3uqGq3cXDXaJAMJfZx1S+6IZP
vExXdTUHgibjVssaW3dMfDSU2iUJhIQ/JVdr1jNR991sny5aEGRQ3z15TPB9
U/sHWhcnCF7uuKf39SEL94+EjXVyg6C1PGPt/SQmRqvced8pCIINYe0N9ya4
4bcD++52lgTBiDorIl+WieWnCIAUBcHsodvfvxm6YuqtlcLO5iDoEz7Kf7XS
BY3qO5I7JUFAyueR5M1dsPk916uTFgyjjQ9DXn92weKO53qdnGAoSTx07vEn
V7RbcUK2kxsM2d5yW59tccefBTqfOgTBsMx7IKje0w1PFW0WdZQEQ9g4axuz
zW4488zo4Q5RMPxq31O7MZKJFlXzV3U0B4Or7tnUzE1MvBrol9YhCYaLl6tf
ad9wwyXx13w6aCGgpv9hWG+vGzrPtqJ3cEJga19j/7WpntizsmjsJzcETMty
78+1dcXKLSoffgpCwPvZ4HWFBlfk6Hy5+7MkBE722C5OeO+MY1ZRZT9FIWB9
8pNMUogzVnnWCn82h0ClvpLfxAnOuDLYg/tTEgLb8+Y0zZvqgp6Jp71+0qaB
Ic+B72DvgoNzDPR/cqbB80ztq0VUJm4c6pH9yZ0GPycNZKTWu+PUCRmf2gXT
IKnhdnCA2BPl9d6I2kumwcxpe4fDF7jhXZvA4nbRNDBeJDTqlXHFNexbq9qb
p4GegpnslI0uqP6wMK1dMg26jB1Eo4tc8FmT7OR2WigsVV5XULPeFbe1Laa3
c0Lh7b3KlOPbXTBk+PtYGzcU3EiC92tVXFB5YtyHNkEo3LDuKOeVOuHB/fb3
2kpCwWd3Xe2QgRPGniwtaxOFwvC6VaPFvx1R66ZGXltzKKgVNQzpjzrjq0fr
uG2SUFiuIxhzfuaEu9/99mqjhUGVzQd3CwcXjPzJ12/jhIH+eEOFcR6u+DnH
W66NGwZqt3b3pm9ywdJNlZ9aBWFwoF1+2vQzzsg9aIytJWEQfGO5fFmYMxqc
3l3cKgoDv4Jjb8+7OuP7W4qrW5vDgL6pLe/ouP9qSRg0cJa2/xPnjAvYJTL9
auGQEzx+ZUWCy39+EA7TLvu/+Cp0wuOrFwn6HcKBlKuk2cV3lPoNJxyGDjUV
cn4xpP4UFg4tp13r6jsZmHw4DX5zw+FxgmFA6C4Xqf/ND4fjZhs2Rl91xN0f
3at/C8LhXXtjQ72LE1KrImUGtodD4Nuy0oytTlI/LgmHQ48cVR7HO2HImIVg
4Hw4/PS9Zrab6ST1e1E4gEFB8ZdZTlI+eBYOHRdi7IYLnFDeUBsGm4n1O+a2
Rmg4SfmjKxwcvE8HZdY4IjF9VYOScJjHL3u5PNIVb3spyQypRQBemdT/UtPx
Px6KgLWshb4bXBj4K/d97pBDBFRlfXk4tNUBCXqpGeJEwJfXIqOZHQ6olvuZ
9CcsArZYhLgV+bniqeJ6zh9uBHSXFo1vbmdI+Xp+BKiP2dYtf8uQ8reAeP3d
tsdr5Bwxtfo2aXh7BOQs3z171NgRRz4e5wyXRIBNzCfBzCJH3CcpzB0+HwFz
H7udeUXsj+7HMzXDoggQ+R+U1PY7SfPBswjgrXvGvFjqiGH/Bo7mCDB5sPJ+
fw4D2zizc0e6ImAXa2D+lgUuONdwY82IhFi/3E0v56UOOI6zgDSqNh1qKprG
POTtpfmFNh0iVGUmbQc79BL65Y46TIdT5Xaim5b2iMkpNaOc6bDmrOBFnZsj
xguCSWNh04GTE3tl4AAD+0tcOWPc6WCae/B2JYkhzVfzp4NjykPTH5YMaf4S
TIfXKn6Z0Q8YeFZkRpJsnw7Xo6bMiytzwgCxGkdSMh2ujasqLdvvgsTurpac
nw6vzLQuFe12xoxmSo1ENB2eL/QKCQtwkubDhulwhZGRrNVkj0X0Nm+SeDrs
O6fS+kjLEQ0lCmtI3dPhnPmdO/piW7xO6yb+JxKS9P8RaJXZYCS8lZDUI0Ey
PDy+d8Raml/pkTCv2j7c5KitNN8yIqE+sJrjZW6PyrxHKAORIJ8SJKrd64jH
hZclMuGRcHnBcbpctQPCkWJvWV4k3Pv0Y9tqfwbeFdzMk82OhAe33bs69Z3/
e94RCdVfkz+eUXTEIdwmkS2MhH7PUza3lzvgrk+E4Esj4f5KjudOPwek4u48
ucpI2PU0lengRuhDnItyxKpLxy/uVXCyw2CZmRK5hkjwe92zyI3o33ejSG95
cSTMalnmsinRGmeS5ufJd0dCuXFi41MfK5Q3ikN50gyYuZr6ZPIDSyz2mSKR
V58B7ywlL/fl2UifJ9BnwP2Y7kD6N2vp8wPGDHjddkRkP5eB0SnOqAAzwL8+
hBNu74y/8gwkCuEzQHd8eXvkYSfcUjbOW5E3A2btMG4/tdoe1fJM8hSzZ4Cv
4deaa6G2ePKICioKZ4Dck5+nNm+1Qd87A2OKhTNAtD7o0ZJUG6wt1Zw8rnQG
sO+7Z06zsUNi2oTjKmdAwdfDJjUatjjy6YdoHBL381+qqllkjftkX4yNa5gB
Bz/OMjn/1QJ1P3X4KIlnwJQw2oapn83xskyjUKl7Briv+HyMV2KOYcZ3REqk
KCA1O3B7DGywbfKZMSX1KLg7UWF6GFjiHKM6n/H0KOA7BFuu22KN4yZfFI5n
RMGsWWcmqFnaYlnqIdF4iIKVhj6rm6g2yF67YWx8eBS09qtF3Ku2QlFKmc8E
XhQcOnLGdtJkK4xfs0U4ITsKKuXnrVhgboX9ZUtFE4RRwJOorS+6Zonb7/LG
JhRGwY+BQfImMyvUKFvlo1waBcveLX72uc4Gz97JFCpXRsF+IZ0p3mmB/l/C
RcoYBaE/W0+tXGCG/z6uUG6IgunWOyf9Fphixudon4niKPBWCmUdyzdFkpyP
cGJ3FPS3tDfYjdriQRMb0URSNEzaeqbmvIE5uvpSxiaqR8Mli/qCDx/M8bqx
o48KPRp0Du7z1lhigdOn6AlVGNHQdjeo3c/eAjvSFEQqEA0fTG7teq1rgfnr
ukZVwqPhyy09waOTFqicpuyjyosGrRytkegeCyTSh0A1Oxpm7K54wn5rjlDe
XK0qjIb9CiNcRw1zvLtmWEatMBq+t1W3+a+ww6Sj30CtNBrsO+aXd981xcG7
zwRqldEwWHp+/Nnfxrjr641qNYyG0xr9M9mqxki9+0pGvSEaVuzd9OnWMmOs
/CICdXE0TLXNKqhPsMFg+VMC9e5o+HHgdGbMSlP8brq7Wp0UA88vngn1dzRF
vlylzCT1GOjS2qV5drUpypkehEn0GCDfX6y644kpFvuuE0xixMC0rh909Wdm
yMyYVz0JYqB+U7np6eMWeGtKgYxGeAwcEH/ddcDeEqPTF4MGLwZmskq2ZwvM
8Ne6ZIFGdgz0VyzN1ZplgpuPBVRrCGNgUe0hv/M77VF1XbqMZmEMyA8Xtm7V
M8aT5aGgWRoDRc9/bIqNoeOU+0yBZmUMnJe9SJr/0BA/fjOu1sQY+P32/ITH
bDqmEMcVuSEGtrzhRAfNNcWRr5ZAFscA55EyZwHbBPcqaArI3TFwtK74+bM/
RuhoPlpFJsWC3jNPJ2NHY7wsryNDUY8F5zC2ocuoMYaayQGFHgtYcGbuilpT
bPXryKUwYqFqZdrPLX/McY7p+DsUiIX1+0f2X4wxx3F+vSRqeCyU/2neZvbC
GI9kfOBQebHwZpeTL7WWjuwNtbnU7Fj407NkxxR9MxSlf6mhCmOBP//ZjXF0
Osatf0LSKoyFS/ZL3Ids9LDv2DWOVmks/GOqvcR9jzZuf3AkV6syFg6SXx0Q
XtJFjWNVNVoYC0tvH9zbZELHM/dPkLQbYol5emLUOJmO/t93cLTFscBm6pFt
WQb4WXFVrnZ3LMiXGqdufG6A6d/21WiT4kCmaChi/IAh/msPOupxoLph9ufw
PzQ8aD6Ho0OPgwymd9A1bzq6+Efn6jDiYGBlWtryyzS8ZrawRgfi4HqhWeY/
awxw+tREkm54HES2bfb8VWeAHZlTObq8OPjyzi266aMubtzIyNXNjgOmQfen
DSa6OCEzpEZXSNS/bBfWzNPBYxvcSHqFcTC+oLK48og2ck7QOXqlcfAxeNel
nfr6+LZ2Qq5eZRzEOxX/2haij0nHzWv0MA6q2jfe/HnDEAcfqJP0G+Lgu6N4
LKHYEHf++OOtL46DjqYFvJ3naUh5QF2j3x0HyhefatsuN8DK76QafVI8rNh/
VnmRHR2DxrVL9NXjoeK9XueLo4b4zeKVtwE9HoxTX675pWaAfEXihGfEw3Nd
9+6uYAOUs3iHBhAPXbME67fW6uFh//sSg3DienJ78odQB5n8896GvHiY+rjm
ZYCjDt6a+jjPMDseJl85+Erruw5GZV1BQ2E8LDGqckkK1cPujSUSw8J4WLjp
5uDpJn3cXLHJm1YaD22d7j5Pduuj6sZjebTKeOhYwlgfeoWGFSe2Iw3j4f3s
zXKyDwxwSt1yCa0hHs6SN+1x+GiAH1vSvOnieAhrjRM23DREXq0gj94dDxnl
Voc7Xxni8I+ZSCclwC3rtNA+DRruVZohoasnwJCe6A75JA0ZVt7eRvQEIAc/
t5mM+nhpXHyeESMBvBrKp5KDDDDU0heNIAHujXaq6ZzVwdYAe4lReAJ01M7O
O12ljWtnansb8xIgR+3eabcX2qgY4JJnnJ0Anad9HatidPEI3xCNhQkwW3e8
cthHfWRtUpIYFybAetXH5y5908PXJ3u8TEoTYO6Pu5+iKw0xLl81z6QyAfbF
Dy00Bzr2VQyKTDABMu7tNv7yzhC3Pfw8ZtKQADvk8YhaqCFOqhjzMRUnwON5
j/ovvzHAM3UtQtPuBIgVnfe6Y26A/q0vRKakRAj070oQE/PwaXzVmKl6IrwN
tXfu/EDoo6XRx4yeCMd+0TxnqumhROmu0IyRCH1GX664l+jgASuC2CARrvzx
DXPx1EGXoH1jZuGJkHjOSyn7kBZes7zkY85LBLX5le8/B2nh9MDDQvPsRBg3
I27J+WZ9/Dlzo8hcmAhmXRt3+a0l9FGwYMy8MBG85k5afGarPk6YudXHojQR
pq2UrbuTrI/lm5YJLSoT4cPKB6WrVAyQcypFZIGJ4FFe5Tzxlh6+fRQ8ZtGQ
COlWPynDtgaYdDLLx1KcCOdUEg/QtfVw4GGE0LI7EQ4dOrRe394Ad7axRJak
JNB+tib7z3NdtFM2H7NUT4Kxbw3rM2bp4vlWHx8rehJUJStuPvCPFgZNsBVa
MZLgvdHIF0+WFn6zpoqsIAl265aZh7Gp+C/+WoUnQWtrL6nsgBbKWuv7WPOS
4MfCbKCc1MfDQYpC6+wkOJ4470vhZUIfs7urrYVJkPC4NL+hXg9vBk6UtSlM
gluif8IKVPUxatZvsClNgmOJRl8lvwh9FIgFNpVJkLjix5tJAfpYcPpRtQ0m
Qd+lIp9giiGqFHyXsW1IgsIfQoflNAOsONUAtuIk8L/QpLhhQAenPL4psO1O
gmWRh30WvtXFD+3l1bakZGiavY96OEwH/8VZO/VkcAkYzVozSQuH206BHT0Z
Ft7ZqaQ+TME9ynsEdoxkyF16+yMsoiDDVlBtB8kwo0pOdw1PCy9NKJKxD0+G
o12XaH/G62KozXqw5yXDBPPaqooMbWwJni+wz06GmADe/SnvdXHtnLhqe2Ey
3LC6cKl9kQ4qBi+RcShMhqHI4fX54bpYOpsLDqXJkFfd+U67XxdZWwIFDpXJ
MO/U5w/BPoQ+zjgTlJ0Mqn7H9qqSdTFuc5gMoyEZsmfLp+QWaWPvaQ9giJMh
+VfAa+FmHdxWbyJgdCfDQcpq4dwXVLTqUKlmkLhQP8dr99MnFDz92ErGUZ0L
3saDgW0+ZJz6UxMc6VxwOj9vz/F/NPHTxLFcRwYXsi7AgcjpVFz57wd+wIW3
PIqyW4U2jinLyziFcyE6Zk50ezEVD9h2cpx4XNi3y6SL8Y2KLtMac52yuZD5
/Wv1x8lUvGrTV+Mk5IKdr9/mHUe1MCLkI8m5kAudO0arBI7a+HNOHce5lAtt
ksLw8nNU3LD1Yq5zJRf6m501z/hQcPycpzVE6ofEsPqa2zJkLN9yneTSwAWG
r/JV6wAycs6WcVzEXHhsWRRhTLze9GRLrks3FwTz83cFBpPRPvolT5fEg70t
4X1NqRRcmRko1FXiwcy2zCkHLlDx4dLqEl11HpjNCxkqHKeF1I3OIl1tHsw5
WZ+/ejsZY5bWiHXpPAhkN7yfv4Is9S9LHhyMqDn1BSnYs/c0TY/Bg8PNEjE8
0pL6GZMHRePjn3bkaGHe3nM8PeDB8dYMo0YbLXx63ESoF8CDqyfOzh5dT0X9
a/tL9MJ5cGOJbNPIeArOrFUR6cXyIGe1uejlcTKeulok1uPxoOb6u6Xe98hS
/+PzYB/lgmFXAgX93qyn6WfzQFFomNvWQ5b6YQ4PxJNSFgUBGV++zufpC3lw
ccbN2QNnyWj0Y1Sgn8+DWU85zIkdFJz37weshTxY/aPDei1HS+qX+3nwdV6T
WG2YiqO/l4j1S3mw+Ziajm8fReqfFTzQanbr/sak4n4tHs2gkgfTIOjO4ssU
bFLsBIPrPEgOSnm27hIFLbTSeAZI3G8G5VRdExUXWzQKDOp4cHndraNQoYU1
7tNKDBp4hP5G9PPTKVK/beSBT96fwP2BZAx3DxcbiHnQZjsu+4omWeq/LTyY
G4SvhhLI2B7jSTPs5sGOTsaFmxMoaOtfB4aDRP/0jnjw11JweYwXz5CUAtcL
XpIlXylYm3VRYKiUAsd+fDqaEUpFco5FiaF6CtxUWu4ySOzH//xaOwVq93IV
YoaoeHSZtdiQngKVHmlXJW+oUv+2TIHXvlnlXY8o6LWfTKMxUuD+/YfZJl7E
+bixDGjMFDhcv8dVGKKF9fuIDYIUqKrvuHS1jYK6FVsEtADi+i+zje/vJ2PW
dZkSWngKLLy1Y7naUU2p38emwLYmtlHOmAb+viYvpvFSIKtC65X+K02p//NT
oPzyo8B6QyquuzbOiJ6dAh6h1hNbtlPxRe0qoOekgMabVu21QEVa4y8uXZgC
deASvGcJBee0ZAro+SlACXS4tmETFc+96SulF6ZAcGjFi0YPLSkv7E8B3wsx
uLCbggGDH5vppSlgsYOPjxZTpPxQkQIuHmt/rnhIwTcDn+hGlSlQJHdmDvsl
Bc2UYsDoegow5ZS8XphQcKF2PdcIU2A594vO4o1kFFn6CIzqUgCXjYReIfQl
o/2s1KghBRwk8mG755GlvNGYApPuqc1WO0TGIuaNZiNxCog3pdfNdaRK+aMl
BXZh0ciWdxS0Zt6mG3engCr56lKnxxRcFuAIxoMpEH59wsXtaVS8H3uca0xK
haNzE7x86VqoMVNPYKyUCo/Vwup9FlAxMvZkqbF6Kmhf1O3wUKJKeUU7FX4n
6QatjKJgZ86uZmN6KvRMC55+uJki5RfLVNAfOOYgIOZ9dc5eugkjFaISBjY/
8qbgo3xlMGGmgmyjkaxvARm1Dwi5JpAKwS/drRs/aGLGyf5ck4BUuLlfvT3a
hYzH968tNQlPhfbW7RNLbShS3olNhazlij3JZyjoc2NuswkvFXSen3om3kXB
f79eYMpPhX67jJ5x9lRsuJ5NN81OhV+6iw7n76OiwcNvHNOcVAg4XUN+t5eK
s5riuabCVHiw7nZl3z9UKR/lp8LP2efHJLspONSYVGpamAoXwzrvz02iSHlp
fyqIazgPaylU3D3k32xamgovB5JmLz9EwVctr0hmFanw1nT5G7/JFDQZCqKb
VabC3U0Dnyf+IGP2eOSYXU+FvM7tCjOoZKzSceWaIXG9hdaHNOLIUr6qS4WG
Ly2LumIpGKLDLDVrSIWglNkrpgVTpLzVmAqvv3yIMiLm+4eHcbOZOBVMYrcF
Wz6koqVVJcm8JRXecWZMIMlTcYmHGd28OxUE/Oz20plUvBt4kGM+mApnDa6O
mbdTUD1ejWtOSoOCkVMrIr9TpHymlAYWFoeXnZChYkmcRqm5ehqkvrC2XqBI
lfKadhrcf/3wwFN9KnquGPloTk8D5hyVlb2zCP+YWUCysEyD77yY7XWzyPiv
HC0YaRCn6K3bTfgDtWAxx4KZBreXmVsnSQj/WC6bYgFpcIsVORpTQJHyXUAa
bJEsUzj5D+EfB36WWISnQXlG7ihFgSrlvdg0UOiIOR6ZTEXhgS6xBS8NSlZZ
nTA5RMWnJ9NJlvw0WDGVfefmDyrq3WyiWWanweNl615ofKAg/1EoxzInDZp0
PbycTKl46sZ7nqUwDVZPvK2yQY0q5cP8NPAo/iAJfU34x9sHJZaFaTDLXiHt
Rg5Fyov706C4judQUU/Gf5oeii1L0yBKZV5eqi7hH23eJKuKNPgCES1ufZo4
788lmlVlGmxuU08bPUjGWxOsOFbX04D2pCKgcj0FR4eu8qwwDcJmWibuWUGV
8mVdGryf+W7FjXIq7tM9UmLVkAYGxdcjuyooUt5sTCP4756L83kKmuuWi63E
acB7HGCbSPRzkbUOybolDSadWO/kSfh1jec2mnV3Gri/GQ73/0RB1WA5jvVg
GpzfnKR4z4uC4Z47eNakdJDjiLddriBL+VQpHXptWftXE+tti19ZYq2eDo2z
X1T9E0pG26DxNdba6ZDSseZaRY0mLo/PFVvT04HBWhbsfUITH8zqlVhbpoOg
lL0/Y1gTySv5NBtGOkjUfRySSylSnmWmg4Pvw3Nrz1OxbMVsng2kQ/whKEx/
RpXybUA6nBAeemw4jopeRVElNuHp0MDkXo3YRMHcgi9oE5sO/U37NqVuJmP9
wVixDS8d1NR93TZ1kFHn9BOJDT8dFreJgsz+kDHz1mSabXY6nBEEnb/wiyzl
4Zx0+D0zPseHOH/6b/rxbIXp4PrHYKPefLKUj/PTQf5J6MDWY2QsfOdQYluY
Dkda98XnyFPw+aMqtN2fDtY/7yoqENejvXMS25amQ6Z16vp4RcI/2k9IbCvS
YdXvjasWNpPxxrA+za4yHR7wdWaeJPjkfzx9PR3I/dob5veTMWCYxrPDdHj4
1ow2ceA/vq5Lh+0uQflTJmrhF70JJXYN6dD6xXtPj6EWmirvR7vGdKB//qfu
2TwqLtBTEduJ06EtQXb0Bp2CIps1EruWdHATkNZcIfxzInvA0L47HYaOtFi+
JPT3Px4fTIdhRuLqwumEf7D+cO1JGUBv+84sSyJL+VwpA+pvZywrKiejNWu0
1F49A77M6zVqcyH8I3gh2mtngO7BPvUrgVS8l/Cj2Z6eATa7OcvX6VFRY06i
xN4yA1b9sgtz8CH8I6GN7sDIgJbNg5QKQm//43lmBihY6DneJvJE58qXXAfI
AOrhzGvxk6hSvg/IgIHjDOWXBA+sWvmm1CE8A3ySQGmwkfCPzSHoEJsBxafL
MciJglqHapodeBlAOpt+Z6kbBdPPuEkc+MT6C7bfN3Gk4PGie3RGdgZYD965
bqFAkeaBnAy4OPvWiSBnMvrcPsdlCDMg3qwx7OtSsjQf5GeAlWLgYyNtCj67
daGUUZgB3psjfgdlUtCg3hwZ+zOg4JpK14pICs56X9TMKM2AOsOMHxmyVLz2
U13CqMiAoXz+Xp1CKg69K6Y7VhL7MW7Z8WB1qjRPXM+AOwe3GDvtpOCukXyu
I2bA3QvHxdNVqNJ8UZcBHcMXU1cR+2M8srnUsSEDmou/p1OPUXD+RBl0bMyA
GVeXtewj5rtKf2mzozgDNLctrbReSJbmj5YMiBlv80jiS8YQ/eV0p+4McFTe
o5WQTJbmkcEMcN0dP9crh4zf2WlcJ1Im+I0l6kvukNHS9pfQSSkTkr9GZ91c
RcEl7MxSJ/VMmH98xdFL96l4J+SdyEk7ExIWRGXmEXlEPSm82YmeCWU/8/eC
FkWaXywzYcA9373wBhmLEyPpzoxM0Fk+PzEJKNI8w8yEJ/Evv58l/MljtRfX
GTLhskJlsU48BVfMeSx0DsiEwd6jI9ZPCf9YBaXO4Zng2prWw3EgI2XrFZFz
bCbU9sZ/V9mviamHrZudeZmwJOfirZXpmtL8w8+ELTO9hMd3a+KvQ3Z0l+xM
CMsKX7bokqY0D+Vkwo1xMs0GD8i4pUqL6yLMBBeWRjdqUPHJmWNCl/xM2Pz8
qFHEZsI/qnRLXQozoW3+9z2T7hP+8WS7yGV/JkS3no+sd6XglQ/yzS6lmfCo
b0Xh23NkHKjfSXKtyISTe8NOL5GloO+HcXTXykxYhS9erkym4I6OVRzX68T1
pgWMW/6B8I/3E1JcMROSRu8rPPlNRnqHQOhalwkTB24+j99ExrmjfSWuDZlw
W2n6O5EK4R8qs0SujZlg3dl4qYqY35GRAbGrOBM0GUYfr/HIGKQyl+TWkgn6
9dFF+QQf7jP4THPrzoRp1TLPi4h889UuhuM2mAkNn2bLfwwk/MPgG8+NlAVN
j6efe1JO+IddvNBNKQvkJkbf6SL4B72elbipZ8HStLYSVQYVVUN9RW7aWbDn
d0ijKIuKYV4vxG70LABWVbVtNhUPTfMnuVtmwbzb49rGv6RiW9JtmjsjCxTL
Jn4w2E1F93mOHHdmFkgExZ1BaUT+SBLx3CELQqsNqmp1KPhgrovQPSALluUE
fRDGklEz92SJe3gWXL81+THnoiambDMUucdmwZvCoymLr2li2eozYndeFugF
ZJyx2EbGrq1GJCY/CzgzRhp7+UT+KN5LY2ZnwbrLs7Q2E/0rOKfMYeZkQciC
4znvb1Hx8eEDPKYwC65oWHgeIfKIzjlVITM/C74lMS3NXlEws3ptCbMwC4QV
67dbEP566elgNXN/FrwO3FnOvUDB/qoNYmZpFvRrLhrR+0HByU+HJcyKLJia
fPFgBFJx+8dsmkdlFnh71JVlEXnj+ZMx8LieBePWHNu0aikFDT8u4nlgFnTe
f/RVi5iXOZ0tAo+6LPByHtA6cJnwj7GkEo+GLChxs/SkfCTjn4529GjMAtu2
/d9XTCTyxxhP7CHOgmvlc05anib8Q/W1xKMlC7RtvdLNnlDws2EwzbM7Cy7/
9H7mQejNVLUJPAezYHXpxPfr9bRwgWEoz5PEB0XK5fe6RJ6ttr8r8FTiw/i9
I8eEBA9N5DBLPNX5MM1aae/uMgpOs3+Antp8UPqcP1v/FBUPerPEnnQ+QPPu
Kn+Cv1pCKyWelnxwjEsukyP2g6BbGovBh0/cs3NNWIR/hF4CFpMP7U4vpr9F
Mt5LtuSxgA+UHcxdZnvJOGn+YQErgA/Xr4sniWrJyBVolLDC+aBccTJ7hNiv
0nmlyIrlw8NVbbmWylTsyKWIWTw+vB0/POXcNsI/thdIWHw+fJt3TEv1BhXz
iTjKzubD8dN6dn7BVHy4bSuwc/hQW1e03ZbIS1olsjy2kA+uIVdytI2omH5+
mYCdzwf5B7bXawn+OlascIRdyIfY5c/MqXQq9p5bgez9fHh5NTf6X78BUVcz
u5QPopzZwTn7KLj1WbqEXcEH2ftVoc8J3nlW3UP3quTDMaX4M/cJ/9F/RvT2
Oh+mGrOWOpeRcda/X/hBPth98a0w2UPGa10RAq86PlSy7wDXk4JEvCz1auDD
1Zr0ZrdWCk7tmoFejXxQsVpbr+JOxV2Sh81eYj40HspYtn4+Ff/9uNyrhQ/x
G5+/XV5BRWNJPd27mw8+67vzRq4S/qE2GbwHif0MHHm9l+CN27RrXG/STDic
+GHitgUU/D/hx/aB
        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means and Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968664508*^9},ExpressionUUID->"c9348508-be46-4f3e-a55b-\
57ebfa157d4a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Starting run \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\". Reading data from \"\>", "\[InvisibleSpace]", 
   "dir"}],
  SequenceForm["Starting run ", 1, ". Reading data from ", $CellContext`dir],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599687315607`*^9},ExpressionUUID->"a0444ee4-1760-4f7f-953d-\
0f716c5dd40f"],

Cell[BoxData["\<\"Preparing to read means input table\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599687335625`*^9},ExpressionUUID->"8a2b5d10-0dd4-4b18-aee1-\
83b4e8d313b8"],

Cell[BoxData["\<\"Preparing to read variance input table\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968735564*^9},ExpressionUUID->"4742afd5-52ab-4d59-b7da-\
2977689f780f"],

Cell[BoxData["\<\"Preparing to create field data tables.\"\>"], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968737565*^9},ExpressionUUID->"fb70b2a5-bd32-44c6-8192-\
8804a57b836c"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-15.98223042610117, 0.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599687806077`*^9},ExpressionUUID->"a59a02a5-cb3b-4e97-b863-\
35c264c33ff2"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -76.14742169746623},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-75.04615102694436, -6.767369454589756}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-73.68272297580947, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-71.38013788281542, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968844619*^9},ExpressionUUID->"2aa9cb9e-6ed7-4a4d-b3a5-\
37007160401c"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599688756466`*^9},ExpressionUUID->"479f4c36-e420-4a4e-b634-\
c0396ce2578b"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[{{0.5, -20.58731462444898}, {0.75, -18.879687777989233`}, {
      1., -22.708201886132294`}, {1.25, -27.50184105161661}}], 
     LineBox[{{4.249998, -23.11696430864725}, {
      4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
     LineBox[{{6.750008, -23.038818749837983`}, {
      7.000009, -20.322035683613738`}}], 
     LineBox[{{7.750011, -20.716014193782303`}, {
      8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
     LineBox[{{11.250025, -19.142376381324734`}, {
      11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
      12.000028, -22.492142720939622`}}], 
     LineBox[{{12.50003, -24.045787259895636`}, {
      12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
     LineBox[{{13.750034, -21.052099541576304`}, {
      14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
      14.500037, -21.409428863587927`}}], 
     LineBox[{{15.500041, -21.61333098548902}, {
      15.750042, -22.10549208407436}}], 
     LineBox[{{17.250023, -22.856107311471863`}, {
      17.500019, -22.566864012429928`}}], 
     LineBox[{{18.000011, -21.834193448858855`}, {
      18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
      18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
     LineBox[{{19.499989, -22.216470803381476`}, {
      19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
     LineBox[{{20.499973, -28.088099516986762`}, {
      20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
      21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
      21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
     LineBox[{{22.999935, -19.74888960999384}, {
      23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
     LineBox[{{28.749847, -22.783129874707647`}, {
      28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
     LineBox[{{30.999813, -24.728294878757325`}, {
      31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
     LineBox[{{32.249794, -20.837058021652666`}, {
      32.49979, -21.361849645654928`}}], 
     LineBox[{{32.999783, -20.84333950660284}, {
      33.249779, -18.469001093501973`}}], 
     LineBox[{{34.999752, -25.06864583779922}, {
      35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
      35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
     LineBox[{{38.499699, -24.377795653123645`}, {
      38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
     LineBox[{{39.74968, -22.650120892941615`}, {
      39.999676, -22.80728905851026}}], 
     LineBox[{{43.749619, -22.041875381710568`}, {
      43.999615, -22.423199188672683`}}], 
     LineBox[{{47.499561, -21.287037875136214`}, {
      47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
     LineBox[{{49.999523, -27.91448197690941}, {
      50.249519, -27.305559271827388`}}], 
     LineBox[{{51.999493, -20.885769001862567`}, {
      52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
     LineBox[{{52.999477, -22.174453342075132`}, {
      53.249474, -24.83933405846568}}], 
     LineBox[{{54.249458, -23.722525323809897`}, {
      54.499454, -23.580299515887834`}}], 
     LineBox[{{56.499424, -21.766646750655234`}, {
      56.74942, -23.57640470224996}}], 
     LineBox[{{58.249397, -23.599923997532017`}, {
      58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
     LineBox[{{59.249382, -17.837453345617426`}, {
      59.499378, -21.77661789863478}}], 
     LineBox[{{59.999371, -21.620808909572247`}, {
      60.249367, -21.022793121071274`}}], 
     LineBox[{{61.749344, -23.521435622331904`}, {
      61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
      62.499332, -19.42225543656815}}], 
     LineBox[{{63.499317, -20.822384760816565`}, {
      63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
     LineBox[{{64.499344, -25.343231741743004`}, {
      64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
      65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
     LineBox[{{68.249573, -26.50222788848888}, {
      68.499588, -26.988563201691523`}}], 
     LineBox[{{70.749725, -20.1140901131646}, {
      70.999741, -20.81539559964317}}], 
     LineBox[{{72.249817, -27.41004150424379}, {
      72.499832, -25.260157006181224`}}], 
     LineBox[{{72.999863, -23.234537488989123`}, {
      73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
      73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
     LineBox[{{75.25, -25.575903773461626`}, {
      75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
      76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
      76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
      77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
      77.500137, -21.438588076795124`}}], 
     LineBox[{{78.000168, -22.06377454291717}, {
      78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-30.753802173434874`, -2.5595472252881692`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359968941392*^9},ExpressionUUID->"db79a653-5c9a-470d-97b4-\
6a430ac07117"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
     1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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      "]]}}, {}, {}, {{}, {}}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -30.303766533418063`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 200.007614}, {-29.898127463585265`, -4.74850513395212}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359969009948*^9},ExpressionUUID->"65c4da96-dac3-4274-a275-\
c6c9c1d6f692"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[{{0.5, -20.58731462444898}, {
       0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
       1.25, -27.50184105161661}}], 
      LineBox[{{4.249998, -23.11696430864725}, {
       4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
      LineBox[{{6.750008, -23.038818749837983`}, {
       7.000009, -20.322035683613738`}}], 
      LineBox[{{7.750011, -20.716014193782303`}, {
       8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
      LineBox[{{11.250025, -19.142376381324734`}, {
       11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
       12.000028, -22.492142720939622`}}], 
      LineBox[{{12.50003, -24.045787259895636`}, {
       12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
      LineBox[{{13.750034, -21.052099541576304`}, {
       14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
       14.500037, -21.409428863587927`}}], 
      LineBox[{{15.500041, -21.61333098548902}, {
       15.750042, -22.10549208407436}}], 
      LineBox[{{17.250023, -22.856107311471863`}, {
       17.500019, -22.566864012429928`}}], 
      LineBox[{{18.000011, -21.834193448858855`}, {
       18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
       18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
      LineBox[{{19.499989, -22.216470803381476`}, {
       19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
      LineBox[{{20.499973, -28.088099516986762`}, {
       20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
       21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
       21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
      LineBox[{{22.999935, -19.74888960999384}, {
       23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
      LineBox[{{28.749847, -22.783129874707647`}, {
       28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
      LineBox[{{30.999813, -24.728294878757325`}, {
       31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
      LineBox[{{32.249794, -20.837058021652666`}, {
       32.49979, -21.361849645654928`}}], 
      LineBox[{{32.999783, -20.84333950660284}, {
       33.249779, -18.469001093501973`}}], 
      LineBox[{{34.999752, -25.06864583779922}, {
       35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
       35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
      LineBox[{{38.499699, -24.377795653123645`}, {
       38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
      LineBox[{{39.74968, -22.650120892941615`}, {
       39.999676, -22.80728905851026}}], 
      LineBox[{{43.749619, -22.041875381710568`}, {
       43.999615, -22.423199188672683`}}], 
      LineBox[{{47.499561, -21.287037875136214`}, {
       47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
      LineBox[{{49.999523, -27.91448197690941}, {
       50.249519, -27.305559271827388`}}], 
      LineBox[{{51.999493, -20.885769001862567`}, {
       52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
      LineBox[{{52.999477, -22.174453342075132`}, {
       53.249474, -24.83933405846568}}], 
      LineBox[{{54.249458, -23.722525323809897`}, {
       54.499454, -23.580299515887834`}}], 
      LineBox[{{56.499424, -21.766646750655234`}, {
       56.74942, -23.57640470224996}}], 
      LineBox[{{58.249397, -23.599923997532017`}, {
       58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
      LineBox[{{59.249382, -17.837453345617426`}, {
       59.499378, -21.77661789863478}}], 
      LineBox[{{59.999371, -21.620808909572247`}, {
       60.249367, -21.022793121071274`}}], 
      LineBox[{{61.749344, -23.521435622331904`}, {
       61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
       62.499332, -19.42225543656815}}], 
      LineBox[{{63.499317, -20.822384760816565`}, {
       63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
      LineBox[{{64.499344, -25.343231741743004`}, {
       64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
       65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
      LineBox[{{68.249573, -26.50222788848888}, {
       68.499588, -26.988563201691523`}}], 
      LineBox[{{70.749725, -20.1140901131646}, {
       70.999741, -20.81539559964317}}], 
      LineBox[{{72.249817, -27.41004150424379}, {
       72.499832, -25.260157006181224`}}], 
      LineBox[{{72.999863, -23.234537488989123`}, {
       73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
       73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
      LineBox[{{75.25, -25.575903773461626`}, {
       75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
       76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
       76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
       77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
       77.500137, -21.438588076795124`}}], 
      LineBox[{{78.000168, -22.06377454291717}, {
       78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs
YIGKij4GWMwmJCQEJPa7n+8ef/zD67wG933tOudzfd6fezNKnT89Q5ZEIhnJ
kUj//v77s+Ogfc/gJjZKqwbOWUWTir7/r8Uc/qGHrcfm/q1bOEcUOuPu8P7W
3Zw8peNnSvz/1n0cZ3/r+rvmf+tBTuAC8at3WmzsX1/YOyYZ5hz4VhSpo/S3
lnBs775RXqjAxj+T65ZLJDLwLm92diT1by0HYatDYJz5379XgBtzz3EzQ//W
4yBKlh/anPG3Hg9mk1S9y5b+rZWhqks9PH0dG7vqYueOSVTgwo19206t/1ur
wX1+ZZKC4O/91EElsSe1fzkbVxt9vS2RTIK7c+pNxZF/348mrI1q7T7uxca1
H/WmkEhk2Lm8tY5vx0bFKvcNJBIFUs5nCHpU2bipKPIhiUSF+pZBx8cjLFRe
MX+iDEkLanbpsQvk2bgtdnOYDEkb9gpLho112DjJ/cROGZIO1F7Y0zWPwcbd
lLuvZEi64Dra3tQxjY1afR+1ZUl6sOj5xqeHE9l48MWfBFmSPliqW5y7m8dG
/QvUElmSATgeXaz0ff3f2hCm2FacHdvKxpLtTp9lSTRYvs1q+enVf+9HB/1v
q+75LmDjdHPXyzJCOoRV/7FOjfp7fyMwPn3xWLsjG1/JRwzICI3g5poPDz5Z
/V2PMUTqTny5VYONsV/meMoKjcGX9KL/tfzf9ZlA7bd/kj8S/X1Xk79aVmgC
J5kJa95T/67PFGyW3/lzn7h+cmk5ygpN4ShrU0NmyN/1moHl41kTm9LZ+CkX
5eSEZnAwqb4wmFi/8bxQMzmSOdCPNETVbmBjetL7qXJCc7ihqCivvouNx0Jm
8eVIFvBTIip/uYKN31mDm+SEFtB+bDEvJIuNljYbTsuRLMGqyfqiPtHfmbrk
J3JCSzjhfm3PE3s2nh5f1ilHsgKxi3Bytx4bfw46qMsLrYAjbxW5Sua/mmQN
g1c9AsyHWWjXUuUoL7SG4ri9d7OJev6b4Eh5kg241F/5skibjZUPmhbLC20g
Z0tzRpIDG3uuZO2VJ9kCuXt68nqin87H+q/JC23hTsLUwWmE3pbsXtskT7KD
31OF7b+Jeb66dtKwvNAObgV/aWMR+hxYWKKvQLKHVQfWh6gWsNEj1c5bQWgP
zedPz3FaxcYVEbe4CiQH8ExXsXmUzMbbEJinIHQAYfGN4DG///abxIDPtvSp
4Yz/+gMMyNTdMLmW8refDPgekPZGMMTCpSNaSrLIgPn2D7u+fmJhr8HIPRmS
I0S2NBf2dLIwmyPOkwFHCA9dH7mL0Gsn7563jNARNFnfLALd2Th7TcUwCR1h
bhGHaRXLxpajW66TSE5wLrdcdXTuf/oBJ3hdA39mrf1PX0InCMpYGfx2xX/6
QyeYHJBXKV75V59OcOjlo87O+f/pl+MMBw/IHrSNY6N24iJ/icAZ5kZHxha4
sXHP6hh5icgZbi7ZcW438X41Slg1YxJnYO2hLQwi5rUQabljHBcYONMz4xrx
flQ+y7HGBC4QY8a3HHrFwgK5loFRkQtUvnv948UPFlbo77o/KnGBKys/q7kT
ejDzXrZmlOMK59d3T7IwYmMZN4EzKnCFHS+LL1EC2EjL44yMiFxB3bPO4cMs
Nh4qM7kxInGFg3VyBpU5bLx56+mGEY4bTGOT/xER++H+4eKUEYEbqEs8qhcS
/b8ytpc0InKDYd1oNdN4NjrRV1YNS9xgsRIlJC6Qjed9uCuGOe5w6atP11dL
Nj6JnxAwLHAHvSeneM+JOmhVp/ywyB22D7/JOtTCwtrDL2r+SNxB06XhrXsV
C31FV3P/cJhQvy3sxNJ9LKwRH2T9ETBhqvnzw5TrLOTICgaHRExIktnwtILY
v0Q96wdDEiZwyD6b/yHm+y1bde0QxwPsB1l3Con+xyT3cIYEHrCXNy+SSpxf
LwWvRwZFHjD09t6fjnA2Rhy5eWNQ4gG1RfMPXk5h4/ybGRsHOZ6wNvz8nfFz
CH29C/QdFHjCHoHgqjrx+sxRO5lBkSd0GJdP5jEJPRtqVA9IPGGK05nY8j8s
TIffKwY4LBhp629pNSDOi5S37gMCFsyco7NW6yQLJSvWKwyIWFDuiBaZXBau
OjTzzm8JC+7sfNb21JqFQ1XTBL85bGi8Om34+Rxi3psd2b8FbMi39SzgE++n
l0Qd6hexIU77egwS59kk3ZoH/RI23ItdljGtl4XbWMfW9nO8wObQ+LR5amxU
TtoE/QIv+N25b8pOF8IPcueO9om84IYsN8mO6L9iacTNPokXrLBz3WkiZKPp
jZGNfRxvINUFC78Rfnbkrdi3T+AN4VeoLRqubDQk5NYn8oayFRkPzp1lYZHB
yepeiTdEZazyuj+BmHfO1pW9HA7o3k1Ur6GxcA9vAbNXwAED895Ot0ueeGm5
vmKviAPJG5oyFy31xIUF2772SDiwxtSN+/qPp7RfNIC4kXcznp1hIWV+uuEQ
B0DgMHV0u9p//eMCwK3tg+IGFqZNPPNlUACg2h9huLWfhUYGhncGSwC2a4zt
fTSDjWK7wtJBEcBawf7Wwo3Eee5NDFAzgFOygbEaoceksMVJgxIAvyDycRJx
vurziBOa5gPXTp8aWUP4++mft4wHOT5wJoy/ZyubJe0/1wemZMpW1O5moaVq
afOAwAdWmkpoKr6e0nko8YGOkVmjenUeeMxh3aEBkQ+Ya3QKtmzxQJfbcWsH
mn2AYvLc5/1mT+ytf5wyIPGBaMvaUI8yT7zwwQsGaJNBfapD7rxgNmZ3njcc
4EyGKzuUq2xobLSXGI3+5k6G39fhQRDRv6rNA19+CyZD07fmhUmT2dJ5KpkM
HLnxtwrnstDz7LvS36LJYCm6tj1zzFM6X82TIepyQppMmydefypK+i2ZDMkP
1ySrnv9v3mhT4OWI4quk+56oMGecyW/OFFBaaq/YkueJ91Ytl/nNnQKvx/P9
4xw9cM3W9uZ+wRSoWbVF0eMqE32Kk6r7S6bAJ4lpYsgWJkrOPTvUL5oCUS/8
Ds/z8ZTOZ/MUeObe1SbM8sBpIVqp/ZIpUPz5Znlxo6d0Xmm+0Ow9q/zQfRY+
mjts2M/xhSfXPKcs9WFJ55frC4qqfrmrEj3Rf3vzuz6BLyw28lvm1OqBr/Wu
3Okr8YXP94dONtV44B5biyN9Il9IWbVMy/iwB0Z6HRD0NfvCnBe8iqVynqgR
qpzcJ/EFs4jFFmZbPLEheTW7j+YHrx9cvbLL1AO57dNN+jh+8GtsTkDBBKZ0
/rl+4H5hl7z6bnf8MNFd3Cvwg6UDqXlpBe5SPZT4wYAXo0JnrSfG2+sd7hX5
QW5Y3z8VoUxsvdm9trfZDwwTGvekdjDxxOPU1F6JH8wfDTpoFeWBme9fQi9t
KhxMydvfR/ZA046ptF7OVDgZ6yfY/ZqJX0avj/Zwp4LZxYQDXj+ZWKZq875H
MBWsVu3UWkfyQEYR6W5PyVSYsGd2w+9iJnadXnikRzQVAvKcK/dlM/Hc7a+C
nuap0DZNvjqizxPnPIlO7pFMBX7uCasvNe5o87GO3UPzh3057qaG793w5qxi
kx6OP1zdWTH3wlw3zFmpLtvD9Yc1UVee++90Q/cta8S/BP6QrvrgshOhz/5D
fdW/SvzhSanfRrll7nj5bObhXyJ/6M45/ipK6I6LqhtX/mr2h4dUtxk7zrmj
bPC51F8Sf3DeoWehf9sdMYHu84sWAAVOO+PG1JgomLOT9osTANabBh7m1THR
a7X8WDc3AHrVTsylanvgyNal77sFAaDRfVqoocHEzbohd7tLAuB2tYb1I7o7
BtpUH+kWBUDJ2psvrWaxUInNEHY3B0B0dc/RnbPcsDakLLlbEgD0Xeafe0+7
4vokslc3LRBmDH37LRvgiuS2VpNuTiA0uIFF8hlX/IfAyW5uIJzjPO4us2Xi
DuWn4i5BIPCKhq2p49wxXB9EXSWBYIpnS5y3uqGq3cXDXaJAMJfZx1S+6IZP
vExXdTUHgibjVssaW3dMfDSU2iUJhIQ/JVdr1jNR991sny5aEGRQ3z15TPB9
U/sHWhcnCF7uuKf39SEL94+EjXVyg6C1PGPt/SQmRqvced8pCIINYe0N9ya4
4bcD++52lgTBiDorIl+WieWnCIAUBcHsodvfvxm6YuqtlcLO5iDoEz7Kf7XS
BY3qO5I7JUFAyueR5M1dsPk916uTFgyjjQ9DXn92weKO53qdnGAoSTx07vEn
V7RbcUK2kxsM2d5yW59tccefBTqfOgTBsMx7IKje0w1PFW0WdZQEQ9g4axuz
zW4488zo4Q5RMPxq31O7MZKJFlXzV3U0B4Or7tnUzE1MvBrol9YhCYaLl6tf
ad9wwyXx13w6aCGgpv9hWG+vGzrPtqJ3cEJga19j/7WpntizsmjsJzcETMty
78+1dcXKLSoffgpCwPvZ4HWFBlfk6Hy5+7MkBE722C5OeO+MY1ZRZT9FIWB9
8pNMUogzVnnWCn82h0ClvpLfxAnOuDLYg/tTEgLb8+Y0zZvqgp6Jp71+0qaB
Ic+B72DvgoNzDPR/cqbB80ztq0VUJm4c6pH9yZ0GPycNZKTWu+PUCRmf2gXT
IKnhdnCA2BPl9d6I2kumwcxpe4fDF7jhXZvA4nbRNDBeJDTqlXHFNexbq9qb
p4GegpnslI0uqP6wMK1dMg26jB1Eo4tc8FmT7OR2WigsVV5XULPeFbe1Laa3
c0Lh7b3KlOPbXTBk+PtYGzcU3EiC92tVXFB5YtyHNkEo3LDuKOeVOuHB/fb3
2kpCwWd3Xe2QgRPGniwtaxOFwvC6VaPFvx1R66ZGXltzKKgVNQzpjzrjq0fr
uG2SUFiuIxhzfuaEu9/99mqjhUGVzQd3CwcXjPzJ12/jhIH+eEOFcR6u+DnH
W66NGwZqt3b3pm9ywdJNlZ9aBWFwoF1+2vQzzsg9aIytJWEQfGO5fFmYMxqc
3l3cKgoDv4Jjb8+7OuP7W4qrW5vDgL6pLe/ouP9qSRg0cJa2/xPnjAvYJTL9
auGQEzx+ZUWCy39+EA7TLvu/+Cp0wuOrFwn6HcKBlKuk2cV3lPoNJxyGDjUV
cn4xpP4UFg4tp13r6jsZmHw4DX5zw+FxgmFA6C4Xqf/ND4fjZhs2Rl91xN0f
3at/C8LhXXtjQ72LE1KrImUGtodD4Nuy0oytTlI/LgmHQ48cVR7HO2HImIVg
4Hw4/PS9Zrab6ST1e1E4gEFB8ZdZTlI+eBYOHRdi7IYLnFDeUBsGm4n1O+a2
Rmg4SfmjKxwcvE8HZdY4IjF9VYOScJjHL3u5PNIVb3spyQypRQBemdT/UtPx
Px6KgLWshb4bXBj4K/d97pBDBFRlfXk4tNUBCXqpGeJEwJfXIqOZHQ6olvuZ
9CcsArZYhLgV+bniqeJ6zh9uBHSXFo1vbmdI+Xp+BKiP2dYtf8uQ8reAeP3d
tsdr5Bwxtfo2aXh7BOQs3z171NgRRz4e5wyXRIBNzCfBzCJH3CcpzB0+HwFz
H7udeUXsj+7HMzXDoggQ+R+U1PY7SfPBswjgrXvGvFjqiGH/Bo7mCDB5sPJ+
fw4D2zizc0e6ImAXa2D+lgUuONdwY82IhFi/3E0v56UOOI6zgDSqNh1qKprG
POTtpfmFNh0iVGUmbQc79BL65Y46TIdT5Xaim5b2iMkpNaOc6bDmrOBFnZsj
xguCSWNh04GTE3tl4AAD+0tcOWPc6WCae/B2JYkhzVfzp4NjykPTH5YMaf4S
TIfXKn6Z0Q8YeFZkRpJsnw7Xo6bMiytzwgCxGkdSMh2ujasqLdvvgsTurpac
nw6vzLQuFe12xoxmSo1ENB2eL/QKCQtwkubDhulwhZGRrNVkj0X0Nm+SeDrs
O6fS+kjLEQ0lCmtI3dPhnPmdO/piW7xO6yb+JxKS9P8RaJXZYCS8lZDUI0Ey
PDy+d8Raml/pkTCv2j7c5KitNN8yIqE+sJrjZW6PyrxHKAORIJ8SJKrd64jH
hZclMuGRcHnBcbpctQPCkWJvWV4k3Pv0Y9tqfwbeFdzMk82OhAe33bs69Z3/
e94RCdVfkz+eUXTEIdwmkS2MhH7PUza3lzvgrk+E4Esj4f5KjudOPwek4u48
ucpI2PU0lengRuhDnItyxKpLxy/uVXCyw2CZmRK5hkjwe92zyI3o33ejSG95
cSTMalnmsinRGmeS5ufJd0dCuXFi41MfK5Q3ikN50gyYuZr6ZPIDSyz2mSKR
V58B7ywlL/fl2UifJ9BnwP2Y7kD6N2vp8wPGDHjddkRkP5eB0SnOqAAzwL8+
hBNu74y/8gwkCuEzQHd8eXvkYSfcUjbOW5E3A2btMG4/tdoe1fJM8hSzZ4Cv
4deaa6G2ePKICioKZ4Dck5+nNm+1Qd87A2OKhTNAtD7o0ZJUG6wt1Zw8rnQG
sO+7Z06zsUNi2oTjKmdAwdfDJjUatjjy6YdoHBL381+qqllkjftkX4yNa5gB
Bz/OMjn/1QJ1P3X4KIlnwJQw2oapn83xskyjUKl7Briv+HyMV2KOYcZ3REqk
KCA1O3B7DGywbfKZMSX1KLg7UWF6GFjiHKM6n/H0KOA7BFuu22KN4yZfFI5n
RMGsWWcmqFnaYlnqIdF4iIKVhj6rm6g2yF67YWx8eBS09qtF3Ku2QlFKmc8E
XhQcOnLGdtJkK4xfs0U4ITsKKuXnrVhgboX9ZUtFE4RRwJOorS+6Zonb7/LG
JhRGwY+BQfImMyvUKFvlo1waBcveLX72uc4Gz97JFCpXRsF+IZ0p3mmB/l/C
RcoYBaE/W0+tXGCG/z6uUG6IgunWOyf9Fphixudon4niKPBWCmUdyzdFkpyP
cGJ3FPS3tDfYjdriQRMb0URSNEzaeqbmvIE5uvpSxiaqR8Mli/qCDx/M8bqx
o48KPRp0Du7z1lhigdOn6AlVGNHQdjeo3c/eAjvSFEQqEA0fTG7teq1rgfnr
ukZVwqPhyy09waOTFqicpuyjyosGrRytkegeCyTSh0A1Oxpm7K54wn5rjlDe
XK0qjIb9CiNcRw1zvLtmWEatMBq+t1W3+a+ww6Sj30CtNBrsO+aXd981xcG7
zwRqldEwWHp+/Nnfxrjr641qNYyG0xr9M9mqxki9+0pGvSEaVuzd9OnWMmOs
/CICdXE0TLXNKqhPsMFg+VMC9e5o+HHgdGbMSlP8brq7Wp0UA88vngn1dzRF
vlylzCT1GOjS2qV5drUpypkehEn0GCDfX6y644kpFvuuE0xixMC0rh909Wdm
yMyYVz0JYqB+U7np6eMWeGtKgYxGeAwcEH/ddcDeEqPTF4MGLwZmskq2ZwvM
8Ne6ZIFGdgz0VyzN1ZplgpuPBVRrCGNgUe0hv/M77VF1XbqMZmEMyA8Xtm7V
M8aT5aGgWRoDRc9/bIqNoeOU+0yBZmUMnJe9SJr/0BA/fjOu1sQY+P32/ITH
bDqmEMcVuSEGtrzhRAfNNcWRr5ZAFscA55EyZwHbBPcqaArI3TFwtK74+bM/
RuhoPlpFJsWC3jNPJ2NHY7wsryNDUY8F5zC2ocuoMYaayQGFHgtYcGbuilpT
bPXryKUwYqFqZdrPLX/McY7p+DsUiIX1+0f2X4wxx3F+vSRqeCyU/2neZvbC
GI9kfOBQebHwZpeTL7WWjuwNtbnU7Fj407NkxxR9MxSlf6mhCmOBP//ZjXF0
Osatf0LSKoyFS/ZL3Ids9LDv2DWOVmks/GOqvcR9jzZuf3AkV6syFg6SXx0Q
XtJFjWNVNVoYC0tvH9zbZELHM/dPkLQbYol5emLUOJmO/t93cLTFscBm6pFt
WQb4WXFVrnZ3LMiXGqdufG6A6d/21WiT4kCmaChi/IAh/msPOupxoLph9ufw
PzQ8aD6Ho0OPgwymd9A1bzq6+Efn6jDiYGBlWtryyzS8ZrawRgfi4HqhWeY/
awxw+tREkm54HES2bfb8VWeAHZlTObq8OPjyzi266aMubtzIyNXNjgOmQfen
DSa6OCEzpEZXSNS/bBfWzNPBYxvcSHqFcTC+oLK48og2ck7QOXqlcfAxeNel
nfr6+LZ2Qq5eZRzEOxX/2haij0nHzWv0MA6q2jfe/HnDEAcfqJP0G+Lgu6N4
LKHYEHf++OOtL46DjqYFvJ3naUh5QF2j3x0HyhefatsuN8DK76QafVI8rNh/
VnmRHR2DxrVL9NXjoeK9XueLo4b4zeKVtwE9HoxTX675pWaAfEXihGfEw3Nd
9+6uYAOUs3iHBhAPXbME67fW6uFh//sSg3DienJ78odQB5n8896GvHiY+rjm
ZYCjDt6a+jjPMDseJl85+Erruw5GZV1BQ2E8LDGqckkK1cPujSUSw8J4WLjp
5uDpJn3cXLHJm1YaD22d7j5Pduuj6sZjebTKeOhYwlgfeoWGFSe2Iw3j4f3s
zXKyDwxwSt1yCa0hHs6SN+1x+GiAH1vSvOnieAhrjRM23DREXq0gj94dDxnl
Voc7Xxni8I+ZSCclwC3rtNA+DRruVZohoasnwJCe6A75JA0ZVt7eRvQEIAc/
t5mM+nhpXHyeESMBvBrKp5KDDDDU0heNIAHujXaq6ZzVwdYAe4lReAJ01M7O
O12ljWtnansb8xIgR+3eabcX2qgY4JJnnJ0Anad9HatidPEI3xCNhQkwW3e8
cthHfWRtUpIYFybAetXH5y5908PXJ3u8TEoTYO6Pu5+iKw0xLl81z6QyAfbF
Dy00Bzr2VQyKTDABMu7tNv7yzhC3Pfw8ZtKQADvk8YhaqCFOqhjzMRUnwON5
j/ovvzHAM3UtQtPuBIgVnfe6Y26A/q0vRKakRAj070oQE/PwaXzVmKl6IrwN
tXfu/EDoo6XRx4yeCMd+0TxnqumhROmu0IyRCH1GX664l+jgASuC2CARrvzx
DXPx1EGXoH1jZuGJkHjOSyn7kBZes7zkY85LBLX5le8/B2nh9MDDQvPsRBg3
I27J+WZ9/Dlzo8hcmAhmXRt3+a0l9FGwYMy8MBG85k5afGarPk6YudXHojQR
pq2UrbuTrI/lm5YJLSoT4cPKB6WrVAyQcypFZIGJ4FFe5Tzxlh6+fRQ8ZtGQ
COlWPynDtgaYdDLLx1KcCOdUEg/QtfVw4GGE0LI7EQ4dOrRe394Ad7axRJak
JNB+tib7z3NdtFM2H7NUT4Kxbw3rM2bp4vlWHx8rehJUJStuPvCPFgZNsBVa
MZLgvdHIF0+WFn6zpoqsIAl265aZh7Gp+C/+WoUnQWtrL6nsgBbKWuv7WPOS
4MfCbKCc1MfDQYpC6+wkOJ4470vhZUIfs7urrYVJkPC4NL+hXg9vBk6UtSlM
gluif8IKVPUxatZvsClNgmOJRl8lvwh9FIgFNpVJkLjix5tJAfpYcPpRtQ0m
Qd+lIp9giiGqFHyXsW1IgsIfQoflNAOsONUAtuIk8L/QpLhhQAenPL4psO1O
gmWRh30WvtXFD+3l1bakZGiavY96OEwH/8VZO/VkcAkYzVozSQuH206BHT0Z
Ft7ZqaQ+TME9ynsEdoxkyF16+yMsoiDDVlBtB8kwo0pOdw1PCy9NKJKxD0+G
o12XaH/G62KozXqw5yXDBPPaqooMbWwJni+wz06GmADe/SnvdXHtnLhqe2Ey
3LC6cKl9kQ4qBi+RcShMhqHI4fX54bpYOpsLDqXJkFfd+U67XxdZWwIFDpXJ
MO/U5w/BPoQ+zjgTlJ0Mqn7H9qqSdTFuc5gMoyEZsmfLp+QWaWPvaQ9giJMh
+VfAa+FmHdxWbyJgdCfDQcpq4dwXVLTqUKlmkLhQP8dr99MnFDz92ErGUZ0L
3saDgW0+ZJz6UxMc6VxwOj9vz/F/NPHTxLFcRwYXsi7AgcjpVFz57wd+wIW3
PIqyW4U2jinLyziFcyE6Zk50ezEVD9h2cpx4XNi3y6SL8Y2KLtMac52yuZD5
/Wv1x8lUvGrTV+Mk5IKdr9/mHUe1MCLkI8m5kAudO0arBI7a+HNOHce5lAtt
ksLw8nNU3LD1Yq5zJRf6m501z/hQcPycpzVE6ofEsPqa2zJkLN9yneTSwAWG
r/JV6wAycs6WcVzEXHhsWRRhTLze9GRLrks3FwTz83cFBpPRPvolT5fEg70t
4X1NqRRcmRko1FXiwcy2zCkHLlDx4dLqEl11HpjNCxkqHKeF1I3OIl1tHsw5
WZ+/ejsZY5bWiHXpPAhkN7yfv4Is9S9LHhyMqDn1BSnYs/c0TY/Bg8PNEjE8
0pL6GZMHRePjn3bkaGHe3nM8PeDB8dYMo0YbLXx63ESoF8CDqyfOzh5dT0X9
a/tL9MJ5cGOJbNPIeArOrFUR6cXyIGe1uejlcTKeulok1uPxoOb6u6Xe98hS
/+PzYB/lgmFXAgX93qyn6WfzQFFomNvWQ5b6YQ4PxJNSFgUBGV++zufpC3lw
ccbN2QNnyWj0Y1Sgn8+DWU85zIkdFJz37weshTxY/aPDei1HS+qX+3nwdV6T
WG2YiqO/l4j1S3mw+Ziajm8fReqfFTzQanbr/sak4n4tHs2gkgfTIOjO4ssU
bFLsBIPrPEgOSnm27hIFLbTSeAZI3G8G5VRdExUXWzQKDOp4cHndraNQoYU1
7tNKDBp4hP5G9PPTKVK/beSBT96fwP2BZAx3DxcbiHnQZjsu+4omWeq/LTyY
G4SvhhLI2B7jSTPs5sGOTsaFmxMoaOtfB4aDRP/0jnjw11JweYwXz5CUAtcL
XpIlXylYm3VRYKiUAsd+fDqaEUpFco5FiaF6CtxUWu4ySOzH//xaOwVq93IV
YoaoeHSZtdiQngKVHmlXJW+oUv+2TIHXvlnlXY8o6LWfTKMxUuD+/YfZJl7E
+bixDGjMFDhcv8dVGKKF9fuIDYIUqKrvuHS1jYK6FVsEtADi+i+zje/vJ2PW
dZkSWngKLLy1Y7naUU2p38emwLYmtlHOmAb+viYvpvFSIKtC65X+K02p//NT
oPzyo8B6QyquuzbOiJ6dAh6h1hNbtlPxRe0qoOekgMabVu21QEVa4y8uXZgC
deASvGcJBee0ZAro+SlACXS4tmETFc+96SulF6ZAcGjFi0YPLSkv7E8B3wsx
uLCbggGDH5vppSlgsYOPjxZTpPxQkQIuHmt/rnhIwTcDn+hGlSlQJHdmDvsl
Bc2UYsDoegow5ZS8XphQcKF2PdcIU2A594vO4o1kFFn6CIzqUgCXjYReIfQl
o/2s1KghBRwk8mG755GlvNGYApPuqc1WO0TGIuaNZiNxCog3pdfNdaRK+aMl
BXZh0ciWdxS0Zt6mG3engCr56lKnxxRcFuAIxoMpEH59wsXtaVS8H3uca0xK
haNzE7x86VqoMVNPYKyUCo/Vwup9FlAxMvZkqbF6Kmhf1O3wUKJKeUU7FX4n
6QatjKJgZ86uZmN6KvRMC55+uJki5RfLVNAfOOYgIOZ9dc5eugkjFaISBjY/
8qbgo3xlMGGmgmyjkaxvARm1Dwi5JpAKwS/drRs/aGLGyf5ck4BUuLlfvT3a
hYzH968tNQlPhfbW7RNLbShS3olNhazlij3JZyjoc2NuswkvFXSen3om3kXB
f79eYMpPhX67jJ5x9lRsuJ5NN81OhV+6iw7n76OiwcNvHNOcVAg4XUN+t5eK
s5riuabCVHiw7nZl3z9UKR/lp8LP2efHJLspONSYVGpamAoXwzrvz02iSHlp
fyqIazgPaylU3D3k32xamgovB5JmLz9EwVctr0hmFanw1nT5G7/JFDQZCqKb
VabC3U0Dnyf+IGP2eOSYXU+FvM7tCjOoZKzSceWaIXG9hdaHNOLIUr6qS4WG
Ly2LumIpGKLDLDVrSIWglNkrpgVTpLzVmAqvv3yIMiLm+4eHcbOZOBVMYrcF
Wz6koqVVJcm8JRXecWZMIMlTcYmHGd28OxUE/Oz20plUvBt4kGM+mApnDa6O
mbdTUD1ejWtOSoOCkVMrIr9TpHymlAYWFoeXnZChYkmcRqm5ehqkvrC2XqBI
lfKadhrcf/3wwFN9KnquGPloTk8D5hyVlb2zCP+YWUCysEyD77yY7XWzyPiv
HC0YaRCn6K3bTfgDtWAxx4KZBreXmVsnSQj/WC6bYgFpcIsVORpTQJHyXUAa
bJEsUzj5D+EfB36WWISnQXlG7ihFgSrlvdg0UOiIOR6ZTEXhgS6xBS8NSlZZ
nTA5RMWnJ9NJlvw0WDGVfefmDyrq3WyiWWanweNl615ofKAg/1EoxzInDZp0
PbycTKl46sZ7nqUwDVZPvK2yQY0q5cP8NPAo/iAJfU34x9sHJZaFaTDLXiHt
Rg5Fyov706C4judQUU/Gf5oeii1L0yBKZV5eqi7hH23eJKuKNPgCES1ufZo4
788lmlVlGmxuU08bPUjGWxOsOFbX04D2pCKgcj0FR4eu8qwwDcJmWibuWUGV
8mVdGryf+W7FjXIq7tM9UmLVkAYGxdcjuyooUt5sTCP4756L83kKmuuWi63E
acB7HGCbSPRzkbUOybolDSadWO/kSfh1jec2mnV3Gri/GQ73/0RB1WA5jvVg
GpzfnKR4z4uC4Z47eNakdJDjiLddriBL+VQpHXptWftXE+tti19ZYq2eDo2z
X1T9E0pG26DxNdba6ZDSseZaRY0mLo/PFVvT04HBWhbsfUITH8zqlVhbpoOg
lL0/Y1gTySv5NBtGOkjUfRySSylSnmWmg4Pvw3Nrz1OxbMVsng2kQ/whKEx/
RpXybUA6nBAeemw4jopeRVElNuHp0MDkXo3YRMHcgi9oE5sO/U37NqVuJmP9
wVixDS8d1NR93TZ1kFHn9BOJDT8dFreJgsz+kDHz1mSabXY6nBEEnb/wiyzl
4Zx0+D0zPseHOH/6b/rxbIXp4PrHYKPefLKUj/PTQf5J6MDWY2QsfOdQYluY
Dkda98XnyFPw+aMqtN2fDtY/7yoqENejvXMS25amQ6Z16vp4RcI/2k9IbCvS
YdXvjasWNpPxxrA+za4yHR7wdWaeJPjkfzx9PR3I/dob5veTMWCYxrPDdHj4
1ow2ceA/vq5Lh+0uQflTJmrhF70JJXYN6dD6xXtPj6EWmirvR7vGdKB//qfu
2TwqLtBTEduJ06EtQXb0Bp2CIps1EruWdHATkNZcIfxzInvA0L47HYaOtFi+
JPT3Px4fTIdhRuLqwumEf7D+cO1JGUBv+84sSyJL+VwpA+pvZywrKiejNWu0
1F49A77M6zVqcyH8I3gh2mtngO7BPvUrgVS8l/Cj2Z6eATa7OcvX6VFRY06i
xN4yA1b9sgtz8CH8I6GN7sDIgJbNg5QKQm//43lmBihY6DneJvJE58qXXAfI
AOrhzGvxk6hSvg/IgIHjDOWXBA+sWvmm1CE8A3ySQGmwkfCPzSHoEJsBxafL
MciJglqHapodeBlAOpt+Z6kbBdPPuEkc+MT6C7bfN3Gk4PGie3RGdgZYD965
bqFAkeaBnAy4OPvWiSBnMvrcPsdlCDMg3qwx7OtSsjQf5GeAlWLgYyNtCj67
daGUUZgB3psjfgdlUtCg3hwZ+zOg4JpK14pICs56X9TMKM2AOsOMHxmyVLz2
U13CqMiAoXz+Xp1CKg69K6Y7VhL7MW7Z8WB1qjRPXM+AOwe3GDvtpOCukXyu
I2bA3QvHxdNVqNJ8UZcBHcMXU1cR+2M8srnUsSEDmou/p1OPUXD+RBl0bMyA
GVeXtewj5rtKf2mzozgDNLctrbReSJbmj5YMiBlv80jiS8YQ/eV0p+4McFTe
o5WQTJbmkcEMcN0dP9crh4zf2WlcJ1Im+I0l6kvukNHS9pfQSSkTkr9GZ91c
RcEl7MxSJ/VMmH98xdFL96l4J+SdyEk7ExIWRGXmEXlEPSm82YmeCWU/8/eC
FkWaXywzYcA9373wBhmLEyPpzoxM0Fk+PzEJKNI8w8yEJ/Evv58l/MljtRfX
GTLhskJlsU48BVfMeSx0DsiEwd6jI9ZPCf9YBaXO4Zng2prWw3EgI2XrFZFz
bCbU9sZ/V9mviamHrZudeZmwJOfirZXpmtL8w8+ELTO9hMd3a+KvQ3Z0l+xM
CMsKX7bokqY0D+Vkwo1xMs0GD8i4pUqL6yLMBBeWRjdqUPHJmWNCl/xM2Pz8
qFHEZsI/qnRLXQozoW3+9z2T7hP+8WS7yGV/JkS3no+sd6XglQ/yzS6lmfCo
b0Xh23NkHKjfSXKtyISTe8NOL5GloO+HcXTXykxYhS9erkym4I6OVRzX68T1
pgWMW/6B8I/3E1JcMROSRu8rPPlNRnqHQOhalwkTB24+j99ExrmjfSWuDZlw
W2n6O5EK4R8qs0SujZlg3dl4qYqY35GRAbGrOBM0GUYfr/HIGKQyl+TWkgn6
9dFF+QQf7jP4THPrzoRp1TLPi4h889UuhuM2mAkNn2bLfwwk/MPgG8+NlAVN
j6efe1JO+IddvNBNKQvkJkbf6SL4B72elbipZ8HStLYSVQYVVUN9RW7aWbDn
d0ijKIuKYV4vxG70LABWVbVtNhUPTfMnuVtmwbzb49rGv6RiW9JtmjsjCxTL
Jn4w2E1F93mOHHdmFkgExZ1BaUT+SBLx3CELQqsNqmp1KPhgrovQPSALluUE
fRDGklEz92SJe3gWXL81+THnoiambDMUucdmwZvCoymLr2li2eozYndeFugF
ZJyx2EbGrq1GJCY/CzgzRhp7+UT+KN5LY2ZnwbrLs7Q2E/0rOKfMYeZkQciC
4znvb1Hx8eEDPKYwC65oWHgeIfKIzjlVITM/C74lMS3NXlEws3ptCbMwC4QV
67dbEP566elgNXN/FrwO3FnOvUDB/qoNYmZpFvRrLhrR+0HByU+HJcyKLJia
fPFgBFJx+8dsmkdlFnh71JVlEXnj+ZMx8LieBePWHNu0aikFDT8u4nlgFnTe
f/RVi5iXOZ0tAo+6LPByHtA6cJnwj7GkEo+GLChxs/SkfCTjn4529GjMAtu2
/d9XTCTyxxhP7CHOgmvlc05anib8Q/W1xKMlC7RtvdLNnlDws2EwzbM7Cy7/
9H7mQejNVLUJPAezYHXpxPfr9bRwgWEoz5PEB0XK5fe6RJ6ttr8r8FTiw/i9
I8eEBA9N5DBLPNX5MM1aae/uMgpOs3+Antp8UPqcP1v/FBUPerPEnnQ+QPPu
Kn+Cv1pCKyWelnxwjEsukyP2g6BbGovBh0/cs3NNWIR/hF4CFpMP7U4vpr9F
Mt5LtuSxgA+UHcxdZnvJOGn+YQErgA/Xr4sniWrJyBVolLDC+aBccTJ7hNiv
0nmlyIrlw8NVbbmWylTsyKWIWTw+vB0/POXcNsI/thdIWHw+fJt3TEv1BhXz
iTjKzubD8dN6dn7BVHy4bSuwc/hQW1e03ZbIS1olsjy2kA+uIVdytI2omH5+
mYCdzwf5B7bXawn+OlascIRdyIfY5c/MqXQq9p5bgez9fHh5NTf6X78BUVcz
u5QPopzZwTn7KLj1WbqEXcEH2ftVoc8J3nlW3UP3quTDMaX4M/cJ/9F/RvT2
Oh+mGrOWOpeRcda/X/hBPth98a0w2UPGa10RAq86PlSy7wDXk4JEvCz1auDD
1Zr0ZrdWCk7tmoFejXxQsVpbr+JOxV2Sh81eYj40HspYtn4+Ff/9uNyrhQ/x
G5+/XV5BRWNJPd27mw8+67vzRq4S/qE2GbwHif0MHHm9l+CN27RrXG/STDic
+GHitgUU/D/hx/aB
       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.7173599690479746`*^9},ExpressionUUID->"99efa6da-7bf2-4281-b863-\
e4841db1b00b"],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
      {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[{{0.5, -20.58731462444898}, {
        0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
        1.25, -27.50184105161661}}], 
       LineBox[{{4.249998, -23.11696430864725}, {
        4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
       LineBox[{{6.750008, -23.038818749837983`}, {
        7.000009, -20.322035683613738`}}], 
       LineBox[{{7.750011, -20.716014193782303`}, {
        8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
       LineBox[{{11.250025, -19.142376381324734`}, {
        11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
        12.000028, -22.492142720939622`}}], 
       LineBox[{{12.50003, -24.045787259895636`}, {
        12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
       LineBox[{{13.750034, -21.052099541576304`}, {
        14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
        14.500037, -21.409428863587927`}}], 
       LineBox[{{15.500041, -21.61333098548902}, {
        15.750042, -22.10549208407436}}], 
       LineBox[{{17.250023, -22.856107311471863`}, {
        17.500019, -22.566864012429928`}}], 
       LineBox[{{18.000011, -21.834193448858855`}, {
        18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
        18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
       LineBox[{{19.499989, -22.216470803381476`}, {
        19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
       LineBox[{{20.499973, -28.088099516986762`}, {
        20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
        21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
        21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
       LineBox[{{22.999935, -19.74888960999384}, {
        23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}],
        LineBox[{{28.749847, -22.783129874707647`}, {
        28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
       LineBox[{{30.999813, -24.728294878757325`}, {
        31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
       LineBox[{{32.249794, -20.837058021652666`}, {
        32.49979, -21.361849645654928`}}], 
       LineBox[{{32.999783, -20.84333950660284}, {
        33.249779, -18.469001093501973`}}], 
       LineBox[{{34.999752, -25.06864583779922}, {
        35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
        35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}],
        LineBox[{{38.499699, -24.377795653123645`}, {
        38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
       LineBox[{{39.74968, -22.650120892941615`}, {
        39.999676, -22.80728905851026}}], 
       LineBox[{{43.749619, -22.041875381710568`}, {
        43.999615, -22.423199188672683`}}], 
       LineBox[{{47.499561, -21.287037875136214`}, {
        47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
       LineBox[{{49.999523, -27.91448197690941}, {
        50.249519, -27.305559271827388`}}], 
       LineBox[{{51.999493, -20.885769001862567`}, {
        52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}],
        LineBox[{{52.999477, -22.174453342075132`}, {
        53.249474, -24.83933405846568}}], 
       LineBox[{{54.249458, -23.722525323809897`}, {
        54.499454, -23.580299515887834`}}], 
       LineBox[{{56.499424, -21.766646750655234`}, {
        56.74942, -23.57640470224996}}], 
       LineBox[{{58.249397, -23.599923997532017`}, {
        58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
       LineBox[{{59.249382, -17.837453345617426`}, {
        59.499378, -21.77661789863478}}], 
       LineBox[{{59.999371, -21.620808909572247`}, {
        60.249367, -21.022793121071274`}}], 
       LineBox[{{61.749344, -23.521435622331904`}, {
        61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
        62.499332, -19.42225543656815}}], 
       LineBox[{{63.499317, -20.822384760816565`}, {
        63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
       LineBox[{{64.499344, -25.343231741743004`}, {
        64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
        65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
       LineBox[{{68.249573, -26.50222788848888}, {
        68.499588, -26.988563201691523`}}], 
       LineBox[{{70.749725, -20.1140901131646}, {
        70.999741, -20.81539559964317}}], 
       LineBox[{{72.249817, -27.41004150424379}, {
        72.499832, -25.260157006181224`}}], 
       LineBox[{{72.999863, -23.234537488989123`}, {
        73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
        73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
       LineBox[{{75.25, -25.575903773461626`}, {
        75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
        76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
        76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
        77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
        77.500137, -21.438588076795124`}}], 
       LineBox[{{78.000168, -22.06377454291717}, {
        78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs
YIGKij4GWMwmJCQEJPa7n+8ef/zD67wG933tOudzfd6fezNKnT89Q5ZEIhnJ
kUj//v77s+Ogfc/gJjZKqwbOWUWTir7/r8Uc/qGHrcfm/q1bOEcUOuPu8P7W
3Zw8peNnSvz/1n0cZ3/r+rvmf+tBTuAC8at3WmzsX1/YOyYZ5hz4VhSpo/S3
lnBs775RXqjAxj+T65ZLJDLwLm92diT1by0HYatDYJz5379XgBtzz3EzQ//W
4yBKlh/anPG3Hg9mk1S9y5b+rZWhqks9PH0dG7vqYueOSVTgwo19206t/1ur
wX1+ZZKC4O/91EElsSe1fzkbVxt9vS2RTIK7c+pNxZF/348mrI1q7T7uxca1
H/WmkEhk2Lm8tY5vx0bFKvcNJBIFUs5nCHpU2bipKPIhiUSF+pZBx8cjLFRe
MX+iDEkLanbpsQvk2bgtdnOYDEkb9gpLho112DjJ/cROGZIO1F7Y0zWPwcbd
lLuvZEi64Dra3tQxjY1afR+1ZUl6sOj5xqeHE9l48MWfBFmSPliqW5y7m8dG
/QvUElmSATgeXaz0ff3f2hCm2FacHdvKxpLtTp9lSTRYvs1q+enVf+9HB/1v
q+75LmDjdHPXyzJCOoRV/7FOjfp7fyMwPn3xWLsjG1/JRwzICI3g5poPDz5Z
/V2PMUTqTny5VYONsV/meMoKjcGX9KL/tfzf9ZlA7bd/kj8S/X1Xk79aVmgC
J5kJa95T/67PFGyW3/lzn7h+cmk5ygpN4ShrU0NmyN/1moHl41kTm9LZ+CkX
5eSEZnAwqb4wmFi/8bxQMzmSOdCPNETVbmBjetL7qXJCc7ihqCivvouNx0Jm
8eVIFvBTIip/uYKN31mDm+SEFtB+bDEvJIuNljYbTsuRLMGqyfqiPtHfmbrk
J3JCSzjhfm3PE3s2nh5f1ilHsgKxi3Bytx4bfw46qMsLrYAjbxW5Sua/mmQN
g1c9AsyHWWjXUuUoL7SG4ri9d7OJev6b4Eh5kg241F/5skibjZUPmhbLC20g
Z0tzRpIDG3uuZO2VJ9kCuXt68nqin87H+q/JC23hTsLUwWmE3pbsXtskT7KD
31OF7b+Jeb66dtKwvNAObgV/aWMR+hxYWKKvQLKHVQfWh6gWsNEj1c5bQWgP
zedPz3FaxcYVEbe4CiQH8ExXsXmUzMbbEJinIHQAYfGN4DG///abxIDPtvSp
4Yz/+gMMyNTdMLmW8refDPgekPZGMMTCpSNaSrLIgPn2D7u+fmJhr8HIPRmS
I0S2NBf2dLIwmyPOkwFHCA9dH7mL0Gsn7563jNARNFnfLALd2Th7TcUwCR1h
bhGHaRXLxpajW66TSE5wLrdcdXTuf/oBJ3hdA39mrf1PX0InCMpYGfx2xX/6
QyeYHJBXKV75V59OcOjlo87O+f/pl+MMBw/IHrSNY6N24iJ/icAZ5kZHxha4
sXHP6hh5icgZbi7ZcW438X41Slg1YxJnYO2hLQwi5rUQabljHBcYONMz4xrx
flQ+y7HGBC4QY8a3HHrFwgK5loFRkQtUvnv948UPFlbo77o/KnGBKys/q7kT
ejDzXrZmlOMK59d3T7IwYmMZN4EzKnCFHS+LL1EC2EjL44yMiFxB3bPO4cMs
Nh4qM7kxInGFg3VyBpU5bLx56+mGEY4bTGOT/xER++H+4eKUEYEbqEs8qhcS
/b8ytpc0InKDYd1oNdN4NjrRV1YNS9xgsRIlJC6Qjed9uCuGOe5w6atP11dL
Nj6JnxAwLHAHvSeneM+JOmhVp/ywyB22D7/JOtTCwtrDL2r+SNxB06XhrXsV
C31FV3P/cJhQvy3sxNJ9LKwRH2T9ETBhqvnzw5TrLOTICgaHRExIktnwtILY
v0Q96wdDEiZwyD6b/yHm+y1bde0QxwPsB1l3Con+xyT3cIYEHrCXNy+SSpxf
LwWvRwZFHjD09t6fjnA2Rhy5eWNQ4gG1RfMPXk5h4/ybGRsHOZ6wNvz8nfFz
CH29C/QdFHjCHoHgqjrx+sxRO5lBkSd0GJdP5jEJPRtqVA9IPGGK05nY8j8s
TIffKwY4LBhp629pNSDOi5S37gMCFsyco7NW6yQLJSvWKwyIWFDuiBaZXBau
OjTzzm8JC+7sfNb21JqFQ1XTBL85bGi8Om34+Rxi3psd2b8FbMi39SzgE++n
l0Qd6hexIU77egwS59kk3ZoH/RI23ItdljGtl4XbWMfW9nO8wObQ+LR5amxU
TtoE/QIv+N25b8pOF8IPcueO9om84IYsN8mO6L9iacTNPokXrLBz3WkiZKPp
jZGNfRxvINUFC78Rfnbkrdi3T+AN4VeoLRqubDQk5NYn8oayFRkPzp1lYZHB
yepeiTdEZazyuj+BmHfO1pW9HA7o3k1Ur6GxcA9vAbNXwAED895Ot0ueeGm5
vmKviAPJG5oyFy31xIUF2772SDiwxtSN+/qPp7RfNIC4kXcznp1hIWV+uuEQ
B0DgMHV0u9p//eMCwK3tg+IGFqZNPPNlUACg2h9huLWfhUYGhncGSwC2a4zt
fTSDjWK7wtJBEcBawf7Wwo3Eee5NDFAzgFOygbEaoceksMVJgxIAvyDycRJx
vurziBOa5gPXTp8aWUP4++mft4wHOT5wJoy/ZyubJe0/1wemZMpW1O5moaVq
afOAwAdWmkpoKr6e0nko8YGOkVmjenUeeMxh3aEBkQ+Ya3QKtmzxQJfbcWsH
mn2AYvLc5/1mT+ytf5wyIPGBaMvaUI8yT7zwwQsGaJNBfapD7rxgNmZ3njcc
4EyGKzuUq2xobLSXGI3+5k6G39fhQRDRv6rNA19+CyZD07fmhUmT2dJ5KpkM
HLnxtwrnstDz7LvS36LJYCm6tj1zzFM6X82TIepyQppMmydefypK+i2ZDMkP
1ySrnv9v3mhT4OWI4quk+56oMGecyW/OFFBaaq/YkueJ91Ytl/nNnQKvx/P9
4xw9cM3W9uZ+wRSoWbVF0eMqE32Kk6r7S6bAJ4lpYsgWJkrOPTvUL5oCUS/8
Ds/z8ZTOZ/MUeObe1SbM8sBpIVqp/ZIpUPz5Znlxo6d0Xmm+0Ow9q/zQfRY+
mjts2M/xhSfXPKcs9WFJ55frC4qqfrmrEj3Rf3vzuz6BLyw28lvm1OqBr/Wu
3Okr8YXP94dONtV44B5biyN9Il9IWbVMy/iwB0Z6HRD0NfvCnBe8iqVynqgR
qpzcJ/EFs4jFFmZbPLEheTW7j+YHrx9cvbLL1AO57dNN+jh+8GtsTkDBBKZ0
/rl+4H5hl7z6bnf8MNFd3Cvwg6UDqXlpBe5SPZT4wYAXo0JnrSfG2+sd7hX5
QW5Y3z8VoUxsvdm9trfZDwwTGvekdjDxxOPU1F6JH8wfDTpoFeWBme9fQi9t
KhxMydvfR/ZA046ptF7OVDgZ6yfY/ZqJX0avj/Zwp4LZxYQDXj+ZWKZq875H
MBWsVu3UWkfyQEYR6W5PyVSYsGd2w+9iJnadXnikRzQVAvKcK/dlM/Hc7a+C
nuap0DZNvjqizxPnPIlO7pFMBX7uCasvNe5o87GO3UPzh3057qaG793w5qxi
kx6OP1zdWTH3wlw3zFmpLtvD9Yc1UVee++90Q/cta8S/BP6QrvrgshOhz/5D
fdW/SvzhSanfRrll7nj5bObhXyJ/6M45/ipK6I6LqhtX/mr2h4dUtxk7zrmj
bPC51F8Sf3DeoWehf9sdMYHu84sWAAVOO+PG1JgomLOT9osTANabBh7m1THR
a7X8WDc3AHrVTsylanvgyNal77sFAaDRfVqoocHEzbohd7tLAuB2tYb1I7o7
BtpUH+kWBUDJ2psvrWaxUInNEHY3B0B0dc/RnbPcsDakLLlbEgD0Xeafe0+7
4vokslc3LRBmDH37LRvgiuS2VpNuTiA0uIFF8hlX/IfAyW5uIJzjPO4us2Xi
DuWn4i5BIPCKhq2p49wxXB9EXSWBYIpnS5y3uqGq3cXDXaJAMJfZx1S+6IZP
vExXdTUHgibjVssaW3dMfDSU2iUJhIQ/JVdr1jNR991sny5aEGRQ3z15TPB9
U/sHWhcnCF7uuKf39SEL94+EjXVyg6C1PGPt/SQmRqvced8pCIINYe0N9ya4
4bcD++52lgTBiDorIl+WieWnCIAUBcHsodvfvxm6YuqtlcLO5iDoEz7Kf7XS
BY3qO5I7JUFAyueR5M1dsPk916uTFgyjjQ9DXn92weKO53qdnGAoSTx07vEn
V7RbcUK2kxsM2d5yW59tccefBTqfOgTBsMx7IKje0w1PFW0WdZQEQ9g4axuz
zW4488zo4Q5RMPxq31O7MZKJFlXzV3U0B4Or7tnUzE1MvBrol9YhCYaLl6tf
ad9wwyXx13w6aCGgpv9hWG+vGzrPtqJ3cEJga19j/7WpntizsmjsJzcETMty
78+1dcXKLSoffgpCwPvZ4HWFBlfk6Hy5+7MkBE722C5OeO+MY1ZRZT9FIWB9
8pNMUogzVnnWCn82h0ClvpLfxAnOuDLYg/tTEgLb8+Y0zZvqgp6Jp71+0qaB
Ic+B72DvgoNzDPR/cqbB80ztq0VUJm4c6pH9yZ0GPycNZKTWu+PUCRmf2gXT
IKnhdnCA2BPl9d6I2kumwcxpe4fDF7jhXZvA4nbRNDBeJDTqlXHFNexbq9qb
p4GegpnslI0uqP6wMK1dMg26jB1Eo4tc8FmT7OR2WigsVV5XULPeFbe1Laa3
c0Lh7b3KlOPbXTBk+PtYGzcU3EiC92tVXFB5YtyHNkEo3LDuKOeVOuHB/fb3
2kpCwWd3Xe2QgRPGniwtaxOFwvC6VaPFvx1R66ZGXltzKKgVNQzpjzrjq0fr
uG2SUFiuIxhzfuaEu9/99mqjhUGVzQd3CwcXjPzJ12/jhIH+eEOFcR6u+DnH
W66NGwZqt3b3pm9ywdJNlZ9aBWFwoF1+2vQzzsg9aIytJWEQfGO5fFmYMxqc
3l3cKgoDv4Jjb8+7OuP7W4qrW5vDgL6pLe/ouP9qSRg0cJa2/xPnjAvYJTL9
auGQEzx+ZUWCy39+EA7TLvu/+Cp0wuOrFwn6HcKBlKuk2cV3lPoNJxyGDjUV
cn4xpP4UFg4tp13r6jsZmHw4DX5zw+FxgmFA6C4Xqf/ND4fjZhs2Rl91xN0f
3at/C8LhXXtjQ72LE1KrImUGtodD4Nuy0oytTlI/LgmHQ48cVR7HO2HImIVg
4Hw4/PS9Zrab6ST1e1E4gEFB8ZdZTlI+eBYOHRdi7IYLnFDeUBsGm4n1O+a2
Rmg4SfmjKxwcvE8HZdY4IjF9VYOScJjHL3u5PNIVb3spyQypRQBemdT/UtPx
Px6KgLWshb4bXBj4K/d97pBDBFRlfXk4tNUBCXqpGeJEwJfXIqOZHQ6olvuZ
9CcsArZYhLgV+bniqeJ6zh9uBHSXFo1vbmdI+Xp+BKiP2dYtf8uQ8reAeP3d
tsdr5Bwxtfo2aXh7BOQs3z171NgRRz4e5wyXRIBNzCfBzCJH3CcpzB0+HwFz
H7udeUXsj+7HMzXDoggQ+R+U1PY7SfPBswjgrXvGvFjqiGH/Bo7mCDB5sPJ+
fw4D2zizc0e6ImAXa2D+lgUuONdwY82IhFi/3E0v56UOOI6zgDSqNh1qKprG
POTtpfmFNh0iVGUmbQc79BL65Y46TIdT5Xaim5b2iMkpNaOc6bDmrOBFnZsj
xguCSWNh04GTE3tl4AAD+0tcOWPc6WCae/B2JYkhzVfzp4NjykPTH5YMaf4S
TIfXKn6Z0Q8YeFZkRpJsnw7Xo6bMiytzwgCxGkdSMh2ujasqLdvvgsTurpac
nw6vzLQuFe12xoxmSo1ENB2eL/QKCQtwkubDhulwhZGRrNVkj0X0Nm+SeDrs
O6fS+kjLEQ0lCmtI3dPhnPmdO/piW7xO6yb+JxKS9P8RaJXZYCS8lZDUI0Ey
PDy+d8Raml/pkTCv2j7c5KitNN8yIqE+sJrjZW6PyrxHKAORIJ8SJKrd64jH
hZclMuGRcHnBcbpctQPCkWJvWV4k3Pv0Y9tqfwbeFdzMk82OhAe33bs69Z3/
e94RCdVfkz+eUXTEIdwmkS2MhH7PUza3lzvgrk+E4Esj4f5KjudOPwek4u48
ucpI2PU0lengRuhDnItyxKpLxy/uVXCyw2CZmRK5hkjwe92zyI3o33ejSG95
cSTMalnmsinRGmeS5ufJd0dCuXFi41MfK5Q3ikN50gyYuZr6ZPIDSyz2mSKR
V58B7ywlL/fl2UifJ9BnwP2Y7kD6N2vp8wPGDHjddkRkP5eB0SnOqAAzwL8+
hBNu74y/8gwkCuEzQHd8eXvkYSfcUjbOW5E3A2btMG4/tdoe1fJM8hSzZ4Cv
4deaa6G2ePKICioKZ4Dck5+nNm+1Qd87A2OKhTNAtD7o0ZJUG6wt1Zw8rnQG
sO+7Z06zsUNi2oTjKmdAwdfDJjUatjjy6YdoHBL381+qqllkjftkX4yNa5gB
Bz/OMjn/1QJ1P3X4KIlnwJQw2oapn83xskyjUKl7Briv+HyMV2KOYcZ3REqk
KCA1O3B7DGywbfKZMSX1KLg7UWF6GFjiHKM6n/H0KOA7BFuu22KN4yZfFI5n
RMGsWWcmqFnaYlnqIdF4iIKVhj6rm6g2yF67YWx8eBS09qtF3Ku2QlFKmc8E
XhQcOnLGdtJkK4xfs0U4ITsKKuXnrVhgboX9ZUtFE4RRwJOorS+6Zonb7/LG
JhRGwY+BQfImMyvUKFvlo1waBcveLX72uc4Gz97JFCpXRsF+IZ0p3mmB/l/C
RcoYBaE/W0+tXGCG/z6uUG6IgunWOyf9Fphixudon4niKPBWCmUdyzdFkpyP
cGJ3FPS3tDfYjdriQRMb0URSNEzaeqbmvIE5uvpSxiaqR8Mli/qCDx/M8bqx
o48KPRp0Du7z1lhigdOn6AlVGNHQdjeo3c/eAjvSFEQqEA0fTG7teq1rgfnr
ukZVwqPhyy09waOTFqicpuyjyosGrRytkegeCyTSh0A1Oxpm7K54wn5rjlDe
XK0qjIb9CiNcRw1zvLtmWEatMBq+t1W3+a+ww6Sj30CtNBrsO+aXd981xcG7
zwRqldEwWHp+/Nnfxrjr641qNYyG0xr9M9mqxki9+0pGvSEaVuzd9OnWMmOs
/CICdXE0TLXNKqhPsMFg+VMC9e5o+HHgdGbMSlP8brq7Wp0UA88vngn1dzRF
vlylzCT1GOjS2qV5drUpypkehEn0GCDfX6y644kpFvuuE0xixMC0rh909Wdm
yMyYVz0JYqB+U7np6eMWeGtKgYxGeAwcEH/ddcDeEqPTF4MGLwZmskq2ZwvM
8Ne6ZIFGdgz0VyzN1ZplgpuPBVRrCGNgUe0hv/M77VF1XbqMZmEMyA8Xtm7V
M8aT5aGgWRoDRc9/bIqNoeOU+0yBZmUMnJe9SJr/0BA/fjOu1sQY+P32/ITH
bDqmEMcVuSEGtrzhRAfNNcWRr5ZAFscA55EyZwHbBPcqaArI3TFwtK74+bM/
RuhoPlpFJsWC3jNPJ2NHY7wsryNDUY8F5zC2ocuoMYaayQGFHgtYcGbuilpT
bPXryKUwYqFqZdrPLX/McY7p+DsUiIX1+0f2X4wxx3F+vSRqeCyU/2neZvbC
GI9kfOBQebHwZpeTL7WWjuwNtbnU7Fj407NkxxR9MxSlf6mhCmOBP//ZjXF0
Osatf0LSKoyFS/ZL3Ids9LDv2DWOVmks/GOqvcR9jzZuf3AkV6syFg6SXx0Q
XtJFjWNVNVoYC0tvH9zbZELHM/dPkLQbYol5emLUOJmO/t93cLTFscBm6pFt
WQb4WXFVrnZ3LMiXGqdufG6A6d/21WiT4kCmaChi/IAh/msPOupxoLph9ufw
PzQ8aD6Ho0OPgwymd9A1bzq6+Efn6jDiYGBlWtryyzS8ZrawRgfi4HqhWeY/
awxw+tREkm54HES2bfb8VWeAHZlTObq8OPjyzi266aMubtzIyNXNjgOmQfen
DSa6OCEzpEZXSNS/bBfWzNPBYxvcSHqFcTC+oLK48og2ck7QOXqlcfAxeNel
nfr6+LZ2Qq5eZRzEOxX/2haij0nHzWv0MA6q2jfe/HnDEAcfqJP0G+Lgu6N4
LKHYEHf++OOtL46DjqYFvJ3naUh5QF2j3x0HyhefatsuN8DK76QafVI8rNh/
VnmRHR2DxrVL9NXjoeK9XueLo4b4zeKVtwE9HoxTX675pWaAfEXihGfEw3Nd
9+6uYAOUs3iHBhAPXbME67fW6uFh//sSg3DienJ78odQB5n8896GvHiY+rjm
ZYCjDt6a+jjPMDseJl85+Erruw5GZV1BQ2E8LDGqckkK1cPujSUSw8J4WLjp
5uDpJn3cXLHJm1YaD22d7j5Pduuj6sZjebTKeOhYwlgfeoWGFSe2Iw3j4f3s
zXKyDwxwSt1yCa0hHs6SN+1x+GiAH1vSvOnieAhrjRM23DREXq0gj94dDxnl
Voc7Xxni8I+ZSCclwC3rtNA+DRruVZohoasnwJCe6A75JA0ZVt7eRvQEIAc/
t5mM+nhpXHyeESMBvBrKp5KDDDDU0heNIAHujXaq6ZzVwdYAe4lReAJ01M7O
O12ljWtnansb8xIgR+3eabcX2qgY4JJnnJ0Anad9HatidPEI3xCNhQkwW3e8
cthHfWRtUpIYFybAetXH5y5908PXJ3u8TEoTYO6Pu5+iKw0xLl81z6QyAfbF
Dy00Bzr2VQyKTDABMu7tNv7yzhC3Pfw8ZtKQADvk8YhaqCFOqhjzMRUnwON5
j/ovvzHAM3UtQtPuBIgVnfe6Y26A/q0vRKakRAj070oQE/PwaXzVmKl6IrwN
tXfu/EDoo6XRx4yeCMd+0TxnqumhROmu0IyRCH1GX664l+jgASuC2CARrvzx
DXPx1EGXoH1jZuGJkHjOSyn7kBZes7zkY85LBLX5le8/B2nh9MDDQvPsRBg3
I27J+WZ9/Dlzo8hcmAhmXRt3+a0l9FGwYMy8MBG85k5afGarPk6YudXHojQR
pq2UrbuTrI/lm5YJLSoT4cPKB6WrVAyQcypFZIGJ4FFe5Tzxlh6+fRQ8ZtGQ
COlWPynDtgaYdDLLx1KcCOdUEg/QtfVw4GGE0LI7EQ4dOrRe394Ad7axRJak
JNB+tib7z3NdtFM2H7NUT4Kxbw3rM2bp4vlWHx8rehJUJStuPvCPFgZNsBVa
MZLgvdHIF0+WFn6zpoqsIAl265aZh7Gp+C/+WoUnQWtrL6nsgBbKWuv7WPOS
4MfCbKCc1MfDQYpC6+wkOJ4470vhZUIfs7urrYVJkPC4NL+hXg9vBk6UtSlM
gluif8IKVPUxatZvsClNgmOJRl8lvwh9FIgFNpVJkLjix5tJAfpYcPpRtQ0m
Qd+lIp9giiGqFHyXsW1IgsIfQoflNAOsONUAtuIk8L/QpLhhQAenPL4psO1O
gmWRh30WvtXFD+3l1bakZGiavY96OEwH/8VZO/VkcAkYzVozSQuH206BHT0Z
Ft7ZqaQ+TME9ynsEdoxkyF16+yMsoiDDVlBtB8kwo0pOdw1PCy9NKJKxD0+G
o12XaH/G62KozXqw5yXDBPPaqooMbWwJni+wz06GmADe/SnvdXHtnLhqe2Ey
3LC6cKl9kQ4qBi+RcShMhqHI4fX54bpYOpsLDqXJkFfd+U67XxdZWwIFDpXJ
MO/U5w/BPoQ+zjgTlJ0Mqn7H9qqSdTFuc5gMoyEZsmfLp+QWaWPvaQ9giJMh
+VfAa+FmHdxWbyJgdCfDQcpq4dwXVLTqUKlmkLhQP8dr99MnFDz92ErGUZ0L
3saDgW0+ZJz6UxMc6VxwOj9vz/F/NPHTxLFcRwYXsi7AgcjpVFz57wd+wIW3
PIqyW4U2jinLyziFcyE6Zk50ezEVD9h2cpx4XNi3y6SL8Y2KLtMac52yuZD5
/Wv1x8lUvGrTV+Mk5IKdr9/mHUe1MCLkI8m5kAudO0arBI7a+HNOHce5lAtt
ksLw8nNU3LD1Yq5zJRf6m501z/hQcPycpzVE6ofEsPqa2zJkLN9yneTSwAWG
r/JV6wAycs6WcVzEXHhsWRRhTLze9GRLrks3FwTz83cFBpPRPvolT5fEg70t
4X1NqRRcmRko1FXiwcy2zCkHLlDx4dLqEl11HpjNCxkqHKeF1I3OIl1tHsw5
WZ+/ejsZY5bWiHXpPAhkN7yfv4Is9S9LHhyMqDn1BSnYs/c0TY/Bg8PNEjE8
0pL6GZMHRePjn3bkaGHe3nM8PeDB8dYMo0YbLXx63ESoF8CDqyfOzh5dT0X9
a/tL9MJ5cGOJbNPIeArOrFUR6cXyIGe1uejlcTKeulok1uPxoOb6u6Xe98hS
/+PzYB/lgmFXAgX93qyn6WfzQFFomNvWQ5b6YQ4PxJNSFgUBGV++zufpC3lw
ccbN2QNnyWj0Y1Sgn8+DWU85zIkdFJz37weshTxY/aPDei1HS+qX+3nwdV6T
WG2YiqO/l4j1S3mw+Ziajm8fReqfFTzQanbr/sak4n4tHs2gkgfTIOjO4ssU
bFLsBIPrPEgOSnm27hIFLbTSeAZI3G8G5VRdExUXWzQKDOp4cHndraNQoYU1
7tNKDBp4hP5G9PPTKVK/beSBT96fwP2BZAx3DxcbiHnQZjsu+4omWeq/LTyY
G4SvhhLI2B7jSTPs5sGOTsaFmxMoaOtfB4aDRP/0jnjw11JweYwXz5CUAtcL
XpIlXylYm3VRYKiUAsd+fDqaEUpFco5FiaF6CtxUWu4ySOzH//xaOwVq93IV
YoaoeHSZtdiQngKVHmlXJW+oUv+2TIHXvlnlXY8o6LWfTKMxUuD+/YfZJl7E
+bixDGjMFDhcv8dVGKKF9fuIDYIUqKrvuHS1jYK6FVsEtADi+i+zje/vJ2PW
dZkSWngKLLy1Y7naUU2p38emwLYmtlHOmAb+viYvpvFSIKtC65X+K02p//NT
oPzyo8B6QyquuzbOiJ6dAh6h1hNbtlPxRe0qoOekgMabVu21QEVa4y8uXZgC
deASvGcJBee0ZAro+SlACXS4tmETFc+96SulF6ZAcGjFi0YPLSkv7E8B3wsx
uLCbggGDH5vppSlgsYOPjxZTpPxQkQIuHmt/rnhIwTcDn+hGlSlQJHdmDvsl
Bc2UYsDoegow5ZS8XphQcKF2PdcIU2A594vO4o1kFFn6CIzqUgCXjYReIfQl
o/2s1KghBRwk8mG755GlvNGYApPuqc1WO0TGIuaNZiNxCog3pdfNdaRK+aMl
BXZh0ciWdxS0Zt6mG3engCr56lKnxxRcFuAIxoMpEH59wsXtaVS8H3uca0xK
haNzE7x86VqoMVNPYKyUCo/Vwup9FlAxMvZkqbF6Kmhf1O3wUKJKeUU7FX4n
6QatjKJgZ86uZmN6KvRMC55+uJki5RfLVNAfOOYgIOZ9dc5eugkjFaISBjY/
8qbgo3xlMGGmgmyjkaxvARm1Dwi5JpAKwS/drRs/aGLGyf5ck4BUuLlfvT3a
hYzH968tNQlPhfbW7RNLbShS3olNhazlij3JZyjoc2NuswkvFXSen3om3kXB
f79eYMpPhX67jJ5x9lRsuJ5NN81OhV+6iw7n76OiwcNvHNOcVAg4XUN+t5eK
s5riuabCVHiw7nZl3z9UKR/lp8LP2efHJLspONSYVGpamAoXwzrvz02iSHlp
fyqIazgPaylU3D3k32xamgovB5JmLz9EwVctr0hmFanw1nT5G7/JFDQZCqKb
VabC3U0Dnyf+IGP2eOSYXU+FvM7tCjOoZKzSceWaIXG9hdaHNOLIUr6qS4WG
Ly2LumIpGKLDLDVrSIWglNkrpgVTpLzVmAqvv3yIMiLm+4eHcbOZOBVMYrcF
Wz6koqVVJcm8JRXecWZMIMlTcYmHGd28OxUE/Oz20plUvBt4kGM+mApnDa6O
mbdTUD1ejWtOSoOCkVMrIr9TpHymlAYWFoeXnZChYkmcRqm5ehqkvrC2XqBI
lfKadhrcf/3wwFN9KnquGPloTk8D5hyVlb2zCP+YWUCysEyD77yY7XWzyPiv
HC0YaRCn6K3bTfgDtWAxx4KZBreXmVsnSQj/WC6bYgFpcIsVORpTQJHyXUAa
bJEsUzj5D+EfB36WWISnQXlG7ihFgSrlvdg0UOiIOR6ZTEXhgS6xBS8NSlZZ
nTA5RMWnJ9NJlvw0WDGVfefmDyrq3WyiWWanweNl615ofKAg/1EoxzInDZp0
PbycTKl46sZ7nqUwDVZPvK2yQY0q5cP8NPAo/iAJfU34x9sHJZaFaTDLXiHt
Rg5Fyov706C4judQUU/Gf5oeii1L0yBKZV5eqi7hH23eJKuKNPgCES1ufZo4
788lmlVlGmxuU08bPUjGWxOsOFbX04D2pCKgcj0FR4eu8qwwDcJmWibuWUGV
8mVdGryf+W7FjXIq7tM9UmLVkAYGxdcjuyooUt5sTCP4756L83kKmuuWi63E
acB7HGCbSPRzkbUOybolDSadWO/kSfh1jec2mnV3Gri/GQ73/0RB1WA5jvVg
GpzfnKR4z4uC4Z47eNakdJDjiLddriBL+VQpHXptWftXE+tti19ZYq2eDo2z
X1T9E0pG26DxNdba6ZDSseZaRY0mLo/PFVvT04HBWhbsfUITH8zqlVhbpoOg
lL0/Y1gTySv5NBtGOkjUfRySSylSnmWmg4Pvw3Nrz1OxbMVsng2kQ/whKEx/
RpXybUA6nBAeemw4jopeRVElNuHp0MDkXo3YRMHcgi9oE5sO/U37NqVuJmP9
wVixDS8d1NR93TZ1kFHn9BOJDT8dFreJgsz+kDHz1mSabXY6nBEEnb/wiyzl
4Zx0+D0zPseHOH/6b/rxbIXp4PrHYKPefLKUj/PTQf5J6MDWY2QsfOdQYluY
Dkda98XnyFPw+aMqtN2fDtY/7yoqENejvXMS25amQ6Z16vp4RcI/2k9IbCvS
YdXvjasWNpPxxrA+za4yHR7wdWaeJPjkfzx9PR3I/dob5veTMWCYxrPDdHj4
1ow2ceA/vq5Lh+0uQflTJmrhF70JJXYN6dD6xXtPj6EWmirvR7vGdKB//qfu
2TwqLtBTEduJ06EtQXb0Bp2CIps1EruWdHATkNZcIfxzInvA0L47HYaOtFi+
JPT3Px4fTIdhRuLqwumEf7D+cO1JGUBv+84sSyJL+VwpA+pvZywrKiejNWu0
1F49A77M6zVqcyH8I3gh2mtngO7BPvUrgVS8l/Cj2Z6eATa7OcvX6VFRY06i
xN4yA1b9sgtz8CH8I6GN7sDIgJbNg5QKQm//43lmBihY6DneJvJE58qXXAfI
AOrhzGvxk6hSvg/IgIHjDOWXBA+sWvmm1CE8A3ySQGmwkfCPzSHoEJsBxafL
MciJglqHapodeBlAOpt+Z6kbBdPPuEkc+MT6C7bfN3Gk4PGie3RGdgZYD965
bqFAkeaBnAy4OPvWiSBnMvrcPsdlCDMg3qwx7OtSsjQf5GeAlWLgYyNtCj67
daGUUZgB3psjfgdlUtCg3hwZ+zOg4JpK14pICs56X9TMKM2AOsOMHxmyVLz2
U13CqMiAoXz+Xp1CKg69K6Y7VhL7MW7Z8WB1qjRPXM+AOwe3GDvtpOCukXyu
I2bA3QvHxdNVqNJ8UZcBHcMXU1cR+2M8srnUsSEDmou/p1OPUXD+RBl0bMyA
GVeXtewj5rtKf2mzozgDNLctrbReSJbmj5YMiBlv80jiS8YQ/eV0p+4McFTe
o5WQTJbmkcEMcN0dP9crh4zf2WlcJ1Im+I0l6kvukNHS9pfQSSkTkr9GZ91c
RcEl7MxSJ/VMmH98xdFL96l4J+SdyEk7ExIWRGXmEXlEPSm82YmeCWU/8/eC
FkWaXywzYcA9373wBhmLEyPpzoxM0Fk+PzEJKNI8w8yEJ/Evv58l/MljtRfX
GTLhskJlsU48BVfMeSx0DsiEwd6jI9ZPCf9YBaXO4Zng2prWw3EgI2XrFZFz
bCbU9sZ/V9mviamHrZudeZmwJOfirZXpmtL8w8+ELTO9hMd3a+KvQ3Z0l+xM
CMsKX7bokqY0D+Vkwo1xMs0GD8i4pUqL6yLMBBeWRjdqUPHJmWNCl/xM2Pz8
qFHEZsI/qnRLXQozoW3+9z2T7hP+8WS7yGV/JkS3no+sd6XglQ/yzS6lmfCo
b0Xh23NkHKjfSXKtyISTe8NOL5GloO+HcXTXykxYhS9erkym4I6OVRzX68T1
pgWMW/6B8I/3E1JcMROSRu8rPPlNRnqHQOhalwkTB24+j99ExrmjfSWuDZlw
W2n6O5EK4R8qs0SujZlg3dl4qYqY35GRAbGrOBM0GUYfr/HIGKQyl+TWkgn6
9dFF+QQf7jP4THPrzoRp1TLPi4h889UuhuM2mAkNn2bLfwwk/MPgG8+NlAVN
j6efe1JO+IddvNBNKQvkJkbf6SL4B72elbipZ8HStLYSVQYVVUN9RW7aWbDn
d0ijKIuKYV4vxG70LABWVbVtNhUPTfMnuVtmwbzb49rGv6RiW9JtmjsjCxTL
Jn4w2E1F93mOHHdmFkgExZ1BaUT+SBLx3CELQqsNqmp1KPhgrovQPSALluUE
fRDGklEz92SJe3gWXL81+THnoiambDMUucdmwZvCoymLr2li2eozYndeFugF
ZJyx2EbGrq1GJCY/CzgzRhp7+UT+KN5LY2ZnwbrLs7Q2E/0rOKfMYeZkQciC
4znvb1Hx8eEDPKYwC65oWHgeIfKIzjlVITM/C74lMS3NXlEws3ptCbMwC4QV
67dbEP566elgNXN/FrwO3FnOvUDB/qoNYmZpFvRrLhrR+0HByU+HJcyKLJia
fPFgBFJx+8dsmkdlFnh71JVlEXnj+ZMx8LieBePWHNu0aikFDT8u4nlgFnTe
f/RVi5iXOZ0tAo+6LPByHtA6cJnwj7GkEo+GLChxs/SkfCTjn4529GjMAtu2
/d9XTCTyxxhP7CHOgmvlc05anib8Q/W1xKMlC7RtvdLNnlDws2EwzbM7Cy7/
9H7mQejNVLUJPAezYHXpxPfr9bRwgWEoz5PEB0XK5fe6RJ6ttr8r8FTiw/i9
I8eEBA9N5DBLPNX5MM1aae/uMgpOs3+Antp8UPqcP1v/FBUPerPEnnQ+QPPu
Kn+Cv1pCKyWelnxwjEsukyP2g6BbGovBh0/cs3NNWIR/hF4CFpMP7U4vpr9F
Mt5LtuSxgA+UHcxdZnvJOGn+YQErgA/Xr4sniWrJyBVolLDC+aBccTJ7hNiv
0nmlyIrlw8NVbbmWylTsyKWIWTw+vB0/POXcNsI/thdIWHw+fJt3TEv1BhXz
iTjKzubD8dN6dn7BVHy4bSuwc/hQW1e03ZbIS1olsjy2kA+uIVdytI2omH5+
mYCdzwf5B7bXawn+OlascIRdyIfY5c/MqXQq9p5bgez9fHh5NTf6X78BUVcz
u5QPopzZwTn7KLj1WbqEXcEH2ftVoc8J3nlW3UP3quTDMaX4M/cJ/9F/RvT2
Oh+mGrOWOpeRcda/X/hBPth98a0w2UPGa10RAq86PlSy7wDXk4JEvCz1auDD
1Zr0ZrdWCk7tmoFejXxQsVpbr+JOxV2Sh81eYj40HspYtn4+Ff/9uNyrhQ/x
G5+/XV5BRWNJPd27mw8+67vzRq4S/qE2GbwHif0MHHm9l+CN27RrXG/STDic
+GHitgUU/D/hx/aB
        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means and Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{
  3.4220311489549356`*^9, 3.422105581891979*^9, {3.422105701566152*^9, 
   3.4221057241915865`*^9}, 3.422105882600878*^9, 3.42210629314001*^9, 
   3.422106331812628*^9, 3.4221064455804367`*^9, 3.422106546832381*^9, 
   3.423922201083881*^9, 3.423922263391527*^9, 3.424183773745148*^9, 
   3.424184139885444*^9, 3.427464165057741*^9, 3.427464284529929*^9, 
   3.42746440970156*^9, 3.428054520613996*^9, 3.428054552223184*^9, 
   3.440254723621361*^9, 3.440254755272017*^9, 3.440254849863035*^9, 
   3.440254897623495*^9, 3.440254948407532*^9, {3.440257470958918*^9, 
   3.440257492220477*^9}, 3.440259352595876*^9, {3.440502170728693*^9, 
   3.440502194599295*^9}, 3.440502414696631*^9, 3.445191094310776*^9, 
   3.445789445920053*^9, 3.446980628345823*^9, 3.717358602276225*^9, 
   3.717359302619423*^9, {3.7173593689287624`*^9, 3.717359398258685*^9}, 
   3.717359826420898*^9, 3.717359883670456*^9, 
   3.717359969089015*^9},ExpressionUUID->"6d2e2938-b812-4351-b4b6-\
87ae8ef9f985"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["COMBINED DATA:  Plot data from different runs together", "Section",
 CellChangeTimes->{{3.7173603482464495`*^9, 
  3.7173603521861567`*^9}},ExpressionUUID->"6332227a-0c48-4249-9341-\
1f872e65137e"],

Cell["Make plots of different runs together", "Text",ExpressionUUID->"9040c3d7-f6d4-4473-8998-66b83bff8ed1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"comparisonnflds", "=", 
  RowBox[{"Min", "[", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"nflds", "[", "run", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"run", ",", "0", ",", 
       RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{
  3.422031090953822*^9},ExpressionUUID->"a6a593c3-bfb2-4e35-9359-\
9f6ba3b71ea1"],

Cell[BoxData["2"], "Output",
 CellChangeTimes->{
  3.4220310918600893`*^9, 3.422105583845142*^9, 3.423922266019533*^9, 
   3.424184142266552*^9, 3.427464290885433*^9, 3.427464421900296*^9, 
   3.428054559898206*^9, 3.440254760868934*^9, 3.440254854387222*^9, 
   3.440254902180536*^9, 3.440254952978624*^9, {3.440257476554689*^9, 
   3.440257496621369*^9}, 3.440259357185748*^9, 3.440502199195964*^9, 
   3.440502421926348*^9, 3.445191097010882*^9, 3.445789446999493*^9, 
   3.446980629886769*^9, 3.717359303347543*^9, {3.717359369557905*^9, 
   3.7173593992289577`*^9}, 
   3.7173599692191124`*^9},ExpressionUUID->"57fecd5c-0145-4a1e-9081-\
a6e189ed8fe5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"numruns", ">", "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"comparisonnflds", "=", 
      RowBox[{"Min", "[", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"nflds", "[", "run", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"run", ",", "0", ",", 
           RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"fld", "=", "0"}], ",", 
       RowBox[{"fld", "<", "comparisonnflds"}], ",", 
       RowBox[{"fld", "++"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"domeans", "\[Equal]", "1"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{
            RowBox[{"comparisonmeansplot", "[", "fld", "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"run", ",", "0", ",", 
                  RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"All", ",", "Automatic"}], "}"}]}]}], "]"}]}], 
           "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"dovars", "\[Equal]", "1"}], ",", 
          RowBox[{"Print", "[", 
           RowBox[{
            RowBox[{"comparisonvarsplot", "[", "fld", "]"}], "=", 
            RowBox[{"Show", "[", 
             RowBox[{
              RowBox[{"Table", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], 
                ",", 
                RowBox[{"{", 
                 RowBox[{"run", ",", "0", ",", 
                  RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{"All", ",", "Automatic"}], "}"}]}]}], "]"}]}], 
           "]"}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"domeans", "\[Equal]", "1"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"comparisoncombinedmeansplot", "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"combinedmeansplot", "[", "run", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"run", ",", "0", ",", 
               RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]}], "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dovars", "\[Equal]", "1"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"comparisoncombinedvarsplot", "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"combinedvarsplot", "[", "run", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"run", ",", "0", ",", 
               RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]}], "]"}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"domeans", "\[Equal]", "1"}], " ", "&&", " ", 
        RowBox[{"dovars", "\[Equal]", "1"}]}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"comparisonmeansvarsplot", "=", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"meansvarsplot", "[", "run", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"run", ",", "0", ",", 
               RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
           RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], "]"}]}], "]"}],
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.71735957249227*^9, 3.7173596218008842`*^9}, {
  3.717359903131406*^9, 
  3.7173599287749195`*^9}},ExpressionUUID->"ad627ec0-b443-4440-9575-\
1db41fa540ed"],

Cell[CellGroupData[{

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox["0.001`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.100\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 3.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.3978952727983707`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.4849066497880004`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.5649493574615367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.6390573296152584`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.772588722239781, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.833213344056216, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.8903717578961645`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969255141*^9},ExpressionUUID->"4fed2145-6e8d-468d-a47d-\
58bc80ba5f40"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[{{0.5, -20.58731462444898}, {
       0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
       1.25, -27.50184105161661}}], 
      LineBox[{{4.249998, -23.11696430864725}, {
       4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
      LineBox[{{6.750008, -23.038818749837983`}, {
       7.000009, -20.322035683613738`}}], 
      LineBox[{{7.750011, -20.716014193782303`}, {
       8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
      LineBox[{{11.250025, -19.142376381324734`}, {
       11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
       12.000028, -22.492142720939622`}}], 
      LineBox[{{12.50003, -24.045787259895636`}, {
       12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
      LineBox[{{13.750034, -21.052099541576304`}, {
       14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
       14.500037, -21.409428863587927`}}], 
      LineBox[{{15.500041, -21.61333098548902}, {
       15.750042, -22.10549208407436}}], 
      LineBox[{{17.250023, -22.856107311471863`}, {
       17.500019, -22.566864012429928`}}], 
      LineBox[{{18.000011, -21.834193448858855`}, {
       18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
       18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
      LineBox[{{19.499989, -22.216470803381476`}, {
       19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
      LineBox[{{20.499973, -28.088099516986762`}, {
       20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
       21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
       21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
      LineBox[{{22.999935, -19.74888960999384}, {
       23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
      LineBox[{{28.749847, -22.783129874707647`}, {
       28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
      LineBox[{{30.999813, -24.728294878757325`}, {
       31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
      LineBox[{{32.249794, -20.837058021652666`}, {
       32.49979, -21.361849645654928`}}], 
      LineBox[{{32.999783, -20.84333950660284}, {
       33.249779, -18.469001093501973`}}], 
      LineBox[{{34.999752, -25.06864583779922}, {
       35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
       35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
      LineBox[{{38.499699, -24.377795653123645`}, {
       38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
      LineBox[{{39.74968, -22.650120892941615`}, {
       39.999676, -22.80728905851026}}], 
      LineBox[{{43.749619, -22.041875381710568`}, {
       43.999615, -22.423199188672683`}}], 
      LineBox[{{47.499561, -21.287037875136214`}, {
       47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
      LineBox[{{49.999523, -27.91448197690941}, {
       50.249519, -27.305559271827388`}}], 
      LineBox[{{51.999493, -20.885769001862567`}, {
       52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
      LineBox[{{52.999477, -22.174453342075132`}, {
       53.249474, -24.83933405846568}}], 
      LineBox[{{54.249458, -23.722525323809897`}, {
       54.499454, -23.580299515887834`}}], 
      LineBox[{{56.499424, -21.766646750655234`}, {
       56.74942, -23.57640470224996}}], 
      LineBox[{{58.249397, -23.599923997532017`}, {
       58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
      LineBox[{{59.249382, -17.837453345617426`}, {
       59.499378, -21.77661789863478}}], 
      LineBox[{{59.999371, -21.620808909572247`}, {
       60.249367, -21.022793121071274`}}], 
      LineBox[{{61.749344, -23.521435622331904`}, {
       61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
       62.499332, -19.42225543656815}}], 
      LineBox[{{63.499317, -20.822384760816565`}, {
       63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
      LineBox[{{64.499344, -25.343231741743004`}, {
       64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
       65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
      LineBox[{{68.249573, -26.50222788848888}, {
       68.499588, -26.988563201691523`}}], 
      LineBox[{{70.749725, -20.1140901131646}, {
       70.999741, -20.81539559964317}}], 
      LineBox[{{72.249817, -27.41004150424379}, {
       72.499832, -25.260157006181224`}}], 
      LineBox[{{72.999863, -23.234537488989123`}, {
       73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
       73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
      LineBox[{{75.25, -25.575903773461626`}, {
       75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
       76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
       76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
       77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
       77.500137, -21.438588076795124`}}], 
      LineBox[{{78.000168, -22.06377454291717}, {
       78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[{{0.5, -20.58731462444898}, {
       0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
       1.25, -27.50184105161661}}], 
      LineBox[{{4.249998, -23.11696430864725}, {
       4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
      LineBox[{{6.750008, -23.038818749837983`}, {
       7.000009, -20.322035683613738`}}], 
      LineBox[{{7.750011, -20.716014193782303`}, {
       8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
      LineBox[{{11.250025, -19.142376381324734`}, {
       11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
       12.000028, -22.492142720939622`}}], 
      LineBox[{{12.50003, -24.045787259895636`}, {
       12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
      LineBox[{{13.750034, -21.052099541576304`}, {
       14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
       14.500037, -21.409428863587927`}}], 
      LineBox[{{15.500041, -21.61333098548902}, {
       15.750042, -22.10549208407436}}], 
      LineBox[{{17.250023, -22.856107311471863`}, {
       17.500019, -22.566864012429928`}}], 
      LineBox[{{18.000011, -21.834193448858855`}, {
       18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
       18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
      LineBox[{{19.499989, -22.216470803381476`}, {
       19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
      LineBox[{{20.499973, -28.088099516986762`}, {
       20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
       21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
       21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
      LineBox[{{22.999935, -19.74888960999384}, {
       23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}], 
      LineBox[{{28.749847, -22.783129874707647`}, {
       28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
      LineBox[{{30.999813, -24.728294878757325`}, {
       31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
      LineBox[{{32.249794, -20.837058021652666`}, {
       32.49979, -21.361849645654928`}}], 
      LineBox[{{32.999783, -20.84333950660284}, {
       33.249779, -18.469001093501973`}}], 
      LineBox[{{34.999752, -25.06864583779922}, {
       35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
       35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}], 
      LineBox[{{38.499699, -24.377795653123645`}, {
       38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
      LineBox[{{39.74968, -22.650120892941615`}, {
       39.999676, -22.80728905851026}}], 
      LineBox[{{43.749619, -22.041875381710568`}, {
       43.999615, -22.423199188672683`}}], 
      LineBox[{{47.499561, -21.287037875136214`}, {
       47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
      LineBox[{{49.999523, -27.91448197690941}, {
       50.249519, -27.305559271827388`}}], 
      LineBox[{{51.999493, -20.885769001862567`}, {
       52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}], 
      LineBox[{{52.999477, -22.174453342075132`}, {
       53.249474, -24.83933405846568}}], 
      LineBox[{{54.249458, -23.722525323809897`}, {
       54.499454, -23.580299515887834`}}], 
      LineBox[{{56.499424, -21.766646750655234`}, {
       56.74942, -23.57640470224996}}], 
      LineBox[{{58.249397, -23.599923997532017`}, {
       58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
      LineBox[{{59.249382, -17.837453345617426`}, {
       59.499378, -21.77661789863478}}], 
      LineBox[{{59.999371, -21.620808909572247`}, {
       60.249367, -21.022793121071274`}}], 
      LineBox[{{61.749344, -23.521435622331904`}, {
       61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
       62.499332, -19.42225543656815}}], 
      LineBox[{{63.499317, -20.822384760816565`}, {
       63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
      LineBox[{{64.499344, -25.343231741743004`}, {
       64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
       65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
      LineBox[{{68.249573, -26.50222788848888}, {
       68.499588, -26.988563201691523`}}], 
      LineBox[{{70.749725, -20.1140901131646}, {
       70.999741, -20.81539559964317}}], 
      LineBox[{{72.249817, -27.41004150424379}, {
       72.499832, -25.260157006181224`}}], 
      LineBox[{{72.999863, -23.234537488989123`}, {
       73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
       73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
      LineBox[{{75.25, -25.575903773461626`}, {
       75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
       76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
       76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
       77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
       77.500137, -21.438588076795124`}}], 
      LineBox[{{78.000168, -22.06377454291717}, {
       78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi
w47HAqjAQixYEOxwLMSCYkFRVLDBl+/k/ZVrX5k9M2vt2fu5b3tBzlTxMBKJ
9EqLRPr/34la04eGt02DyGWnilTvgvG1/bRIbdU06E/q9Uv9h4vTSTmF2r3T
QMY7M+HnyRDUtk9BbVI8RF7dsr95GRfLokcNadPioTUOY+Z8DcIQgVekDise
Vn5OzXZ2D8SLML5QhxMPWyZvPOnX7I+JfH/UgXg49OhrrqzQHz8X2g7pxMVD
3fCKBiLMH9dWkCN1iXgIOnFu2EwnfzQudCzUzY0HHfH9Qy/H+uPhvYaoq4gH
dv2lmCff/HH0pf5B3ZJ40O36M/34yQC8pmSMJCvj4eGvd+Nv0oOR3/hHQa6K
B+a50lajy0H4+/mbBjLGg537ynGWi4Jw+7C7g+S2eNg+MH9D6OsgtHreE01R
xYO4Sf8RvzkYz2i1Kyi98XBtbLiPwaMg/MvhUgOFlAC2BoHdhbwAfDfy2CCF
lgCyD4z6ged+mGXfHK3HSgDF7ZNb+l77InnkPwo9TgL0pS594xHtixWC3Q16
kADDTFkVuR85GF60clAvLgHsX/1tFtDFwQZ+RbQ+kQCC+tVPrgX5YuqytQr9
3AQw7lgcGfHKF79VLGjQVySA0fiBv5rp/rihiRjUL0mA/gCX4q6TgWhSkR9N
VSbA1hHpHlWqQDx+SaKgViUAyePpFM+8ABz3Mq6BignwtbXR4PQ/AfhieNgg
tS0B7sRcz3bZH4jiF4nRBqoECL89enx/aACShkcrDHoToOrlxsnVZ31xp6NH
gwEpEcK63XLtJBwMHG02aEBLBIv7yWdnfvDGGgffaENWIsy7NWr7jyteOHWU
tcKQkwj8cfJDVyO8sEeo02AIiTCrM8v02RQvLF7+6Y9hXCIE2X8vf2rojVQh
NdqISITI+4nt5zf64IGib3Kj3EQIHhnQdsfRF2F/Z72RIhGWXZ3+4tx2f2xa
9kvLuCQRomj5T82p/sjb1wXGykSY//VGY7WrHw40tcqNqxJBZPKjsW+bH25+
VVtvjInwK23WUxf192Xe9ECL1pYIN5rnur2M9cWqlw1AUyUCeV3aPfjthRO1
j8hpvYlQ1TN15YfVHvjaaUs9jZQEY9+9DXZ55Iay4VVadFoSsBPv+pm3sHG4
006gs5LAak7bsLGZbCwbvVxO5yRBWtjC4/+uYyNXnF1PhyToenycPErqhhdG
rdYyiUsCKr2sM8bEAxNF88CESII8cYvFF7I3fl6eITfJTYJRKQ/TL8z1xTUH
YupNFEmw1tYwJ28xB42Wi7QYJepxx2d9YYEPHt4fCwxlEpRcc559i8vBUVe4
ckZVEgx+fPyQm8jBZ10O9QxMAv0bRIDpbQ/kX47UMm1LAuNTv4xmXnLF36/Y
YKpKAuLOutjZBc64TYchN+1NgkOxVlPCBhzR1+VPnSkpGfyFa5suGDviGe0R
Wma0ZAjLaf88WOeAsc7DwYyVDPOM3+ZydR3x7ZieAjNOMkQyD8jb+h0xy0nv
khkkAyPsmqz8vDOSx/SRzOOSYWfrgier1P3bK34aZU4kQ/7B8vn3uV4YvvJa
gXluMohebzxrsdsDG0QvG80VyfBSl9+wdZs7pqxoIVmUJMOOm4wwxgZ3/Hqg
OspCmQxt01dc1Y5www1X9xZYVCXD7LRho8qvOKLJgbpGC0wG6ehr86heLDx2
5RDJsi0Zqkb7pAiCbHDc641Rlqpk0JpPy83LGYEvdPMLLHuTYWPcm4mL1DNF
XdsbLUkpIC3/1Whvb4FDOstII2gp4DpR9l2wygJ3umRFjWClwN7r7fdvfLPE
gHGJBSM4KTDnbueECQutsdp5TuMISAFGh+6o8zZMnDo2nWQVlwJnn/6uMC62
xx7J2CgrIgWSusT9CQ8dcNUqToFVbgqMlu3156+3R33JpEYrRQqQtGBR6jEW
HlgZRLIuSYHqqxlTu93tMeoQK8pamQJim5CQkc/s8d9r+gXWVSnQXf7n7VaJ
LfIOujRaYwr4XbHvIO2yxIGrNJJNWwrUFS5+EbDdDDe9+Rlpo0qBBaJ+7sVn
DDS7ar7MpjcFomyu2y+IYGDVa1KjDSkVCv+cLBqQMXAC+f2QDS0Vdh4yTrKa
Z4pdrg8ibVmpMHdhjqrJ2xxluuoTnpMK53j+43vsLHG462O0hVSYNrWw2WuR
Fe4Zd2XINi4VYuzPekyZaoNc2clIOyIV6owOzP1lZYsXxt4stMtNhTkrEs+t
CLfFBOlZtFOkwovxc3LiSTbYu6p8yK4kFYSksXHnxo/ANZV/RzKVqXA3cu1d
v1PmaLTqQCGzKhX6rmZ+XXXKFCsPbUAmpgJ3sWnBr+UMHNW8aIjZlgrPjj8O
emvFwGfdwkiWKhWalRfXso8xkLgmL2T1pgLn+xfF8rVm+OvNdGSR0uDVp9HH
zQYscRslfohFS4NLO7Y4uVNskOMWGWnPSgNDd9aYlyut8DQ5tdCekwZW9vkp
gxWWGMsejfaQBqfkZfSvvyzwbYz3kH1cGry+xzYp67PAoumWkQ5EGnhQWsf3
3bFA3ZiAQofcNAjp89pmPMUC98rs0EGRBiQbi2UH15pj2N+UIYeSNGgNejkW
R5rjw8NfIhyVacCbo3UxOtkcU4qNCh2r0mD/Yz9b+Qpz/Fo50OCIafB7YElG
yhhzXH/9xaBjWxqc+bHy0P12M6RXDkY7qdKgRvzv5TRPczzW3K1w6lXPl8VN
/b3RAse9vdvgREoHUpBpfIj7CHyuVzfoREuH09XyIy/8RqCouz3amZUOxwcO
nqCuscQhSpPCmZMOYtohZxHXEne4HW9whnRweqdyXvzRAgMmbB90jkuHzFVN
S8+p91c1+3S0C5EOd7O6pr6tscCp4/coXHLVzxtqGoziWeCH6asaXBTpcJKc
fbHtizmuWj170KUkHd63MWfuYpmj/vR10a5K9fz3Z0UyAzPc//dChWtVOsQE
DZ3boWeKUUf4Da6YDorEzXmj7jLw3xsTB13b0mFPi2JqbZIp8g5Lo9mqdFhU
OCG0eqUZ9l+fomD3psOxajfD4C/q/fEurIFN4oF8DGedhZ45elFdBtk0Hphw
F9n8DDDHk2+jo91YPGB2LWGseGCOE/Q9FW4cHmjVXP545oUFdrmbN7gBD26u
3GZa8cgS5RNJg25xPGjaUn2GO8USh7nbRLsTPPCo3Ep0CcxxzwRdhXuuenxi
wFZywxS5M3vr3RU8SBhzvmgqj4HnxxsM8yjhwdeb5pKKShNMmPEdPJQ8GLXt
8IEtl02wd7VK7lHFA/rVwdH7VjNw9dEb9R7IA8ajNZZvskzRcPVrLc82HnDf
Jq1ufaneH0fawFPFA+mEEGarkRmOunle7tnLg0/VPQ10NMOn7/fXe5IygKh7
N0o81hKJG6jlRcuA2jNMx87vVvjr3RHwYmXA6P6rg6s/W+JW6la5FycDIpSp
7491miPHU17vBRnA+iB9XhFnjqf1d2l5x2VAtt2cFrf7ZhjrsQK8iQy4YNwp
mrjcFLsn5si9czNAmJ1zXp5lgkVZKfXeigw4u9/GaeU4OupOnK/lU5IBPevz
83e8p6FyZib4KDPA6+Gag5OS6Ri2drzcpyoD+sp+TfGbaIIPj/nX+2AG3Ljw
zPMZn4Epa/7S4rRlwIa8C/JkuSn2HQ0Bjkp9/3vZ1JjpZrj+lqOc05sBl9LX
vlk4zhzdegzrOaRMWGGmnTZJ2wKP3nTT8qVlgmLvT1XXTQsc+4EBvqxMWNK3
2+Cw3AKfGwwW+HIywfGk8IjwiCku8equ84VM8Bu83JdaS8dBqraWX1wmSKKu
UfdkG+MOz49RfoT6+rxEm8gRBhgwub3ALzcT4rJEjmUL9fCcx9dGP0UmTHNL
u+75noxTJj0j+ZdkQuCcn/dVl8n4Ias5yl+pvv+R/Y5PT1Jw5bp/CvyrMmH9
1wi36in6qJd1u9EfMyHp5Pm5VfsMcP/aGlJAWybUGb5KeTNkjFHHK6ICVJkw
r37S/a1jTLCjZW1BQG8mlF3LOGmu7o934n3CikSA2/sHRcOmqOuRjFdYUdTj
wNJf/jvoeH1BfbkVjYBE/0T30AIjNF/l32BlScBnm+DiLYZUTFrQqLJiEeBB
WNuNtaNo8otNwL3zjtssOnXwy7ajTGsOATprAw7Mv6utyTMuAa+iVvDMzHSw
cNsJwhoIcCGeGcUSunj7oKPCOoaAsfONawtWUdCmurTcOo6AB8fLx9/cRsXp
1wwbrJMJuCbd3nTc3xiPnNulsiYIWDjQ6JW3k67JPxkBSQVzX/2eysAxj1Yw
bXIJID3Z2hlJMDR5mEeAYX5P4a1bdLz/sJiwURCQe2L6228UY7R/80duU0zA
NPqS4csL9TG7f065TQkB7cvClz7TI2vyspSAr7o6FVuNdfDP9/kqGyUBtrPH
d/Ut0tbkZyUBP18//uLVr42lFgTTtooAzqz0Zx8SdLFD9yPY1hCw5OCdWIaC
gq4WQsIWCdj4zHH39CYqznNtl9s2E3C0LnZB1kwaNgZPLrdtI+DM2RbP74cZ
mrxtV89PulzOmWWKccFxKlsVAcM8o2doU0w0+dtNQMdkwbKOP8b4PimUader
7kfqOUlyswF6jmsGuwECrhb81O95q4eLkiIIOxIfLI/dnnKjgozXpP/I7Sh8
QHZsbV64LprmuZbb0fgwJrsm93W9jiavLflQTV7MejKog/sWuqvsWHzIN+ie
dS+IrMlvNh/6P797MOZvPYwoNWUyOXyg9/onm8oNUL6qAphcPnzom53nnWeM
t7arGwR8EERbNlpy6WhVuVbOjOGDLt+opaDEBKU1WuXMOD5sCnyzUfXDRJP3
yXxo6tVqevCDjt+rtVVMgg9ORcfG5CyjafJfxodVZSlvLNhGuLyabM/K5cOF
ugPbnJqpePdaPrDy+PB2KLK2OkQfme2fM1kKPvgoToUes9TDrG6JnFWsru9Y
y/PPHAqeePRVySrhg69p1erUW2QNL5TyYVTizakbHSkYM/Csk6Xkw7vvXbGN
dykafqhU17PfvPb6Hz181P+cZV/Fh4FllGKDHio6U5LAvoYP06ZdGZew0Ajn
WN7KtEc+nJbqu51eT8MGdrTcvpkPLbGnFYf30VHLslVp38aHlbLkgrsX6Rre
aOfDhDdjlrcU0XAXt7bTXsWHxjqHE4/V9f7HH918yBrbt/GvnVR0515kOfTy
gfTlxw1rPz1cGOMLDgN8yIgetWxdFhmvJB/MdCAJ4ETO3tiI6bpoMt1a7kAR
wPG8vQce9uvgtOTDSgeaAJ7V3p4/2ldXwyuWAkibHOxTG0bGj3mbOx1YArhe
1rXK3VZPwy9sARRqhf6cfZmKS/O2sRw5AjiwJqRv6y8jvFFMBUeuAFIdXDMN
3tHQcoci0xEEUGVgmjX6IB3Fh78VOMYIYP3medkXFtDxYGmR0jFOAInCsQ4t
c2ga3kkWwKX8b/GTSw0xunZWpyMhgLmct61nZ+njsspfJCeZAC771o49z6Bg
W00uyylXAGvW5uW+U+ii7fWuKKc8Acy6PrKRt0kHZ3SkZjopBLDJs76gPF1H
w0fFAjAt2vyi21QXf7TzlE4lAmh1k07adJ2s4aVSASxbsXfsimx93PJjXKeT
UgA+lU4B+y4a4oPuByTnSgEsCbw7Nb+eho4/JrCcqwRAFu5qr5WbYK4eRjnX
CGD8Gi0DyQMTrBsRmOmMAvgnzEDXNJeu4atmAXzMiNrkvNgIJ43gKp3bBMAu
vpLrX6yv4a129XrknGHePk3GNyEOnc4qAVQ0r6rd8kAH2W5VJJduAdh9K03o
1dXB+SHOLJdeASSM3LDt62gdbBq/M8plQH397n3KbZN1kZZqnOlCEsLbOQHb
Pnwha/iMIoQzLYqdhlH6WJ5ionShCaEmpHGYw1+GGl6zFIKvVn++xxoahi7+
/cyFJQSPGZXasb10XDJ9NcmVLYR1D2O4JSo6/v92dOUIIeG55HBIMw3NV8+L
cuUKIZfaVzGSZ4RJi4bxXUEIDwP39XGyqBq+ixHCdXnJ3HBXPfyy40O5a5wQ
lmodWmiUQ9bwXrIQnnb9Xdafo4uKHZ9UroQQVpwy8ysdo86PwyISWyYEq2xS
/r53umh9voPJzhXC7qicyT05FJTdiI1i5wnhRcIj+r27+nik9gnBVggh5mbG
Pru3hho+LBZCaIcB+VQ1Dcf8e7WcXSIEXD8t9IW9iYYXS4XQ3Mw1KtFi4L2O
6yq2UggZsx3onHoTtH8XSXKrFMKqXJ9di+fSMfvnaaZblRDAt+mkU7MxXtB3
i3KrEcLZq7XkeYcN8M+Pc4Qbqvuf+2XhY/V59B9fNgthz7CRlq0VFNxutbfc
rU0I7TN5z3sekDW82S4EifWwmfk1ZHSx2q9yUwlh8/vIiHthFJzrPoLk3i2E
BTuLGhTJetgYup7p3iuEltl/LKuYVDSaODzKfUAIn/kuH3afM8S40I2EO0kE
8zZtFq87RtPwKUUEWkeFjeUHTfBd6pJyd5oIRLFrf/IiTdFzgl6ju6UIHF2a
R90jmeKi1AKVO0sEbpF/DFaZmeDVGX1D7mwRHHo/4dp+Nf+YLpExPTgi8DU5
eNNlIlXDs1wR3Hly8dWdRApWLJ5JeIAIzDKKu61X6Gr4NkYEKmermZPqdDBi
V0K5R5wIRpTAssMdOliw+iV6JIuAXHX/3pk3unhrZ7LKgxDBmy1DK44gBUcc
bRnykInAvZQ8M2A8FSUXRjI9c0VwNG5JZs5ZIw0P54lg7tyd53lFdPx2fgzh
qRDBAHW0cfIrhoaPi0Wwh5f/6jzDDEse+5R7lojg5FDjur+kDLxzow49S0Vw
NYrvxvhJQ+ZjP5WnUgRhxrsVF28ZYtb7Q0OelSJwnTTq4uM/+lj7y4bpVSWC
NNmE8IPq8/c/nq4Rwfw9rxsof8gY84tJeKH6f3J46Vv19/0fXzeLwOnr+FK3
SjK+tNYv92oTAe8mw3/lYwo6UUvRq10Ey20+dOsYUXG2taHKSyWC3l5hmjjQ
CBs8lg15dYug/sqCRVe06GgQ3m/n3ateH2ig/mIyNDw+IIKticfym26b4q6w
n5neJDHMqhFbtx76H59TxLB93GO9GBID3cP+KL1pYnCyi5VxWmi4cOIc9LYU
g4EyPN7qviFeTnvT6c0Sw8gWgf4DBhVNstKHvNli4CyO/rLfQQ+npb1j+XDE
EDn55MIfEykanueKoXFfgNjJm4Ifl9zP9AExvNwjn7q5jKLh+xgxbOj3uu/w
RA/zlzxS+sSJYdqCnC+791LxxppJ6JMshuObKHfaLI3QYndjpw8hhgpT1cyH
rTQUHQsa8pGJIXFlUs6+HhM8uOsyi5Mrhl02U7TXM/7nA3licKHbzFQdYmD0
xROZHIUYzpqPfHlwgK7xg2Ix/Ft117rbjoatF04pOSViKHvfkRASZIi2t1yQ
UyqGXhrr67pr+jjjya5OjlIMX9LvN2Uy9LD6A22IUykG56Ki5Uii4I/HZSzf
KjHEPOSEzFWf1//5RI36/W/Pc/jLjYKbfxdn+qIYvku2xdZ562n8olkM4U0k
bHqujw6/1yh928Tw6a+nFox8Q8wx0ELfdjFcOfri0NEFNKyzWdDpqxKD94eH
WbIZJhr/6BaDRdvJuMBBBk6yWcTy6xWD6wf6+1tsU42PDIgh2uZT9uwDJvg6
XJjpR5LAQ58RCVFiGrI9Pyv8KBJ4dJbRUPzNAOeHS5R+NAkczardqjDSx0uT
Hjf4WUpgYc2HswfYFKTx4jr9WBKotG0bsrb+n7+wJTB/6OXLjke6WJY+jeXP
kUDHREfWfMX/fIYrAf7tB7F33lEwZGlEpj9IYMq/b/5e5EPFxVk3Ff4xEthU
3zu0VmyEzfmg9I+TgGjn7xML4tXGuu5sg3+yBI7FTm4uppuiYI97pz8hgeQ3
R6eOyjTT+I9MAuMCOi9938PAz7u9WAG5ErBZGLa5toum8aE8CSSUdo1e8tEA
19ZZZAYoJGDabSN/rPaxlmMHFAHFEvh64nJ4aDoZreuslAEl6nobpn3aCboo
a9nQEFAqAd7vp+cf9ung2afanQFKCdzbe6WsbKku9t/aRAqslIDtkzBjq3tk
HP2UzAqskoCL4MlPkr4+buzJjwqskcDdcSPcnk4zxHtP9PmBKIFZyf9cDL9F
Q1aPXBHYLIHhbO03TbkMnPXna3lgmwQWRO9sk7LN8ILhjIbAdgl8vp7xrs7O
FH//7lcFqiTw8rjvw5+v6DjBcBYpqFvd/4Ozml7cM8btti+YQb3q9du89TNj
twG+8kqKChqQQIwy6sF2iT662HYRQSQpPN/Us1bB0sO5XqmKIIoU9jyVz1qv
9k2MaC0PokmhUd/U6kwHBY1iRzcEWUohO5vnXnhMD/+KuKsKYknhQZO1z8Ew
Ku6ePI4UzJZCt8xxz/FUQ3zHu8gM5kjhRu9+UZLaR4OzfaOCuVJwfZNRWJFH
x0W8BiIYpLDijO0YfKzOj1kBiuAYKWzP5rUUixjIKDhcHhwnBcMX2qUJaIL8
9XYNwclS4AWFmR0X07Fi6TFVMCGFbXO2OxWZ0/DTOnsSVyYF7bhql6n/GmJE
2TYmN1f9PlZei870UnH1CWoUN08KVJcvS7TL9PHmnh0EVyEFnX4y9Q9LH0ec
MFJwi6WwQLF+2Pw0fZTUF5VzS6QwlZwt5U+j4unbA/XcUikk7XmvZ95kgN/q
Vqq4SilgwPro6QFGOPL2ryFupRT6bxuuGNNhjBue5TJDqqRgXuPcWtRNwzst
gxBSI4U/R2ubdRaZoN2zuUQISmFocJL8bAcDsz52y0OapTBnfJzB7xcMrB3k
lYe0SWF6Qm9eTIcJ/ux5jyHtUlBD2saTi+kYM0ioQlRSuPPKlm4WQsOtRg+H
Qrql8EJnUc/RWCN8YTeRGdorhU8Bab652wzQyagDQgek4De3vH5cnDo/7GKJ
UJIMjpfPMMu5o4/13k3yUIoMGk5E+1uMoKJBFLc8lCYDrSDXCcGDVJzsfRVD
LWVQyM0UjSwyxJ2RYapQlgzOGT/O6T9tjN2xVUOhbBnMEhb+rFf7nJpumWEc
GTCW7Q6uqTPBhbGnIYwrg0XmrHSPzwy8nMEmwkAG5VsUp46XmSI9Z488LEYG
E4s2T52s9ttMuUl5WJwMXMtW5smMGajMVmJYsgwE93/E9sfRsafATBVGyCDs
kv/Wph3GGLZh9VCYTAavyHP0HvEMsVito+G5Mji7+eLbQ8YGeH39OgjPk0F3
9dLqXUlUtCgfRoQrZOC1JHjyP2wqik4ulIcXy6Dv5p2lqSuoeKBMZ294iQzm
PPrZmnPZAPtOLMbwUhmspgYGMV8aITR86gxXyoCd1fGPVhMN17WKhsIrZbDl
9piOZDDB1vovrIgqGexctcj3pzpvbFqlEFEjA49/+y/8mWeKMzqfZEaguj8b
Nh7MqGVg9acp8ohmGSRs0fl+w9kE1XqpjGiTwbB5hlpeI2k49lM8RrTLwO/f
1MY0L0PcPHS9M0Ilg/EU1VLxKX1UGUcNRXTLwNwqesF0Jz10GLrFiuyVQcnn
+6J7EgrmGI+EyAEZXEq+aDVlHQUvMqszI0nTYauc7Dhlnh7+HzlzcVU=
       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Phi]\"", TraditionalForm]},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969291119*^9},ExpressionUUID->"76305f36-f310-45f1-8bc4-\
694e8cef5bc3"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -76.14742169746623},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-73.68272297580947, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-71.38013788281542, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.7173599693391533`*^9},ExpressionUUID->"0e3ef7e2-e5c2-4d06-a468-\
30e7ca094a70"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -30.303766533418063`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, Automatic},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {3.912023005428146, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969374181*^9},ExpressionUUID->"c2280691-1039-436b-96a6-\
c9618996badc"],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
      {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969408207*^9},ExpressionUUID->"c3ebb88d-5f2b-43f8-b46d-\
7cae24289415"],

Cell[BoxData[
 GraphicsBox[{{{{}, {{}, {}, 
      {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[{{0.5, -20.58731462444898}, {
        0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
        1.25, -27.50184105161661}}], 
       LineBox[{{4.249998, -23.11696430864725}, {
        4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
       LineBox[{{6.750008, -23.038818749837983`}, {
        7.000009, -20.322035683613738`}}], 
       LineBox[{{7.750011, -20.716014193782303`}, {
        8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
       LineBox[{{11.250025, -19.142376381324734`}, {
        11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
        12.000028, -22.492142720939622`}}], 
       LineBox[{{12.50003, -24.045787259895636`}, {
        12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
       LineBox[{{13.750034, -21.052099541576304`}, {
        14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
        14.500037, -21.409428863587927`}}], 
       LineBox[{{15.500041, -21.61333098548902}, {
        15.750042, -22.10549208407436}}], 
       LineBox[{{17.250023, -22.856107311471863`}, {
        17.500019, -22.566864012429928`}}], 
       LineBox[{{18.000011, -21.834193448858855`}, {
        18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
        18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
       LineBox[{{19.499989, -22.216470803381476`}, {
        19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
       LineBox[{{20.499973, -28.088099516986762`}, {
        20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
        21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
        21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
       LineBox[{{22.999935, -19.74888960999384}, {
        23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}],
        LineBox[{{28.749847, -22.783129874707647`}, {
        28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
       LineBox[{{30.999813, -24.728294878757325`}, {
        31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
       LineBox[{{32.249794, -20.837058021652666`}, {
        32.49979, -21.361849645654928`}}], 
       LineBox[{{32.999783, -20.84333950660284}, {
        33.249779, -18.469001093501973`}}], 
       LineBox[{{34.999752, -25.06864583779922}, {
        35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
        35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}],
        LineBox[{{38.499699, -24.377795653123645`}, {
        38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
       LineBox[{{39.74968, -22.650120892941615`}, {
        39.999676, -22.80728905851026}}], 
       LineBox[{{43.749619, -22.041875381710568`}, {
        43.999615, -22.423199188672683`}}], 
       LineBox[{{47.499561, -21.287037875136214`}, {
        47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
       LineBox[{{49.999523, -27.91448197690941}, {
        50.249519, -27.305559271827388`}}], 
       LineBox[{{51.999493, -20.885769001862567`}, {
        52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}],
        LineBox[{{52.999477, -22.174453342075132`}, {
        53.249474, -24.83933405846568}}], 
       LineBox[{{54.249458, -23.722525323809897`}, {
        54.499454, -23.580299515887834`}}], 
       LineBox[{{56.499424, -21.766646750655234`}, {
        56.74942, -23.57640470224996}}], 
       LineBox[{{58.249397, -23.599923997532017`}, {
        58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
       LineBox[{{59.249382, -17.837453345617426`}, {
        59.499378, -21.77661789863478}}], 
       LineBox[{{59.999371, -21.620808909572247`}, {
        60.249367, -21.022793121071274`}}], 
       LineBox[{{61.749344, -23.521435622331904`}, {
        61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
        62.499332, -19.42225543656815}}], 
       LineBox[{{63.499317, -20.822384760816565`}, {
        63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
       LineBox[{{64.499344, -25.343231741743004`}, {
        64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
        65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
       LineBox[{{68.249573, -26.50222788848888}, {
        68.499588, -26.988563201691523`}}], 
       LineBox[{{70.749725, -20.1140901131646}, {
        70.999741, -20.81539559964317}}], 
       LineBox[{{72.249817, -27.41004150424379}, {
        72.499832, -25.260157006181224`}}], 
       LineBox[{{72.999863, -23.234537488989123`}, {
        73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
        73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
       LineBox[{{75.25, -25.575903773461626`}, {
        75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
        76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
        76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
        77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
        77.500137, -21.438588076795124`}}], 
       LineBox[{{78.000168, -22.06377454291717}, {
        78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
      {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[{{0.5, -20.58731462444898}, {
        0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
        1.25, -27.50184105161661}}], 
       LineBox[{{4.249998, -23.11696430864725}, {
        4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
       LineBox[{{6.750008, -23.038818749837983`}, {
        7.000009, -20.322035683613738`}}], 
       LineBox[{{7.750011, -20.716014193782303`}, {
        8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
       LineBox[{{11.250025, -19.142376381324734`}, {
        11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
        12.000028, -22.492142720939622`}}], 
       LineBox[{{12.50003, -24.045787259895636`}, {
        12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
       LineBox[{{13.750034, -21.052099541576304`}, {
        14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
        14.500037, -21.409428863587927`}}], 
       LineBox[{{15.500041, -21.61333098548902}, {
        15.750042, -22.10549208407436}}], 
       LineBox[{{17.250023, -22.856107311471863`}, {
        17.500019, -22.566864012429928`}}], 
       LineBox[{{18.000011, -21.834193448858855`}, {
        18.250008, -22.051414693782682`}, {18.500004, -18.077316596913327`}, {
        18.75, -24.91015999289932}, {18.999996, -23.72588738716398}}], 
       LineBox[{{19.499989, -22.216470803381476`}, {
        19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
       LineBox[{{20.499973, -28.088099516986762`}, {
        20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
        21.249962, -26.024262389309694`}, {21.499958, -23.934378126196787`}, {
        21.749954, -21.38673829965319}, {21.99995, -20.845251905483718`}}], 
       LineBox[{{22.999935, -19.74888960999384}, {
        23.249931, -22.259315286011166`}, {23.499928, -24.055265008205094`}}],
        LineBox[{{28.749847, -22.783129874707647`}, {
        28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}], 
       LineBox[{{30.999813, -24.728294878757325`}, {
        31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
       LineBox[{{32.249794, -20.837058021652666`}, {
        32.49979, -21.361849645654928`}}], 
       LineBox[{{32.999783, -20.84333950660284}, {
        33.249779, -18.469001093501973`}}], 
       LineBox[{{34.999752, -25.06864583779922}, {
        35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
        35.749741, -28.101735397627934`}, {35.999737, -20.484837298503287`}}],
        LineBox[{{38.499699, -24.377795653123645`}, {
        38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
       LineBox[{{39.74968, -22.650120892941615`}, {
        39.999676, -22.80728905851026}}], 
       LineBox[{{43.749619, -22.041875381710568`}, {
        43.999615, -22.423199188672683`}}], 
       LineBox[{{47.499561, -21.287037875136214`}, {
        47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
       LineBox[{{49.999523, -27.91448197690941}, {
        50.249519, -27.305559271827388`}}], 
       LineBox[{{51.999493, -20.885769001862567`}, {
        52.249489, -22.895170973799672`}, {52.499485, -19.058190778324565`}}],
        LineBox[{{52.999477, -22.174453342075132`}, {
        53.249474, -24.83933405846568}}], 
       LineBox[{{54.249458, -23.722525323809897`}, {
        54.499454, -23.580299515887834`}}], 
       LineBox[{{56.499424, -21.766646750655234`}, {
        56.74942, -23.57640470224996}}], 
       LineBox[{{58.249397, -23.599923997532017`}, {
        58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}], 
       LineBox[{{59.249382, -17.837453345617426`}, {
        59.499378, -21.77661789863478}}], 
       LineBox[{{59.999371, -21.620808909572247`}, {
        60.249367, -21.022793121071274`}}], 
       LineBox[{{61.749344, -23.521435622331904`}, {
        61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
        62.499332, -19.42225543656815}}], 
       LineBox[{{63.499317, -20.822384760816565`}, {
        63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
       LineBox[{{64.499344, -25.343231741743004`}, {
        64.749359, -28.307484449102994`}, {64.999374, -26.398401381300623`}, {
        65.24939, -25.315002655989222`}, {65.499405, -22.723177048349438`}}], 
       LineBox[{{68.249573, -26.50222788848888}, {
        68.499588, -26.988563201691523`}}], 
       LineBox[{{70.749725, -20.1140901131646}, {
        70.999741, -20.81539559964317}}], 
       LineBox[{{72.249817, -27.41004150424379}, {
        72.499832, -25.260157006181224`}}], 
       LineBox[{{72.999863, -23.234537488989123`}, {
        73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
        73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
       LineBox[{{75.25, -25.575903773461626`}, {
        75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
        76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
        76.500076, -23.461493017322223`}, {76.750092, -22.502769318560176`}, {
        77.000107, -22.727530149759858`}, {77.250122, -21.607547857437314`}, {
        77.500137, -21.438588076795124`}}], 
       LineBox[{{78.000168, -22.06377454291717}, {
        78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi
w47HAqjAQixYEOxwLMSCYkFRVLDBl+/k/ZVrX5k9M2vt2fu5b3tBzlTxMBKJ
9EqLRPr/34la04eGt02DyGWnilTvgvG1/bRIbdU06E/q9Uv9h4vTSTmF2r3T
QMY7M+HnyRDUtk9BbVI8RF7dsr95GRfLokcNadPioTUOY+Z8DcIQgVekDise
Vn5OzXZ2D8SLML5QhxMPWyZvPOnX7I+JfH/UgXg49OhrrqzQHz8X2g7pxMVD
3fCKBiLMH9dWkCN1iXgIOnFu2EwnfzQudCzUzY0HHfH9Qy/H+uPhvYaoq4gH
dv2lmCff/HH0pf5B3ZJ40O36M/34yQC8pmSMJCvj4eGvd+Nv0oOR3/hHQa6K
B+a50lajy0H4+/mbBjLGg537ynGWi4Jw+7C7g+S2eNg+MH9D6OsgtHreE01R
xYO4Sf8RvzkYz2i1Kyi98XBtbLiPwaMg/MvhUgOFlAC2BoHdhbwAfDfy2CCF
lgCyD4z6ged+mGXfHK3HSgDF7ZNb+l77InnkPwo9TgL0pS594xHtixWC3Q16
kADDTFkVuR85GF60clAvLgHsX/1tFtDFwQZ+RbQ+kQCC+tVPrgX5YuqytQr9
3AQw7lgcGfHKF79VLGjQVySA0fiBv5rp/rihiRjUL0mA/gCX4q6TgWhSkR9N
VSbA1hHpHlWqQDx+SaKgViUAyePpFM+8ABz3Mq6BignwtbXR4PQ/AfhieNgg
tS0B7sRcz3bZH4jiF4nRBqoECL89enx/aACShkcrDHoToOrlxsnVZ31xp6NH
gwEpEcK63XLtJBwMHG02aEBLBIv7yWdnfvDGGgffaENWIsy7NWr7jyteOHWU
tcKQkwj8cfJDVyO8sEeo02AIiTCrM8v02RQvLF7+6Y9hXCIE2X8vf2rojVQh
NdqISITI+4nt5zf64IGib3Kj3EQIHhnQdsfRF2F/Z72RIhGWXZ3+4tx2f2xa
9kvLuCQRomj5T82p/sjb1wXGykSY//VGY7WrHw40tcqNqxJBZPKjsW+bH25+
VVtvjInwK23WUxf192Xe9ECL1pYIN5rnur2M9cWqlw1AUyUCeV3aPfjthRO1
j8hpvYlQ1TN15YfVHvjaaUs9jZQEY9+9DXZ55Iay4VVadFoSsBPv+pm3sHG4
006gs5LAak7bsLGZbCwbvVxO5yRBWtjC4/+uYyNXnF1PhyToenycPErqhhdG
rdYyiUsCKr2sM8bEAxNF88CESII8cYvFF7I3fl6eITfJTYJRKQ/TL8z1xTUH
YupNFEmw1tYwJ28xB42Wi7QYJepxx2d9YYEPHt4fCwxlEpRcc559i8vBUVe4
ckZVEgx+fPyQm8jBZ10O9QxMAv0bRIDpbQ/kX47UMm1LAuNTv4xmXnLF36/Y
YKpKAuLOutjZBc64TYchN+1NgkOxVlPCBhzR1+VPnSkpGfyFa5suGDviGe0R
Wma0ZAjLaf88WOeAsc7DwYyVDPOM3+ZydR3x7ZieAjNOMkQyD8jb+h0xy0nv
khkkAyPsmqz8vDOSx/SRzOOSYWfrgier1P3bK34aZU4kQ/7B8vn3uV4YvvJa
gXluMohebzxrsdsDG0QvG80VyfBSl9+wdZs7pqxoIVmUJMOOm4wwxgZ3/Hqg
OspCmQxt01dc1Y5www1X9xZYVCXD7LRho8qvOKLJgbpGC0wG6ehr86heLDx2
5RDJsi0Zqkb7pAiCbHDc641Rlqpk0JpPy83LGYEvdPMLLHuTYWPcm4mL1DNF
XdsbLUkpIC3/1Whvb4FDOstII2gp4DpR9l2wygJ3umRFjWClwN7r7fdvfLPE
gHGJBSM4KTDnbueECQutsdp5TuMISAFGh+6o8zZMnDo2nWQVlwJnn/6uMC62
xx7J2CgrIgWSusT9CQ8dcNUqToFVbgqMlu3156+3R33JpEYrRQqQtGBR6jEW
HlgZRLIuSYHqqxlTu93tMeoQK8pamQJim5CQkc/s8d9r+gXWVSnQXf7n7VaJ
LfIOujRaYwr4XbHvIO2yxIGrNJJNWwrUFS5+EbDdDDe9+Rlpo0qBBaJ+7sVn
DDS7ar7MpjcFomyu2y+IYGDVa1KjDSkVCv+cLBqQMXAC+f2QDS0Vdh4yTrKa
Z4pdrg8ibVmpMHdhjqrJ2xxluuoTnpMK53j+43vsLHG462O0hVSYNrWw2WuR
Fe4Zd2XINi4VYuzPekyZaoNc2clIOyIV6owOzP1lZYsXxt4stMtNhTkrEs+t
CLfFBOlZtFOkwovxc3LiSTbYu6p8yK4kFYSksXHnxo/ANZV/RzKVqXA3cu1d
v1PmaLTqQCGzKhX6rmZ+XXXKFCsPbUAmpgJ3sWnBr+UMHNW8aIjZlgrPjj8O
emvFwGfdwkiWKhWalRfXso8xkLgmL2T1pgLn+xfF8rVm+OvNdGSR0uDVp9HH
zQYscRslfohFS4NLO7Y4uVNskOMWGWnPSgNDd9aYlyut8DQ5tdCekwZW9vkp
gxWWGMsejfaQBqfkZfSvvyzwbYz3kH1cGry+xzYp67PAoumWkQ5EGnhQWsf3
3bFA3ZiAQofcNAjp89pmPMUC98rs0EGRBiQbi2UH15pj2N+UIYeSNGgNejkW
R5rjw8NfIhyVacCbo3UxOtkcU4qNCh2r0mD/Yz9b+Qpz/Fo50OCIafB7YElG
yhhzXH/9xaBjWxqc+bHy0P12M6RXDkY7qdKgRvzv5TRPczzW3K1w6lXPl8VN
/b3RAse9vdvgREoHUpBpfIj7CHyuVzfoREuH09XyIy/8RqCouz3amZUOxwcO
nqCuscQhSpPCmZMOYtohZxHXEne4HW9whnRweqdyXvzRAgMmbB90jkuHzFVN
S8+p91c1+3S0C5EOd7O6pr6tscCp4/coXHLVzxtqGoziWeCH6asaXBTpcJKc
fbHtizmuWj170KUkHd63MWfuYpmj/vR10a5K9fz3Z0UyAzPc//dChWtVOsQE
DZ3boWeKUUf4Da6YDorEzXmj7jLw3xsTB13b0mFPi2JqbZIp8g5Lo9mqdFhU
OCG0eqUZ9l+fomD3psOxajfD4C/q/fEurIFN4oF8DGedhZ45elFdBtk0Hphw
F9n8DDDHk2+jo91YPGB2LWGseGCOE/Q9FW4cHmjVXP545oUFdrmbN7gBD26u
3GZa8cgS5RNJg25xPGjaUn2GO8USh7nbRLsTPPCo3Ep0CcxxzwRdhXuuenxi
wFZywxS5M3vr3RU8SBhzvmgqj4HnxxsM8yjhwdeb5pKKShNMmPEdPJQ8GLXt
8IEtl02wd7VK7lHFA/rVwdH7VjNw9dEb9R7IA8ajNZZvskzRcPVrLc82HnDf
Jq1ufaneH0fawFPFA+mEEGarkRmOunle7tnLg0/VPQ10NMOn7/fXe5IygKh7
N0o81hKJG6jlRcuA2jNMx87vVvjr3RHwYmXA6P6rg6s/W+JW6la5FycDIpSp
7491miPHU17vBRnA+iB9XhFnjqf1d2l5x2VAtt2cFrf7ZhjrsQK8iQy4YNwp
mrjcFLsn5si9czNAmJ1zXp5lgkVZKfXeigw4u9/GaeU4OupOnK/lU5IBPevz
83e8p6FyZib4KDPA6+Gag5OS6Ri2drzcpyoD+sp+TfGbaIIPj/nX+2AG3Ljw
zPMZn4Epa/7S4rRlwIa8C/JkuSn2HQ0Bjkp9/3vZ1JjpZrj+lqOc05sBl9LX
vlk4zhzdegzrOaRMWGGmnTZJ2wKP3nTT8qVlgmLvT1XXTQsc+4EBvqxMWNK3
2+Cw3AKfGwwW+HIywfGk8IjwiCku8equ84VM8Bu83JdaS8dBqraWX1wmSKKu
UfdkG+MOz49RfoT6+rxEm8gRBhgwub3ALzcT4rJEjmUL9fCcx9dGP0UmTHNL
u+75noxTJj0j+ZdkQuCcn/dVl8n4Ias5yl+pvv+R/Y5PT1Jw5bp/CvyrMmH9
1wi36in6qJd1u9EfMyHp5Pm5VfsMcP/aGlJAWybUGb5KeTNkjFHHK6ICVJkw
r37S/a1jTLCjZW1BQG8mlF3LOGmu7o934n3CikSA2/sHRcOmqOuRjFdYUdTj
wNJf/jvoeH1BfbkVjYBE/0T30AIjNF/l32BlScBnm+DiLYZUTFrQqLJiEeBB
WNuNtaNo8otNwL3zjtssOnXwy7ajTGsOATprAw7Mv6utyTMuAa+iVvDMzHSw
cNsJwhoIcCGeGcUSunj7oKPCOoaAsfONawtWUdCmurTcOo6AB8fLx9/cRsXp
1wwbrJMJuCbd3nTc3xiPnNulsiYIWDjQ6JW3k67JPxkBSQVzX/2eysAxj1Yw
bXIJID3Z2hlJMDR5mEeAYX5P4a1bdLz/sJiwURCQe2L6228UY7R/80duU0zA
NPqS4csL9TG7f065TQkB7cvClz7TI2vyspSAr7o6FVuNdfDP9/kqGyUBtrPH
d/Ut0tbkZyUBP18//uLVr42lFgTTtooAzqz0Zx8SdLFD9yPY1hCw5OCdWIaC
gq4WQsIWCdj4zHH39CYqznNtl9s2E3C0LnZB1kwaNgZPLrdtI+DM2RbP74cZ
mrxtV89PulzOmWWKccFxKlsVAcM8o2doU0w0+dtNQMdkwbKOP8b4PimUader
7kfqOUlyswF6jmsGuwECrhb81O95q4eLkiIIOxIfLI/dnnKjgozXpP/I7Sh8
QHZsbV64LprmuZbb0fgwJrsm93W9jiavLflQTV7MejKog/sWuqvsWHzIN+ie
dS+IrMlvNh/6P797MOZvPYwoNWUyOXyg9/onm8oNUL6qAphcPnzom53nnWeM
t7arGwR8EERbNlpy6WhVuVbOjOGDLt+opaDEBKU1WuXMOD5sCnyzUfXDRJP3
yXxo6tVqevCDjt+rtVVMgg9ORcfG5CyjafJfxodVZSlvLNhGuLyabM/K5cOF
ugPbnJqpePdaPrDy+PB2KLK2OkQfme2fM1kKPvgoToUes9TDrG6JnFWsru9Y
y/PPHAqeePRVySrhg69p1erUW2QNL5TyYVTizakbHSkYM/Csk6Xkw7vvXbGN
dykafqhU17PfvPb6Hz181P+cZV/Fh4FllGKDHio6U5LAvoYP06ZdGZew0Ajn
WN7KtEc+nJbqu51eT8MGdrTcvpkPLbGnFYf30VHLslVp38aHlbLkgrsX6Rre
aOfDhDdjlrcU0XAXt7bTXsWHxjqHE4/V9f7HH918yBrbt/GvnVR0515kOfTy
gfTlxw1rPz1cGOMLDgN8yIgetWxdFhmvJB/MdCAJ4ETO3tiI6bpoMt1a7kAR
wPG8vQce9uvgtOTDSgeaAJ7V3p4/2ldXwyuWAkibHOxTG0bGj3mbOx1YArhe
1rXK3VZPwy9sARRqhf6cfZmKS/O2sRw5AjiwJqRv6y8jvFFMBUeuAFIdXDMN
3tHQcoci0xEEUGVgmjX6IB3Fh78VOMYIYP3medkXFtDxYGmR0jFOAInCsQ4t
c2ga3kkWwKX8b/GTSw0xunZWpyMhgLmct61nZ+njsspfJCeZAC771o49z6Bg
W00uyylXAGvW5uW+U+ii7fWuKKc8Acy6PrKRt0kHZ3SkZjopBLDJs76gPF1H
w0fFAjAt2vyi21QXf7TzlE4lAmh1k07adJ2s4aVSASxbsXfsimx93PJjXKeT
UgA+lU4B+y4a4oPuByTnSgEsCbw7Nb+eho4/JrCcqwRAFu5qr5WbYK4eRjnX
CGD8Gi0DyQMTrBsRmOmMAvgnzEDXNJeu4atmAXzMiNrkvNgIJ43gKp3bBMAu
vpLrX6yv4a129XrknGHePk3GNyEOnc4qAVQ0r6rd8kAH2W5VJJduAdh9K03o
1dXB+SHOLJdeASSM3LDt62gdbBq/M8plQH397n3KbZN1kZZqnOlCEsLbOQHb
Pnwha/iMIoQzLYqdhlH6WJ5ionShCaEmpHGYw1+GGl6zFIKvVn++xxoahi7+
/cyFJQSPGZXasb10XDJ9NcmVLYR1D2O4JSo6/v92dOUIIeG55HBIMw3NV8+L
cuUKIZfaVzGSZ4RJi4bxXUEIDwP39XGyqBq+ixHCdXnJ3HBXPfyy40O5a5wQ
lmodWmiUQ9bwXrIQnnb9Xdafo4uKHZ9UroQQVpwy8ysdo86PwyISWyYEq2xS
/r53umh9voPJzhXC7qicyT05FJTdiI1i5wnhRcIj+r27+nik9gnBVggh5mbG
Pru3hho+LBZCaIcB+VQ1Dcf8e7WcXSIEXD8t9IW9iYYXS4XQ3Mw1KtFi4L2O
6yq2UggZsx3onHoTtH8XSXKrFMKqXJ9di+fSMfvnaaZblRDAt+mkU7MxXtB3
i3KrEcLZq7XkeYcN8M+Pc4Qbqvuf+2XhY/V59B9fNgthz7CRlq0VFNxutbfc
rU0I7TN5z3sekDW82S4EifWwmfk1ZHSx2q9yUwlh8/vIiHthFJzrPoLk3i2E
BTuLGhTJetgYup7p3iuEltl/LKuYVDSaODzKfUAIn/kuH3afM8S40I2EO0kE
8zZtFq87RtPwKUUEWkeFjeUHTfBd6pJyd5oIRLFrf/IiTdFzgl6ju6UIHF2a
R90jmeKi1AKVO0sEbpF/DFaZmeDVGX1D7mwRHHo/4dp+Nf+YLpExPTgi8DU5
eNNlIlXDs1wR3Hly8dWdRApWLJ5JeIAIzDKKu61X6Gr4NkYEKmermZPqdDBi
V0K5R5wIRpTAssMdOliw+iV6JIuAXHX/3pk3unhrZ7LKgxDBmy1DK44gBUcc
bRnykInAvZQ8M2A8FSUXRjI9c0VwNG5JZs5ZIw0P54lg7tyd53lFdPx2fgzh
qRDBAHW0cfIrhoaPi0Wwh5f/6jzDDEse+5R7lojg5FDjur+kDLxzow49S0Vw
NYrvxvhJQ+ZjP5WnUgRhxrsVF28ZYtb7Q0OelSJwnTTq4uM/+lj7y4bpVSWC
NNmE8IPq8/c/nq4Rwfw9rxsof8gY84tJeKH6f3J46Vv19/0fXzeLwOnr+FK3
SjK+tNYv92oTAe8mw3/lYwo6UUvRq10Ey20+dOsYUXG2taHKSyWC3l5hmjjQ
CBs8lg15dYug/sqCRVe06GgQ3m/n3ateH2ig/mIyNDw+IIKticfym26b4q6w
n5neJDHMqhFbtx76H59TxLB93GO9GBID3cP+KL1pYnCyi5VxWmi4cOIc9LYU
g4EyPN7qviFeTnvT6c0Sw8gWgf4DBhVNstKHvNli4CyO/rLfQQ+npb1j+XDE
EDn55MIfEykanueKoXFfgNjJm4Ifl9zP9AExvNwjn7q5jKLh+xgxbOj3uu/w
RA/zlzxS+sSJYdqCnC+791LxxppJ6JMshuObKHfaLI3QYndjpw8hhgpT1cyH
rTQUHQsa8pGJIXFlUs6+HhM8uOsyi5Mrhl02U7TXM/7nA3licKHbzFQdYmD0
xROZHIUYzpqPfHlwgK7xg2Ix/Ft117rbjoatF04pOSViKHvfkRASZIi2t1yQ
UyqGXhrr67pr+jjjya5OjlIMX9LvN2Uy9LD6A22IUykG56Ki5Uii4I/HZSzf
KjHEPOSEzFWf1//5RI36/W/Pc/jLjYKbfxdn+qIYvku2xdZ562n8olkM4U0k
bHqujw6/1yh928Tw6a+nFox8Q8wx0ELfdjFcOfri0NEFNKyzWdDpqxKD94eH
WbIZJhr/6BaDRdvJuMBBBk6yWcTy6xWD6wf6+1tsU42PDIgh2uZT9uwDJvg6
XJjpR5LAQ58RCVFiGrI9Pyv8KBJ4dJbRUPzNAOeHS5R+NAkczardqjDSx0uT
Hjf4WUpgYc2HswfYFKTx4jr9WBKotG0bsrb+n7+wJTB/6OXLjke6WJY+jeXP
kUDHREfWfMX/fIYrAf7tB7F33lEwZGlEpj9IYMq/b/5e5EPFxVk3Ff4xEthU
3zu0VmyEzfmg9I+TgGjn7xML4tXGuu5sg3+yBI7FTm4uppuiYI97pz8hgeQ3
R6eOyjTT+I9MAuMCOi9938PAz7u9WAG5ErBZGLa5toum8aE8CSSUdo1e8tEA
19ZZZAYoJGDabSN/rPaxlmMHFAHFEvh64nJ4aDoZreuslAEl6nobpn3aCboo
a9nQEFAqAd7vp+cf9ung2afanQFKCdzbe6WsbKku9t/aRAqslIDtkzBjq3tk
HP2UzAqskoCL4MlPkr4+buzJjwqskcDdcSPcnk4zxHtP9PmBKIFZyf9cDL9F
Q1aPXBHYLIHhbO03TbkMnPXna3lgmwQWRO9sk7LN8ILhjIbAdgl8vp7xrs7O
FH//7lcFqiTw8rjvw5+v6DjBcBYpqFvd/4Ozml7cM8btti+YQb3q9du89TNj
twG+8kqKChqQQIwy6sF2iT662HYRQSQpPN/Us1bB0sO5XqmKIIoU9jyVz1qv
9k2MaC0PokmhUd/U6kwHBY1iRzcEWUohO5vnXnhMD/+KuKsKYknhQZO1z8Ew
Ku6ePI4UzJZCt8xxz/FUQ3zHu8gM5kjhRu9+UZLaR4OzfaOCuVJwfZNRWJFH
x0W8BiIYpLDijO0YfKzOj1kBiuAYKWzP5rUUixjIKDhcHhwnBcMX2qUJaIL8
9XYNwclS4AWFmR0X07Fi6TFVMCGFbXO2OxWZ0/DTOnsSVyYF7bhql6n/GmJE
2TYmN1f9PlZei870UnH1CWoUN08KVJcvS7TL9PHmnh0EVyEFnX4y9Q9LH0ec
MFJwi6WwQLF+2Pw0fZTUF5VzS6QwlZwt5U+j4unbA/XcUikk7XmvZ95kgN/q
Vqq4SilgwPro6QFGOPL2ryFupRT6bxuuGNNhjBue5TJDqqRgXuPcWtRNwzst
gxBSI4U/R2ubdRaZoN2zuUQISmFocJL8bAcDsz52y0OapTBnfJzB7xcMrB3k
lYe0SWF6Qm9eTIcJ/ux5jyHtUlBD2saTi+kYM0ioQlRSuPPKlm4WQsOtRg+H
Qrql8EJnUc/RWCN8YTeRGdorhU8Bab652wzQyagDQgek4De3vH5cnDo/7GKJ
UJIMjpfPMMu5o4/13k3yUIoMGk5E+1uMoKJBFLc8lCYDrSDXCcGDVJzsfRVD
LWVQyM0UjSwyxJ2RYapQlgzOGT/O6T9tjN2xVUOhbBnMEhb+rFf7nJpumWEc
GTCW7Q6uqTPBhbGnIYwrg0XmrHSPzwy8nMEmwkAG5VsUp46XmSI9Z488LEYG
E4s2T52s9ttMuUl5WJwMXMtW5smMGajMVmJYsgwE93/E9sfRsafATBVGyCDs
kv/Wph3GGLZh9VCYTAavyHP0HvEMsVito+G5Mji7+eLbQ8YGeH39OgjPk0F3
9dLqXUlUtCgfRoQrZOC1JHjyP2wqik4ulIcXy6Dv5p2lqSuoeKBMZ294iQzm
PPrZmnPZAPtOLMbwUhmspgYGMV8aITR86gxXyoCd1fGPVhMN17WKhsIrZbDl
9piOZDDB1vovrIgqGexctcj3pzpvbFqlEFEjA49/+y/8mWeKMzqfZEaguj8b
Nh7MqGVg9acp8ohmGSRs0fl+w9kE1XqpjGiTwbB5hlpeI2k49lM8RrTLwO/f
1MY0L0PcPHS9M0Ilg/EU1VLxKX1UGUcNRXTLwNwqesF0Jz10GLrFiuyVQcnn
+6J7EgrmGI+EyAEZXEq+aDVlHQUvMqszI0nTYauc7Dhlnh7+HzlzcVU=
        "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
      {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
       1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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        "]]}}, {}, {}, {{}, {}}, {{}, {}}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -31.208548220985634`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-27.631021115928547`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "12"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "10"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "8"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "6"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "4"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "2"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969435227*^9},ExpressionUUID->"e19543aa-fc0e-4a42-87cd-\
f9be4a5cb1db"],

Cell[BoxData[
 GraphicsBox[{{{{{}, {{}, {}, 
       {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
       {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
       {Hue[0., 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[{{0.5, -20.58731462444898}, {
         0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
         1.25, -27.50184105161661}}], 
        LineBox[{{4.249998, -23.11696430864725}, {
         4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
        LineBox[{{6.750008, -23.038818749837983`}, {
         7.000009, -20.322035683613738`}}], 
        LineBox[{{7.750011, -20.716014193782303`}, {
         8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
        LineBox[{{11.250025, -19.142376381324734`}, {
         11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
         12.000028, -22.492142720939622`}}], 
        LineBox[{{12.50003, -24.045787259895636`}, {
         12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
        LineBox[{{13.750034, -21.052099541576304`}, {
         14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
         14.500037, -21.409428863587927`}}], 
        LineBox[{{15.500041, -21.61333098548902}, {
         15.750042, -22.10549208407436}}], 
        LineBox[{{17.250023, -22.856107311471863`}, {
         17.500019, -22.566864012429928`}}], 
        LineBox[{{18.000011, -21.834193448858855`}, {
         18.250008, -22.051414693782682`}, {
         18.500004, -18.077316596913327`}, {18.75, -24.91015999289932}, {
         18.999996, -23.72588738716398}}], 
        LineBox[{{19.499989, -22.216470803381476`}, {
         19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
        LineBox[{{20.499973, -28.088099516986762`}, {
         20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
         21.249962, -26.024262389309694`}, {
         21.499958, -23.934378126196787`}, {21.749954, -21.38673829965319}, {
         21.99995, -20.845251905483718`}}], 
        LineBox[{{22.999935, -19.74888960999384}, {
         23.249931, -22.259315286011166`}, {
         23.499928, -24.055265008205094`}}], 
        LineBox[{{28.749847, -22.783129874707647`}, {
         28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}],
         LineBox[{{30.999813, -24.728294878757325`}, {
         31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
        LineBox[{{32.249794, -20.837058021652666`}, {
         32.49979, -21.361849645654928`}}], 
        LineBox[{{32.999783, -20.84333950660284}, {
         33.249779, -18.469001093501973`}}], 
        LineBox[{{34.999752, -25.06864583779922}, {
         35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
         35.749741, -28.101735397627934`}, {
         35.999737, -20.484837298503287`}}], 
        LineBox[{{38.499699, -24.377795653123645`}, {
         38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
        LineBox[{{39.74968, -22.650120892941615`}, {
         39.999676, -22.80728905851026}}], 
        LineBox[{{43.749619, -22.041875381710568`}, {
         43.999615, -22.423199188672683`}}], 
        LineBox[{{47.499561, -21.287037875136214`}, {
         47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
        LineBox[{{49.999523, -27.91448197690941}, {
         50.249519, -27.305559271827388`}}], 
        LineBox[{{51.999493, -20.885769001862567`}, {
         52.249489, -22.895170973799672`}, {
         52.499485, -19.058190778324565`}}], 
        LineBox[{{52.999477, -22.174453342075132`}, {
         53.249474, -24.83933405846568}}], 
        LineBox[{{54.249458, -23.722525323809897`}, {
         54.499454, -23.580299515887834`}}], 
        LineBox[{{56.499424, -21.766646750655234`}, {
         56.74942, -23.57640470224996}}], 
        LineBox[{{58.249397, -23.599923997532017`}, {
         58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}],
         LineBox[{{59.249382, -17.837453345617426`}, {
         59.499378, -21.77661789863478}}], 
        LineBox[{{59.999371, -21.620808909572247`}, {
         60.249367, -21.022793121071274`}}], 
        LineBox[{{61.749344, -23.521435622331904`}, {
         61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
         62.499332, -19.42225543656815}}], 
        LineBox[{{63.499317, -20.822384760816565`}, {
         63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
        LineBox[{{64.499344, -25.343231741743004`}, {
         64.749359, -28.307484449102994`}, {
         64.999374, -26.398401381300623`}, {65.24939, -25.315002655989222`}, {
         65.499405, -22.723177048349438`}}], 
        LineBox[{{68.249573, -26.50222788848888}, {
         68.499588, -26.988563201691523`}}], 
        LineBox[{{70.749725, -20.1140901131646}, {
         70.999741, -20.81539559964317}}], 
        LineBox[{{72.249817, -27.41004150424379}, {
         72.499832, -25.260157006181224`}}], 
        LineBox[{{72.999863, -23.234537488989123`}, {
         73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
         73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
        LineBox[{{75.25, -25.575903773461626`}, {
         75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
         76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
         76.500076, -23.461493017322223`}, {
         76.750092, -22.502769318560176`}, {
         77.000107, -22.727530149759858`}, {
         77.250122, -21.607547857437314`}, {
         77.500137, -21.438588076795124`}}], 
        LineBox[{{78.000168, -22.06377454291717}, {
         78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
       {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs
YIGKij4GWMwmJCQEJPa7n+8ef/zD67wG933tOudzfd6fezNKnT89Q5ZEIhnJ
kUj//v77s+Ogfc/gJjZKqwbOWUWTir7/r8Uc/qGHrcfm/q1bOEcUOuPu8P7W
3Zw8peNnSvz/1n0cZ3/r+rvmf+tBTuAC8at3WmzsX1/YOyYZ5hz4VhSpo/S3
lnBs775RXqjAxj+T65ZLJDLwLm92diT1by0HYatDYJz5379XgBtzz3EzQ//W
4yBKlh/anPG3Hg9mk1S9y5b+rZWhqks9PH0dG7vqYueOSVTgwo19206t/1ur
wX1+ZZKC4O/91EElsSe1fzkbVxt9vS2RTIK7c+pNxZF/348mrI1q7T7uxca1
H/WmkEhk2Lm8tY5vx0bFKvcNJBIFUs5nCHpU2bipKPIhiUSF+pZBx8cjLFRe
MX+iDEkLanbpsQvk2bgtdnOYDEkb9gpLho112DjJ/cROGZIO1F7Y0zWPwcbd
lLuvZEi64Dra3tQxjY1afR+1ZUl6sOj5xqeHE9l48MWfBFmSPliqW5y7m8dG
/QvUElmSATgeXaz0ff3f2hCm2FacHdvKxpLtTp9lSTRYvs1q+enVf+9HB/1v
q+75LmDjdHPXyzJCOoRV/7FOjfp7fyMwPn3xWLsjG1/JRwzICI3g5poPDz5Z
/V2PMUTqTny5VYONsV/meMoKjcGX9KL/tfzf9ZlA7bd/kj8S/X1Xk79aVmgC
J5kJa95T/67PFGyW3/lzn7h+cmk5ygpN4ShrU0NmyN/1moHl41kTm9LZ+CkX
5eSEZnAwqb4wmFi/8bxQMzmSOdCPNETVbmBjetL7qXJCc7ihqCivvouNx0Jm
8eVIFvBTIip/uYKN31mDm+SEFtB+bDEvJIuNljYbTsuRLMGqyfqiPtHfmbrk
J3JCSzjhfm3PE3s2nh5f1ilHsgKxi3Bytx4bfw46qMsLrYAjbxW5Sua/mmQN
g1c9AsyHWWjXUuUoL7SG4ri9d7OJev6b4Eh5kg241F/5skibjZUPmhbLC20g
Z0tzRpIDG3uuZO2VJ9kCuXt68nqin87H+q/JC23hTsLUwWmE3pbsXtskT7KD
31OF7b+Jeb66dtKwvNAObgV/aWMR+hxYWKKvQLKHVQfWh6gWsNEj1c5bQWgP
zedPz3FaxcYVEbe4CiQH8ExXsXmUzMbbEJinIHQAYfGN4DG///abxIDPtvSp
4Yz/+gMMyNTdMLmW8refDPgekPZGMMTCpSNaSrLIgPn2D7u+fmJhr8HIPRmS
I0S2NBf2dLIwmyPOkwFHCA9dH7mL0Gsn7563jNARNFnfLALd2Th7TcUwCR1h
bhGHaRXLxpajW66TSE5wLrdcdXTuf/oBJ3hdA39mrf1PX0InCMpYGfx2xX/6
QyeYHJBXKV75V59OcOjlo87O+f/pl+MMBw/IHrSNY6N24iJ/icAZ5kZHxha4
sXHP6hh5icgZbi7ZcW438X41Slg1YxJnYO2hLQwi5rUQabljHBcYONMz4xrx
flQ+y7HGBC4QY8a3HHrFwgK5loFRkQtUvnv948UPFlbo77o/KnGBKys/q7kT
ejDzXrZmlOMK59d3T7IwYmMZN4EzKnCFHS+LL1EC2EjL44yMiFxB3bPO4cMs
Nh4qM7kxInGFg3VyBpU5bLx56+mGEY4bTGOT/xER++H+4eKUEYEbqEs8qhcS
/b8ytpc0InKDYd1oNdN4NjrRV1YNS9xgsRIlJC6Qjed9uCuGOe5w6atP11dL
Nj6JnxAwLHAHvSeneM+JOmhVp/ywyB22D7/JOtTCwtrDL2r+SNxB06XhrXsV
C31FV3P/cJhQvy3sxNJ9LKwRH2T9ETBhqvnzw5TrLOTICgaHRExIktnwtILY
v0Q96wdDEiZwyD6b/yHm+y1bde0QxwPsB1l3Con+xyT3cIYEHrCXNy+SSpxf
LwWvRwZFHjD09t6fjnA2Rhy5eWNQ4gG1RfMPXk5h4/ybGRsHOZ6wNvz8nfFz
CH29C/QdFHjCHoHgqjrx+sxRO5lBkSd0GJdP5jEJPRtqVA9IPGGK05nY8j8s
TIffKwY4LBhp629pNSDOi5S37gMCFsyco7NW6yQLJSvWKwyIWFDuiBaZXBau
OjTzzm8JC+7sfNb21JqFQ1XTBL85bGi8Om34+Rxi3psd2b8FbMi39SzgE++n
l0Qd6hexIU77egwS59kk3ZoH/RI23ItdljGtl4XbWMfW9nO8wObQ+LR5amxU
TtoE/QIv+N25b8pOF8IPcueO9om84IYsN8mO6L9iacTNPokXrLBz3WkiZKPp
jZGNfRxvINUFC78Rfnbkrdi3T+AN4VeoLRqubDQk5NYn8oayFRkPzp1lYZHB
yepeiTdEZazyuj+BmHfO1pW9HA7o3k1Ur6GxcA9vAbNXwAED895Ot0ueeGm5
vmKviAPJG5oyFy31xIUF2772SDiwxtSN+/qPp7RfNIC4kXcznp1hIWV+uuEQ
B0DgMHV0u9p//eMCwK3tg+IGFqZNPPNlUACg2h9huLWfhUYGhncGSwC2a4zt
fTSDjWK7wtJBEcBawf7Wwo3Eee5NDFAzgFOygbEaoceksMVJgxIAvyDycRJx
vurziBOa5gPXTp8aWUP4++mft4wHOT5wJoy/ZyubJe0/1wemZMpW1O5moaVq
afOAwAdWmkpoKr6e0nko8YGOkVmjenUeeMxh3aEBkQ+Ya3QKtmzxQJfbcWsH
mn2AYvLc5/1mT+ytf5wyIPGBaMvaUI8yT7zwwQsGaJNBfapD7rxgNmZ3njcc
4EyGKzuUq2xobLSXGI3+5k6G39fhQRDRv6rNA19+CyZD07fmhUmT2dJ5KpkM
HLnxtwrnstDz7LvS36LJYCm6tj1zzFM6X82TIepyQppMmydefypK+i2ZDMkP
1ySrnv9v3mhT4OWI4quk+56oMGecyW/OFFBaaq/YkueJ91Ytl/nNnQKvx/P9
4xw9cM3W9uZ+wRSoWbVF0eMqE32Kk6r7S6bAJ4lpYsgWJkrOPTvUL5oCUS/8
Ds/z8ZTOZ/MUeObe1SbM8sBpIVqp/ZIpUPz5Znlxo6d0Xmm+0Ow9q/zQfRY+
mjts2M/xhSfXPKcs9WFJ55frC4qqfrmrEj3Rf3vzuz6BLyw28lvm1OqBr/Wu
3Okr8YXP94dONtV44B5biyN9Il9IWbVMy/iwB0Z6HRD0NfvCnBe8iqVynqgR
qpzcJ/EFs4jFFmZbPLEheTW7j+YHrx9cvbLL1AO57dNN+jh+8GtsTkDBBKZ0
/rl+4H5hl7z6bnf8MNFd3Cvwg6UDqXlpBe5SPZT4wYAXo0JnrSfG2+sd7hX5
QW5Y3z8VoUxsvdm9trfZDwwTGvekdjDxxOPU1F6JH8wfDTpoFeWBme9fQi9t
KhxMydvfR/ZA046ptF7OVDgZ6yfY/ZqJX0avj/Zwp4LZxYQDXj+ZWKZq875H
MBWsVu3UWkfyQEYR6W5PyVSYsGd2w+9iJnadXnikRzQVAvKcK/dlM/Hc7a+C
nuap0DZNvjqizxPnPIlO7pFMBX7uCasvNe5o87GO3UPzh3057qaG793w5qxi
kx6OP1zdWTH3wlw3zFmpLtvD9Yc1UVee++90Q/cta8S/BP6QrvrgshOhz/5D
fdW/SvzhSanfRrll7nj5bObhXyJ/6M45/ipK6I6LqhtX/mr2h4dUtxk7zrmj
bPC51F8Sf3DeoWehf9sdMYHu84sWAAVOO+PG1JgomLOT9osTANabBh7m1THR
a7X8WDc3AHrVTsylanvgyNal77sFAaDRfVqoocHEzbohd7tLAuB2tYb1I7o7
BtpUH+kWBUDJ2psvrWaxUInNEHY3B0B0dc/RnbPcsDakLLlbEgD0Xeafe0+7
4vokslc3LRBmDH37LRvgiuS2VpNuTiA0uIFF8hlX/IfAyW5uIJzjPO4us2Xi
DuWn4i5BIPCKhq2p49wxXB9EXSWBYIpnS5y3uqGq3cXDXaJAMJfZx1S+6IZP
vExXdTUHgibjVssaW3dMfDSU2iUJhIQ/JVdr1jNR991sny5aEGRQ3z15TPB9
U/sHWhcnCF7uuKf39SEL94+EjXVyg6C1PGPt/SQmRqvced8pCIINYe0N9ya4
4bcD++52lgTBiDorIl+WieWnCIAUBcHsodvfvxm6YuqtlcLO5iDoEz7Kf7XS
BY3qO5I7JUFAyueR5M1dsPk916uTFgyjjQ9DXn92weKO53qdnGAoSTx07vEn
V7RbcUK2kxsM2d5yW59tccefBTqfOgTBsMx7IKje0w1PFW0WdZQEQ9g4axuz
zW4488zo4Q5RMPxq31O7MZKJFlXzV3U0B4Or7tnUzE1MvBrol9YhCYaLl6tf
ad9wwyXx13w6aCGgpv9hWG+vGzrPtqJ3cEJga19j/7WpntizsmjsJzcETMty
78+1dcXKLSoffgpCwPvZ4HWFBlfk6Hy5+7MkBE722C5OeO+MY1ZRZT9FIWB9
8pNMUogzVnnWCn82h0ClvpLfxAnOuDLYg/tTEgLb8+Y0zZvqgp6Jp71+0qaB
Ic+B72DvgoNzDPR/cqbB80ztq0VUJm4c6pH9yZ0GPycNZKTWu+PUCRmf2gXT
IKnhdnCA2BPl9d6I2kumwcxpe4fDF7jhXZvA4nbRNDBeJDTqlXHFNexbq9qb
p4GegpnslI0uqP6wMK1dMg26jB1Eo4tc8FmT7OR2WigsVV5XULPeFbe1Laa3
c0Lh7b3KlOPbXTBk+PtYGzcU3EiC92tVXFB5YtyHNkEo3LDuKOeVOuHB/fb3
2kpCwWd3Xe2QgRPGniwtaxOFwvC6VaPFvx1R66ZGXltzKKgVNQzpjzrjq0fr
uG2SUFiuIxhzfuaEu9/99mqjhUGVzQd3CwcXjPzJ12/jhIH+eEOFcR6u+DnH
W66NGwZqt3b3pm9ywdJNlZ9aBWFwoF1+2vQzzsg9aIytJWEQfGO5fFmYMxqc
3l3cKgoDv4Jjb8+7OuP7W4qrW5vDgL6pLe/ouP9qSRg0cJa2/xPnjAvYJTL9
auGQEzx+ZUWCy39+EA7TLvu/+Cp0wuOrFwn6HcKBlKuk2cV3lPoNJxyGDjUV
cn4xpP4UFg4tp13r6jsZmHw4DX5zw+FxgmFA6C4Xqf/ND4fjZhs2Rl91xN0f
3at/C8LhXXtjQ72LE1KrImUGtodD4Nuy0oytTlI/LgmHQ48cVR7HO2HImIVg
4Hw4/PS9Zrab6ST1e1E4gEFB8ZdZTlI+eBYOHRdi7IYLnFDeUBsGm4n1O+a2
Rmg4SfmjKxwcvE8HZdY4IjF9VYOScJjHL3u5PNIVb3spyQypRQBemdT/UtPx
Px6KgLWshb4bXBj4K/d97pBDBFRlfXk4tNUBCXqpGeJEwJfXIqOZHQ6olvuZ
9CcsArZYhLgV+bniqeJ6zh9uBHSXFo1vbmdI+Xp+BKiP2dYtf8uQ8reAeP3d
tsdr5Bwxtfo2aXh7BOQs3z171NgRRz4e5wyXRIBNzCfBzCJH3CcpzB0+HwFz
H7udeUXsj+7HMzXDoggQ+R+U1PY7SfPBswjgrXvGvFjqiGH/Bo7mCDB5sPJ+
fw4D2zizc0e6ImAXa2D+lgUuONdwY82IhFi/3E0v56UOOI6zgDSqNh1qKprG
POTtpfmFNh0iVGUmbQc79BL65Y46TIdT5Xaim5b2iMkpNaOc6bDmrOBFnZsj
xguCSWNh04GTE3tl4AAD+0tcOWPc6WCae/B2JYkhzVfzp4NjykPTH5YMaf4S
TIfXKn6Z0Q8YeFZkRpJsnw7Xo6bMiytzwgCxGkdSMh2ujasqLdvvgsTurpac
nw6vzLQuFe12xoxmSo1ENB2eL/QKCQtwkubDhulwhZGRrNVkj0X0Nm+SeDrs
O6fS+kjLEQ0lCmtI3dPhnPmdO/piW7xO6yb+JxKS9P8RaJXZYCS8lZDUI0Ey
PDy+d8Raml/pkTCv2j7c5KitNN8yIqE+sJrjZW6PyrxHKAORIJ8SJKrd64jH
hZclMuGRcHnBcbpctQPCkWJvWV4k3Pv0Y9tqfwbeFdzMk82OhAe33bs69Z3/
e94RCdVfkz+eUXTEIdwmkS2MhH7PUza3lzvgrk+E4Esj4f5KjudOPwek4u48
ucpI2PU0lengRuhDnItyxKpLxy/uVXCyw2CZmRK5hkjwe92zyI3o33ejSG95
cSTMalnmsinRGmeS5ufJd0dCuXFi41MfK5Q3ikN50gyYuZr6ZPIDSyz2mSKR
V58B7ywlL/fl2UifJ9BnwP2Y7kD6N2vp8wPGDHjddkRkP5eB0SnOqAAzwL8+
hBNu74y/8gwkCuEzQHd8eXvkYSfcUjbOW5E3A2btMG4/tdoe1fJM8hSzZ4Cv
4deaa6G2ePKICioKZ4Dck5+nNm+1Qd87A2OKhTNAtD7o0ZJUG6wt1Zw8rnQG
sO+7Z06zsUNi2oTjKmdAwdfDJjUatjjy6YdoHBL381+qqllkjftkX4yNa5gB
Bz/OMjn/1QJ1P3X4KIlnwJQw2oapn83xskyjUKl7Briv+HyMV2KOYcZ3REqk
KCA1O3B7DGywbfKZMSX1KLg7UWF6GFjiHKM6n/H0KOA7BFuu22KN4yZfFI5n
RMGsWWcmqFnaYlnqIdF4iIKVhj6rm6g2yF67YWx8eBS09qtF3Ku2QlFKmc8E
XhQcOnLGdtJkK4xfs0U4ITsKKuXnrVhgboX9ZUtFE4RRwJOorS+6Zonb7/LG
JhRGwY+BQfImMyvUKFvlo1waBcveLX72uc4Gz97JFCpXRsF+IZ0p3mmB/l/C
RcoYBaE/W0+tXGCG/z6uUG6IgunWOyf9Fphixudon4niKPBWCmUdyzdFkpyP
cGJ3FPS3tDfYjdriQRMb0URSNEzaeqbmvIE5uvpSxiaqR8Mli/qCDx/M8bqx
o48KPRp0Du7z1lhigdOn6AlVGNHQdjeo3c/eAjvSFEQqEA0fTG7teq1rgfnr
ukZVwqPhyy09waOTFqicpuyjyosGrRytkegeCyTSh0A1Oxpm7K54wn5rjlDe
XK0qjIb9CiNcRw1zvLtmWEatMBq+t1W3+a+ww6Sj30CtNBrsO+aXd981xcG7
zwRqldEwWHp+/Nnfxrjr641qNYyG0xr9M9mqxki9+0pGvSEaVuzd9OnWMmOs
/CICdXE0TLXNKqhPsMFg+VMC9e5o+HHgdGbMSlP8brq7Wp0UA88vngn1dzRF
vlylzCT1GOjS2qV5drUpypkehEn0GCDfX6y644kpFvuuE0xixMC0rh909Wdm
yMyYVz0JYqB+U7np6eMWeGtKgYxGeAwcEH/ddcDeEqPTF4MGLwZmskq2ZwvM
8Ne6ZIFGdgz0VyzN1ZplgpuPBVRrCGNgUe0hv/M77VF1XbqMZmEMyA8Xtm7V
M8aT5aGgWRoDRc9/bIqNoeOU+0yBZmUMnJe9SJr/0BA/fjOu1sQY+P32/ITH
bDqmEMcVuSEGtrzhRAfNNcWRr5ZAFscA55EyZwHbBPcqaArI3TFwtK74+bM/
RuhoPlpFJsWC3jNPJ2NHY7wsryNDUY8F5zC2ocuoMYaayQGFHgtYcGbuilpT
bPXryKUwYqFqZdrPLX/McY7p+DsUiIX1+0f2X4wxx3F+vSRqeCyU/2neZvbC
GI9kfOBQebHwZpeTL7WWjuwNtbnU7Fj407NkxxR9MxSlf6mhCmOBP//ZjXF0
Osatf0LSKoyFS/ZL3Ids9LDv2DWOVmks/GOqvcR9jzZuf3AkV6syFg6SXx0Q
XtJFjWNVNVoYC0tvH9zbZELHM/dPkLQbYol5emLUOJmO/t93cLTFscBm6pFt
WQb4WXFVrnZ3LMiXGqdufG6A6d/21WiT4kCmaChi/IAh/msPOupxoLph9ufw
PzQ8aD6Ho0OPgwymd9A1bzq6+Efn6jDiYGBlWtryyzS8ZrawRgfi4HqhWeY/
awxw+tREkm54HES2bfb8VWeAHZlTObq8OPjyzi266aMubtzIyNXNjgOmQfen
DSa6OCEzpEZXSNS/bBfWzNPBYxvcSHqFcTC+oLK48og2ck7QOXqlcfAxeNel
nfr6+LZ2Qq5eZRzEOxX/2haij0nHzWv0MA6q2jfe/HnDEAcfqJP0G+Lgu6N4
LKHYEHf++OOtL46DjqYFvJ3naUh5QF2j3x0HyhefatsuN8DK76QafVI8rNh/
VnmRHR2DxrVL9NXjoeK9XueLo4b4zeKVtwE9HoxTX675pWaAfEXihGfEw3Nd
9+6uYAOUs3iHBhAPXbME67fW6uFh//sSg3DienJ78odQB5n8896GvHiY+rjm
ZYCjDt6a+jjPMDseJl85+Erruw5GZV1BQ2E8LDGqckkK1cPujSUSw8J4WLjp
5uDpJn3cXLHJm1YaD22d7j5Pduuj6sZjebTKeOhYwlgfeoWGFSe2Iw3j4f3s
zXKyDwxwSt1yCa0hHs6SN+1x+GiAH1vSvOnieAhrjRM23DREXq0gj94dDxnl
Voc7Xxni8I+ZSCclwC3rtNA+DRruVZohoasnwJCe6A75JA0ZVt7eRvQEIAc/
t5mM+nhpXHyeESMBvBrKp5KDDDDU0heNIAHujXaq6ZzVwdYAe4lReAJ01M7O
O12ljWtnansb8xIgR+3eabcX2qgY4JJnnJ0Anad9HatidPEI3xCNhQkwW3e8
cthHfWRtUpIYFybAetXH5y5908PXJ3u8TEoTYO6Pu5+iKw0xLl81z6QyAfbF
Dy00Bzr2VQyKTDABMu7tNv7yzhC3Pfw8ZtKQADvk8YhaqCFOqhjzMRUnwON5
j/ovvzHAM3UtQtPuBIgVnfe6Y26A/q0vRKakRAj070oQE/PwaXzVmKl6IrwN
tXfu/EDoo6XRx4yeCMd+0TxnqumhROmu0IyRCH1GX664l+jgASuC2CARrvzx
DXPx1EGXoH1jZuGJkHjOSyn7kBZes7zkY85LBLX5le8/B2nh9MDDQvPsRBg3
I27J+WZ9/Dlzo8hcmAhmXRt3+a0l9FGwYMy8MBG85k5afGarPk6YudXHojQR
pq2UrbuTrI/lm5YJLSoT4cPKB6WrVAyQcypFZIGJ4FFe5Tzxlh6+fRQ8ZtGQ
COlWPynDtgaYdDLLx1KcCOdUEg/QtfVw4GGE0LI7EQ4dOrRe394Ad7axRJak
JNB+tib7z3NdtFM2H7NUT4Kxbw3rM2bp4vlWHx8rehJUJStuPvCPFgZNsBVa
MZLgvdHIF0+WFn6zpoqsIAl265aZh7Gp+C/+WoUnQWtrL6nsgBbKWuv7WPOS
4MfCbKCc1MfDQYpC6+wkOJ4470vhZUIfs7urrYVJkPC4NL+hXg9vBk6UtSlM
gluif8IKVPUxatZvsClNgmOJRl8lvwh9FIgFNpVJkLjix5tJAfpYcPpRtQ0m
Qd+lIp9giiGqFHyXsW1IgsIfQoflNAOsONUAtuIk8L/QpLhhQAenPL4psO1O
gmWRh30WvtXFD+3l1bakZGiavY96OEwH/8VZO/VkcAkYzVozSQuH206BHT0Z
Ft7ZqaQ+TME9ynsEdoxkyF16+yMsoiDDVlBtB8kwo0pOdw1PCy9NKJKxD0+G
o12XaH/G62KozXqw5yXDBPPaqooMbWwJni+wz06GmADe/SnvdXHtnLhqe2Ey
3LC6cKl9kQ4qBi+RcShMhqHI4fX54bpYOpsLDqXJkFfd+U67XxdZWwIFDpXJ
MO/U5w/BPoQ+zjgTlJ0Mqn7H9qqSdTFuc5gMoyEZsmfLp+QWaWPvaQ9giJMh
+VfAa+FmHdxWbyJgdCfDQcpq4dwXVLTqUKlmkLhQP8dr99MnFDz92ErGUZ0L
3saDgW0+ZJz6UxMc6VxwOj9vz/F/NPHTxLFcRwYXsi7AgcjpVFz57wd+wIW3
PIqyW4U2jinLyziFcyE6Zk50ezEVD9h2cpx4XNi3y6SL8Y2KLtMac52yuZD5
/Wv1x8lUvGrTV+Mk5IKdr9/mHUe1MCLkI8m5kAudO0arBI7a+HNOHce5lAtt
ksLw8nNU3LD1Yq5zJRf6m501z/hQcPycpzVE6ofEsPqa2zJkLN9yneTSwAWG
r/JV6wAycs6WcVzEXHhsWRRhTLze9GRLrks3FwTz83cFBpPRPvolT5fEg70t
4X1NqRRcmRko1FXiwcy2zCkHLlDx4dLqEl11HpjNCxkqHKeF1I3OIl1tHsw5
WZ+/ejsZY5bWiHXpPAhkN7yfv4Is9S9LHhyMqDn1BSnYs/c0TY/Bg8PNEjE8
0pL6GZMHRePjn3bkaGHe3nM8PeDB8dYMo0YbLXx63ESoF8CDqyfOzh5dT0X9
a/tL9MJ5cGOJbNPIeArOrFUR6cXyIGe1uejlcTKeulok1uPxoOb6u6Xe98hS
/+PzYB/lgmFXAgX93qyn6WfzQFFomNvWQ5b6YQ4PxJNSFgUBGV++zufpC3lw
ccbN2QNnyWj0Y1Sgn8+DWU85zIkdFJz37weshTxY/aPDei1HS+qX+3nwdV6T
WG2YiqO/l4j1S3mw+Ziajm8fReqfFTzQanbr/sak4n4tHs2gkgfTIOjO4ssU
bFLsBIPrPEgOSnm27hIFLbTSeAZI3G8G5VRdExUXWzQKDOp4cHndraNQoYU1
7tNKDBp4hP5G9PPTKVK/beSBT96fwP2BZAx3DxcbiHnQZjsu+4omWeq/LTyY
G4SvhhLI2B7jSTPs5sGOTsaFmxMoaOtfB4aDRP/0jnjw11JweYwXz5CUAtcL
XpIlXylYm3VRYKiUAsd+fDqaEUpFco5FiaF6CtxUWu4ySOzH//xaOwVq93IV
YoaoeHSZtdiQngKVHmlXJW+oUv+2TIHXvlnlXY8o6LWfTKMxUuD+/YfZJl7E
+bixDGjMFDhcv8dVGKKF9fuIDYIUqKrvuHS1jYK6FVsEtADi+i+zje/vJ2PW
dZkSWngKLLy1Y7naUU2p38emwLYmtlHOmAb+viYvpvFSIKtC65X+K02p//NT
oPzyo8B6QyquuzbOiJ6dAh6h1hNbtlPxRe0qoOekgMabVu21QEVa4y8uXZgC
deASvGcJBee0ZAro+SlACXS4tmETFc+96SulF6ZAcGjFi0YPLSkv7E8B3wsx
uLCbggGDH5vppSlgsYOPjxZTpPxQkQIuHmt/rnhIwTcDn+hGlSlQJHdmDvsl
Bc2UYsDoegow5ZS8XphQcKF2PdcIU2A594vO4o1kFFn6CIzqUgCXjYReIfQl
o/2s1KghBRwk8mG755GlvNGYApPuqc1WO0TGIuaNZiNxCog3pdfNdaRK+aMl
BXZh0ciWdxS0Zt6mG3engCr56lKnxxRcFuAIxoMpEH59wsXtaVS8H3uca0xK
haNzE7x86VqoMVNPYKyUCo/Vwup9FlAxMvZkqbF6Kmhf1O3wUKJKeUU7FX4n
6QatjKJgZ86uZmN6KvRMC55+uJki5RfLVNAfOOYgIOZ9dc5eugkjFaISBjY/
8qbgo3xlMGGmgmyjkaxvARm1Dwi5JpAKwS/drRs/aGLGyf5ck4BUuLlfvT3a
hYzH968tNQlPhfbW7RNLbShS3olNhazlij3JZyjoc2NuswkvFXSen3om3kXB
f79eYMpPhX67jJ5x9lRsuJ5NN81OhV+6iw7n76OiwcNvHNOcVAg4XUN+t5eK
s5riuabCVHiw7nZl3z9UKR/lp8LP2efHJLspONSYVGpamAoXwzrvz02iSHlp
fyqIazgPaylU3D3k32xamgovB5JmLz9EwVctr0hmFanw1nT5G7/JFDQZCqKb
VabC3U0Dnyf+IGP2eOSYXU+FvM7tCjOoZKzSceWaIXG9hdaHNOLIUr6qS4WG
Ly2LumIpGKLDLDVrSIWglNkrpgVTpLzVmAqvv3yIMiLm+4eHcbOZOBVMYrcF
Wz6koqVVJcm8JRXecWZMIMlTcYmHGd28OxUE/Oz20plUvBt4kGM+mApnDa6O
mbdTUD1ejWtOSoOCkVMrIr9TpHymlAYWFoeXnZChYkmcRqm5ehqkvrC2XqBI
lfKadhrcf/3wwFN9KnquGPloTk8D5hyVlb2zCP+YWUCysEyD77yY7XWzyPiv
HC0YaRCn6K3bTfgDtWAxx4KZBreXmVsnSQj/WC6bYgFpcIsVORpTQJHyXUAa
bJEsUzj5D+EfB36WWISnQXlG7ihFgSrlvdg0UOiIOR6ZTEXhgS6xBS8NSlZZ
nTA5RMWnJ9NJlvw0WDGVfefmDyrq3WyiWWanweNl615ofKAg/1EoxzInDZp0
PbycTKl46sZ7nqUwDVZPvK2yQY0q5cP8NPAo/iAJfU34x9sHJZaFaTDLXiHt
Rg5Fyov706C4judQUU/Gf5oeii1L0yBKZV5eqi7hH23eJKuKNPgCES1ufZo4
788lmlVlGmxuU08bPUjGWxOsOFbX04D2pCKgcj0FR4eu8qwwDcJmWibuWUGV
8mVdGryf+W7FjXIq7tM9UmLVkAYGxdcjuyooUt5sTCP4756L83kKmuuWi63E
acB7HGCbSPRzkbUOybolDSadWO/kSfh1jec2mnV3Gri/GQ73/0RB1WA5jvVg
GpzfnKR4z4uC4Z47eNakdJDjiLddriBL+VQpHXptWftXE+tti19ZYq2eDo2z
X1T9E0pG26DxNdba6ZDSseZaRY0mLo/PFVvT04HBWhbsfUITH8zqlVhbpoOg
lL0/Y1gTySv5NBtGOkjUfRySSylSnmWmg4Pvw3Nrz1OxbMVsng2kQ/whKEx/
RpXybUA6nBAeemw4jopeRVElNuHp0MDkXo3YRMHcgi9oE5sO/U37NqVuJmP9
wVixDS8d1NR93TZ1kFHn9BOJDT8dFreJgsz+kDHz1mSabXY6nBEEnb/wiyzl
4Zx0+D0zPseHOH/6b/rxbIXp4PrHYKPefLKUj/PTQf5J6MDWY2QsfOdQYluY
Dkda98XnyFPw+aMqtN2fDtY/7yoqENejvXMS25amQ6Z16vp4RcI/2k9IbCvS
YdXvjasWNpPxxrA+za4yHR7wdWaeJPjkfzx9PR3I/dob5veTMWCYxrPDdHj4
1ow2ceA/vq5Lh+0uQflTJmrhF70JJXYN6dD6xXtPj6EWmirvR7vGdKB//qfu
2TwqLtBTEduJ06EtQXb0Bp2CIps1EruWdHATkNZcIfxzInvA0L47HYaOtFi+
JPT3Px4fTIdhRuLqwumEf7D+cO1JGUBv+84sSyJL+VwpA+pvZywrKiejNWu0
1F49A77M6zVqcyH8I3gh2mtngO7BPvUrgVS8l/Cj2Z6eATa7OcvX6VFRY06i
xN4yA1b9sgtz8CH8I6GN7sDIgJbNg5QKQm//43lmBihY6DneJvJE58qXXAfI
AOrhzGvxk6hSvg/IgIHjDOWXBA+sWvmm1CE8A3ySQGmwkfCPzSHoEJsBxafL
MciJglqHapodeBlAOpt+Z6kbBdPPuEkc+MT6C7bfN3Gk4PGie3RGdgZYD965
bqFAkeaBnAy4OPvWiSBnMvrcPsdlCDMg3qwx7OtSsjQf5GeAlWLgYyNtCj67
daGUUZgB3psjfgdlUtCg3hwZ+zOg4JpK14pICs56X9TMKM2AOsOMHxmyVLz2
U13CqMiAoXz+Xp1CKg69K6Y7VhL7MW7Z8WB1qjRPXM+AOwe3GDvtpOCukXyu
I2bA3QvHxdNVqNJ8UZcBHcMXU1cR+2M8srnUsSEDmou/p1OPUXD+RBl0bMyA
GVeXtewj5rtKf2mzozgDNLctrbReSJbmj5YMiBlv80jiS8YQ/eV0p+4McFTe
o5WQTJbmkcEMcN0dP9crh4zf2WlcJ1Im+I0l6kvukNHS9pfQSSkTkr9GZ91c
RcEl7MxSJ/VMmH98xdFL96l4J+SdyEk7ExIWRGXmEXlEPSm82YmeCWU/8/eC
FkWaXywzYcA9373wBhmLEyPpzoxM0Fk+PzEJKNI8w8yEJ/Evv58l/MljtRfX
GTLhskJlsU48BVfMeSx0DsiEwd6jI9ZPCf9YBaXO4Zng2prWw3EgI2XrFZFz
bCbU9sZ/V9mviamHrZudeZmwJOfirZXpmtL8w8+ELTO9hMd3a+KvQ3Z0l+xM
CMsKX7bokqY0D+Vkwo1xMs0GD8i4pUqL6yLMBBeWRjdqUPHJmWNCl/xM2Pz8
qFHEZsI/qnRLXQozoW3+9z2T7hP+8WS7yGV/JkS3no+sd6XglQ/yzS6lmfCo
b0Xh23NkHKjfSXKtyISTe8NOL5GloO+HcXTXykxYhS9erkym4I6OVRzX68T1
pgWMW/6B8I/3E1JcMROSRu8rPPlNRnqHQOhalwkTB24+j99ExrmjfSWuDZlw
W2n6O5EK4R8qs0SujZlg3dl4qYqY35GRAbGrOBM0GUYfr/HIGKQyl+TWkgn6
9dFF+QQf7jP4THPrzoRp1TLPi4h889UuhuM2mAkNn2bLfwwk/MPgG8+NlAVN
j6efe1JO+IddvNBNKQvkJkbf6SL4B72elbipZ8HStLYSVQYVVUN9RW7aWbDn
d0ijKIuKYV4vxG70LABWVbVtNhUPTfMnuVtmwbzb49rGv6RiW9JtmjsjCxTL
Jn4w2E1F93mOHHdmFkgExZ1BaUT+SBLx3CELQqsNqmp1KPhgrovQPSALluUE
fRDGklEz92SJe3gWXL81+THnoiambDMUucdmwZvCoymLr2li2eozYndeFugF
ZJyx2EbGrq1GJCY/CzgzRhp7+UT+KN5LY2ZnwbrLs7Q2E/0rOKfMYeZkQciC
4znvb1Hx8eEDPKYwC65oWHgeIfKIzjlVITM/C74lMS3NXlEws3ptCbMwC4QV
67dbEP566elgNXN/FrwO3FnOvUDB/qoNYmZpFvRrLhrR+0HByU+HJcyKLJia
fPFgBFJx+8dsmkdlFnh71JVlEXnj+ZMx8LieBePWHNu0aikFDT8u4nlgFnTe
f/RVi5iXOZ0tAo+6LPByHtA6cJnwj7GkEo+GLChxs/SkfCTjn4529GjMAtu2
/d9XTCTyxxhP7CHOgmvlc05anib8Q/W1xKMlC7RtvdLNnlDws2EwzbM7Cy7/
9H7mQejNVLUJPAezYHXpxPfr9bRwgWEoz5PEB0XK5fe6RJ6ttr8r8FTiw/i9
I8eEBA9N5DBLPNX5MM1aae/uMgpOs3+Antp8UPqcP1v/FBUPerPEnnQ+QPPu
Kn+Cv1pCKyWelnxwjEsukyP2g6BbGovBh0/cs3NNWIR/hF4CFpMP7U4vpr9F
Mt5LtuSxgA+UHcxdZnvJOGn+YQErgA/Xr4sniWrJyBVolLDC+aBccTJ7hNiv
0nmlyIrlw8NVbbmWylTsyKWIWTw+vB0/POXcNsI/thdIWHw+fJt3TEv1BhXz
iTjKzubD8dN6dn7BVHy4bSuwc/hQW1e03ZbIS1olsjy2kA+uIVdytI2omH5+
mYCdzwf5B7bXawn+OlascIRdyIfY5c/MqXQq9p5bgez9fHh5NTf6X78BUVcz
u5QPopzZwTn7KLj1WbqEXcEH2ftVoc8J3nlW3UP3quTDMaX4M/cJ/9F/RvT2
Oh+mGrOWOpeRcda/X/hBPth98a0w2UPGa10RAq86PlSy7wDXk4JEvCz1auDD
1Zr0ZrdWCk7tmoFejXxQsVpbr+JOxV2Sh81eYj40HspYtn4+Ff/9uNyrhQ/x
G5+/XV5BRWNJPd27mw8+67vzRq4S/qE2GbwHif0MHHm9l+CN27RrXG/STDic
+GHitgUU/D/hx/aB
         "]]}}, {}, {}, {{}, {}}, {{}, {}}}}}, {{{{}, {{}, {}, 
       {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJxtmmdYE13XhSeE3gwdaQm99y4lG0FARap0IaGjoGJHQRKsWFDs2CDyqChY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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
       {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}}, {{{}, {{}, {}, 
       {Hue[0.2, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[{{0.5, -20.58731462444898}, {
         0.75, -18.879687777989233`}, {1., -22.708201886132294`}, {
         1.25, -27.50184105161661}}], 
        LineBox[{{4.249998, -23.11696430864725}, {
         4.499999, -20.194598919807454`}, {4.75, -21.792806238013178`}}], 
        LineBox[{{6.750008, -23.038818749837983`}, {
         7.000009, -20.322035683613738`}}], 
        LineBox[{{7.750011, -20.716014193782303`}, {
         8.000012, -21.719935624719493`}, {8.250013, -21.44478512614736}}], 
        LineBox[{{11.250025, -19.142376381324734`}, {
         11.500026, -20.454171959512298`}, {11.750027, -22.54961426647512}, {
         12.000028, -22.492142720939622`}}], 
        LineBox[{{12.50003, -24.045787259895636`}, {
         12.750031, -24.44167132583875}, {13.000031, -27.837797960476642`}}], 
        LineBox[{{13.750034, -21.052099541576304`}, {
         14.000035, -22.29667514481993}, {14.250036, -21.354059819949928`}, {
         14.500037, -21.409428863587927`}}], 
        LineBox[{{15.500041, -21.61333098548902}, {
         15.750042, -22.10549208407436}}], 
        LineBox[{{17.250023, -22.856107311471863`}, {
         17.500019, -22.566864012429928`}}], 
        LineBox[{{18.000011, -21.834193448858855`}, {
         18.250008, -22.051414693782682`}, {
         18.500004, -18.077316596913327`}, {18.75, -24.91015999289932}, {
         18.999996, -23.72588738716398}}], 
        LineBox[{{19.499989, -22.216470803381476`}, {
         19.749985, -24.54145156494038}, {19.999981, -23.01552047332444}}], 
        LineBox[{{20.499973, -28.088099516986762`}, {
         20.749969, -22.96718964597576}, {20.999966, -24.556480434597365`}, {
         21.249962, -26.024262389309694`}, {
         21.499958, -23.934378126196787`}, {21.749954, -21.38673829965319}, {
         21.99995, -20.845251905483718`}}], 
        LineBox[{{22.999935, -19.74888960999384}, {
         23.249931, -22.259315286011166`}, {
         23.499928, -24.055265008205094`}}], 
        LineBox[{{28.749847, -22.783129874707647`}, {
         28.999844, -24.518053512237017`}, {29.24984, -20.393256583336353`}}],
         LineBox[{{30.999813, -24.728294878757325`}, {
         31.249809, -25.55760456309719}, {31.499805, -27.716912284222655`}}], 
        LineBox[{{32.249794, -20.837058021652666`}, {
         32.49979, -21.361849645654928`}}], 
        LineBox[{{32.999783, -20.84333950660284}, {
         33.249779, -18.469001093501973`}}], 
        LineBox[{{34.999752, -25.06864583779922}, {
         35.249748, -27.243467464507535`}, {35.499744, -25.47470950947303}, {
         35.749741, -28.101735397627934`}, {
         35.999737, -20.484837298503287`}}], 
        LineBox[{{38.499699, -24.377795653123645`}, {
         38.749695, -25.47949359136677}, {38.999691, -27.373977132939284`}}], 
        LineBox[{{39.74968, -22.650120892941615`}, {
         39.999676, -22.80728905851026}}], 
        LineBox[{{43.749619, -22.041875381710568`}, {
         43.999615, -22.423199188672683`}}], 
        LineBox[{{47.499561, -21.287037875136214`}, {
         47.749557, -22.97094332504933}, {47.999554, -20.930891171053855`}}], 
        LineBox[{{49.999523, -27.91448197690941}, {
         50.249519, -27.305559271827388`}}], 
        LineBox[{{51.999493, -20.885769001862567`}, {
         52.249489, -22.895170973799672`}, {
         52.499485, -19.058190778324565`}}], 
        LineBox[{{52.999477, -22.174453342075132`}, {
         53.249474, -24.83933405846568}}], 
        LineBox[{{54.249458, -23.722525323809897`}, {
         54.499454, -23.580299515887834`}}], 
        LineBox[{{56.499424, -21.766646750655234`}, {
         56.74942, -23.57640470224996}}], 
        LineBox[{{58.249397, -23.599923997532017`}, {
         58.499393, -23.050493683773798`}, {58.74939, -21.604841906142585`}}],
         LineBox[{{59.249382, -17.837453345617426`}, {
         59.499378, -21.77661789863478}}], 
        LineBox[{{59.999371, -21.620808909572247`}, {
         60.249367, -21.022793121071274`}}], 
        LineBox[{{61.749344, -23.521435622331904`}, {
         61.99934, -22.588096769535223`}, {62.249336, -21.22407892057315}, {
         62.499332, -19.42225543656815}}], 
        LineBox[{{63.499317, -20.822384760816565`}, {
         63.749313, -22.23244944827509}, {63.999313, -23.152029875313758`}}], 
        LineBox[{{64.499344, -25.343231741743004`}, {
         64.749359, -28.307484449102994`}, {
         64.999374, -26.398401381300623`}, {65.24939, -25.315002655989222`}, {
         65.499405, -22.723177048349438`}}], 
        LineBox[{{68.249573, -26.50222788848888}, {
         68.499588, -26.988563201691523`}}], 
        LineBox[{{70.749725, -20.1140901131646}, {
         70.999741, -20.81539559964317}}], 
        LineBox[{{72.249817, -27.41004150424379}, {
         72.499832, -25.260157006181224`}}], 
        LineBox[{{72.999863, -23.234537488989123`}, {
         73.249878, -23.30735333592371}, {73.499893, -23.73247775405723}, {
         73.749908, -22.01890227780448}, {73.999924, -21.764126804245652`}}], 
        LineBox[{{75.25, -25.575903773461626`}, {
         75.500015, -24.22107643699905}, {75.750031, -24.947994748931166`}, {
         76.000046, -26.792413910119915`}, {76.250061, -26.28331660699657}, {
         76.500076, -23.461493017322223`}, {
         76.750092, -22.502769318560176`}, {
         77.000107, -22.727530149759858`}, {
         77.250122, -21.607547857437314`}, {
         77.500137, -21.438588076795124`}}], 
        LineBox[{{78.000168, -22.06377454291717}, {
         78.250183, -21.350001501519262`}}], LineBox[CompressedData["
1:eJwtl2dYE1vXhoMCCYSSEJq0hB566KEvrNg4qHQITHpUBOyoSIJYOFbs2CBi
w47HAqjAQixYEOxwLMSCYkFRVLDBl+/k/ZVrX5k9M2vt2fu5b3tBzlTxMBKJ
9EqLRPr/34la04eGt02DyGWnilTvgvG1/bRIbdU06E/q9Uv9h4vTSTmF2r3T
QMY7M+HnyRDUtk9BbVI8RF7dsr95GRfLokcNadPioTUOY+Z8DcIQgVekDise
Vn5OzXZ2D8SLML5QhxMPWyZvPOnX7I+JfH/UgXg49OhrrqzQHz8X2g7pxMVD
3fCKBiLMH9dWkCN1iXgIOnFu2EwnfzQudCzUzY0HHfH9Qy/H+uPhvYaoq4gH
dv2lmCff/HH0pf5B3ZJ40O36M/34yQC8pmSMJCvj4eGvd+Nv0oOR3/hHQa6K
B+a50lajy0H4+/mbBjLGg537ynGWi4Jw+7C7g+S2eNg+MH9D6OsgtHreE01R
xYO4Sf8RvzkYz2i1Kyi98XBtbLiPwaMg/MvhUgOFlAC2BoHdhbwAfDfy2CCF
lgCyD4z6ged+mGXfHK3HSgDF7ZNb+l77InnkPwo9TgL0pS594xHtixWC3Q16
kADDTFkVuR85GF60clAvLgHsX/1tFtDFwQZ+RbQ+kQCC+tVPrgX5YuqytQr9
3AQw7lgcGfHKF79VLGjQVySA0fiBv5rp/rihiRjUL0mA/gCX4q6TgWhSkR9N
VSbA1hHpHlWqQDx+SaKgViUAyePpFM+8ABz3Mq6BignwtbXR4PQ/AfhieNgg
tS0B7sRcz3bZH4jiF4nRBqoECL89enx/aACShkcrDHoToOrlxsnVZ31xp6NH
gwEpEcK63XLtJBwMHG02aEBLBIv7yWdnfvDGGgffaENWIsy7NWr7jyteOHWU
tcKQkwj8cfJDVyO8sEeo02AIiTCrM8v02RQvLF7+6Y9hXCIE2X8vf2rojVQh
NdqISITI+4nt5zf64IGib3Kj3EQIHhnQdsfRF2F/Z72RIhGWXZ3+4tx2f2xa
9kvLuCQRomj5T82p/sjb1wXGykSY//VGY7WrHw40tcqNqxJBZPKjsW+bH25+
VVtvjInwK23WUxf192Xe9ECL1pYIN5rnur2M9cWqlw1AUyUCeV3aPfjthRO1
j8hpvYlQ1TN15YfVHvjaaUs9jZQEY9+9DXZ55Iay4VVadFoSsBPv+pm3sHG4
006gs5LAak7bsLGZbCwbvVxO5yRBWtjC4/+uYyNXnF1PhyToenycPErqhhdG
rdYyiUsCKr2sM8bEAxNF88CESII8cYvFF7I3fl6eITfJTYJRKQ/TL8z1xTUH
YupNFEmw1tYwJ28xB42Wi7QYJepxx2d9YYEPHt4fCwxlEpRcc559i8vBUVe4
ckZVEgx+fPyQm8jBZ10O9QxMAv0bRIDpbQ/kX47UMm1LAuNTv4xmXnLF36/Y
YKpKAuLOutjZBc64TYchN+1NgkOxVlPCBhzR1+VPnSkpGfyFa5suGDviGe0R
Wma0ZAjLaf88WOeAsc7DwYyVDPOM3+ZydR3x7ZieAjNOMkQyD8jb+h0xy0nv
khkkAyPsmqz8vDOSx/SRzOOSYWfrgier1P3bK34aZU4kQ/7B8vn3uV4YvvJa
gXluMohebzxrsdsDG0QvG80VyfBSl9+wdZs7pqxoIVmUJMOOm4wwxgZ3/Hqg
OspCmQxt01dc1Y5www1X9xZYVCXD7LRho8qvOKLJgbpGC0wG6ehr86heLDx2
5RDJsi0Zqkb7pAiCbHDc641Rlqpk0JpPy83LGYEvdPMLLHuTYWPcm4mL1DNF
XdsbLUkpIC3/1Whvb4FDOstII2gp4DpR9l2wygJ3umRFjWClwN7r7fdvfLPE
gHGJBSM4KTDnbueECQutsdp5TuMISAFGh+6o8zZMnDo2nWQVlwJnn/6uMC62
xx7J2CgrIgWSusT9CQ8dcNUqToFVbgqMlu3156+3R33JpEYrRQqQtGBR6jEW
HlgZRLIuSYHqqxlTu93tMeoQK8pamQJim5CQkc/s8d9r+gXWVSnQXf7n7VaJ
LfIOujRaYwr4XbHvIO2yxIGrNJJNWwrUFS5+EbDdDDe9+Rlpo0qBBaJ+7sVn
DDS7ar7MpjcFomyu2y+IYGDVa1KjDSkVCv+cLBqQMXAC+f2QDS0Vdh4yTrKa
Z4pdrg8ibVmpMHdhjqrJ2xxluuoTnpMK53j+43vsLHG462O0hVSYNrWw2WuR
Fe4Zd2XINi4VYuzPekyZaoNc2clIOyIV6owOzP1lZYsXxt4stMtNhTkrEs+t
CLfFBOlZtFOkwovxc3LiSTbYu6p8yK4kFYSksXHnxo/ANZV/RzKVqXA3cu1d
v1PmaLTqQCGzKhX6rmZ+XXXKFCsPbUAmpgJ3sWnBr+UMHNW8aIjZlgrPjj8O
emvFwGfdwkiWKhWalRfXso8xkLgmL2T1pgLn+xfF8rVm+OvNdGSR0uDVp9HH
zQYscRslfohFS4NLO7Y4uVNskOMWGWnPSgNDd9aYlyut8DQ5tdCekwZW9vkp
gxWWGMsejfaQBqfkZfSvvyzwbYz3kH1cGry+xzYp67PAoumWkQ5EGnhQWsf3
3bFA3ZiAQofcNAjp89pmPMUC98rs0EGRBiQbi2UH15pj2N+UIYeSNGgNejkW
R5rjw8NfIhyVacCbo3UxOtkcU4qNCh2r0mD/Yz9b+Qpz/Fo50OCIafB7YElG
yhhzXH/9xaBjWxqc+bHy0P12M6RXDkY7qdKgRvzv5TRPczzW3K1w6lXPl8VN
/b3RAse9vdvgREoHUpBpfIj7CHyuVzfoREuH09XyIy/8RqCouz3amZUOxwcO
nqCuscQhSpPCmZMOYtohZxHXEne4HW9whnRweqdyXvzRAgMmbB90jkuHzFVN
S8+p91c1+3S0C5EOd7O6pr6tscCp4/coXHLVzxtqGoziWeCH6asaXBTpcJKc
fbHtizmuWj170KUkHd63MWfuYpmj/vR10a5K9fz3Z0UyAzPc//dChWtVOsQE
DZ3boWeKUUf4Da6YDorEzXmj7jLw3xsTB13b0mFPi2JqbZIp8g5Lo9mqdFhU
OCG0eqUZ9l+fomD3psOxajfD4C/q/fEurIFN4oF8DGedhZ45elFdBtk0Hphw
F9n8DDDHk2+jo91YPGB2LWGseGCOE/Q9FW4cHmjVXP545oUFdrmbN7gBD26u
3GZa8cgS5RNJg25xPGjaUn2GO8USh7nbRLsTPPCo3Ep0CcxxzwRdhXuuenxi
wFZywxS5M3vr3RU8SBhzvmgqj4HnxxsM8yjhwdeb5pKKShNMmPEdPJQ8GLXt
8IEtl02wd7VK7lHFA/rVwdH7VjNw9dEb9R7IA8ajNZZvskzRcPVrLc82HnDf
Jq1ufaneH0fawFPFA+mEEGarkRmOunle7tnLg0/VPQ10NMOn7/fXe5IygKh7
N0o81hKJG6jlRcuA2jNMx87vVvjr3RHwYmXA6P6rg6s/W+JW6la5FycDIpSp
7491miPHU17vBRnA+iB9XhFnjqf1d2l5x2VAtt2cFrf7ZhjrsQK8iQy4YNwp
mrjcFLsn5si9czNAmJ1zXp5lgkVZKfXeigw4u9/GaeU4OupOnK/lU5IBPevz
83e8p6FyZib4KDPA6+Gag5OS6Ri2drzcpyoD+sp+TfGbaIIPj/nX+2AG3Ljw
zPMZn4Epa/7S4rRlwIa8C/JkuSn2HQ0Bjkp9/3vZ1JjpZrj+lqOc05sBl9LX
vlk4zhzdegzrOaRMWGGmnTZJ2wKP3nTT8qVlgmLvT1XXTQsc+4EBvqxMWNK3
2+Cw3AKfGwwW+HIywfGk8IjwiCku8equ84VM8Bu83JdaS8dBqraWX1wmSKKu
UfdkG+MOz49RfoT6+rxEm8gRBhgwub3ALzcT4rJEjmUL9fCcx9dGP0UmTHNL
u+75noxTJj0j+ZdkQuCcn/dVl8n4Ias5yl+pvv+R/Y5PT1Jw5bp/CvyrMmH9
1wi36in6qJd1u9EfMyHp5Pm5VfsMcP/aGlJAWybUGb5KeTNkjFHHK6ICVJkw
r37S/a1jTLCjZW1BQG8mlF3LOGmu7o934n3CikSA2/sHRcOmqOuRjFdYUdTj
wNJf/jvoeH1BfbkVjYBE/0T30AIjNF/l32BlScBnm+DiLYZUTFrQqLJiEeBB
WNuNtaNo8otNwL3zjtssOnXwy7ajTGsOATprAw7Mv6utyTMuAa+iVvDMzHSw
cNsJwhoIcCGeGcUSunj7oKPCOoaAsfONawtWUdCmurTcOo6AB8fLx9/cRsXp
1wwbrJMJuCbd3nTc3xiPnNulsiYIWDjQ6JW3k67JPxkBSQVzX/2eysAxj1Yw
bXIJID3Z2hlJMDR5mEeAYX5P4a1bdLz/sJiwURCQe2L6228UY7R/80duU0zA
NPqS4csL9TG7f065TQkB7cvClz7TI2vyspSAr7o6FVuNdfDP9/kqGyUBtrPH
d/Ut0tbkZyUBP18//uLVr42lFgTTtooAzqz0Zx8SdLFD9yPY1hCw5OCdWIaC
gq4WQsIWCdj4zHH39CYqznNtl9s2E3C0LnZB1kwaNgZPLrdtI+DM2RbP74cZ
mrxtV89PulzOmWWKccFxKlsVAcM8o2doU0w0+dtNQMdkwbKOP8b4PimUader
7kfqOUlyswF6jmsGuwECrhb81O95q4eLkiIIOxIfLI/dnnKjgozXpP/I7Sh8
QHZsbV64LprmuZbb0fgwJrsm93W9jiavLflQTV7MejKog/sWuqvsWHzIN+ie
dS+IrMlvNh/6P797MOZvPYwoNWUyOXyg9/onm8oNUL6qAphcPnzom53nnWeM
t7arGwR8EERbNlpy6WhVuVbOjOGDLt+opaDEBKU1WuXMOD5sCnyzUfXDRJP3
yXxo6tVqevCDjt+rtVVMgg9ORcfG5CyjafJfxodVZSlvLNhGuLyabM/K5cOF
ugPbnJqpePdaPrDy+PB2KLK2OkQfme2fM1kKPvgoToUes9TDrG6JnFWsru9Y
y/PPHAqeePRVySrhg69p1erUW2QNL5TyYVTizakbHSkYM/Csk6Xkw7vvXbGN
dykafqhU17PfvPb6Hz181P+cZV/Fh4FllGKDHio6U5LAvoYP06ZdGZew0Ajn
WN7KtEc+nJbqu51eT8MGdrTcvpkPLbGnFYf30VHLslVp38aHlbLkgrsX6Rre
aOfDhDdjlrcU0XAXt7bTXsWHxjqHE4/V9f7HH918yBrbt/GvnVR0515kOfTy
gfTlxw1rPz1cGOMLDgN8yIgetWxdFhmvJB/MdCAJ4ETO3tiI6bpoMt1a7kAR
wPG8vQce9uvgtOTDSgeaAJ7V3p4/2ldXwyuWAkibHOxTG0bGj3mbOx1YArhe
1rXK3VZPwy9sARRqhf6cfZmKS/O2sRw5AjiwJqRv6y8jvFFMBUeuAFIdXDMN
3tHQcoci0xEEUGVgmjX6IB3Fh78VOMYIYP3medkXFtDxYGmR0jFOAInCsQ4t
c2ga3kkWwKX8b/GTSw0xunZWpyMhgLmct61nZ+njsspfJCeZAC771o49z6Bg
W00uyylXAGvW5uW+U+ii7fWuKKc8Acy6PrKRt0kHZ3SkZjopBLDJs76gPF1H
w0fFAjAt2vyi21QXf7TzlE4lAmh1k07adJ2s4aVSASxbsXfsimx93PJjXKeT
UgA+lU4B+y4a4oPuByTnSgEsCbw7Nb+eho4/JrCcqwRAFu5qr5WbYK4eRjnX
CGD8Gi0DyQMTrBsRmOmMAvgnzEDXNJeu4atmAXzMiNrkvNgIJ43gKp3bBMAu
vpLrX6yv4a129XrknGHePk3GNyEOnc4qAVQ0r6rd8kAH2W5VJJduAdh9K03o
1dXB+SHOLJdeASSM3LDt62gdbBq/M8plQH397n3KbZN1kZZqnOlCEsLbOQHb
Pnwha/iMIoQzLYqdhlH6WJ5ionShCaEmpHGYw1+GGl6zFIKvVn++xxoahi7+
/cyFJQSPGZXasb10XDJ9NcmVLYR1D2O4JSo6/v92dOUIIeG55HBIMw3NV8+L
cuUKIZfaVzGSZ4RJi4bxXUEIDwP39XGyqBq+ixHCdXnJ3HBXPfyy40O5a5wQ
lmodWmiUQ9bwXrIQnnb9Xdafo4uKHZ9UroQQVpwy8ysdo86PwyISWyYEq2xS
/r53umh9voPJzhXC7qicyT05FJTdiI1i5wnhRcIj+r27+nik9gnBVggh5mbG
Pru3hho+LBZCaIcB+VQ1Dcf8e7WcXSIEXD8t9IW9iYYXS4XQ3Mw1KtFi4L2O
6yq2UggZsx3onHoTtH8XSXKrFMKqXJ9di+fSMfvnaaZblRDAt+mkU7MxXtB3
i3KrEcLZq7XkeYcN8M+Pc4Qbqvuf+2XhY/V59B9fNgthz7CRlq0VFNxutbfc
rU0I7TN5z3sekDW82S4EifWwmfk1ZHSx2q9yUwlh8/vIiHthFJzrPoLk3i2E
BTuLGhTJetgYup7p3iuEltl/LKuYVDSaODzKfUAIn/kuH3afM8S40I2EO0kE
8zZtFq87RtPwKUUEWkeFjeUHTfBd6pJyd5oIRLFrf/IiTdFzgl6ju6UIHF2a
R90jmeKi1AKVO0sEbpF/DFaZmeDVGX1D7mwRHHo/4dp+Nf+YLpExPTgi8DU5
eNNlIlXDs1wR3Hly8dWdRApWLJ5JeIAIzDKKu61X6Gr4NkYEKmermZPqdDBi
V0K5R5wIRpTAssMdOliw+iV6JIuAXHX/3pk3unhrZ7LKgxDBmy1DK44gBUcc
bRnykInAvZQ8M2A8FSUXRjI9c0VwNG5JZs5ZIw0P54lg7tyd53lFdPx2fgzh
qRDBAHW0cfIrhoaPi0Wwh5f/6jzDDEse+5R7lojg5FDjur+kDLxzow49S0Vw
NYrvxvhJQ+ZjP5WnUgRhxrsVF28ZYtb7Q0OelSJwnTTq4uM/+lj7y4bpVSWC
NNmE8IPq8/c/nq4Rwfw9rxsof8gY84tJeKH6f3J46Vv19/0fXzeLwOnr+FK3
SjK+tNYv92oTAe8mw3/lYwo6UUvRq10Ey20+dOsYUXG2taHKSyWC3l5hmjjQ
CBs8lg15dYug/sqCRVe06GgQ3m/n3ateH2ig/mIyNDw+IIKticfym26b4q6w
n5neJDHMqhFbtx76H59TxLB93GO9GBID3cP+KL1pYnCyi5VxWmi4cOIc9LYU
g4EyPN7qviFeTnvT6c0Sw8gWgf4DBhVNstKHvNli4CyO/rLfQQ+npb1j+XDE
EDn55MIfEykanueKoXFfgNjJm4Ifl9zP9AExvNwjn7q5jKLh+xgxbOj3uu/w
RA/zlzxS+sSJYdqCnC+791LxxppJ6JMshuObKHfaLI3QYndjpw8hhgpT1cyH
rTQUHQsa8pGJIXFlUs6+HhM8uOsyi5Mrhl02U7TXM/7nA3licKHbzFQdYmD0
xROZHIUYzpqPfHlwgK7xg2Ix/Ft117rbjoatF04pOSViKHvfkRASZIi2t1yQ
UyqGXhrr67pr+jjjya5OjlIMX9LvN2Uy9LD6A22IUykG56Ki5Uii4I/HZSzf
KjHEPOSEzFWf1//5RI36/W/Pc/jLjYKbfxdn+qIYvku2xdZ562n8olkM4U0k
bHqujw6/1yh928Tw6a+nFox8Q8wx0ELfdjFcOfri0NEFNKyzWdDpqxKD94eH
WbIZJhr/6BaDRdvJuMBBBk6yWcTy6xWD6wf6+1tsU42PDIgh2uZT9uwDJvg6
XJjpR5LAQ58RCVFiGrI9Pyv8KBJ4dJbRUPzNAOeHS5R+NAkczardqjDSx0uT
Hjf4WUpgYc2HswfYFKTx4jr9WBKotG0bsrb+n7+wJTB/6OXLjke6WJY+jeXP
kUDHREfWfMX/fIYrAf7tB7F33lEwZGlEpj9IYMq/b/5e5EPFxVk3Ff4xEthU
3zu0VmyEzfmg9I+TgGjn7xML4tXGuu5sg3+yBI7FTm4uppuiYI97pz8hgeQ3
R6eOyjTT+I9MAuMCOi9938PAz7u9WAG5ErBZGLa5toum8aE8CSSUdo1e8tEA
19ZZZAYoJGDabSN/rPaxlmMHFAHFEvh64nJ4aDoZreuslAEl6nobpn3aCboo
a9nQEFAqAd7vp+cf9ung2afanQFKCdzbe6WsbKku9t/aRAqslIDtkzBjq3tk
HP2UzAqskoCL4MlPkr4+buzJjwqskcDdcSPcnk4zxHtP9PmBKIFZyf9cDL9F
Q1aPXBHYLIHhbO03TbkMnPXna3lgmwQWRO9sk7LN8ILhjIbAdgl8vp7xrs7O
FH//7lcFqiTw8rjvw5+v6DjBcBYpqFvd/4Ozml7cM8btti+YQb3q9du89TNj
twG+8kqKChqQQIwy6sF2iT662HYRQSQpPN/Us1bB0sO5XqmKIIoU9jyVz1qv
9k2MaC0PokmhUd/U6kwHBY1iRzcEWUohO5vnXnhMD/+KuKsKYknhQZO1z8Ew
Ku6ePI4UzJZCt8xxz/FUQ3zHu8gM5kjhRu9+UZLaR4OzfaOCuVJwfZNRWJFH
x0W8BiIYpLDijO0YfKzOj1kBiuAYKWzP5rUUixjIKDhcHhwnBcMX2qUJaIL8
9XYNwclS4AWFmR0X07Fi6TFVMCGFbXO2OxWZ0/DTOnsSVyYF7bhql6n/GmJE
2TYmN1f9PlZei870UnH1CWoUN08KVJcvS7TL9PHmnh0EVyEFnX4y9Q9LH0ec
MFJwi6WwQLF+2Pw0fZTUF5VzS6QwlZwt5U+j4unbA/XcUikk7XmvZ95kgN/q
Vqq4SilgwPro6QFGOPL2ryFupRT6bxuuGNNhjBue5TJDqqRgXuPcWtRNwzst
gxBSI4U/R2ubdRaZoN2zuUQISmFocJL8bAcDsz52y0OapTBnfJzB7xcMrB3k
lYe0SWF6Qm9eTIcJ/ux5jyHtUlBD2saTi+kYM0ioQlRSuPPKlm4WQsOtRg+H
Qrql8EJnUc/RWCN8YTeRGdorhU8Bab652wzQyagDQgek4De3vH5cnDo/7GKJ
UJIMjpfPMMu5o4/13k3yUIoMGk5E+1uMoKJBFLc8lCYDrSDXCcGDVJzsfRVD
LWVQyM0UjSwyxJ2RYapQlgzOGT/O6T9tjN2xVUOhbBnMEhb+rFf7nJpumWEc
GTCW7Q6uqTPBhbGnIYwrg0XmrHSPzwy8nMEmwkAG5VsUp46XmSI9Z488LEYG
E4s2T52s9ttMuUl5WJwMXMtW5smMGajMVmJYsgwE93/E9sfRsafATBVGyCDs
kv/Wph3GGLZh9VCYTAavyHP0HvEMsVito+G5Mji7+eLbQ8YGeH39OgjPk0F3
9dLqXUlUtCgfRoQrZOC1JHjyP2wqik4ulIcXy6Dv5p2lqSuoeKBMZ294iQzm
PPrZmnPZAPtOLMbwUhmspgYGMV8aITR86gxXyoCd1fGPVhMN17WKhsIrZbDl
9piOZDDB1vovrIgqGexctcj3pzpvbFqlEFEjA49/+y/8mWeKMzqfZEaguj8b
Nh7MqGVg9acp8ohmGSRs0fl+w9kE1XqpjGiTwbB5hlpeI2k49lM8RrTLwO/f
1MY0L0PcPHS9M0Ilg/EU1VLxKX1UGUcNRXTLwNwqesF0Jz10GLrFiuyVQcnn
+6J7EgrmGI+EyAEZXEq+aDVlHQUvMqszI0nTYauc7Dhlnh7+HzlzcVU=
         "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
       {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
        1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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         "]]}}, {}, {}, {{}, {}}, {{}, {}}}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], None},
  AxesOrigin->{0, -16.24000833619958},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox["\"Square Means and Variances\"", TraditionalForm],
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-71.38013788281542, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "31"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "21"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "1"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {4.605170185988092, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{{3.717359579599248*^9, 3.717359592291067*^9}, 
   3.717359622770668*^9, 3.7173599301958513`*^9, 
   3.717359969470254*^9},ExpressionUUID->"5d587c57-584a-446c-ae37-\
0d629ff4f759"]
}, Open  ]]
}, Open  ]],

Cell["Show plots of different runs side by side", "Text",ExpressionUUID->"6eab1306-dc54-4e59-aa26-4f88be59fb69"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fld", "=", "1"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"numruns", ">", "1"}], ",", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"numruns", ">", "2"}], ",", 
       RowBox[{"plotwidth", "=", "700"}], ",", 
       RowBox[{"plotwidth", "=", 
        RowBox[{"288", " ", "numruns"}]}]}], "]"}], ";", 
     RowBox[{"For", "[", 
      RowBox[{
       RowBox[{"run", "=", "0"}], ",", 
       RowBox[{"run", "<", "numruns"}], ",", 
       RowBox[{"run", "++"}], ",", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Run \>\"", ",", "run", ",", "\"\<: \>\"", ",", 
         RowBox[{"dir", "[", "run", "]"}]}], "]"}]}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"GraphicsRow", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"run", ",", "0", ",", 
             RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"plotwidth", ",", 
           FractionBox["plotwidth", 
            RowBox[{"numruns", " ", "GoldenRatio"}]]}], "}"}]}]}], "]"}], 
      "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"meansplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"run", ",", "0", ",", 
            RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"GraphicsRow", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"run", ",", "0", ",", 
             RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], "]"}], ",", 
        RowBox[{"ImageSize", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"plotwidth", ",", 
           FractionBox["plotwidth", 
            RowBox[{"numruns", " ", "GoldenRatio"}]]}], "}"}]}]}], "]"}], 
      "]"}], ";", 
     RowBox[{"Print", "[", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"varsplot", "[", "run", "]"}], "[", "fld", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"run", ",", "0", ",", 
            RowBox[{"numruns", "-", "1"}]}], "}"}]}], "]"}], ",", 
        RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}], "]"}]}]}], "]"}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.4220308955438204`*^9, 3.422030920747429*^9}, {
  3.427464450292389*^9, 
  3.427464450394611*^9}},ExpressionUUID->"d69ae831-f194-4cd1-ab9b-\
ffab9dd882f2"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Run \"\>", "\[InvisibleSpace]", "0", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\"\>"}],
  SequenceForm[
  "Run ", 0, ": ", 
   "c:\\Users\\gfelder\\Google Drive\\Research\\latticeeasy\\webinar\\"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.7173599695073004`*^9},ExpressionUUID->"be6c8d43-0621-41e1-8004-\
9a4f9765141a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Run \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\": \"\>", 
   "\[InvisibleSpace]", "\<\"c:\\\\Users\\\\gfelder\\\\Google \
Drive\\\\Research\\\\latticeeasy\\\\webinar\\\\\"\>"}],
  SequenceForm[
  "Run ", 1, ": ", 
   "c:\\Users\\gfelder\\Google Drive\\Research\\latticeeasy\\webinar\\"],
  Editable->False]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.717359969508301*^9},ExpressionUUID->"8b8a50bb-4585-4377-a2c1-\
5432cf47f5f1"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
         1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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          "]]}}, {}, {}, {{}, {}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
      AxesOrigin->{0, -76.14742169746623},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 200.007614}, {-75.04615102694436, -6.767369454589756}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-73.68272297580947, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-71.38013788281542, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-69.07755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-66.77496769682732, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-64.47238260383328, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
         1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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          "]]}}, {}, {}, {{}, {}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
      AxesOrigin->{0, -76.14742169746623},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 200.007614}, {-75.04615102694436, -6.767369454589756}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-52.95945713886305, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-73.68272297580947, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-71.38013788281542, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-69.07755278982137, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-66.77496769682732, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-64.47238260383328, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-62.16979751083923, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-59.86721241784519, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-50.65687204586901, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-48.35428695287496, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-43.74911676688687, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-41.44653167389282, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-39.14394658089878, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-32.23619130191664, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{576, 288/GoldenRatio}, {576, 177.9937887599697}],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.7173599695743504`*^9},ExpressionUUID->"dc5560b2-6336-451e-992f-\
86313d9c5734"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw1mndYU0sTxkMREaQpItISkgChh97J0HtHOiT0qCjYUZQEsSA27AU1wWuv
2MFCBnsF7NggoiggINKRki/3i5d/8syzZzmT3Zl9f+850U/LjcyUJhAI+jIE
wr+f//1NWhDvPfgpAiVRA2Nw8e4DVr5hf2Mh47DC7+edvP/iNsbu6oiSUvX/
4h7GkwVw4k7if3E/Y+e3RsNivdC/8TDDMl4m+lRPCA6sK+ubEI0yWnFdy7KW
/2IRQ88yZL31xxD84/lohUgkBeqPU29NTw/9G8uAxtbSnYWt/10/CQpycz9d
Vgv9G0+GfK2Jx6de/Tc+BXZNPVhI2P7fuCKcz17RF2IUir8exc2fECnB2y+v
Z75Q+C9WAZzbN7et/b/7qcKWfMaS08wwXK3/7ZZIpAbEQW5s+6L/vs90aEzx
PRtZH4LFTdpeBII6ZKWsNFe4E4Zytx3WEwgzgPmcUH1SJRQ3lkc9JhA0oNfh
W/twTygqrsydKkWYCXVXGXsqcsJwa9ymMCmCJky49lmS2kJRzeHEDinCLGC7
NTRNjQ3FXTPuvpEiaMHDuVd+PxOE4Mz+Jk1pgjacNEs4O54aigde/kmUJuiA
T3CLYs/VUNS5qMGTJuiC5orVwRzaf7Ee+E8ov1QyC0XeNusWaQIRnvVfnjaz
Kezv/Uhw2aB7w6h7OEYa2l2R4pLg3b6jntsT/ru/PkyhOYYPEEPxjWzEkBRX
HzZw5wX6BIb/zYcM+5uvrPg1HoJxX3OcpblkkEMFD/m9IX/zo4B9+ZcfrYkh
+LG2ZLU0lwLpbjPmTeaH/M2PCtvPJbus2RqKKfyjKM2lAmvD4nxLq7C/+RrA
pzczMuVKQvFLIcrIcA1A90esTm51KJIXhBrIEAzhwC5zHYJfOGYkf/KV4RqC
imry+jX8MDwWPJctQzCCj5tTP1QsDsXvLsMbZbhG0Jb7xXvCOhRppuvPyBBo
cMyWFDEgDMc5WurPZbg04Dg93lEyIxTPTDnSLUMwhm+nd6D1UAh2DluqynKN
YeyZ+mmmyt+YYAI/fnqqfb4ajOZtt61kuSYwulVp2bSiYMx9FxQlSzCFqCNb
nMNnhmDlg/dLZLmmcNFm1ZVdWiHYezV7jyzBDBJG042sa0PR5tjAdVmuGZgY
+u1wcg/FpbuK38sSzOH0P9LqVIcwvFasNirLNYfZgqa1b+ihOLSIpzOJYAHp
35yIgwdD0CnN3H0S1wK6j1zUZm4NwZURN5mTCJbwRTjxbXN0CN6CgKJJXEv4
kUyglfWGSNabQIdHszQvWLUGS/YH6LBwzZYQm6z/9pMO71M2H72bHIzLxmbK
SyMdGNeKFl6YHox9umP3pAhWsELpm3VgRxDmMYRFUmAFF0pz+ylzgrGbdc9d
imsFJTy1zfTtwThvzclRAlpBVdVatt3FUGz7Z3MVgWANFt2Fm06NhUj6B6wh
cKpczmzx/v6/v7jWsOuNZnTW6RBJ/6E1HLx+sfD65+C//WkN1+sq+quqgyX9
y7ABzUkiLacrwaiZtNhPxLEBy5y6ewoWIbh7daysSGADhxbtPBCcHYzTeC61
EyIbeNW7R3RtLBjLkFg4wbCFJ4cX7S8QBqFSi4zLBMcWXiVS4qxXB2GpTNvQ
uEAcl35/uio4CE/q7Lw/LrKF4z2kSqJGMBq4L18zzrCDurTNCq/uBuERZiJj
nGMHDdWDG3JLg5FYxBgbE9jByNXZUvc+BePBI5TqMZEd2KyLMTm+KRhv3Kxb
P8awB8W3DmEky2B0+HzJa4xjD1cfKJcJRoPw6sQewpjAHkTrbYrqmoLQmlRw
e1RkDxWsdpOzjUF4wYO5cpThACMWc0lShsH4PEHBf5TjAPutd6mHhAZj4Kpu
2VGBA8yV/r37wuUgfHjoZe0fkQPYPtc5UdEXiN6Ca4V/GI6wLOxJ6+E9gVgr
PODyh+MIC2umWrqXBCJDmjM8InCENdyBSX3dwZikbfJgROQIWR8fhum0BeIH
V+XiEYYTZE6JUlinGISxKb2MEY4TvHi52UbfPAhfc96ODQucgDSrm8ukBmFE
xY3qYZETNIW5qdjZB2HujcwNwwxnsOK5mTGXB2HnxwDvYY4zrFWNjdm1LQjn
jJtLDQucwSb4k89yWhB+15tWMyRyBlOvkbbMT4GYAYMrhxguEDGS9Ew1MgS/
pH5wGOK4AHfZ1pwNmwNRtHLdpCGBCxj2me/hzQjEVQfn3BkUuYDer83qz18G
4MjtEM4gwxUulDddK/sZgMuarVwHOa6Qp757QVFdEPYRNEYGBK7gU7w06Fth
IKpp1T4YELnCjVtObT+SAnGry7HiAYYbCG5WXujNDUTF5I0wwHGDeIdPpEn7
A3Fj4fzxfoEbuOveqTJUDUI5fsSNfpEb+JW9p0RPCUZq9diGfoY7+PQGHL3D
CsaKD0Lvfo47OHFWurr1BqKeuN36Be4w4relYxExEMt1T9X0idxh4Mf4zkMy
4npnbCnoYzAgkjfv3rqaANzNWujYx2HAFPU5qS1hAXh5hY5cn4ABEa+jpoap
BOCi0q3fekUMWPMgz9IzMECyX0SAnx2Bt3oMAnFGbobeCAPAYOmKtT6OgZL9
YwK0zrv7LfBVAKZPPft1mANwNNpx+8GuANTX1bszzAO46f1+YFN6IArNy/jD
AgC1bQ9ub1sRjDx3cQE1A+xouR/Y3h+IyWFLkodFAI5h77SKxfunwxKf0EQP
+CX42n7GLgjPdN4kDzM84M+7ndSuOQGS/Wd6QM0/twYUYgORpsxvHuJ4ABZd
8dzb7i+pB54HtE98nzV9nT8es1x7cEjgAYF2CoX3gv3R9lZ88VCzB8xJ1HKi
3/DHvmdPU4dEHqDx4kHr0B9/vPjZDYaInnCIaaGjHSQ+z7ov6A0xPOHDZsLz
pU8D0EKkPz7I9ASjkzkbK6wC8famoa+DHE8Id9W2WEwPktQTzxNebS9pC9wV
gM7nPvIHBZ4A0erT9tL/1lezJ0h9XNOYYBqAVXWC5EGRJyQk6B7oFK/v/+uN
6AWk+KQDOs/9cVLOZMogwwsyvnwrWKUdgPdWrZAaZHpB+MzLei0a/rhmy8/m
AY4XDMZl3NO54Yceh5NrBnheYP/aw9J2ix+KztcfHBB4wZdtLV4unv6S+mz2
Ai9Dfcueyf4YEjwzbUDkBTGUa22TDAIk9Ur0hvAp4/6n1wfik/mjegMMbzi5
cVxVuzRAUr9Mb0g0DTHOP+uPftuaP/ZzvEFtX9zFYfH6vtW+eqef5w1N0/4p
Njfzx91mRhX9Am9wt40Xqev7Y5Tbfk5/szecmPV8GW+TP04LVUzpF3mDo/D2
hYYQf2xIWe3aT/SBnDkRpNtT/ZH5M5LSz/CBN6S2wngfP0n9M31AoWTjS/1f
vvh5qoOwj+MDpS/mjV1/6SvpB54P2If67pSZ4o8JFtqH+gQ+8Cj+4dFtdn7Y
fqOnuK/ZBzQeFk6p+McPTzxNS+sT+YCVT5NxaqsfZn16DX1EXyBXblttdcUP
qV2+xD6GL6z38xOlcP3w63jVeC/TF0JsEjfdXOmHR5RNP/VyfCEg00vu2Co/
pJcT7vbyfOFNdxCzJtoPf51ZVNEr8AWtnJqC8SQ/PH/rG6e32RcOGj3/1ajn
jznPY1J6Rb4Qsz/85WdFPzRteuTaS/QDN6MF538t8cUbcw9Tehl+oDl1p8sk
mi/mF6hK9zL9wPCsUXwh1RcdNq8R/ub4gfph3x+tr/xx4GB/zW+eH9Qcae+p
3uaLV85lHfot8IOudL3C3cd9cXFNY8HvZj8gBt0orUFflA46n/Zb5Af7ST84
H277IiaSPH4T/SFq7ugdzltf5OTsIP5m+MMJ5fNL4rT80G217EQP0x/SuW/e
Rtv44diWZZ96OP7gsc5Sf9JjX9ykFXy3h+cP/IrTAe+X+mKAaU1Fj8Afbi1Y
d2xVuT/Ku9K5Pc3+8FawcWCxsS8+DD6S0iPyhyJvTrbCaR9cl6zu1kMMgI37
3senp/mgekc7pYcRAOVn5y99sMoHX4lxsocZAOE3/Oe8N/HD7Yp1wl+cAIDG
l4aVM30xXAcEv3gBMLHdKf57lw8qm1869EsQAHkmn4vNCL743I266ldzANgN
NO41p/ti0pORtF+iAHg3+vjVxau+qPVxnscvYiCsezKyWK/FD9///Ez8xQiE
iQ+u2/uS/HHfWNhENzMQYnQKjOu2+2KM0p1P3ZxACGw8PINy3gdb9++9280L
BEvqR897mX549LQYIAWBsKCuif0syAfTbhZwu5sDYfC4zKGZzd6o/6wrpVsU
COev1jS18ryx+RPTrZsYBI2Xln1a99UbD3e90O5mBMHvYW7hpIM+aL7yhHQ3
MwiyXg3mh437YGfprC9dnCCYzaTWsrk+eLp8k6CLFwRfgkd+PDvig3POjh/q
EgQBQesbZWWgLxrdzl3V1RwEKWvaZ8cd8cNrAT7pXaIg8F2xI/CIni8uTbju
0UUMhmf3xu4XqviizTxjUhcjGK4fX7kk6qYf9haUT3Qyg4H3fTC+XcYHKzcr
fe7kBMN391wX51s+yJj19W4nLxi6tmZ06y73xgnj2Uc6BcGgeoLTbDTTG287
P+R2NgdD2gk130UtXlgQ5MTsFAUDfdJqn5AUb3ROOuPWSQyBDuO2Wr9ibxzO
0dXpZIRA86ZKje1H/HHDSK90JzMEvrBWXd1/2Qd9FTK//OSEQH7dojd7YnxR
Vvud4CcvBPZM+ydkzYQP3jUNOPxTEAJBSvVRu8e8cY3rzVU/m0Ogr9PgZ895
b1R9XJb+UxQCG58XXPhzyhvr30t7/iSGgnn3AorNch/c2rGE9JMRCta2L2ym
LPHG4NHvEx3MULivWY2lu71RcWr85w5OKIxOoVy9ftILD+yzuNfBCwVd8y0N
dWFeGHeKf6RDEArP7X01Dht54cwb04o6mkNh4L7UFLUhL3zzZC2zQxQKr2vW
yq/b74W7Pg66dRDDoKdQ7f3afG+M6mTrdDDCQGRXOv21rQ+25LvLdDDDgPzA
TUu+0hv5Gyu/tHPCoDtHRfG1ljcyD5CxnRcG9i0lVywavVD3zK7D7YIw8DKQ
Khqt9cJPN+VWtzeHgc189rT4i39jURjI3KYYzxd54UJXntSASji8kSXvJsp5
/9WDcCjexb8dvt0Lj69ezBmwDIfPFzc/ZXz0lOgNIxzYxJJ94yWeEn0KC4fY
BiHdfZEnphxKh0FmODybd+bq41deEv3LDQf5i/v0rF974q4mh5pBTjjkLq33
UTX3Qo3bUVJD28Lhmnp18ax0L4ke88LBoHLBjLeuXhg8YcQZuhAOmTWJ+U80
vSR6LwiHHMsxnTail4QP6sNh4yJ53xWGXiirpwnDzeGQ8c/y0J2DnhL++BUO
I6sPDXr+8kRx9d0eFoXDixh1h9hmL7zlJi81ohIB3187FhZVeP7loQiQh4fh
VSqe+LvwU+GIZQRIG32fefKuB4rppXaEEQF9hJ++Rvc9UKWwhfAnLAKskyZf
mxD36+nDzxh/mBFAeJKfqW/vKeHr3AhQeXzi4TGGp4S/ORFgslu0OzzGE9Nq
bhFGt0UAbuktD0ryxLGm44xRXgR0GxS9V17viXtFZYWjFyKALr//n2ihJ2o1
na0dFUTA06aMZ8sJXhJ/UB8BHDlzjfaVnhj2r+FojgDZ391DC5Q9sYMxr3Ds
VwRM1bx6NY/mg/P1NtSOiSKAgfzX+2s8cDJjIWFcJRKGaG8yl3l7SPwLMRJe
ndmY9GQC0I3rUzhuGQkrlUqfHNH3QExJrR1nRMKqH0ffblrriQmcIMJEWCS0
8A1GT9d74ADPjjHBjAR2avnLuj0eEn+VGwntX1cUuJ32kPgvTiQ85RnbW3d4
4DmBAUG0LRIOffaMnXPIE/2FKgwRLxLmT1IK958vrn/Cn9WiC5HQ2Lc5cQbD
BzObZ9SKBJHQuk7QvCfFU+IPGyLh/Dq2+XCwB5aTOtwJwkgIXt669vldT9QT
TVpD6ImEtx8qvD2+AVYRe8RzooCR3kwirwCMgg8igmoUaFcnUl1cQOJfSVGg
+MFRS2ojSPwtPQr68+ut5+h5oCLrCUpBFPTQt/vmvfHA49wrIqnwKIiyk6q7
6uSBUHHYXZoVBbLhe8oj0j3wLudGkXReFMzLV14i5+P593lHFAitaR80l3ni
CG4VSZdFgdrHMZ9LGzxw5xdxw/OjwLTKZrsi1wM1cFeRTGUUKKgo7+PY+OBF
YSHKiLPmGKg8/1YBGCQ1RyTTEAVW83kfzwZ54Hf9KHdZYRTQWhqaFqsAziHk
Fsn2RIFrQ/ikrkQGyurHoywhGjYFJrPW9rnjYQ8vkaxqNAgP6T2NlgLJ8wRS
NFyjeB6VFs////MDejRUcHtzS5M9MSbVBidBNJDf1hkRj3rg7yJd0aTwaJD/
4mj79ZEnbj4y2V2OFQ03Nf7Qcj3E/VFEKZLLi4aHk+zkS8XrfapCCeW40fAt
TEHG3hHQ+87QhFxZNNy4fVnqtQ3gQ/50z8n8aDgzvPPPzx5AcbVxJ1dGg/SS
WpH0VMCxLz8EkzEaXm30NeAYA+6VfjkxuSEaQnwOulzPd0etL10e8sJoKOaG
zxDUuuEVqUaufE803KvnpPYucsMw8h2BPGE2kBVLTp63Y2CH59kJedXZEPn1
yZQpwe6Yo//IYwppNuQf0BwnP2XgZM9L3Cn02SBjmPEkchngkbSDgikgvv5w
g2e1GqBr8fqJKeGzQSRYWidDZ6Ag9YiHAms23Extqlh21x0T1mzmKuTNhj9T
Xy6ffdgdB44sEyhwZ0PaRKit+Qp33HaXNaFQNhtIry4QKOoMnHZklYcifzbo
TnVgDKgx8NydLK5i5WyAIHJxQKQ7+n0NFyjibGA1eM8IfeaK/z6uUGwQzy+q
2bhslitmtsR4TBXOhh4FL8H0ThckyHhwp/bMhjeMW27dBAYeoJgKphJiwLS9
9fTi865o5z1jYqpqDNh8dDRnM9ywimzloUSKgSN9U0aGDrlhpJc2V4keA1HM
hYQTqW7YlT5JoAQxsIj4IXaesRuWrP01rhQeA4MLX3dZO7mhYrqihzIrBur/
7Fnk5eyGYvfBUc4TX/+5InX0jSvC0eYaZW4MCBybr/l1uOLdNaNSKmUx0JDm
32gx6obJ/7SCCj8Gdmos6pJa6orDd+s5KpUxEP0h4+RlJRfc+a26RgVj4KSN
Qn1brDNq3H0jpdoQAwSLzr0vI5yx8qsAVIUx8KQXorePeWCQ7GmOak8MBE6u
qdaku+B36q4aVUIs5Exiaf12dkG2TKWUmmosKKfvTK3MckEZ6gFQI8WCdVay
+sp0FzzsvZajRhfH/UETs9a6oGPmgho1iIVlB+Ptea9c8KZXqdS08FhI78SH
qvddMCZjCUxjxYJDaJDrKRUX/L02hTMtLxa849afYf52xk3H/GumccXzl08J
o7a4oPLaDKnpZbHguc+oZNtHZzx1NBSm82OBuFbx8mJbJ/S678iZXhkLnWmf
P6tkOmJTK7lmOsaC436fZl6hI6aKjyv1hlgwO+FyXGO6K459o4G6MBYMvoYT
s7hOuGfSdI56TyyoemteWWbihFaG47fVCXEQK334J8PGCa/IzpKaoRoHwv4r
t+vIThhqIAMzSHFAUT2/UEPbCdt9ugpn0OOAlj9j6Q51J8yhTrkzA+Jgfcat
jJkCR5zs00fQCI+DPMU9Uv5+jliR+ZmhwYqDhhPB3mPlTui6/mGhRl4cXLS7
8CX7tgMKMr7WanDjIJ55/NOvzc4Yv+45YWZZHHger+pizXfE/mPXGTP5cTB3
+h2d9Q/tcduDisKZlXGwTo5l/G2XPU47drt2JsaBRvmWxut8Vzx7/wRBsyEO
jGUzT96ssUe/79sZmsI4UAn6s7HthT22yK0q1OyJg99qhz1XKThiRuveWk1C
PJSF7NR7u8IF/5WHWarxMHbsT+vbdkc8YJjDmEWKh7CdJOmEenu09YspnEWP
B8vFpU2qm+3wusGi2lkQD8vvVV3Km2eHkb5JBK3weFjlLeP7cbYDdmX5MrRY
8VCRLjywdrIdbthAL9TKi4f46u9KZcq2qJAVXKvFjYfOjAblWeU2eGy9PUG7
LB5CwF7eqdoGGSdIDG1+PChyLNyq9jjih4cKhdqV8WA0bfhZvbUtJh83rNXG
eLg9ndDJMbbH4QeqBJ2GeDj7NH3urV02uOPHH3cdoTieluX8o9QWZzzQWKPT
Ew+vtNMv2eaK++M7oVaHkACzZ3eyLqg5YeDknyId1QQ4WJhz/+h3Z2w1euOu
S0qAbUbmW/217ZAtJz7h6QmwdF/QjfBMG5Qx+oi6kADEmdUXL263xUN+90W6
4Qlwq7jTv17eFh3ZF9z1WAnw40dnjoqLNd70fVqkl5cABru0mLFJVjg7+yrq
cRMA0Zd9fZCOPRt4Ir2yBLj26Ux+y5gVbjq50Z3IT4CWL2t3FHdZofKGY0XE
ygT47Rj4/lEjHU+e2IZETIAbiza8zr1JR69HK0TEBnE+XcGiLIo9NrWlu5OE
CXD1xsU97gfoyHrIKSL1JMD0x58cXZUscfTHHCQREmHvgSPc4b3muEc+WkRS
TYTl7/pPpHw1Q7qxu7s+KRHojjaZEefpeHlyQpE+PRF+xNDwbLophtLEHg4S
QUmv9O0KJ2ts97cQ6Ycnghvv5CFulgkWz9F0J7MSITVvy4VIFxrK+dsWkfMS
IQActhw1McIKth6SuYmAaT5X432M0WWjvIhclgiWpu8Op1sZ49tTvW4UfiLI
SKs/owyZY3yJchGlMhFmvTt2zyzaGPtPDgsoKM5/+bro789ouPVxywSlIREE
R9dQz92nodrJCQ+qMBG+rx5NLP0szvlRG5fakwi/C3+v273NGP3aXwqohCS4
KspZ3pJgjl+m3J6gqiYBYeujL+eyTTGjrdHDgJQEoex764M0TVAkf5drQE+C
uwcpyQ0yJrjfWExskAQ/h08pynywRtvAvRMG4Ukwt8FynxrNGK/TLnsYspKg
wfHtEs9DRhgZcIhrmJcEvzpLrlY8MsbOORsEhtwkyBmoqpbmm+KG0oUThmVJ
4DGvPpaw2wgV5mzxMOInQZH/mzmEakM8unE516gyCXac8OYPWpog43SqwAiT
4L3xdQerRCv88CRowqghCS67tw7k7DbB5FPZHjShOL8P+WT9MUMcehzBpfUk
gapnz/VSbyvc0eEioBGSQVD9j8f1Oms0VzScoKkmw/7jueUN0y3xQruHhzEp
Ge7GPRTKetAwUMGMa0xPhteurSRaARVbTTQExpAMXDP2/jvHyPgv/hqHJ4PJ
ifKWKfJklDbR8TBhJUOSZmG/wTMDPBQoxzXJS4ZrDrvtzbeS0XFeT40JNxnC
3F8tnatAxxsBU6VNy5Jhb/Hj2OodFJw9dxBM+cngnartek2Vgj2lQo5pZTJ8
NhO+XJRExdIzT2pMMRm2/Ck/nZRFQ6XS71JmDcmw2XRwxlJrYzx5ugHMhMmg
/Kb2wiclGno9vcEx60mGnzv7d+7RM8LPP4/WmBFS4NNTjWB7jin+i7Pmqikg
SvlxaUeuIY52nAZzUgoUJV1m/nQ3wN2Kuznm9BTYe3hBAyuYinQzTo05pMAq
vldP5SkqXlYol7IITwFvs6JTm9qNMNR0HViwUqD1wTe/OQuNsC0ol2ORlwIG
pgZye630sTgnvsaCmwLn0x99ezyVjHJBS6Usy1LAdBrv7fwdBsifxwRLfgos
m/Nl058qMrpsDuBYVqaAhrHs6c33jPDtWZsaS0yBwiIDcvZNE4zfFCZFb0iB
wbkXWxJNqdh3xgnowhTYE7IxMOuYMW59RuHQe1LgW4F6i5MaGY27lGroBCac
KN909PpeIp55aixlpcoEGerFRzPZuujbOR2sSEyxH32rtXmfDn6ZOlFoRWdC
f9R9uftEEhb8+8IPmGDUKLOhl2uIE4qyUtbhTGgcf/A8WY6E+826GdYsJnx7
Ket97RsZbUMaC63zmLCDMTGtS8kIr5n211pzmaB08eC9xgwKRgQ3EWzKmOAv
enIl7SAZO3MeMWz4TIjL5O9bupWK67dcKrSpZMLl0cKeGwP6OCWnrtYGmfC6
+BH73B99PLq5imDbwATuRP34WpYxMs4dYdgKmXD2x57iAldDfP98c6FtDxNI
Jo+52poGaBHzmqVFYMGm+voGr4+GWJAVwNWSZ0FBbMjIwXvG+HhZDU9LlQWM
oYsOHyKpqLHBRqClyQLrnY9PZaw1w9hltUItEgvq1Zxjw/4hS/SLxoIV+w8r
23eZY++eM0RtOgu+NT1eyDpPkeiZIwtc3zZPekMxxKI951nawILx6F/fN4UZ
YN1xClfbnwXJfH/G9jYD1Lm+j6cdzoKvfkffy1+i4pyHSgLtOBaY+9i5E/t1
8fS1cqE2iwWH/GD3rDgdif6xWdCwr9167mlt9Hm3jqiTxwKP48nBj9W0JXqY
zwIlu/IFZ1R18PXbEpYOlwXNTy5/XUMlof6PcY5OCQt2rKATWysNcMG/L1jL
WCBXo7/1oSVFopf7WKBTeu74yhMkHB9cKtThs0B5pTp/fK2+RD9PsuBG/0fm
tVAS7pvJIupWsgDW7X+4TcMA38t1g24VC/JGjrk9PGKMRjPTWbrIAucfbsJL
0Ua4xKiRo/uIBcWKZ2JmdVKw1iGEp9vAgjMV9dtWxtIketvIgjs2Q1cCg6gY
7hAu1BWyYMYjtTifNySJ/raxgFNywbWjmog/Y52Jej0swKEngf0fSWjm9wj0
hsX5/0O670EwwBWxbiw9Qip4vO1bLn/LGh9mX+LoyafCk6O8sACxfqnnG/H0
VFNBhjFnC2+zgUSvNVPB042BvxcZ4j/LTYR6pFS4tzJU6YC1kUS/aalQY5XR
9ES8f2771IlEeiosuaT4T7D4+3E2HAGiYyr4b5q7/8tVA3y2V7xAkArGRUNP
N7dSUevkZg7RPxXaEle3dY2RMbtKikcMF4+HtUWf26Av0fu4VFiqENaDfiQc
vC4rJLJSIXoste6IL1Gi/+xUeFSZ2lB2VR/XXp+sT8oTX6972LlnGxVfPlwF
pPxU2B2Ws/NuLAWJjb+ZJG4qEJRkaOVCKua0ZXFIJamg5jXBnnOWjuff9fNJ
Zanw9GxxaG0JTcIL+1JB7ullDVEyFf2Hm5pJ/FToYNU13Qw2kfDDyVQweBJ8
he1piu+GvpD0K1Ph56ZTx/LkaGggHwv6Valg274i8kQ1BRdpPmPqYyq0xoze
6R2nooDmwdF/lAox04yWSF8zQinNer5+QyoMkmULZhyhS3ijMRX2+jl92kWg
YbljdbO+MBV0ZoUmmU01kvBHWyqclbn7OCPYGE0cb5HIPang+tzk15qnprjc
3wrIw+L1Xfpk745pRng/7jiTTEgDPZrsY8pLMk6bo80hy6fB7Cb7xXlMCkbF
neKTVdPAUCS8jaNUCa9opkFLy+QnDcsMsDt/ZzOZlAZxHe83UN+TJfxCSwMd
Vs6zs1JkXJ2/h0Shp8E/z+SVLreR8EmJIlAc04D0rDjttD8JNfdzmRRIg8c6
ePCZBQkzTw0UUvzToEat5FXacRIe31fMp4SnwarPgXJPyWQJ78SlwYGKW+sz
11DRo3p+M4WVBvsXbzkeKEfFf39eQGWL7zfm+uzFUktsqMojUfPSYE82pl/J
1Efdx60Man4aWFqdax9cqI9z3ycwqVxxXDpT4ZopRcJHJWnQlHpom02tBY40
JvOpZWlQmGOufEXJQMJL+9LAx+Ks3PWnVNw14tdM5aeBtNoUn+xIU3zT9oZg
cDINJg7Uf7CTMULKSCDJoDIN+t/dr742g4p5U5BhUJUGxYv2uRe1kPH2LDum
AabBE5lukfVJioSvHqXBrR+Kx1k1thg8y5Fv0JAG1Tw53jspioS3GtPEfHWA
ldNIxh9O5GYDYRp4ct75uk2iI824kmDYlga07gcVHyhmuNTJgGTYkwb1p4Lz
orSN8G7AAYbhcBpYbw3JjZehoGqCCtOQkA47KMIVK4+YSPhMPh3kB07TR76a
Iy9+Gt9QNR0u7jN7arf/L69ppsO9sTKd5j1kdF451mRISoeqs2GvrxwW6+Gc
UoIRLR0iL/5zzWsNEf9tRyN6OlAyR8KPahBRo3QJw8gxHR6ee9FrUkDC2BXS
qUaQDtQv1/wSPpIlfOefDvUDhskH1hpg7/5OnlG4OL9l8+tuT6dKeC8uHT7f
TTr1agUZuft/CY1Y6fCg5ZbZemVDrDuVQaCx06FgwcA8xw4aat94T6Tlif//
wvNqNSsNkf0klEHLTwf7++zz9B00PF39iUXjpoNle31eZS9Fwocl6bCn7Bxz
50Iy+nx4wKOVpYNyt9Ro2iqyhBf3pYNJQcCU2eFkfPX+sZDGT4dNsaw8RwUy
6ne4E4xPpsO0vfpbFtiSccGfy0TjynTwfXvTqcCdgjcVjBnGVelQsW3Ky5Pt
Bjg+ck2s0ulwwKHlwKERYwlfPkqHKPNVsyoyDXCvVgXPuCEdRBMsr+AmAwlv
NqZDUsjxih8++miodVRoLEyHb4FF8FyBhItNZhFM2tJhY1FVX7I5GWudtxJN
etLh1SSfaBUjM1QOkmGYDKfDRO/kbIF4PNx5O8uEkAGK5K6viU+JEj6Vz4BE
Qw3r4gI97Ego4JmoZoAu0fmy6KcumgVOqTXRzIDrWgaC8kFdXJFQKDQhZUDR
nl1RB4yI+GBun8iElgEou3N0y04Sqhewiab0DFg5U/7U2mskCc86ZoBBysxo
LZ4+Hlk5j2UKGXBktaxOA9IkfOsvHh/oiPHlk9GtfDbPNDwD1qe8dZES6mNh
6Vc0jcuAKL36skInEj47ECc0ZWXAd07LdVabHs4681xkys6AT3h129r9Oph1
05NolpcBQXLbA5co6Eh4OD8DfGOO3/pjq4cDN3xYZlzx/OxPT4PX6Ev4uCQD
XsTSQPelEZZ9tOSZlWUATyfzhcp+Cr54chvN9mVAo3SEgsxqEhI/WgvN+Bmw
fUek+kp3Iub8PCEyO5kBPW65j1r9iVg9qkM0r8wA6mhGzSslPQlPV2WA4Tl5
+YiHRPQfJbLMMQMe5qs6rO8nS/j6UQZkxKjmlK41xK/aCjzzhgxw/vSN9WU+
GamK+9C8MQMmzgvMOHr6uFBbSWguzIBtVfymINBHgekakXlbBsxarTOrezMR
p7oO6Vn0ZMBi++0n6m7oSnh8OAOUhKfUkaGL5S5/mBaETHhubNuVn6kr4XP5
TEhut42s9dVDE5dxvoVqJpRvaeg7yyPh8qBFaKGZCVnjIeZMHwO8l/ij2YKU
CQmMye1L4o1wWk6SyIKWCZbWP3bMqCVjVGIHyZKeCdv3vt53UIUk4XnHTDCN
6d50jk3C7oLXTEvIhBDLlsqufRQJ3/tnwrqSNp+JzTRcVfCObxmeCXWryUb4
xRCfbApGy7hMoDU4RdfrGeLMg7XNlqxMqGrtgb3zaJhx1l5kyc6E6rJJrkrl
Vni8/B6JnpcJ6olplYdeGEr8QH4m9O4toMVxxfpx6zyTzs2EPVdkY+q/UST+
oCQTctQ/HdYXnzf1Ny/y6WXi/MyXCAbCqKj7zBDp+zLB1mns+MUOCs79VN5M
52fCUEixk84KKl7vVBXRT2ZCx+PZzcYOFBz5eJhkVZkJm9en8c2nUSR+oioT
DLSaXr/6bIo7x0qYVpgJi97HdRGmmEj8xaNMIGSbJe/QpSJ5bBPfqiETNG8Z
cjfF6GPuVCm0asyEsJtLJh9UJOFtnWXNVsJMOLkt4qahuD//7z/aMuFVQkdo
/zodDNZZQbLuyQRfuS1Hx09pS/zIcCas/XHy+Z/F2vjdNZ1pTciCJIWk/V9e
6SDN7DfXWj4LPK2sV9GOkXCpaxbfWjULuHfnn2teTcM7wR8F1ppZcGjqzRdZ
78iomhzebE3KAnyzQfNJNUniX2hZsNmreemOnyQ8nBRFsqFnwcDSOoMYJ32J
n3HMAt9Uxw8q0mR0Wu3GtIEsGPTafYHTQcaVOU+5Nv7i8WPWmdu3GOCjVcC3
Cc+CdL6LvSoa4owtVwU2cVkQWsGmUXPImHbIpNmGlQUuId+LzrwgSfwPOwvs
NPWV8q4T8fdBc5JtXhYc8I1JPdGpJ/FD+Vmw+uzJeRr7ibj59kymLTcL/J8Z
C3Qfk/D52WNc25IssP/1ZXKVJgW1b2vxbcuyIGFv/pKcY+bIfr5NYLsvCyot
V5wK0afh1c+yzbb8LOgv9q9aEiLWj2c7CHYns4B2jrHEDSno/Xkyya4yC1pS
Cpao9Bng9q5VDLuqLLi2/8ylHhNDfPVJIdUOs2BN0payZV7GSOricO0eZcFF
+a/xSotNcf54P8+uIQumZu5UFwsr3lSaK7BrzAJnE1aonYUhjo0NCe2EWZDq
Lv8kVewPA5XmE+zbxPtDeXiiVZ6Ce3VbiPY9WZATytj/tJmM38xjGfbDWfCp
VaR4IJWGhrqtLHtCNjhuObj4kgwVF5sncO3ls6Gp7qzqZ4I+ols9z141GyZf
WhnmnKmHyqHeAnvNbMjpTqHUTidhmNtLoT0pGwi2LWfiWil4MMSP4EDLht43
wmUPrlKxI/kW0YGeDRc1TqmtDdBHhwVWDAfHbNjndti4qJGEK5IFLAfIhj3m
NXNKxOMP5ttyHfyzYf4ALWp3ChmnF57iOYRnQ9aFgkmtGVRM3aoncIjLhrXW
shupXcZ4ZPVZoQMrG25lSdHPPDXCX1v0CY7sbLhd/VrsUo3Q7fAeomNeNryI
kzFZWmOMpecVGY752RCafcknfgkVnx7az3LkZkNd8fvdpZOpOOu8MtexJBvm
eb+z3Z5lhlk1xTzHsmz4w07WvfiLipfrhmsc92XDg3qV+uedVBy4vV7oyM8G
33xlxu/pluhZNypyPJkN0T3nDfnrKLitKY/oVJkN7Y90x5ZPFevH8wlwqsqG
71N8B3eJ+UavaTHLCbMhlasb+2LMBHO62zhOj7LBIpbqXthIweqJZJ5TQzY4
KE/TO/RSH/90/USnxmxYdMiIMLxAH/0nWEInYTbEDJx9fOO6WD+U34qc2rIh
asGexz1rjbFFL4jo3JMNCfpf36v/oCBV+T04D2fD02fB6b9Pk3GhXijLmcAG
zul3q5f9McIai7scZ3k2HJwu/GZCp+JUhiPPWZUNkSOPlXZvoGKIxQN01mTD
6zJG3aoaCzzg7iJ0JrFh3reuUScx37SFVoqcaWw4oTdGXfCbhGK6JbrQ2bBj
ZFmbmrdYP0Ivg4sjG64mxJQt3kbCeyk0lguw4fLtp3OXJuqjWu4hjos/G+Kf
dHp0TKcgkzON5xLOht0tF1jHr5sgfwEfXeLYoJC+zMF3IwW7CmcIXVhs8H38
aZVrhz66bCsVubDZwBcle8RrUrFEbEdd89iwhDhfrznKEh9v3QKu+Wwov96R
UC5rhDN50ixXLhsu1Z55zN1pgBkXlnNcS9hgd0ee5zODgscOT6pwLWNDv/+x
B/Je+th3fiW67mNDYYC/1bdQfQTBr2ZXPhvsO4p6dhpScEt9hsj1JBu+L7JI
/jJhhPU1vSS3SjbgKW8tWwsa6tRng1sVG5qzLHPn6FBx7r8/+EE22GBWz84A
Ml7/FcFxe8QGhskL7YhAfRTbS75bAxv829+eqtfWR99f0ejWyIZn033+UC+R
cafocbObkA1fR5uzN9FN8N/X5W5tbJgxrHNwRKzHZNEzknsPG458Ze1ap0/F
XBVPcB9mg23p4tcWJH28RbzOdCfMAVbj6dxl9kT8H5lhFDU=
       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Square Mean: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -76.14742169746623},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->NCache[{576, 288/GoldenRatio}, {576, 177.9937887599697}],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-75.9853080688035, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "33"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-52.95945713886305, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "23"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-73.68272297580947, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-71.38013788281542, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-69.07755278982137, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-66.77496769682732, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-64.47238260383328, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-62.16979751083923, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-59.86721241784519, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-57.564627324851145`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-55.262042231857095`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-50.65687204586901, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-48.35428695287496, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-46.051701859880914`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-43.74911676688687, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-41.44653167389282, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-39.14394658089878, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-36.841361487904734`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.7173599696494074`*^9},ExpressionUUID->"31eb7e7f-2c9c-4144-abb0-\
caaa8bdae886"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
         1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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          "]]}}, {}, {}, {{}, {}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
      AxesOrigin->{0, -30.303766533418063`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 200.007614}, {-29.898127463585265`, -4.74850513395212}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {
        Automatic, {{-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{}, {{}, {}, 
        {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
         1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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          "]]}}, {}, {}, {{}, {}}, {{}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{
        FormBox["\"t\"", TraditionalForm], 
        FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
      AxesOrigin->{0, -30.303766533418063`},
      DisplayFunction->Identity,
      Frame->{{False, False}, {False, False}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{
         Charting`ScaledTicks[{Log, Exp}], 
         Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Exp[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{{0, 200.007614}, {-29.898127463585265`, -4.74850513395212}},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->FrontEndValueCache[{Automatic, 
         Charting`ScaledTicks[{Log, Exp}]}, {
        Automatic, {{-29.933606208922594`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-20.72326583694641, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-16.11809565095832, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-6.907755278982137, 
           FormBox[
            TemplateBox[{"10", 
              RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> 
             SuperscriptBox], TraditionalForm], {0.01, 0.}, {
            AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-9.210340371976182, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-4.605170185988091, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
           FormBox[
            InterpretationBox[
             StyleBox[
              
              GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
               Baseline], "CacheGraphics" -> False], 
             Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005,
            0.}, {
            AbsoluteThickness[0.1]}}}}]], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  ImageSize->NCache[{576, 288/GoldenRatio}, {576, 177.9937887599697}],
  PlotRangePadding->{6, 5}]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.7173599696739445`*^9},ExpressionUUID->"317761aa-cff7-4ed3-8378-\
e2b755ceca58"],

Cell[BoxData[
 GraphicsBox[{{{}, {{}, {}, 
     {Hue[0.5, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs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       "]]}}, {}, {}, {{}, {}}, {{}, {}}}, {{}, {{}, {}, 
     {Hue[0.7, 1, 1], PointSize[0.0055000000000000005`], AbsoluteThickness[
      1.6], LineBox[CompressedData["
1:eJw9mnVck+33x0eKIiFso9nohtGDDXZQkJQQ6djo2dhYbJiIhR0oIKJiYyfs
YIGKij4GWMwmJCQEJPa7n+8ef/zD67wG933tOudzfd6fezNKnT89Q5ZEIhnJ
kUj//v77s+Ogfc/gJjZKqwbOWUWTir7/r8Uc/qGHrcfm/q1bOEcUOuPu8P7W
3Zw8peNnSvz/1n0cZ3/r+rvmf+tBTuAC8at3WmzsX1/YOyYZ5hz4VhSpo/S3
lnBs775RXqjAxj+T65ZLJDLwLm92diT1by0HYatDYJz5379XgBtzz3EzQ//W
4yBKlh/anPG3Hg9mk1S9y5b+rZWhqks9PH0dG7vqYueOSVTgwo19206t/1ur
wX1+ZZKC4O/91EElsSe1fzkbVxt9vS2RTIK7c+pNxZF/348mrI1q7T7uxca1
H/WmkEhk2Lm8tY5vx0bFKvcNJBIFUs5nCHpU2bipKPIhiUSF+pZBx8cjLFRe
MX+iDEkLanbpsQvk2bgtdnOYDEkb9gpLho112DjJ/cROGZIO1F7Y0zWPwcbd
lLuvZEi64Dra3tQxjY1afR+1ZUl6sOj5xqeHE9l48MWfBFmSPliqW5y7m8dG
/QvUElmSATgeXaz0ff3f2hCm2FacHdvKxpLtTp9lSTRYvs1q+enVf+9HB/1v
q+75LmDjdHPXyzJCOoRV/7FOjfp7fyMwPn3xWLsjG1/JRwzICI3g5poPDz5Z
/V2PMUTqTny5VYONsV/meMoKjcGX9KL/tfzf9ZlA7bd/kj8S/X1Xk79aVmgC
J5kJa95T/67PFGyW3/lzn7h+cmk5ygpN4ShrU0NmyN/1moHl41kTm9LZ+CkX
5eSEZnAwqb4wmFi/8bxQMzmSOdCPNETVbmBjetL7qXJCc7ihqCivvouNx0Jm
8eVIFvBTIip/uYKN31mDm+SEFtB+bDEvJIuNljYbTsuRLMGqyfqiPtHfmbrk
J3JCSzjhfm3PE3s2nh5f1ilHsgKxi3Bytx4bfw46qMsLrYAjbxW5Sua/mmQN
g1c9AsyHWWjXUuUoL7SG4ri9d7OJev6b4Eh5kg241F/5skibjZUPmhbLC20g
Z0tzRpIDG3uuZO2VJ9kCuXt68nqin87H+q/JC23hTsLUwWmE3pbsXtskT7KD
31OF7b+Jeb66dtKwvNAObgV/aWMR+hxYWKKvQLKHVQfWh6gWsNEj1c5bQWgP
zedPz3FaxcYVEbe4CiQH8ExXsXmUzMbbEJinIHQAYfGN4DG///abxIDPtvSp
4Yz/+gMMyNTdMLmW8refDPgekPZGMMTCpSNaSrLIgPn2D7u+fmJhr8HIPRmS
I0S2NBf2dLIwmyPOkwFHCA9dH7mL0Gsn7563jNARNFnfLALd2Th7TcUwCR1h
bhGHaRXLxpajW66TSE5wLrdcdXTuf/oBJ3hdA39mrf1PX0InCMpYGfx2xX/6
QyeYHJBXKV75V59OcOjlo87O+f/pl+MMBw/IHrSNY6N24iJ/icAZ5kZHxha4
sXHP6hh5icgZbi7ZcW438X41Slg1YxJnYO2hLQwi5rUQabljHBcYONMz4xrx
flQ+y7HGBC4QY8a3HHrFwgK5loFRkQtUvnv948UPFlbo77o/KnGBKys/q7kT
ejDzXrZmlOMK59d3T7IwYmMZN4EzKnCFHS+LL1EC2EjL44yMiFxB3bPO4cMs
Nh4qM7kxInGFg3VyBpU5bLx56+mGEY4bTGOT/xER++H+4eKUEYEbqEs8qhcS
/b8ytpc0InKDYd1oNdN4NjrRV1YNS9xgsRIlJC6Qjed9uCuGOe5w6atP11dL
Nj6JnxAwLHAHvSeneM+JOmhVp/ywyB22D7/JOtTCwtrDL2r+SNxB06XhrXsV
C31FV3P/cJhQvy3sxNJ9LKwRH2T9ETBhqvnzw5TrLOTICgaHRExIktnwtILY
v0Q96wdDEiZwyD6b/yHm+y1bde0QxwPsB1l3Con+xyT3cIYEHrCXNy+SSpxf
LwWvRwZFHjD09t6fjnA2Rhy5eWNQ4gG1RfMPXk5h4/ybGRsHOZ6wNvz8nfFz
CH29C/QdFHjCHoHgqjrx+sxRO5lBkSd0GJdP5jEJPRtqVA9IPGGK05nY8j8s
TIffKwY4LBhp629pNSDOi5S37gMCFsyco7NW6yQLJSvWKwyIWFDuiBaZXBau
OjTzzm8JC+7sfNb21JqFQ1XTBL85bGi8Om34+Rxi3psd2b8FbMi39SzgE++n
l0Qd6hexIU77egwS59kk3ZoH/RI23ItdljGtl4XbWMfW9nO8wObQ+LR5amxU
TtoE/QIv+N25b8pOF8IPcueO9om84IYsN8mO6L9iacTNPokXrLBz3WkiZKPp
jZGNfRxvINUFC78Rfnbkrdi3T+AN4VeoLRqubDQk5NYn8oayFRkPzp1lYZHB
yepeiTdEZazyuj+BmHfO1pW9HA7o3k1Ur6GxcA9vAbNXwAED895Ot0ueeGm5
vmKviAPJG5oyFy31xIUF2772SDiwxtSN+/qPp7RfNIC4kXcznp1hIWV+uuEQ
B0DgMHV0u9p//eMCwK3tg+IGFqZNPPNlUACg2h9huLWfhUYGhncGSwC2a4zt
fTSDjWK7wtJBEcBawf7Wwo3Eee5NDFAzgFOygbEaoceksMVJgxIAvyDycRJx
vurziBOa5gPXTp8aWUP4++mft4wHOT5wJoy/ZyubJe0/1wemZMpW1O5moaVq
afOAwAdWmkpoKr6e0nko8YGOkVmjenUeeMxh3aEBkQ+Ya3QKtmzxQJfbcWsH
mn2AYvLc5/1mT+ytf5wyIPGBaMvaUI8yT7zwwQsGaJNBfapD7rxgNmZ3njcc
4EyGKzuUq2xobLSXGI3+5k6G39fhQRDRv6rNA19+CyZD07fmhUmT2dJ5KpkM
HLnxtwrnstDz7LvS36LJYCm6tj1zzFM6X82TIepyQppMmydefypK+i2ZDMkP
1ySrnv9v3mhT4OWI4quk+56oMGecyW/OFFBaaq/YkueJ91Ytl/nNnQKvx/P9
4xw9cM3W9uZ+wRSoWbVF0eMqE32Kk6r7S6bAJ4lpYsgWJkrOPTvUL5oCUS/8
Ds/z8ZTOZ/MUeObe1SbM8sBpIVqp/ZIpUPz5Znlxo6d0Xmm+0Ow9q/zQfRY+
mjts2M/xhSfXPKcs9WFJ55frC4qqfrmrEj3Rf3vzuz6BLyw28lvm1OqBr/Wu
3Okr8YXP94dONtV44B5biyN9Il9IWbVMy/iwB0Z6HRD0NfvCnBe8iqVynqgR
qpzcJ/EFs4jFFmZbPLEheTW7j+YHrx9cvbLL1AO57dNN+jh+8GtsTkDBBKZ0
/rl+4H5hl7z6bnf8MNFd3Cvwg6UDqXlpBe5SPZT4wYAXo0JnrSfG2+sd7hX5
QW5Y3z8VoUxsvdm9trfZDwwTGvekdjDxxOPU1F6JH8wfDTpoFeWBme9fQi9t
KhxMydvfR/ZA046ptF7OVDgZ6yfY/ZqJX0avj/Zwp4LZxYQDXj+ZWKZq875H
MBWsVu3UWkfyQEYR6W5PyVSYsGd2w+9iJnadXnikRzQVAvKcK/dlM/Hc7a+C
nuap0DZNvjqizxPnPIlO7pFMBX7uCasvNe5o87GO3UPzh3057qaG793w5qxi
kx6OP1zdWTH3wlw3zFmpLtvD9Yc1UVee++90Q/cta8S/BP6QrvrgshOhz/5D
fdW/SvzhSanfRrll7nj5bObhXyJ/6M45/ipK6I6LqhtX/mr2h4dUtxk7zrmj
bPC51F8Sf3DeoWehf9sdMYHu84sWAAVOO+PG1JgomLOT9osTANabBh7m1THR
a7X8WDc3AHrVTsylanvgyNal77sFAaDRfVqoocHEzbohd7tLAuB2tYb1I7o7
BtpUH+kWBUDJ2psvrWaxUInNEHY3B0B0dc/RnbPcsDakLLlbEgD0Xeafe0+7
4vokslc3LRBmDH37LRvgiuS2VpNuTiA0uIFF8hlX/IfAyW5uIJzjPO4us2Xi
DuWn4i5BIPCKhq2p49wxXB9EXSWBYIpnS5y3uqGq3cXDXaJAMJfZx1S+6IZP
vExXdTUHgibjVssaW3dMfDSU2iUJhIQ/JVdr1jNR991sny5aEGRQ3z15TPB9
U/sHWhcnCF7uuKf39SEL94+EjXVyg6C1PGPt/SQmRqvced8pCIINYe0N9ya4
4bcD++52lgTBiDorIl+WieWnCIAUBcHsodvfvxm6YuqtlcLO5iDoEz7Kf7XS
BY3qO5I7JUFAyueR5M1dsPk916uTFgyjjQ9DXn92weKO53qdnGAoSTx07vEn
V7RbcUK2kxsM2d5yW59tccefBTqfOgTBsMx7IKje0w1PFW0WdZQEQ9g4axuz
zW4488zo4Q5RMPxq31O7MZKJFlXzV3U0B4Or7tnUzE1MvBrol9YhCYaLl6tf
ad9wwyXx13w6aCGgpv9hWG+vGzrPtqJ3cEJga19j/7WpntizsmjsJzcETMty
78+1dcXKLSoffgpCwPvZ4HWFBlfk6Hy5+7MkBE722C5OeO+MY1ZRZT9FIWB9
8pNMUogzVnnWCn82h0ClvpLfxAnOuDLYg/tTEgLb8+Y0zZvqgp6Jp71+0qaB
Ic+B72DvgoNzDPR/cqbB80ztq0VUJm4c6pH9yZ0GPycNZKTWu+PUCRmf2gXT
IKnhdnCA2BPl9d6I2kumwcxpe4fDF7jhXZvA4nbRNDBeJDTqlXHFNexbq9qb
p4GegpnslI0uqP6wMK1dMg26jB1Eo4tc8FmT7OR2WigsVV5XULPeFbe1Laa3
c0Lh7b3KlOPbXTBk+PtYGzcU3EiC92tVXFB5YtyHNkEo3LDuKOeVOuHB/fb3
2kpCwWd3Xe2QgRPGniwtaxOFwvC6VaPFvx1R66ZGXltzKKgVNQzpjzrjq0fr
uG2SUFiuIxhzfuaEu9/99mqjhUGVzQd3CwcXjPzJ12/jhIH+eEOFcR6u+DnH
W66NGwZqt3b3pm9ywdJNlZ9aBWFwoF1+2vQzzsg9aIytJWEQfGO5fFmYMxqc
3l3cKgoDv4Jjb8+7OuP7W4qrW5vDgL6pLe/ouP9qSRg0cJa2/xPnjAvYJTL9
auGQEzx+ZUWCy39+EA7TLvu/+Cp0wuOrFwn6HcKBlKuk2cV3lPoNJxyGDjUV
cn4xpP4UFg4tp13r6jsZmHw4DX5zw+FxgmFA6C4Xqf/ND4fjZhs2Rl91xN0f
3at/C8LhXXtjQ72LE1KrImUGtodD4Nuy0oytTlI/LgmHQ48cVR7HO2HImIVg
4Hw4/PS9Zrab6ST1e1E4gEFB8ZdZTlI+eBYOHRdi7IYLnFDeUBsGm4n1O+a2
Rmg4SfmjKxwcvE8HZdY4IjF9VYOScJjHL3u5PNIVb3spyQypRQBemdT/UtPx
Px6KgLWshb4bXBj4K/d97pBDBFRlfXk4tNUBCXqpGeJEwJfXIqOZHQ6olvuZ
9CcsArZYhLgV+bniqeJ6zh9uBHSXFo1vbmdI+Xp+BKiP2dYtf8uQ8reAeP3d
tsdr5Bwxtfo2aXh7BOQs3z171NgRRz4e5wyXRIBNzCfBzCJH3CcpzB0+HwFz
H7udeUXsj+7HMzXDoggQ+R+U1PY7SfPBswjgrXvGvFjqiGH/Bo7mCDB5sPJ+
fw4D2zizc0e6ImAXa2D+lgUuONdwY82IhFi/3E0v56UOOI6zgDSqNh1qKprG
POTtpfmFNh0iVGUmbQc79BL65Y46TIdT5Xaim5b2iMkpNaOc6bDmrOBFnZsj
xguCSWNh04GTE3tl4AAD+0tcOWPc6WCae/B2JYkhzVfzp4NjykPTH5YMaf4S
TIfXKn6Z0Q8YeFZkRpJsnw7Xo6bMiytzwgCxGkdSMh2ujasqLdvvgsTurpac
nw6vzLQuFe12xoxmSo1ENB2eL/QKCQtwkubDhulwhZGRrNVkj0X0Nm+SeDrs
O6fS+kjLEQ0lCmtI3dPhnPmdO/piW7xO6yb+JxKS9P8RaJXZYCS8lZDUI0Ey
PDy+d8Raml/pkTCv2j7c5KitNN8yIqE+sJrjZW6PyrxHKAORIJ8SJKrd64jH
hZclMuGRcHnBcbpctQPCkWJvWV4k3Pv0Y9tqfwbeFdzMk82OhAe33bs69Z3/
e94RCdVfkz+eUXTEIdwmkS2MhH7PUza3lzvgrk+E4Esj4f5KjudOPwek4u48
ucpI2PU0lengRuhDnItyxKpLxy/uVXCyw2CZmRK5hkjwe92zyI3o33ejSG95
cSTMalnmsinRGmeS5ufJd0dCuXFi41MfK5Q3ikN50gyYuZr6ZPIDSyz2mSKR
V58B7ywlL/fl2UifJ9BnwP2Y7kD6N2vp8wPGDHjddkRkP5eB0SnOqAAzwL8+
hBNu74y/8gwkCuEzQHd8eXvkYSfcUjbOW5E3A2btMG4/tdoe1fJM8hSzZ4Cv
4deaa6G2ePKICioKZ4Dck5+nNm+1Qd87A2OKhTNAtD7o0ZJUG6wt1Zw8rnQG
sO+7Z06zsUNi2oTjKmdAwdfDJjUatjjy6YdoHBL381+qqllkjftkX4yNa5gB
Bz/OMjn/1QJ1P3X4KIlnwJQw2oapn83xskyjUKl7Briv+HyMV2KOYcZ3REqk
KCA1O3B7DGywbfKZMSX1KLg7UWF6GFjiHKM6n/H0KOA7BFuu22KN4yZfFI5n
RMGsWWcmqFnaYlnqIdF4iIKVhj6rm6g2yF67YWx8eBS09qtF3Ku2QlFKmc8E
XhQcOnLGdtJkK4xfs0U4ITsKKuXnrVhgboX9ZUtFE4RRwJOorS+6Zonb7/LG
JhRGwY+BQfImMyvUKFvlo1waBcveLX72uc4Gz97JFCpXRsF+IZ0p3mmB/l/C
RcoYBaE/W0+tXGCG/z6uUG6IgunWOyf9Fphixudon4niKPBWCmUdyzdFkpyP
cGJ3FPS3tDfYjdriQRMb0URSNEzaeqbmvIE5uvpSxiaqR8Mli/qCDx/M8bqx
o48KPRp0Du7z1lhigdOn6AlVGNHQdjeo3c/eAjvSFEQqEA0fTG7teq1rgfnr
ukZVwqPhyy09waOTFqicpuyjyosGrRytkegeCyTSh0A1Oxpm7K54wn5rjlDe
XK0qjIb9CiNcRw1zvLtmWEatMBq+t1W3+a+ww6Sj30CtNBrsO+aXd981xcG7
zwRqldEwWHp+/Nnfxrjr641qNYyG0xr9M9mqxki9+0pGvSEaVuzd9OnWMmOs
/CICdXE0TLXNKqhPsMFg+VMC9e5o+HHgdGbMSlP8brq7Wp0UA88vngn1dzRF
vlylzCT1GOjS2qV5drUpypkehEn0GCDfX6y644kpFvuuE0xixMC0rh909Wdm
yMyYVz0JYqB+U7np6eMWeGtKgYxGeAwcEH/ddcDeEqPTF4MGLwZmskq2ZwvM
8Ne6ZIFGdgz0VyzN1ZplgpuPBVRrCGNgUe0hv/M77VF1XbqMZmEMyA8Xtm7V
M8aT5aGgWRoDRc9/bIqNoeOU+0yBZmUMnJe9SJr/0BA/fjOu1sQY+P32/ITH
bDqmEMcVuSEGtrzhRAfNNcWRr5ZAFscA55EyZwHbBPcqaArI3TFwtK74+bM/
RuhoPlpFJsWC3jNPJ2NHY7wsryNDUY8F5zC2ocuoMYaayQGFHgtYcGbuilpT
bPXryKUwYqFqZdrPLX/McY7p+DsUiIX1+0f2X4wxx3F+vSRqeCyU/2neZvbC
GI9kfOBQebHwZpeTL7WWjuwNtbnU7Fj407NkxxR9MxSlf6mhCmOBP//ZjXF0
Osatf0LSKoyFS/ZL3Ids9LDv2DWOVmks/GOqvcR9jzZuf3AkV6syFg6SXx0Q
XtJFjWNVNVoYC0tvH9zbZELHM/dPkLQbYol5emLUOJmO/t93cLTFscBm6pFt
WQb4WXFVrnZ3LMiXGqdufG6A6d/21WiT4kCmaChi/IAh/msPOupxoLph9ufw
PzQ8aD6Ho0OPgwymd9A1bzq6+Efn6jDiYGBlWtryyzS8ZrawRgfi4HqhWeY/
awxw+tREkm54HES2bfb8VWeAHZlTObq8OPjyzi266aMubtzIyNXNjgOmQfen
DSa6OCEzpEZXSNS/bBfWzNPBYxvcSHqFcTC+oLK48og2ck7QOXqlcfAxeNel
nfr6+LZ2Qq5eZRzEOxX/2haij0nHzWv0MA6q2jfe/HnDEAcfqJP0G+Lgu6N4
LKHYEHf++OOtL46DjqYFvJ3naUh5QF2j3x0HyhefatsuN8DK76QafVI8rNh/
VnmRHR2DxrVL9NXjoeK9XueLo4b4zeKVtwE9HoxTX675pWaAfEXihGfEw3Nd
9+6uYAOUs3iHBhAPXbME67fW6uFh//sSg3DienJ78odQB5n8896GvHiY+rjm
ZYCjDt6a+jjPMDseJl85+Erruw5GZV1BQ2E8LDGqckkK1cPujSUSw8J4WLjp
5uDpJn3cXLHJm1YaD22d7j5Pduuj6sZjebTKeOhYwlgfeoWGFSe2Iw3j4f3s
zXKyDwxwSt1yCa0hHs6SN+1x+GiAH1vSvOnieAhrjRM23DREXq0gj94dDxnl
Voc7Xxni8I+ZSCclwC3rtNA+DRruVZohoasnwJCe6A75JA0ZVt7eRvQEIAc/
t5mM+nhpXHyeESMBvBrKp5KDDDDU0heNIAHujXaq6ZzVwdYAe4lReAJ01M7O
O12ljWtnansb8xIgR+3eabcX2qgY4JJnnJ0Anad9HatidPEI3xCNhQkwW3e8
cthHfWRtUpIYFybAetXH5y5908PXJ3u8TEoTYO6Pu5+iKw0xLl81z6QyAfbF
Dy00Bzr2VQyKTDABMu7tNv7yzhC3Pfw8ZtKQADvk8YhaqCFOqhjzMRUnwON5
j/ovvzHAM3UtQtPuBIgVnfe6Y26A/q0vRKakRAj070oQE/PwaXzVmKl6IrwN
tXfu/EDoo6XRx4yeCMd+0TxnqumhROmu0IyRCH1GX664l+jgASuC2CARrvzx
DXPx1EGXoH1jZuGJkHjOSyn7kBZes7zkY85LBLX5le8/B2nh9MDDQvPsRBg3
I27J+WZ9/Dlzo8hcmAhmXRt3+a0l9FGwYMy8MBG85k5afGarPk6YudXHojQR
pq2UrbuTrI/lm5YJLSoT4cPKB6WrVAyQcypFZIGJ4FFe5Tzxlh6+fRQ8ZtGQ
COlWPynDtgaYdDLLx1KcCOdUEg/QtfVw4GGE0LI7EQ4dOrRe394Ad7axRJak
JNB+tib7z3NdtFM2H7NUT4Kxbw3rM2bp4vlWHx8rehJUJStuPvCPFgZNsBVa
MZLgvdHIF0+WFn6zpoqsIAl265aZh7Gp+C/+WoUnQWtrL6nsgBbKWuv7WPOS
4MfCbKCc1MfDQYpC6+wkOJ4470vhZUIfs7urrYVJkPC4NL+hXg9vBk6UtSlM
gluif8IKVPUxatZvsClNgmOJRl8lvwh9FIgFNpVJkLjix5tJAfpYcPpRtQ0m
Qd+lIp9giiGqFHyXsW1IgsIfQoflNAOsONUAtuIk8L/QpLhhQAenPL4psO1O
gmWRh30WvtXFD+3l1bakZGiavY96OEwH/8VZO/VkcAkYzVozSQuH206BHT0Z
Ft7ZqaQ+TME9ynsEdoxkyF16+yMsoiDDVlBtB8kwo0pOdw1PCy9NKJKxD0+G
o12XaH/G62KozXqw5yXDBPPaqooMbWwJni+wz06GmADe/SnvdXHtnLhqe2Ey
3LC6cKl9kQ4qBi+RcShMhqHI4fX54bpYOpsLDqXJkFfd+U67XxdZWwIFDpXJ
MO/U5w/BPoQ+zjgTlJ0Mqn7H9qqSdTFuc5gMoyEZsmfLp+QWaWPvaQ9giJMh
+VfAa+FmHdxWbyJgdCfDQcpq4dwXVLTqUKlmkLhQP8dr99MnFDz92ErGUZ0L
3saDgW0+ZJz6UxMc6VxwOj9vz/F/NPHTxLFcRwYXsi7AgcjpVFz57wd+wIW3
PIqyW4U2jinLyziFcyE6Zk50ezEVD9h2cpx4XNi3y6SL8Y2KLtMac52yuZD5
/Wv1x8lUvGrTV+Mk5IKdr9/mHUe1MCLkI8m5kAudO0arBI7a+HNOHce5lAtt
ksLw8nNU3LD1Yq5zJRf6m501z/hQcPycpzVE6ofEsPqa2zJkLN9yneTSwAWG
r/JV6wAycs6WcVzEXHhsWRRhTLze9GRLrks3FwTz83cFBpPRPvolT5fEg70t
4X1NqRRcmRko1FXiwcy2zCkHLlDx4dLqEl11HpjNCxkqHKeF1I3OIl1tHsw5
WZ+/ejsZY5bWiHXpPAhkN7yfv4Is9S9LHhyMqDn1BSnYs/c0TY/Bg8PNEjE8
0pL6GZMHRePjn3bkaGHe3nM8PeDB8dYMo0YbLXx63ESoF8CDqyfOzh5dT0X9
a/tL9MJ5cGOJbNPIeArOrFUR6cXyIGe1uejlcTKeulok1uPxoOb6u6Xe98hS
/+PzYB/lgmFXAgX93qyn6WfzQFFomNvWQ5b6YQ4PxJNSFgUBGV++zufpC3lw
ccbN2QNnyWj0Y1Sgn8+DWU85zIkdFJz37weshTxY/aPDei1HS+qX+3nwdV6T
WG2YiqO/l4j1S3mw+Ziajm8fReqfFTzQanbr/sak4n4tHs2gkgfTIOjO4ssU
bFLsBIPrPEgOSnm27hIFLbTSeAZI3G8G5VRdExUXWzQKDOp4cHndraNQoYU1
7tNKDBp4hP5G9PPTKVK/beSBT96fwP2BZAx3DxcbiHnQZjsu+4omWeq/LTyY
G4SvhhLI2B7jSTPs5sGOTsaFmxMoaOtfB4aDRP/0jnjw11JweYwXz5CUAtcL
XpIlXylYm3VRYKiUAsd+fDqaEUpFco5FiaF6CtxUWu4ySOzH//xaOwVq93IV
YoaoeHSZtdiQngKVHmlXJW+oUv+2TIHXvlnlXY8o6LWfTKMxUuD+/YfZJl7E
+bixDGjMFDhcv8dVGKKF9fuIDYIUqKrvuHS1jYK6FVsEtADi+i+zje/vJ2PW
dZkSWngKLLy1Y7naUU2p38emwLYmtlHOmAb+viYvpvFSIKtC65X+K02p//NT
oPzyo8B6QyquuzbOiJ6dAh6h1hNbtlPxRe0qoOekgMabVu21QEVa4y8uXZgC
deASvGcJBee0ZAro+SlACXS4tmETFc+96SulF6ZAcGjFi0YPLSkv7E8B3wsx
uLCbggGDH5vppSlgsYOPjxZTpPxQkQIuHmt/rnhIwTcDn+hGlSlQJHdmDvsl
Bc2UYsDoegow5ZS8XphQcKF2PdcIU2A594vO4o1kFFn6CIzqUgCXjYReIfQl
o/2s1KghBRwk8mG755GlvNGYApPuqc1WO0TGIuaNZiNxCog3pdfNdaRK+aMl
BXZh0ciWdxS0Zt6mG3engCr56lKnxxRcFuAIxoMpEH59wsXtaVS8H3uca0xK
haNzE7x86VqoMVNPYKyUCo/Vwup9FlAxMvZkqbF6Kmhf1O3wUKJKeUU7FX4n
6QatjKJgZ86uZmN6KvRMC55+uJki5RfLVNAfOOYgIOZ9dc5eugkjFaISBjY/
8qbgo3xlMGGmgmyjkaxvARm1Dwi5JpAKwS/drRs/aGLGyf5ck4BUuLlfvT3a
hYzH968tNQlPhfbW7RNLbShS3olNhazlij3JZyjoc2NuswkvFXSen3om3kXB
f79eYMpPhX67jJ5x9lRsuJ5NN81OhV+6iw7n76OiwcNvHNOcVAg4XUN+t5eK
s5riuabCVHiw7nZl3z9UKR/lp8LP2efHJLspONSYVGpamAoXwzrvz02iSHlp
fyqIazgPaylU3D3k32xamgovB5JmLz9EwVctr0hmFanw1nT5G7/JFDQZCqKb
VabC3U0Dnyf+IGP2eOSYXU+FvM7tCjOoZKzSceWaIXG9hdaHNOLIUr6qS4WG
Ly2LumIpGKLDLDVrSIWglNkrpgVTpLzVmAqvv3yIMiLm+4eHcbOZOBVMYrcF
Wz6koqVVJcm8JRXecWZMIMlTcYmHGd28OxUE/Oz20plUvBt4kGM+mApnDa6O
mbdTUD1ejWtOSoOCkVMrIr9TpHymlAYWFoeXnZChYkmcRqm5ehqkvrC2XqBI
lfKadhrcf/3wwFN9KnquGPloTk8D5hyVlb2zCP+YWUCysEyD77yY7XWzyPiv
HC0YaRCn6K3bTfgDtWAxx4KZBreXmVsnSQj/WC6bYgFpcIsVORpTQJHyXUAa
bJEsUzj5D+EfB36WWISnQXlG7ihFgSrlvdg0UOiIOR6ZTEXhgS6xBS8NSlZZ
nTA5RMWnJ9NJlvw0WDGVfefmDyrq3WyiWWanweNl615ofKAg/1EoxzInDZp0
PbycTKl46sZ7nqUwDVZPvK2yQY0q5cP8NPAo/iAJfU34x9sHJZaFaTDLXiHt
Rg5Fyov706C4judQUU/Gf5oeii1L0yBKZV5eqi7hH23eJKuKNPgCES1ufZo4
788lmlVlGmxuU08bPUjGWxOsOFbX04D2pCKgcj0FR4eu8qwwDcJmWibuWUGV
8mVdGryf+W7FjXIq7tM9UmLVkAYGxdcjuyooUt5sTCP4756L83kKmuuWi63E
acB7HGCbSPRzkbUOybolDSadWO/kSfh1jec2mnV3Gri/GQ73/0RB1WA5jvVg
GpzfnKR4z4uC4Z47eNakdJDjiLddriBL+VQpHXptWftXE+tti19ZYq2eDo2z
X1T9E0pG26DxNdba6ZDSseZaRY0mLo/PFVvT04HBWhbsfUITH8zqlVhbpoOg
lL0/Y1gTySv5NBtGOkjUfRySSylSnmWmg4Pvw3Nrz1OxbMVsng2kQ/whKEx/
RpXybUA6nBAeemw4jopeRVElNuHp0MDkXo3YRMHcgi9oE5sO/U37NqVuJmP9
wVixDS8d1NR93TZ1kFHn9BOJDT8dFreJgsz+kDHz1mSabXY6nBEEnb/wiyzl
4Zx0+D0zPseHOH/6b/rxbIXp4PrHYKPefLKUj/PTQf5J6MDWY2QsfOdQYluY
Dkda98XnyFPw+aMqtN2fDtY/7yoqENejvXMS25amQ6Z16vp4RcI/2k9IbCvS
YdXvjasWNpPxxrA+za4yHR7wdWaeJPjkfzx9PR3I/dob5veTMWCYxrPDdHj4
1ow2ceA/vq5Lh+0uQflTJmrhF70JJXYN6dD6xXtPj6EWmirvR7vGdKB//qfu
2TwqLtBTEduJ06EtQXb0Bp2CIps1EruWdHATkNZcIfxzInvA0L47HYaOtFi+
JPT3Px4fTIdhRuLqwumEf7D+cO1JGUBv+84sSyJL+VwpA+pvZywrKiejNWu0
1F49A77M6zVqcyH8I3gh2mtngO7BPvUrgVS8l/Cj2Z6eATa7OcvX6VFRY06i
xN4yA1b9sgtz8CH8I6GN7sDIgJbNg5QKQm//43lmBihY6DneJvJE58qXXAfI
AOrhzGvxk6hSvg/IgIHjDOWXBA+sWvmm1CE8A3ySQGmwkfCPzSHoEJsBxafL
MciJglqHapodeBlAOpt+Z6kbBdPPuEkc+MT6C7bfN3Gk4PGie3RGdgZYD965
bqFAkeaBnAy4OPvWiSBnMvrcPsdlCDMg3qwx7OtSsjQf5GeAlWLgYyNtCj67
daGUUZgB3psjfgdlUtCg3hwZ+zOg4JpK14pICs56X9TMKM2AOsOMHxmyVLz2
U13CqMiAoXz+Xp1CKg69K6Y7VhL7MW7Z8WB1qjRPXM+AOwe3GDvtpOCukXyu
I2bA3QvHxdNVqNJ8UZcBHcMXU1cR+2M8srnUsSEDmou/p1OPUXD+RBl0bMyA
GVeXtewj5rtKf2mzozgDNLctrbReSJbmj5YMiBlv80jiS8YQ/eV0p+4McFTe
o5WQTJbmkcEMcN0dP9crh4zf2WlcJ1Im+I0l6kvukNHS9pfQSSkTkr9GZ91c
RcEl7MxSJ/VMmH98xdFL96l4J+SdyEk7ExIWRGXmEXlEPSm82YmeCWU/8/eC
FkWaXywzYcA9373wBhmLEyPpzoxM0Fk+PzEJKNI8w8yEJ/Evv58l/MljtRfX
GTLhskJlsU48BVfMeSx0DsiEwd6jI9ZPCf9YBaXO4Zng2prWw3EgI2XrFZFz
bCbU9sZ/V9mviamHrZudeZmwJOfirZXpmtL8w8+ELTO9hMd3a+KvQ3Z0l+xM
CMsKX7bokqY0D+Vkwo1xMs0GD8i4pUqL6yLMBBeWRjdqUPHJmWNCl/xM2Pz8
qFHEZsI/qnRLXQozoW3+9z2T7hP+8WS7yGV/JkS3no+sd6XglQ/yzS6lmfCo
b0Xh23NkHKjfSXKtyISTe8NOL5GloO+HcXTXykxYhS9erkym4I6OVRzX68T1
pgWMW/6B8I/3E1JcMROSRu8rPPlNRnqHQOhalwkTB24+j99ExrmjfSWuDZlw
W2n6O5EK4R8qs0SujZlg3dl4qYqY35GRAbGrOBM0GUYfr/HIGKQyl+TWkgn6
9dFF+QQf7jP4THPrzoRp1TLPi4h889UuhuM2mAkNn2bLfwwk/MPgG8+NlAVN
j6efe1JO+IddvNBNKQvkJkbf6SL4B72elbipZ8HStLYSVQYVVUN9RW7aWbDn
d0ijKIuKYV4vxG70LABWVbVtNhUPTfMnuVtmwbzb49rGv6RiW9JtmjsjCxTL
Jn4w2E1F93mOHHdmFkgExZ1BaUT+SBLx3CELQqsNqmp1KPhgrovQPSALluUE
fRDGklEz92SJe3gWXL81+THnoiambDMUucdmwZvCoymLr2li2eozYndeFugF
ZJyx2EbGrq1GJCY/CzgzRhp7+UT+KN5LY2ZnwbrLs7Q2E/0rOKfMYeZkQciC
4znvb1Hx8eEDPKYwC65oWHgeIfKIzjlVITM/C74lMS3NXlEws3ptCbMwC4QV
67dbEP566elgNXN/FrwO3FnOvUDB/qoNYmZpFvRrLhrR+0HByU+HJcyKLJia
fPFgBFJx+8dsmkdlFnh71JVlEXnj+ZMx8LieBePWHNu0aikFDT8u4nlgFnTe
f/RVi5iXOZ0tAo+6LPByHtA6cJnwj7GkEo+GLChxs/SkfCTjn4529GjMAtu2
/d9XTCTyxxhP7CHOgmvlc05anib8Q/W1xKMlC7RtvdLNnlDws2EwzbM7Cy7/
9H7mQejNVLUJPAezYHXpxPfr9bRwgWEoz5PEB0XK5fe6RJ6ttr8r8FTiw/i9
I8eEBA9N5DBLPNX5MM1aae/uMgpOs3+Antp8UPqcP1v/FBUPerPEnnQ+QPPu
Kn+Cv1pCKyWelnxwjEsukyP2g6BbGovBh0/cs3NNWIR/hF4CFpMP7U4vpr9F
Mt5LtuSxgA+UHcxdZnvJOGn+YQErgA/Xr4sniWrJyBVolLDC+aBccTJ7hNiv
0nmlyIrlw8NVbbmWylTsyKWIWTw+vB0/POXcNsI/thdIWHw+fJt3TEv1BhXz
iTjKzubD8dN6dn7BVHy4bSuwc/hQW1e03ZbIS1olsjy2kA+uIVdytI2omH5+
mYCdzwf5B7bXawn+OlascIRdyIfY5c/MqXQq9p5bgez9fHh5NTf6X78BUVcz
u5QPopzZwTn7KLj1WbqEXcEH2ftVoc8J3nlW3UP3quTDMaX4M/cJ/9F/RvT2
Oh+mGrOWOpeRcda/X/hBPth98a0w2UPGa10RAq86PlSy7wDXk4JEvCz1auDD
1Zr0ZrdWCk7tmoFejXxQsVpbr+JOxV2Sh81eYj40HspYtn4+Ff/9uNyrhQ/x
G5+/XV5BRWNJPd27mw8+67vzRq4S/qE2GbwHif0MHHm9l+CN27RrXG/STDic
+GHitgUU/D/hx/aB
       "]]}}, {}, {}, {{}, {}}, {{}, {}}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"Variance: \[Chi]\"", TraditionalForm]},
  AxesOrigin->{0, -30.303766533418063`},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  ImageSize->NCache[{576, 288/GoldenRatio}, {576, 177.9937887599697}],
  Method->{"CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Exp[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->All,
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-29.933606208922594`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "13"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "9"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "5"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}], Selectable -> False], TraditionalForm], {0.005, 
       0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Print",
 CellChangeTimes->{3.7173593993015137`*^9, 
  3.717359969738477*^9},ExpressionUUID->"808291b2-00f0-48a7-97ea-\
21b14c75b62e"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
WindowSize->{1536, 781},
WindowMargins->{{-8, Automatic}, {Automatic, -8}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.1 for Microsoft Windows (64-bit) (April 18, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 187, 3, 101, "Title", "ExpressionUUID" -> \
"d3458181-ffde-4bca-9afc-bcb1fca4a8cd"],
Cell[757, 27, 886, 15, 125, "Text", "ExpressionUUID" -> \
"0a993e0d-4bab-4e22-bbaa-a9d5ee83aa04"],
Cell[1646, 44, 190, 3, 30, "Text", "ExpressionUUID" -> \
"8b341ede-c8e3-4a5a-8142-dd655f018ad4"],
Cell[1839, 49, 206, 4, 30, "Input", "ExpressionUUID" -> \
"cc4a1111-769e-4973-9c10-1e5887346c35"],
Cell[CellGroupData[{
Cell[2070, 57, 221, 5, 70, "Section", "ExpressionUUID" -> \
"b65873f5-afb3-47e6-bb19-9587c07fcbcf"],
Cell[2294, 64, 189, 3, 30, "Text", "ExpressionUUID" -> \
"93d5b6a3-57f2-4d80-ad57-a835ba8230b4"],
Cell[2486, 69, 626, 16, 30, "Input", "ExpressionUUID" -> \
"d0eac3ce-ae82-43df-9880-f3dd55fa6dbf"],
Cell[3115, 87, 140, 2, 30, "Text", "ExpressionUUID" -> \
"6c8cad30-12a1-451e-b8f8-6ee97df66600"],
Cell[3258, 91, 168, 4, 30, "Input", "ExpressionUUID" -> \
"52f9b709-07e1-4688-af97-ad69f82e5a49"],
Cell[3429, 97, 383, 8, 144, "Text", "ExpressionUUID" -> \
"d7d7b5f0-54aa-46eb-a7f5-82f8138379b4"],
Cell[3815, 107, 1551, 37, 88, "Input", "ExpressionUUID" -> \
"40608368-8548-4d1b-b9d8-69ed1384b765"]
}, Closed]],
Cell[CellGroupData[{
Cell[5403, 149, 232, 4, 56, "Section", "ExpressionUUID" -> \
"fce04f5f-a9be-4d64-949c-c0057b17c525"],
Cell[CellGroupData[{
Cell[5660, 157, 12291, 298, 866, "Input", "ExpressionUUID" -> \
"cb2c6eeb-804f-4352-a4d3-f0a59dc5790e"],
Cell[CellGroupData[{
Cell[17976, 459, 1296, 22, 22, "Print", "ExpressionUUID" -> \
"de782feb-c803-42ee-8c32-4fca7bde16b1"],
Cell[19275, 483, 1075, 16, 22, "Print", "ExpressionUUID" -> \
"bf706d1d-3f36-4584-b30b-f18dd5868041"],
Cell[20353, 501, 1078, 16, 22, "Print", "ExpressionUUID" -> \
"4e606527-b7f2-4136-a6c2-4d9624be2d8a"],
Cell[21434, 519, 1078, 16, 22, "Print", "ExpressionUUID" -> \
"6dcb8a3d-d725-4006-8c37-4aca03b7eb66"],
Cell[22515, 537, 23645, 452, 238, "Print", "ExpressionUUID" -> \
"856555c1-688d-487b-b16b-3679324aa431"],
Cell[46163, 991, 29020, 596, 238, "Print", "ExpressionUUID" -> \
"21112e9a-25b7-4c68-a255-442b070ff0bd"],
Cell[75186, 1589, 45566, 872, 228, "Print", "ExpressionUUID" -> \
"1c2484eb-f811-4542-8f89-6c11b49997d2"],
Cell[120755, 2463, 22369, 433, 243, "Print", "ExpressionUUID" -> \
"74eab9f2-9919-4d1e-bb01-00fe3f5fb897"],
Cell[143127, 2898, 22636, 426, 243, "Print", "ExpressionUUID" -> \
"89174521-26c5-4af6-a225-d3e46bc8a3ef"],
Cell[165766, 3326, 38469, 698, 236, "Print", "ExpressionUUID" -> \
"e799a63c-8357-4501-94b5-8ecad57c5708"],
Cell[204238, 4026, 76954, 1390, 228, "Print", "ExpressionUUID" -> \
"c9348508-be46-4f3e-a55b-57ebfa157d4a"],
Cell[281195, 5418, 1299, 22, 22, "Print", "ExpressionUUID" -> \
"a0444ee4-1760-4f7f-953d-0f716c5dd40f"],
Cell[282497, 5442, 1075, 16, 22, "Print", "ExpressionUUID" -> \
"8a2b5d10-0dd4-4b18-aee1-83b4e8d313b8"],
Cell[283575, 5460, 1076, 16, 22, "Print", "ExpressionUUID" -> \
"4742afd5-52ab-4d59-b7da-2977689f780f"],
Cell[284654, 5478, 1076, 16, 22, "Print", "ExpressionUUID" -> \
"fb70b2a5-bd32-44c6-8192-8804a57b836c"],
Cell[285733, 5496, 23648, 452, 238, "Print", "ExpressionUUID" -> \
"a59a02a5-cb3b-4e97-b863-35c264c33ff2"],
Cell[309384, 5950, 29018, 596, 238, "Print", "ExpressionUUID" -> \
"2aa9cb9e-6ed7-4a4d-b3a5-37007160401c"],
Cell[338405, 6548, 45567, 872, 228, "Print", "ExpressionUUID" -> \
"479f4c36-e420-4a4e-b634-c0396ce2578b"],
Cell[383975, 7422, 22370, 433, 243, "Print", "ExpressionUUID" -> \
"db79a653-5c9a-470d-97b4-6a430ac07117"],
Cell[406348, 7857, 22636, 426, 243, "Print", "ExpressionUUID" -> \
"65c4da96-dac3-4274-a275-c6c9c1d6f692"],
Cell[428987, 8285, 38472, 698, 236, "Print", "ExpressionUUID" -> \
"99efa6da-7bf2-4281-b863-e4841db1b00b"],
Cell[467462, 8985, 76956, 1390, 228, "Print", "ExpressionUUID" -> \
"6d2e2938-b812-4351-b4b6-87ae8ef9f985"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[544479, 10382, 203, 3, 56, "Section", "ExpressionUUID" -> \
"6332227a-0c48-4249-9341-1f872e65137e"],
Cell[544685, 10387, 108, 0, 30, "Text", "ExpressionUUID" -> \
"9040c3d7-f6d4-4473-8998-66b83bff8ed1"],
Cell[CellGroupData[{
Cell[544818, 10391, 389, 11, 30, "Input", "ExpressionUUID" -> \
"a6a593c3-bfb2-4e35-9359-9f6ba3b71ea1"],
Cell[545210, 10404, 656, 11, 30, "Output", "ExpressionUUID" -> \
"57fecd5c-0145-4a1e-9081-a6e189ed8fe5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[545903, 10420, 4432, 112, 202, "Input", "ExpressionUUID" -> \
"ad627ec0-b443-4440-9575-1db41fa540ed"],
Cell[CellGroupData[{
Cell[550360, 10536, 39087, 707, 235, "Print", "ExpressionUUID" -> \
"4fed2145-6e8d-468d-a47d-58bc80ba5f40"],
Cell[589450, 11245, 37199, 688, 240, "Print", "ExpressionUUID" -> \
"76305f36-f310-45f1-8bc4-694e8cef5bc3"],
Cell[626652, 11935, 45258, 875, 235, "Print", "ExpressionUUID" -> \
"0e3ef7e2-e5c2-4d06-a468-30e7ca094a70"],
Cell[671913, 12812, 39757, 731, 240, "Print", "ExpressionUUID" -> \
"c2280691-1039-436b-96a6-c9618996badc"],
Cell[711673, 13545, 77126, 1391, 228, "Print", "ExpressionUUID" -> \
"c3ebb88d-5f2b-43f8-b46d-7cae24289415"],
Cell[788802, 14938, 69132, 1204, 236, "Print", "ExpressionUUID" -> \
"e19543aa-fc0e-4a42-87cd-f9be4a5cb1db"],
Cell[857937, 16144, 140247, 2443, 228, "Print", "ExpressionUUID" -> \
"5d587c57-584a-446c-ae37-0d629ff4f759"]
}, Open  ]]
}, Open  ]],
Cell[998211, 18591, 112, 0, 30, "Text", "ExpressionUUID" -> \
"6eab1306-dc54-4e59-aa26-4f88be59fb69"],
Cell[CellGroupData[{
Cell[998348, 18595, 3023, 82, 222, "Input", "ExpressionUUID" -> \
"d69ae831-f194-4cd1-ab9b-ffab9dd882f2"],
Cell[CellGroupData[{
Cell[1001396, 18681, 513, 12, 22, "Print", "ExpressionUUID" -> \
"be6c8d43-0621-41e1-8004-9a4f9765141a"],
Cell[1001912, 18695, 511, 12, 22, "Print", "ExpressionUUID" -> \
"8b8a50bb-4585-4377-a2c1-5432cf47f5f1"],
Cell[1002426, 18709, 59013, 1167, 186, "Print", "ExpressionUUID" -> \
"dc5560b2-6336-451e-992f-86313d9c5734"],
Cell[1061442, 19878, 44244, 848, 186, "Print", "ExpressionUUID" -> \
"31eb7e7f-2c9c-4144-abb0-caaa8bdae886"],
Cell[1105689, 20728, 44941, 831, 186, "Print", "ExpressionUUID" -> \
"317761aa-cff7-4ed3-8378-e2b755ceca58"],
Cell[1150633, 21561, 37827, 678, 186, "Print", "ExpressionUUID" -> \
"808291b2-00f0-48a7-97ea-21b14c75b62e"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

